Class: Increase::Models::ACHPrenotification::NotificationsOfChange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_prenotification.rb,
sig/increase/models/ach_prenotification.rbs

Defined Under Namespace

Modules: ChangeCode, CorrectedAccountFunding

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(change_code:, corrected_account_funding:, corrected_account_number:, corrected_individual_id:, corrected_routing_number:, created_at:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::ACHPrenotification::NotificationsOfChange for more details.

Parameters:



# File 'lib/increase/models/ach_prenotification.rb', line 245

Instance Attribute Details

#change_codeSymbol, Increase::Models::ACHPrenotification::NotificationsOfChange::ChangeCode

The required type of change that is being signaled by the receiving financial institution.

Parameters:

  • value (Increase::Models::ACHPrenotification::NotificationsOfChange::change_code)

Returns:



209
# File 'lib/increase/models/ach_prenotification.rb', line 209

required :change_code, enum: -> { Increase::ACHPrenotification::NotificationsOfChange::ChangeCode }

#corrected_account_fundingSymbol, ...

The corrected account funding type that should be used in future ACHs to this account. This is derived from the corrected transaction code.

Parameters:

  • value (Increase::Models::ACHPrenotification::NotificationsOfChange::corrected_account_funding, nil)

Returns:



216
217
218
# File 'lib/increase/models/ach_prenotification.rb', line 216

required :corrected_account_funding,
enum: -> { Increase::ACHPrenotification::NotificationsOfChange::CorrectedAccountFunding },
nil?: true

#corrected_account_numberString?

The corrected account number that should be used in future ACHs to this account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


224
# File 'lib/increase/models/ach_prenotification.rb', line 224

required :corrected_account_number, String, nil?: true

#corrected_individual_idString?

The corrected individual identifier that should be used in future ACHs.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


230
# File 'lib/increase/models/ach_prenotification.rb', line 230

required :corrected_individual_id, String, nil?: true

#corrected_routing_numberString?

The corrected routing number that should be used in future ACHs to this account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


236
# File 'lib/increase/models/ach_prenotification.rb', line 236

required :corrected_routing_number, String, nil?: true

#created_atTime

The ISO 8601 date and time at which the notification occurred.

Parameters:

  • value (Time)

Returns:

  • (Time)


243
# File 'lib/increase/models/ach_prenotification.rb', line 243

required :created_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/ach_prenotification.rb', line 331

Instance Method Details

#to_hash{

Returns:

  • ({)


160
# File 'sig/increase/models/ach_prenotification.rbs', line 160

def to_hash: -> {