Class: Increase::Models::ACHPrenotificationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/ach_prenotification_create_params.rb,
sig/increase/models/ach_prenotification_create_params.rbs

Overview

See Also:

  • Increase::Resources::ACHPrenotifications#create

Defined Under Namespace

Modules: CreditDebitIndicator, StandardEntryClassCode

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, account_number:, routing_number:, addendum: nil, company_descriptive_date: nil, company_discretionary_data: nil, company_entry_description: nil, company_name: nil, credit_debit_indicator: nil, effective_date: nil, individual_id: nil, individual_name: nil, standard_entry_class_code: nil, request_options: {}) ⇒ Object



# File 'lib/increase/models/ach_prenotification_create_params.rb', line 99


Instance Attribute Details

#account_idString

The Increase identifier for the account that will send the ACH Prenotification.



14
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 14

required :account_id, String

#account_numberString

The account number for the destination account.



20
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 20

required :account_number, String

#addendumString?

Additional information that will be sent to the recipient.



33
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 33

optional :addendum, String

#company_descriptive_dateString?

The description of the date of the ACH Prenotification.



39
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 39

optional :company_descriptive_date, String

#company_discretionary_dataString?

The data you choose to associate with the ACH Prenotification.



45
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 45

optional :company_discretionary_data, String

#company_entry_descriptionString?

The description you wish to be shown to the recipient.



51
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 51

optional :company_entry_description, String

#company_nameString?

The name by which the recipient knows you.



57
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 57

optional :company_name, String

#credit_debit_indicatorSymbol, ...

Whether the Prenotification is for a future debit or credit.

Defaults to debit.



65
66
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 65

optional :credit_debit_indicator,
enum: -> { Increase::ACHPrenotificationCreateParams::CreditDebitIndicator }

#effective_dateDate?

The ACH Prenotification effective date in ISO 8601 format.



73
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 73

optional :effective_date, Date

#individual_idString?

Your identifier for the recipient.



79
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 79

optional :individual_id, String

#individual_nameString?

The name of the recipient. This value is informational and not verified by the recipient's bank.



86
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 86

optional :individual_name, String

#routing_numberString

The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.



27
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 27

required :routing_number, String

#standard_entry_class_codeSymbol, ...

The Standard Entry Class (SEC) code to use for the ACH Prenotification.

Defaults to corporate_credit_or_debit.



96
97
# File 'lib/increase/models/ach_prenotification_create_params.rb', line 96

optional :standard_entry_class_code,
enum: -> { Increase::ACHPrenotificationCreateParams::StandardEntryClassCode }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/ach_prenotification_create_params.rb', line 154


Instance Method Details

#to_hash{



92
# File 'sig/increase/models/ach_prenotification_create_params.rbs', line 92

def to_hash: -> {