Module: Increase::Models::ACHTransfer::Addenda::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs
Overview
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
Constant Summary collapse
- FREEFORM =
Unstructured
payment_related_informationpassed through with the transfer. :freeform- PAYMENT_ORDER_REMITTANCE_ADVICE =
Structured ASC X12 820 remittance advice records. Please reach out to support@increase.com for more information.
:payment_order_remittance_advice- OTHER =
Unknown addenda type.
:other
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::ACHTransfer::Addenda::category]
244 |
# File 'sig/increase/models/ach_transfer.rbs', line 244
def self?.values: -> ::Array[Increase::Models::ACHTransfer::Addenda::category]
|