Class: Increase::Models::ACHTransfer::Addenda::PaymentOrderRemittanceAdvice::Invoice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ACHTransfer::Addenda::PaymentOrderRemittanceAdvice::Invoice
- Defined in:
- lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs
Instance Attribute Summary collapse
-
#invoice_number ⇒ String
The invoice number for this reference, determined in advance with the receiver.
-
#paid_amount ⇒ Integer
The amount that was paid for this invoice in the minor unit of its currency.
Instance Method Summary collapse
-
#initialize(invoices:) ⇒ Object
constructor
Structured ASC X12 820 remittance advice records.
- #to_hash ⇒ { invoice_number: String, paid_amount: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(invoices:) ⇒ Object
Structured ASC X12 820 remittance advice records. Please reach out to support@increase.com for more information.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 |
# File 'lib/increase/models/ach_transfer.rb', line 502 class Invoice < Increase::Internal::Type::BaseModel # @!attribute invoice_number # The invoice number for this reference, determined in advance with the receiver. # # @return [String] required :invoice_number, String # @!attribute paid_amount # The amount that was paid for this invoice in the minor unit of its currency. For # dollars, for example, this is cents. # # @return [Integer] required :paid_amount, Integer # @!method initialize(invoice_number:, paid_amount:) # @param invoice_number [String] # The invoice number for this reference, determined in advance with the receiver. # # @param paid_amount [Integer] # The amount that was paid for this invoice in the minor unit of its currency. For # dollars, for example, this is cents. end |
Instance Attribute Details
#invoice_number ⇒ String
The invoice number for this reference, determined in advance with the receiver.
507 |
# File 'lib/increase/models/ach_transfer.rb', line 507 required :invoice_number, String |
#paid_amount ⇒ Integer
The amount that was paid for this invoice in the minor unit of its currency. For dollars, for example, this is cents.
514 |
# File 'lib/increase/models/ach_transfer.rb', line 514 required :paid_amount, Integer |
Instance Method Details
#to_hash ⇒ { invoice_number: String, paid_amount: Integer }
300 |
# File 'sig/increase/models/ach_transfer.rbs', line 300
def to_hash: -> { invoice_number: String, paid_amount: Integer }
|