Class: Increase::Models::ACHTransfer::NotificationsOfChange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs

Defined Under Namespace

Modules: ChangeCode, CorrectedAccountFunding

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(change_code:, corrected_account_funding:, corrected_account_number:, corrected_individual_id:, corrected_routing_number:, created_at:) ⇒ Object



# File 'lib/increase/models/ach_transfer.rb', line 934


Instance Attribute Details

#change_codeSymbol, Increase::Models::ACHTransfer::NotificationsOfChange::ChangeCode

The required type of change that is being signaled by the receiving financial institution.



898
# File 'lib/increase/models/ach_transfer.rb', line 898

required :change_code, enum: -> { Increase::ACHTransfer::NotificationsOfChange::ChangeCode }

#corrected_account_fundingSymbol, ...

The corrected account funding type that should be used in future ACHs to this account. This is derived from the corrected transaction code.



905
906
907
# File 'lib/increase/models/ach_transfer.rb', line 905

required :corrected_account_funding,
enum: -> { Increase::ACHTransfer::NotificationsOfChange::CorrectedAccountFunding },
nil?: true

#corrected_account_numberString?

The corrected account number that should be used in future ACHs to this account.



913
# File 'lib/increase/models/ach_transfer.rb', line 913

required :corrected_account_number, String, nil?: true

#corrected_individual_idString?

The corrected individual identifier that should be used in future ACHs.



919
# File 'lib/increase/models/ach_transfer.rb', line 919

required :corrected_individual_id, String, nil?: true

#corrected_routing_numberString?

The corrected routing number that should be used in future ACHs to this account.



925
# File 'lib/increase/models/ach_transfer.rb', line 925

required :corrected_routing_number, String, nil?: true

#created_atTime

The ISO 8601 date and time at which the notification occurred.



932
# File 'lib/increase/models/ach_transfer.rb', line 932

required :created_at, Time

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/ach_transfer.rb', line 1026


Instance Method Details

#to_hash{



590
# File 'sig/increase/models/ach_transfer.rbs', line 590

def to_hash: -> {