Module: Increase::Models::ACHTransfer::PreferredEffectiveDate::SettlementSchedule
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs
Overview
A schedule by which Increase will choose an effective date for the transfer.
Constant Summary collapse
- SAME_DAY =
The chosen effective date will be the same as the ACH processing date on which the transfer is submitted. This is necessary, but not sufficient for the transfer to be settled same-day: it must also be submitted before the last same-day cutoff and be less than or equal to $1,000,000.00.
:same_day- FUTURE_DATED =
The chosen effective date will be the business day following the ACH processing date on which the transfer is submitted. The transfer will be settled on that future day.
:future_dated
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::ACHTransfer::PreferredEffectiveDate::settlement_schedule]
740 |
# File 'sig/increase/models/ach_transfer.rbs', line 740
def self?.values: -> ::Array[Increase::Models::ACHTransfer::PreferredEffectiveDate::settlement_schedule]
|