Class: Increase::Models::ACHTransfer::Settlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ACHTransfer::Settlement
- Defined in:
- lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#settled_at ⇒ Time
When the funds for this transfer have settled at the destination bank at the Federal Reserve.
Instance Method Summary collapse
-
#initialize ⇒ Settlement
constructor
A new instance of Settlement.
- #to_hash ⇒ { settled_at: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Settlement
Returns a new instance of Settlement.
1079 |
# File 'sig/increase/models/ach_transfer.rbs', line 1079
def initialize: (settled_at: Time) -> void
|
Instance Attribute Details
#settled_at ⇒ Time
When the funds for this transfer have settled at the destination bank at the Federal Reserve.
1327 |
# File 'lib/increase/models/ach_transfer.rb', line 1327 required :settled_at, Time |
Instance Method Details
#to_hash ⇒ { settled_at: Time }
1081 |
# File 'sig/increase/models/ach_transfer.rbs', line 1081
def to_hash: -> { settled_at: Time }
|