Class: Increase::Models::ACHTransfer::Submission

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer.rb

Overview

See Also:

Defined Under Namespace

Modules: ExpectedSettlementSchedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(administrative_returns_expected_by:, effective_date:, expected_funds_settlement_at:, expected_settlement_schedule:, submitted_at:, trace_number:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::ACHTransfer::Submission for more details.

After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their [posted schedule](www.frbservices.org/resources/resource-centers/same-day-ach/fedach-processing-schedule.html).

Parameters:

  • administrative_returns_expected_by (Time)

    The timestamp by which any administrative returns are expected to be received by

  • effective_date (Date)

    The ACH transfer’s effective date as sent to the Federal Reserve. If a specific

  • expected_funds_settlement_at (Time)

    When the transfer is expected to settle in the recipient’s account. Credits may

  • expected_settlement_schedule (Symbol, Increase::Models::ACHTransfer::Submission::ExpectedSettlementSchedule)

    The settlement schedule the transfer is expected to follow. This expectation tak

  • submitted_at (Time)

    When the ACH transfer was sent to FedACH.

  • trace_number (String)

    A 15 digit number recorded in the Nacha file and transmitted to the receiving ba



# File 'lib/increase/models/ach_transfer.rb', line 1406

Instance Attribute Details

#administrative_returns_expected_byTime

The timestamp by which any administrative returns are expected to be received by. This follows the NACHA guidelines for return windows, which are: “In general, return entries must be received by the RDFI’s ACH Operator by its deposit deadline for the return entry to be made available to the ODFI no later than the opening of business on the second banking day following the Settlement Date of the original entry.”.

Returns:

  • (Time)


1361
# File 'lib/increase/models/ach_transfer.rb', line 1361

required :administrative_returns_expected_by, Time

#effective_dateDate

The ACH transfer’s effective date as sent to the Federal Reserve. If a specific date was configured using ‘preferred_effective_date`, this will match that value. Otherwise, it will be the date selected (following the specified settlement schedule) at the time the transfer was submitted.

Returns:

  • (Date)


1370
# File 'lib/increase/models/ach_transfer.rb', line 1370

required :effective_date, Date

#expected_funds_settlement_atTime

When the transfer is expected to settle in the recipient’s account. Credits may be available sooner, at the receiving bank’s discretion. The FedACH schedule is published [here](www.frbservices.org/resources/resource-centers/same-day-ach/fedach-processing-schedule.html).

Returns:

  • (Time)


1379
# File 'lib/increase/models/ach_transfer.rb', line 1379

required :expected_funds_settlement_at, Time

#expected_settlement_scheduleSymbol, Increase::Models::ACHTransfer::Submission::ExpectedSettlementSchedule

The settlement schedule the transfer is expected to follow. This expectation takes into account the ‘effective_date`, `submitted_at`, and the amount of the transfer.



1387
1388
# File 'lib/increase/models/ach_transfer.rb', line 1387

required :expected_settlement_schedule,
enum: -> { Increase::ACHTransfer::Submission::ExpectedSettlementSchedule }

#submitted_atTime

When the ACH transfer was sent to FedACH.

Returns:

  • (Time)


1394
# File 'lib/increase/models/ach_transfer.rb', line 1394

required :submitted_at, Time

#trace_numberString

A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at the receiving bank. ACH trace numbers are not unique, but are [used to correlate returns](increase.com/documentation/ach-returns#ach-returns).

Returns:

  • (String)


1404
# File 'lib/increase/models/ach_transfer.rb', line 1404

required :trace_number, String