Module: Increase::Models::ACHTransfer::Submission::ExpectedSettlementSchedule

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs

Overview

The settlement schedule the transfer is expected to follow. This expectation takes into account the effective_date, submitted_at, and the amount of the transfer.

See Also:

  • Increase::Models::ACHTransfer::Submission#expected_settlement_schedule

Constant Summary collapse

SAME_DAY =

The transfer is expected to settle same-day.

Returns:

  • (:same_day)
:same_day
FUTURE_DATED =

The transfer is expected to settle on a future date.

Returns:

  • (:future_dated)
:future_dated

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::ACHTransfer::Submission::expected_settlement_schedule]

Returns:

  • (::Array[Increase::Models::ACHTransfer::Submission::expected_settlement_schedule])


1204
# File 'sig/increase/models/ach_transfer.rbs', line 1204

def self?.values: -> ::Array[Increase::Models::ACHTransfer::Submission::expected_settlement_schedule]