Class: Increase::Models::ACHTransferCreateParams::Addenda::PaymentOrderRemittanceAdvice::Invoice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer_create_params.rb,
sig/increase/models/ach_transfer_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(invoices:) ⇒ Object

Structured ASC X12 820 remittance advice records. Please reach out to support@increase.com for more information. Required if and only if category is payment_order_remittance_advice.

Parameters:



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/increase/models/ach_transfer_create_params.rb', line 355

class Invoice < Increase::Internal::Type::BaseModel
  # @!attribute invoice_number
  #   The invoice number for this reference, determined in advance with the receiver.
  #
  #   @return [String]
  required :invoice_number, String

  # @!attribute paid_amount
  #   The amount that was paid for this invoice in the minor unit of its currency. For
  #   dollars, for example, this is cents.
  #
  #   @return [Integer]
  required :paid_amount, Integer

  # @!method initialize(invoice_number:, paid_amount:)
  #   @param invoice_number [String]
  #     The invoice number for this reference, determined in advance with the receiver.
  #
  #   @param paid_amount [Integer]
  #     The amount that was paid for this invoice in the minor unit of its currency. For
  #     dollars, for example, this is cents.
end

Instance Attribute Details

#invoice_numberString

The invoice number for this reference, determined in advance with the receiver.

Parameters:

  • value (String)

Returns:

  • (String)


360
# File 'lib/increase/models/ach_transfer_create_params.rb', line 360

required :invoice_number, String

The amount that was paid for this invoice in the minor unit of its currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


367
# File 'lib/increase/models/ach_transfer_create_params.rb', line 367

required :paid_amount, Integer

Instance Method Details

#to_hash{ invoice_number: String, paid_amount: Integer }

Returns:

  • ({ invoice_number: String, paid_amount: Integer })


262
# File 'sig/increase/models/ach_transfer_create_params.rbs', line 262

def to_hash: -> { invoice_number: String, paid_amount: Integer }