Module: Increase::Models::ACHTransferCreateParams::PreferredEffectiveDate::SettlementSchedule

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/ach_transfer_create_params.rb,
sig/increase/models/ach_transfer_create_params.rbs

Overview

A schedule by which Increase will choose an effective date for the transfer.

See Also:

  • Increase::Models::ACHTransferCreateParams::PreferredEffectiveDate#settlement_schedule

Constant Summary collapse

SAME_DAY =

The chosen effective date will be the same as the ACH processing date on which the transfer is submitted. This is necessary, but not sufficient for the transfer to be settled same-day: it must also be submitted before the last same-day cutoff and be less than or equal to $1,000,000.00.

Returns:

  • (:same_day)
:same_day
FUTURE_DATED =

The chosen effective date will be the business day following the ACH processing date on which the transfer is submitted. The transfer will be settled on that future day.

Returns:

  • (:future_dated)
:future_dated

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::ACHTransferCreateParams::PreferredEffectiveDate::settlement_schedule]

Returns:

  • (::Array[Increase::Models::ACHTransferCreateParams::PreferredEffectiveDate::settlement_schedule])


342
# File 'sig/increase/models/ach_transfer_create_params.rbs', line 342

def self?.values: -> ::Array[Increase::Models::ACHTransferCreateParams::PreferredEffectiveDate::settlement_schedule]