Module: Increase::Models::ACHTransferListParams::Status::In
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/ach_transfer_list_params.rb,
sig/increase/models/ach_transfer_list_params.rbs
Constant Summary collapse
- PENDING_APPROVAL =
The transfer is pending approval.
:pending_approval- PENDING_TRANSFER_SESSION_CONFIRMATION =
The transfer belongs to a Transfer Session that is pending confirmation.
:pending_transfer_session_confirmation- CANCELED =
The transfer has been canceled.
:canceled- PENDING_SUBMISSION =
The transfer is pending submission to the Federal Reserve.
:pending_submission- PENDING_REVIEWING =
The transfer is pending review by Increase.
:pending_reviewing- REQUIRES_ATTENTION =
The transfer requires attention from an Increase operator.
:requires_attention- REJECTED =
The transfer has been rejected.
:rejected- SUBMITTED =
The transfer has been submitted to the Federal Reserve. When the transfer settles, the status remains
submittedand thesettlementsub-object is populated. :submitted- RETURNED =
The transfer has been returned.
:returned
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(in_: nil) ⇒ Object
- #self?.values ⇒ ::Array[Increase::Models::ACHTransferListParams::Status::in_]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/ach_transfer_list_params.rb', line 169
|
Instance Method Details
#initialize(in_: nil) ⇒ Object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/increase/models/ach_transfer_list_params.rb', line 139 module In extend Increase::Internal::Type::Enum # The transfer is pending approval. PENDING_APPROVAL = :pending_approval # The transfer belongs to a Transfer Session that is pending confirmation. PENDING_TRANSFER_SESSION_CONFIRMATION = :pending_transfer_session_confirmation # The transfer has been canceled. CANCELED = :canceled # The transfer is pending submission to the Federal Reserve. PENDING_SUBMISSION = :pending_submission # The transfer is pending review by Increase. PENDING_REVIEWING = :pending_reviewing # The transfer requires attention from an Increase operator. REQUIRES_ATTENTION = :requires_attention # The transfer has been rejected. REJECTED = :rejected # The transfer has been submitted to the Federal Reserve. When the transfer settles, the status remains `submitted` and the `settlement` sub-object is populated. SUBMITTED = :submitted # The transfer has been returned. RETURNED = :returned # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[Increase::Models::ACHTransferListParams::Status::in_]
167 |
# File 'sig/increase/models/ach_transfer_list_params.rbs', line 167
def self?.values: -> ::Array[Increase::Models::ACHTransferListParams::Status::in_]
|