Class: Increase::Models::Account

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account.rb,
sig/increase/models/account.rbs

Overview

See Also:

  • Increase::Resources::Accounts#create

Defined Under Namespace

Modules: Bank, Currency, Funding, Status, Type Classes: Loan

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, account_revenue_rate:, bank:, closed_at:, created_at:, currency:, entity_id:, funding:, idempotency_key:, informational_entity_id:, interest_rate:, loan:, name:, program_id:, status:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Account for more details.

Accounts are your bank accounts with Increase. They store money, receive transfers, and send payments. They earn interest and have depository insurance.

Parameters:

  • id (String)

    The Account identifier.

  • account_revenue_rate (String, nil)

    The account revenue rate currently being earned on the account, as a string cont

  • bank (Symbol, Increase::Models::Account::Bank)

    The bank the Account is with.

  • closed_at (Time, nil)

    The ISO 8601 time at which the Account

  • created_at (Time)

    The ISO 8601 time at which the Account

  • currency (Symbol, Increase::Models::Account::Currency)

    The ISO 4217 code for the Account curr

  • entity_id (String)

    The identifier for the Entity the Account belongs to.

  • funding (Symbol, Increase::Models::Account::Funding)

    Whether the Account is funded by a loan or by deposits.

  • idempotency_key (String, nil)

    The idempotency key you chose for this object. This value is unique across Incre

  • informational_entity_id (String, nil)

    The identifier of an Entity that, while not owning the Account, is associated wi

  • interest_rate (String)

    The interest rate currently being earned on the account, as a string containing

  • loan (Increase::Models::Account::Loan, nil)

    The Account's loan-related information, if the Account is a loan account.

  • name (String)

    The name you choose for the Account.

  • program_id (String)

    The identifier of the Program determining the compliance and commercial terms of

  • status (Symbol, Increase::Models::Account::Status)

    The status of the Account.

  • type (Symbol, Increase::Models::Account::Type)

    A constant representing the object's type. For this resource it will always be `



# File 'lib/increase/models/account.rb', line 116

Instance Attribute Details

#account_revenue_rateString?

The account revenue rate currently being earned on the account, as a string containing a decimal number. For example, a 1% account revenue rate would be represented as "0.01". Account revenue is a type of non-interest income accrued on the account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/increase/models/account.rb', line 20

required :account_revenue_rate, String, nil?: true

#bankSymbol, Increase::Models::Account::Bank

The bank the Account is with.

Parameters:

  • value (Increase::Models::Account::bank)

Returns:



26
# File 'lib/increase/models/account.rb', line 26

required :bank, enum: -> { Increase::Account::Bank }

#closed_atTime?

The ISO 8601 time at which the Account was closed.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


33
# File 'lib/increase/models/account.rb', line 33

required :closed_at, Time, nil?: true

#created_atTime

The ISO 8601 time at which the Account was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


40
# File 'lib/increase/models/account.rb', line 40

required :created_at, Time

#currencySymbol, Increase::Models::Account::Currency

The ISO 4217 code for the Account currency.

Parameters:

  • value (Increase::Models::Account::currency)

Returns:



47
# File 'lib/increase/models/account.rb', line 47

required :currency, enum: -> { Increase::Account::Currency }

#entity_idString

The identifier for the Entity the Account belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


53
# File 'lib/increase/models/account.rb', line 53

required :entity_id, String

#fundingSymbol, Increase::Models::Account::Funding

Whether the Account is funded by a loan or by deposits.

Parameters:

  • value (Increase::Models::Account::funding)

Returns:



59
# File 'lib/increase/models/account.rb', line 59

required :funding, enum: -> { Increase::Account::Funding }

#idString

The Account identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/account.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


67
# File 'lib/increase/models/account.rb', line 67

required :idempotency_key, String, nil?: true

#informational_entity_idString?

The identifier of an Entity that, while not owning the Account, is associated with its activity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


74
# File 'lib/increase/models/account.rb', line 74

required :informational_entity_id, String, nil?: true

#interest_rateString

The interest rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".

Parameters:

  • value (String)

Returns:

  • (String)


82
# File 'lib/increase/models/account.rb', line 82

required :interest_rate, String

#loanIncrease::Models::Account::Loan?

The Account's loan-related information, if the Account is a loan account.

Parameters:

  • value (Increase::Account::Loan, nil)

Returns:



88
# File 'lib/increase/models/account.rb', line 88

required :loan, -> { Increase::Account::Loan }, nil?: true

#nameString

The name you choose for the Account.

Parameters:

  • value (String)

Returns:

  • (String)


94
# File 'lib/increase/models/account.rb', line 94

required :name, String

#program_idString

The identifier of the Program determining the compliance and commercial terms of this Account.

Parameters:

  • value (String)

Returns:

  • (String)


101
# File 'lib/increase/models/account.rb', line 101

required :program_id, String

#statusSymbol, Increase::Models::Account::Status

The status of the Account.

Parameters:

  • value (Increase::Models::Account::status)

Returns:



107
# File 'lib/increase/models/account.rb', line 107

required :status, enum: -> { Increase::Account::Status }

#typeSymbol, Increase::Models::Account::Type

A constant representing the object's type. For this resource it will always be account.

Parameters:

  • value (Increase::Models::Account::type_)

Returns:



114
# File 'lib/increase/models/account.rb', line 114

required :type, enum: -> { Increase::Account::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/account.rb', line 170

Instance Method Details

#to_hash{

Returns:

  • ({)


75
# File 'sig/increase/models/account.rbs', line 75

def to_hash: -> {