Class: Increase::Models::Account::Loan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Account::Loan
- Defined in:
- lib/increase/models/account.rb,
sig/increase/models/account.rbs
Overview
Defined Under Namespace
Modules: StatementPaymentType
Instance Attribute Summary collapse
-
#credit_limit ⇒ Integer
The maximum amount of money that can be borrowed on the Account.
-
#grace_period_days ⇒ Integer
The number of days after the statement date that the Account can be past due before being considered delinquent.
-
#maturity_date ⇒ Date?
The date on which the loan matures.
-
#statement_day_of_month ⇒ Integer
The day of the month on which the loan statement is generated.
-
#statement_payment_type ⇒ Symbol, Increase::Models::Account::Loan::StatementPaymentType
The type of payment for the loan.
Instance Method Summary collapse
-
#initialize(credit_limit:, grace_period_days:, maturity_date:, statement_day_of_month:, statement_payment_type:) ⇒ Object
constructor
The Account's loan-related information, if the Account is a loan account.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_limit:, grace_period_days:, maturity_date:, statement_day_of_month:, statement_payment_type:) ⇒ Object
The Account's loan-related information, if the Account is a loan account.
|
|
# File 'lib/increase/models/account.rb', line 258
|
Instance Attribute Details
#credit_limit ⇒ Integer
The maximum amount of money that can be borrowed on the Account.
231 |
# File 'lib/increase/models/account.rb', line 231 required :credit_limit, Integer |
#grace_period_days ⇒ Integer
The number of days after the statement date that the Account can be past due before being considered delinquent.
238 |
# File 'lib/increase/models/account.rb', line 238 required :grace_period_days, Integer |
#maturity_date ⇒ Date?
The date on which the loan matures.
244 |
# File 'lib/increase/models/account.rb', line 244 required :maturity_date, Date, nil?: true |
#statement_day_of_month ⇒ Integer
The day of the month on which the loan statement is generated.
250 |
# File 'lib/increase/models/account.rb', line 250 required :statement_day_of_month, Integer |
#statement_payment_type ⇒ Symbol, Increase::Models::Account::Loan::StatementPaymentType
The type of payment for the loan.
256 |
# File 'lib/increase/models/account.rb', line 256 required :statement_payment_type, enum: -> { Increase::Account::Loan::StatementPaymentType } |
Instance Method Details
#to_hash ⇒ {
164 |
# File 'sig/increase/models/account.rbs', line 164
def to_hash: -> {
|