Module: Increase::Models::Account::Loan::StatementPaymentType

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/account.rb,
sig/increase/models/account.rbs

Overview

The type of payment for the loan.

See Also:

  • Increase::Models::Account::Loan#statement_payment_type

Constant Summary collapse

BALANCE =

The borrower must pay the full balance of the loan at the end of the statement period.

Returns:

  • (:balance)
:balance
INTEREST_UNTIL_MATURITY =

The borrower must pay the accrued interest at the end of the statement period.

Returns:

  • (:interest_until_maturity)
:interest_until_maturity

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Account::Loan::statement_payment_type]

Returns:

  • (::Array[Increase::Models::Account::Loan::statement_payment_type])


183
# File 'sig/increase/models/account.rbs', line 183

def self?.values: -> ::Array[Increase::Models::Account::Loan::statement_payment_type]