Class: Increase::Models::AccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/account_create_params.rb

Overview

Defined Under Namespace

Modules: Funding Classes: Loan

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, entity_id: nil, funding: nil, informational_entity_id: nil, loan: nil, program_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::AccountCreateParams for more details.

Parameters:

  • name (String)

    The name you choose for the Account.

  • entity_id (String) (defaults to: nil)

    The identifier for the Entity that will own the Account.

  • funding (Symbol, Increase::Models::AccountCreateParams::Funding) (defaults to: nil)

    Whether the Account is funded by a loan or by deposits.

  • informational_entity_id (String) (defaults to: nil)

    The identifier of an Entity that, while not owning the Account, is associated wi

  • loan (Increase::Models::AccountCreateParams::Loan) (defaults to: nil)

    The loan details for the account.

  • program_id (String) (defaults to: nil)

    The identifier for the Program that this Account falls under. Required if you op

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/increase/models/account_create_params.rb', line 48

Instance Attribute Details

#entity_idString?

The identifier for the Entity that will own the Account.

Returns:

  • (String, nil)


20
# File 'lib/increase/models/account_create_params.rb', line 20

optional :entity_id, String

#fundingSymbol, ...

Whether the Account is funded by a loan or by deposits.



26
# File 'lib/increase/models/account_create_params.rb', line 26

optional :funding, enum: -> { Increase::AccountCreateParams::Funding }

#informational_entity_idString?

The identifier of an Entity that, while not owning the Account, is associated with its activity. This is generally the beneficiary of the funds.

Returns:

  • (String, nil)


33
# File 'lib/increase/models/account_create_params.rb', line 33

optional :informational_entity_id, String

#loanIncrease::Models::AccountCreateParams::Loan?

The loan details for the account.



39
# File 'lib/increase/models/account_create_params.rb', line 39

optional :loan, -> { Increase::AccountCreateParams::Loan }

#nameString

The name you choose for the Account.

Returns:

  • (String)


14
# File 'lib/increase/models/account_create_params.rb', line 14

required :name, String

#program_idString?

The identifier for the Program that this Account falls under. Required if you operate more than one Program.

Returns:

  • (String, nil)


46
# File 'lib/increase/models/account_create_params.rb', line 46

optional :program_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/account_create_params.rb', line 76