Class: Increase::Models::AccountCreateParams::Loan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account_create_params.rb,
sig/increase/models/account_create_params.rbs

Defined Under Namespace

Modules: StatementPaymentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_limit:, grace_period_days: nil, maturity_date: nil, statement_day_of_month: nil, statement_payment_type: nil) ⇒ Object

The loan details for the account.

Parameters:

  • credit_limit (Integer)

    The maximum amount of money that can be drawn from the Account.

  • grace_period_days (Integer) (defaults to: nil)

    The number of days after the statement date that the Account can be past due before being considered delinquent.

  • maturity_date (Date) (defaults to: nil)

    The date on which the loan matures.

  • statement_day_of_month (Integer) (defaults to: nil)

    The day of the month on which the loan statement is generated.

  • statement_payment_type (Symbol, Increase::Models::AccountCreateParams::Loan::StatementPaymentType) (defaults to: nil)

    The type of statement payment for the account.



# File 'lib/increase/models/account_create_params.rb', line 116

Instance Attribute Details

#credit_limitInteger

The maximum amount of money that can be drawn from the Account.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


89
# File 'lib/increase/models/account_create_params.rb', line 89

required :credit_limit, Integer

#grace_period_daysInteger?

The number of days after the statement date that the Account can be past due before being considered delinquent.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


96
# File 'lib/increase/models/account_create_params.rb', line 96

optional :grace_period_days, Integer

#maturity_dateDate?

The date on which the loan matures.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


102
# File 'lib/increase/models/account_create_params.rb', line 102

optional :maturity_date, Date

#statement_day_of_monthInteger?

The day of the month on which the loan statement is generated.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


108
# File 'lib/increase/models/account_create_params.rb', line 108

optional :statement_day_of_month, Integer

#statement_payment_typeSymbol, ...

The type of statement payment for the account.



114
# File 'lib/increase/models/account_create_params.rb', line 114

optional :statement_payment_type, enum: -> { Increase::AccountCreateParams::Loan::StatementPaymentType }

Instance Method Details

#to_hash{

Returns:

  • ({)


116
# File 'sig/increase/models/account_create_params.rbs', line 116

def to_hash: -> {