Module: Increase::Models::AccountCreateParams::Loan::StatementPaymentType

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/account_create_params.rb,
sig/increase/models/account_create_params.rbs

Overview

The type of statement payment for the account.

See Also:

  • Increase::Models::AccountCreateParams::Loan#statement_payment_type

Constant Summary collapse

BALANCE =

The borrower must pay the full balance of the loan at the end of the statement period.

Returns:

  • (:balance)
:balance
INTEREST_UNTIL_MATURITY =

The borrower must pay the accrued interest at the end of the statement period.

Returns:

  • (:interest_until_maturity)
:interest_until_maturity

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/account_create_params.rb', line 141

Instance Method Details

#self?.values::Array[Increase::Models::AccountCreateParams::Loan::statement_payment_type]

Returns:

  • (::Array[Increase::Models::AccountCreateParams::Loan::statement_payment_type])


127
# File 'sig/increase/models/account_create_params.rbs', line 127

def self?.values: -> ::Array[Increase::Models::AccountCreateParams::Loan::statement_payment_type]