Class: Increase::Models::AccountListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/account_list_params.rb,
sig/increase/models/account_list_params.rbs

Overview

See Also:

  • Increase::Resources::Accounts#list

Defined Under Namespace

Classes: CreatedAt, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, on_or_after: nil, on_or_before: nil) ⇒ Object

Some parameter documentations has been truncated, see CreatedAt for more details.

Parameters:



# File 'lib/increase/models/account_list_params.rb', line 111

Instance Attribute Details

#created_atIncrease::Models::AccountListParams::CreatedAt?



13
# File 'lib/increase/models/account_list_params.rb', line 13

optional :created_at, -> { Increase::AccountListParams::CreatedAt }

#cursorString?

Return the page of entries after this one.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/increase/models/account_list_params.rb', line 19

optional :cursor, String

#entity_idString?

Filter Accounts for those belonging to the specified Entity.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/increase/models/account_list_params.rb', line 25

optional :entity_id, String

#idempotency_keyString?

Filter records to the one with the specified idempotency_key you chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/increase/models/account_list_params.rb', line 34

optional :idempotency_key, String

#informational_entity_idString?

Filter Accounts for those belonging to the specified Entity as informational.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/increase/models/account_list_params.rb', line 40

optional :informational_entity_id, String

#limitInteger?

Limit the size of the list that is returned. The default (and maximum) is 100 objects.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


47
# File 'lib/increase/models/account_list_params.rb', line 47

optional :limit, Integer

#program_idString?

Filter Accounts for those in a specific Program.

Parameters:

  • (String)

Returns:

  • (String, nil)


53
# File 'lib/increase/models/account_list_params.rb', line 53

optional :program_id, String

#statusIncrease::Models::AccountListParams::Status?



58
# File 'lib/increase/models/account_list_params.rb', line 58

optional :status, -> { Increase::AccountListParams::Status }

Instance Method Details

#to_hash{

Returns:

  • ({)


68
# File 'sig/increase/models/account_list_params.rbs', line 68

def to_hash: -> {