Module: Increase::Models::AccountListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/account_list_params.rb,
sig/increase/models/account_list_params.rbs

Constant Summary collapse

CLOSED =

Closed Accounts on which no new activity can occur.

:closed
OPEN =

Open Accounts that are ready to use.

:open

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/account_list_params.rb', line 161


Instance Method Details

#initialize(in_: nil) ⇒ Object



152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/increase/models/account_list_params.rb', line 152

module In
  extend Increase::Internal::Type::Enum

  # Closed Accounts on which no new activity can occur.
  CLOSED = :closed

  # Open Accounts that are ready to use.
  OPEN = :open

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::AccountListParams::Status::in_]



144
# File 'sig/increase/models/account_list_params.rbs', line 144

def self?.values: -> ::Array[Increase::Models::AccountListParams::Status::in_]