Class: Increase::Models::AccountNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account_number.rb,
sig/increase/models/account_number.rbs

Overview

See Also:

  • Increase::Resources::AccountNumbers#create

Defined Under Namespace

Modules: Status, Type Classes: InboundACH, InboundChecks

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, account_id:, account_number:, created_at:, idempotency_key:, inbound_ach:, inbound_checks:, name:, routing_number:, status:, type:) ⇒ Object

Each account can have multiple account and routing numbers. We recommend that you use a set per vendor. This is similar to how you use different passwords for different websites. Account numbers can also be used to seamlessly reconcile inbound payments. Generating a unique account number per vendor ensures you always know the originator of an incoming payment.



# File 'lib/increase/models/account_number.rb', line 78


Instance Attribute Details

#account_idString

The identifier for the account this Account Number belongs to.



17
# File 'lib/increase/models/account_number.rb', line 17

required :account_id, String

#account_numberString

The account number.



23
# File 'lib/increase/models/account_number.rb', line 23

required :account_number, String

#created_atTime

The ISO 8601 time at which the Account Number was created.



30
# File 'lib/increase/models/account_number.rb', line 30

required :created_at, Time

#idString

The Account Number identifier.



11
# File 'lib/increase/models/account_number.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.



38
# File 'lib/increase/models/account_number.rb', line 38

required :idempotency_key, String, nil?: true

#inbound_achIncrease::Models::AccountNumber::InboundACH

Properties related to how this Account Number handles inbound ACH transfers.



44
# File 'lib/increase/models/account_number.rb', line 44

required :inbound_ach, -> { Increase::AccountNumber::InboundACH }

#inbound_checksIncrease::Models::AccountNumber::InboundChecks

Properties related to how this Account Number should handle inbound check withdrawals.



51
# File 'lib/increase/models/account_number.rb', line 51

required :inbound_checks, -> { Increase::AccountNumber::InboundChecks }

#nameString

The name you choose for the Account Number.



57
# File 'lib/increase/models/account_number.rb', line 57

required :name, String

#routing_numberString

The American Bankers' Association (ABA) Routing Transit Number (RTN).



63
# File 'lib/increase/models/account_number.rb', line 63

required :routing_number, String

#statusSymbol, Increase::Models::AccountNumber::Status

This indicates if payments can be made to the Account Number.



69
# File 'lib/increase/models/account_number.rb', line 69

required :status, enum: -> { Increase::AccountNumber::Status }

#typeSymbol, Increase::Models::AccountNumber::Type

A constant representing the object's type. For this resource it will always be account_number.



76
# File 'lib/increase/models/account_number.rb', line 76

required :type, enum: -> { Increase::AccountNumber::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/account_number.rb', line 147


Instance Method Details

#to_hash{



55
# File 'sig/increase/models/account_number.rbs', line 55

def to_hash: -> {