Class: Increase::Models::AccountNumberCreateParams::InboundACH

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account_number_create_params.rb,
sig/increase/models/account_number_create_params.rbs

Defined Under Namespace

Modules: DebitStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(debit_status:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::AccountNumberCreateParams::InboundACH for more details.

Options related to how this Account Number should handle inbound ACH transfers.

Parameters:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/increase/models/account_number_create_params.rb', line 49

class InboundACH < Increase::Internal::Type::BaseModel
  # @!attribute debit_status
  #   Whether ACH debits are allowed against this Account Number. Note that ACH debits
  #   will be declined if this is `allowed` but the Account Number is not active. If
  #   you do not specify this field, the default is `allowed`.
  #
  #   @return [Symbol, Increase::Models::AccountNumberCreateParams::InboundACH::DebitStatus]
  required :debit_status, enum: -> { Increase::AccountNumberCreateParams::InboundACH::DebitStatus }

  # @!method initialize(debit_status:)
  #   Some parameter documentations has been truncated, see
  #   {Increase::Models::AccountNumberCreateParams::InboundACH} for more details.
  #
  #   Options related to how this Account Number should handle inbound ACH transfers.
  #
  #   @param debit_status [Symbol, Increase::Models::AccountNumberCreateParams::InboundACH::DebitStatus] Whether ACH debits are allowed against this Account Number. Note that ACH debits

  # Whether ACH debits are allowed against this Account Number. Note that ACH debits
  # will be declined if this is `allowed` but the Account Number is not active. If
  # you do not specify this field, the default is `allowed`.
  #
  # @see Increase::Models::AccountNumberCreateParams::InboundACH#debit_status
  module DebitStatus
    extend Increase::Internal::Type::Enum

    # ACH Debits are allowed.
    ALLOWED = :allowed

    # ACH Debits are blocked.
    BLOCKED = :blocked

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#debit_statusSymbol, Increase::Models::AccountNumberCreateParams::InboundACH::DebitStatus

Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is allowed but the Account Number is not active. If you do not specify this field, the default is allowed.

Parameters:

  • value (Increase::Models::AccountNumberCreateParams::InboundACH::debit_status)

Returns:



56
# File 'lib/increase/models/account_number_create_params.rb', line 56

required :debit_status, enum: -> { Increase::AccountNumberCreateParams::InboundACH::DebitStatus }

Instance Method Details

#to_hash{

Returns:

  • ({)


60
# File 'sig/increase/models/account_number_create_params.rbs', line 60

def to_hash: -> {