Module: Increase::Models::AccountNumberCreateParams::InboundACH::DebitStatus
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/account_number_create_params.rb,
sig/increase/models/account_number_create_params.rbs
Overview
Whether ACH debits are allowed against this Account Number. Note that ACH debits
will be declined if this is allowed but the Account Number is not active. If
you do not specify this field, the default is allowed.
Constant Summary collapse
- ALLOWED =
ACH Debits are allowed.
:allowed- BLOCKED =
ACH Debits are blocked.
:blocked
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::AccountNumberCreateParams::InboundACH::debit_status]
75 |
# File 'sig/increase/models/account_number_create_params.rbs', line 75
def self?.values: -> ::Array[Increase::Models::AccountNumberCreateParams::InboundACH::debit_status]
|