Class: Increase::Models::AccountStatement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account_statement.rb,
sig/increase/models/account_statement.rbs

Overview

See Also:

  • Increase::Resources::AccountStatements#retrieve

Defined Under Namespace

Modules: Type Classes: Loan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(due_at:, due_balance:, past_due_balance:) ⇒ Object

The loan balances.



# File 'lib/increase/models/account_statement.rb', line 75


Instance Attribute Details

#account_idString

The identifier for the Account this Account Statement belongs to.



17
# File 'lib/increase/models/account_statement.rb', line 17

required :account_id, String

#created_atTime

The ISO 8601 time at which the Account Statement was created.



24
# File 'lib/increase/models/account_statement.rb', line 24

required :created_at, Time

#ending_balanceInteger

The Account's balance at the end of its statement period.



30
# File 'lib/increase/models/account_statement.rb', line 30

required :ending_balance, Integer

#file_idString

The identifier of the File containing a PDF of the statement.



36
# File 'lib/increase/models/account_statement.rb', line 36

required :file_id, String

#idString

The Account Statement identifier.



11
# File 'lib/increase/models/account_statement.rb', line 11

required :id, String

#loanIncrease::Models::AccountStatement::Loan?

The loan balances.



42
# File 'lib/increase/models/account_statement.rb', line 42

required :loan, -> { Increase::AccountStatement::Loan }, nil?: true

#starting_balanceInteger

The Account's balance at the start of its statement period.



48
# File 'lib/increase/models/account_statement.rb', line 48

required :starting_balance, Integer

#statement_period_endTime

The ISO 8601 time representing the end of the period the Account Statement covers. The statement covers all transactions up to, but not including this timestamp. Usually, this is the beginning of the following month.



57
# File 'lib/increase/models/account_statement.rb', line 57

required :statement_period_end, Time

#statement_period_startTime

The ISO 8601 time representing the start of the period the Account Statement covers. This is the first moment of the statement period and is inclusive. Usually, this is the beginning of the month this statement covers.



66
# File 'lib/increase/models/account_statement.rb', line 66

required :statement_period_start, Time

#typeSymbol, Increase::Models::AccountStatement::Type

A constant representing the object's type. For this resource it will always be account_statement.



73
# File 'lib/increase/models/account_statement.rb', line 73

required :type, enum: -> { Increase::AccountStatement::Type }

Instance Method Details

#to_hash{



51
# File 'sig/increase/models/account_statement.rbs', line 51

def to_hash: -> {