Class: Increase::Models::AccountTransfer::Cancellation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::AccountTransfer::Cancellation
- Defined in:
- lib/increase/models/account_transfer.rb,
sig/increase/models/account_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#canceled_at ⇒ Time
The ISO 8601 date and time at which the Transfer was canceled.
-
#canceled_by ⇒ String?
If the Transfer was canceled by a user in the dashboard, the email address of that user.
Instance Method Summary collapse
-
#initialize ⇒ Cancellation
constructor
A new instance of Cancellation.
- #to_hash ⇒ { canceled_at: Time, canceled_by: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Cancellation
Returns a new instance of Cancellation.
113 |
# File 'sig/increase/models/account_transfer.rbs', line 113
def initialize: (canceled_at: Time, canceled_by: String?) -> void
|
Instance Attribute Details
#canceled_at ⇒ Time
The ISO 8601 date and time at which the Transfer was canceled.
195 |
# File 'lib/increase/models/account_transfer.rb', line 195 required :canceled_at, Time |
#canceled_by ⇒ String?
If the Transfer was canceled by a user in the dashboard, the email address of that user.
202 |
# File 'lib/increase/models/account_transfer.rb', line 202 required :canceled_by, String, nil?: true |
Instance Method Details
#to_hash ⇒ { canceled_at: Time, canceled_by: String? }
115 |
# File 'sig/increase/models/account_transfer.rbs', line 115
def to_hash: -> { canceled_at: Time, canceled_by: String? }
|