Class: Increase::Models::AccountTransferCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/account_transfer_create_params.rb,
sig/increase/models/account_transfer_create_params.rbs

Overview

See Also:

  • Increase::Resources::AccountTransfers#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, amount:, description:, destination_account_id:, require_approval: nil, request_options: {}) ⇒ Object



# File 'lib/increase/models/account_transfer_create_params.rb', line 44


Instance Attribute Details

#account_idString

The identifier for the originating Account that will send the transfer.



14
# File 'lib/increase/models/account_transfer_create_params.rb', line 14

required :account_id, String

#amountInteger

The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.



21
# File 'lib/increase/models/account_transfer_create_params.rb', line 21

required :amount, Integer

#descriptionString

An internal-facing description for the transfer for display in the API and dashboard. This will also show in the description of the created Transactions.



28
# File 'lib/increase/models/account_transfer_create_params.rb', line 28

required :description, String

#destination_account_idString

The identifier for the destination Account that will receive the transfer.



34
# File 'lib/increase/models/account_transfer_create_params.rb', line 34

required :destination_account_id, String

#require_approvalBoolean?

Whether the transfer should require explicit approval via the dashboard or API. For more information, see Transfer Approvals.



42
# File 'lib/increase/models/account_transfer_create_params.rb', line 42

optional :require_approval, Increase::Internal::Type::Boolean

Instance Method Details

#to_hash{



38
# File 'sig/increase/models/account_transfer_create_params.rbs', line 38

def to_hash: -> {