Class: Increase::Models::AccountUpdateParams::Loan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::AccountUpdateParams::Loan
- Defined in:
- lib/increase/models/account_update_params.rb
Instance Attribute Summary collapse
-
#credit_limit ⇒ Integer
The maximum amount of money that can be drawn from the Account.
Instance Method Summary collapse
-
#initialize(credit_limit:) ⇒ Object
constructor
The loan details for the account.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credit_limit:) ⇒ Object
The loan details for the account.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/increase/models/account_update_params.rb', line 37 class Loan < Increase::Internal::Type::BaseModel # @!attribute credit_limit # The maximum amount of money that can be drawn from the Account. # # @return [Integer] required :credit_limit, Integer # @!method initialize(credit_limit:) # The loan details for the account. # # @param credit_limit [Integer] The maximum amount of money that can be drawn from the Account. end |
Instance Attribute Details
#credit_limit ⇒ Integer
The maximum amount of money that can be drawn from the Account.
42 |
# File 'lib/increase/models/account_update_params.rb', line 42 required :credit_limit, Integer |