Class: Increase::Models::BalanceLookup

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/balance_lookup.rb,
sig/increase/models/balance_lookup.rbs

Overview

See Also:

  • Increase::Resources::Accounts#balance

Defined Under Namespace

Modules: Type Classes: Loan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(due_fees:, due_interest:, due_principal:, not_due_fees:, not_due_interest:, not_due_principal:) ⇒ Object

The loan balances for the Account.

Parameters:

  • The fees on the loan that are due and unpaid.

  • The interest on the loan that is due and unpaid.

  • The principal on the loan that is due and unpaid.

  • The fees on the loan that are not yet due.

  • The interest on the loan that is not yet due.

  • The principal on the loan that is not yet due.



# File 'lib/increase/models/balance_lookup.rb', line 40


Instance Attribute Details

#account_idString

The identifier for the account for which the balance was queried.

Parameters:

Returns:



11
# File 'lib/increase/models/balance_lookup.rb', line 11

required :account_id, String

#available_balanceInteger

The Account's available balance, representing the current balance less any open Pending Transactions on the Account.

Parameters:

Returns:



18
# File 'lib/increase/models/balance_lookup.rb', line 18

required :available_balance, Integer

#current_balanceInteger

The Account's current balance, representing the sum of all posted Transactions on the Account.

Parameters:

Returns:



25
# File 'lib/increase/models/balance_lookup.rb', line 25

required :current_balance, Integer

#loanIncrease::Models::BalanceLookup::Loan?

The loan balances for the Account.

Parameters:

Returns:



31
# File 'lib/increase/models/balance_lookup.rb', line 31

required :loan, -> { Increase::BalanceLookup::Loan }, nil?: true

#typeSymbol, Increase::Models::BalanceLookup::Type

A constant representing the object's type. For this resource it will always be balance_lookup.

Parameters:

Returns:



38
# File 'lib/increase/models/balance_lookup.rb', line 38

required :type, enum: -> { Increase::BalanceLookup::Type }

Instance Method Details

#to_hash{

Returns:



31
# File 'sig/increase/models/balance_lookup.rbs', line 31

def to_hash: -> {