Class: Increase::Models::BalanceLookup::Loan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/balance_lookup.rb,
sig/increase/models/balance_lookup.rbs

Overview

See Also:

  • Increase::Models::BalanceLookup#loan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



62
# File 'sig/increase/models/balance_lookup.rbs', line 62

def initialize: (

Instance Attribute Details

#due_feesInteger?

The fees on the loan that are due and unpaid.

Parameters:

Returns:



66
# File 'lib/increase/models/balance_lookup.rb', line 66

required :due_fees, Integer, nil?: true

#due_interestInteger?

The interest on the loan that is due and unpaid.

Parameters:

Returns:



72
# File 'lib/increase/models/balance_lookup.rb', line 72

required :due_interest, Integer, nil?: true

#due_principalInteger?

The principal on the loan that is due and unpaid.

Parameters:

Returns:



78
# File 'lib/increase/models/balance_lookup.rb', line 78

required :due_principal, Integer, nil?: true

#not_due_feesInteger?

The fees on the loan that are not yet due.

Parameters:

Returns:



84
# File 'lib/increase/models/balance_lookup.rb', line 84

required :not_due_fees, Integer, nil?: true

#not_due_interestInteger?

The interest on the loan that is not yet due.

Parameters:

Returns:



90
# File 'lib/increase/models/balance_lookup.rb', line 90

required :not_due_interest, Integer, nil?: true

#not_due_principalInteger?

The principal on the loan that is not yet due.

Parameters:

Returns:



96
# File 'lib/increase/models/balance_lookup.rb', line 96

required :not_due_principal, Integer, nil?: true

Instance Method Details

#to_hash{

Returns:



71
# File 'sig/increase/models/balance_lookup.rbs', line 71

def to_hash: -> {