Class: Increase::Models::BalanceLookup::Loan::Receivables
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BalanceLookup::Loan::Receivables
- Defined in:
- lib/increase/models/balance_lookup.rb,
sig/increase/models/balance_lookup.rbs
Overview
Instance Attribute Summary collapse
-
#purchasable_balance ⇒ Integer
The balance of seasoned receivables available to be purchased.
-
#purchased_balance ⇒ Integer
The balance of receivables that have been purchased.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
78 |
# File 'sig/increase/models/balance_lookup.rbs', line 78
def initialize: (
|
Instance Attribute Details
#purchasable_balance ⇒ Integer
The balance of seasoned receivables available to be purchased.
104 |
# File 'lib/increase/models/balance_lookup.rb', line 104 required :purchasable_balance, Integer |
#purchased_balance ⇒ Integer
The balance of receivables that have been purchased.
110 |
# File 'lib/increase/models/balance_lookup.rb', line 110 required :purchased_balance, Integer |
Instance Method Details
#to_hash ⇒ {
83 |
# File 'sig/increase/models/balance_lookup.rbs', line 83
def to_hash: -> {
|