Class: Increase::Models::BeneficialOwnerCreateParams::Individual::Identification::Other

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/beneficial_owner_create_params.rb,
sig/increase/models/beneficial_owner_create_params.rbs

Overview

See Also:

  • Increase::Models::BeneficialOwnerCreateParams::Individual::Identification#other

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



262
# File 'sig/increase/models/beneficial_owner_create_params.rbs', line 262

def initialize: (

Instance Attribute Details

#back_file_idString?

The identifier of the File containing the back of the document. Not every document has a reverse side.

Parameters:

  • (String)

Returns:

  • (String, nil)


312
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 312

optional :back_file_id, String

#countryString

The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).

Parameters:

  • value (String)

Returns:

  • (String)


293
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 293

required :country, String

#descriptionString

A description of the document submitted.

Parameters:

  • value (String)

Returns:

  • (String)


299
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 299

required :description, String

#expiration_dateDate?

The document's expiration date in YYYY-MM-DD format.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


318
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 318

optional :expiration_date, Date

#file_idString

The identifier of the File containing the front of the document.

Parameters:

  • value (String)

Returns:

  • (String)


305
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 305

required :file_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


270
# File 'sig/increase/models/beneficial_owner_create_params.rbs', line 270

def to_hash: -> {