Class: Increase::Models::BeneficialOwnerListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/beneficial_owner_list_params.rb,
sig/increase/models/beneficial_owner_list_params.rbs

Overview

See Also:

  • Increase::Resources::BeneficialOwners#list

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(entity_id:, cursor: nil, idempotency_key: nil, limit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::BeneficialOwnerListParams for more details.

Parameters:

  • entity_id (String)

    The identifier of the Entity to list beneficial owners for. Only corporation e

  • cursor (String) (defaults to: nil)

    Return the page of entries after this one.

  • idempotency_key (String) (defaults to: nil)

    Filter records to the one with the specified idempotency_key you chose for tha

  • limit (Integer) (defaults to: nil)

    Limit the size of the list that is returned. The default (and maximum) is 100 ob

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/increase/models/beneficial_owner_list_params.rb', line 39

Instance Attribute Details

#cursorString?

Return the page of entries after this one.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/increase/models/beneficial_owner_list_params.rb', line 21

optional :cursor, String

#entity_idString

The identifier of the Entity to list beneficial owners for. Only corporation entities have beneficial owners.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/increase/models/beneficial_owner_list_params.rb', line 15

required :entity_id, String

#idempotency_keyString?

Filter records to the one with the specified idempotency_key you chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

Parameters:

  • (String)

Returns:

  • (String, nil)


30
# File 'lib/increase/models/beneficial_owner_list_params.rb', line 30

optional :idempotency_key, String

#limitInteger?

Limit the size of the list that is returned. The default (and maximum) is 100 objects.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


37
# File 'lib/increase/models/beneficial_owner_list_params.rb', line 37

optional :limit, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/increase/models/beneficial_owner_list_params.rbs', line 38

def to_hash: -> {