Class: Increase::Models::BeneficialOwnerUpdateParams::Identification::DriversLicense
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerUpdateParams::Identification::DriversLicense
- Defined in:
- lib/increase/models/beneficial_owner_update_params.rb,
sig/increase/models/beneficial_owner_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#back_file_id ⇒ String?
The identifier of the File containing the back of the driver's license.
-
#expiration_date ⇒ Date
The driver's license's expiration date in YYYY-MM-DD format.
-
#file_id ⇒ String
The identifier of the File containing the front of the driver's license.
-
#state ⇒ String
The state that issued the provided driver's license.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
209 |
# File 'sig/increase/models/beneficial_owner_update_params.rbs', line 209
def initialize: (
|
Instance Attribute Details
#back_file_id ⇒ String?
The identifier of the File containing the back of the driver's license.
236 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 236 optional :back_file_id, String |
#expiration_date ⇒ Date
The driver's license's expiration date in YYYY-MM-DD format.
218 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 218 required :expiration_date, Date |
#file_id ⇒ String
The identifier of the File containing the front of the driver's license.
224 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 224 required :file_id, String |
#state ⇒ String
The state that issued the provided driver's license.
230 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 230 required :state, String |
Instance Method Details
#to_hash ⇒ {
216 |
# File 'sig/increase/models/beneficial_owner_update_params.rbs', line 216
def to_hash: -> {
|