Class: Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport
- Defined in:
- lib/increase/models/beneficial_owner_update_params.rb
Overview
Instance Attribute Summary collapse
-
#country ⇒ String
The two-character ISO 3166-1 code representing the country that issued the document (e.g., ‘US`).
-
#expiration_date ⇒ Date
The passport’s expiration date in YYYY-MM-DD format.
-
#file_id ⇒ String
The identifier of the File containing the passport.
Instance Method Summary collapse
-
#initialize(country:, expiration_date:, file_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Passport for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, expiration_date:, file_id:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport for more details.
Information about the passport used for identification. Required if ‘method` is equal to `passport`.
|
|
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 310
|
Instance Attribute Details
#country ⇒ String
The two-character ISO 3166-1 code representing the country that issued the document (e.g., ‘US`).
296 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 296 required :country, String |
#expiration_date ⇒ Date
The passport’s expiration date in YYYY-MM-DD format.
302 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 302 required :expiration_date, Date |
#file_id ⇒ String
The identifier of the File containing the passport.
308 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 308 required :file_id, String |