Module: Increase::Models::BeneficialOwnerUpdateParams::Prong

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/beneficial_owner_update_params.rb,
sig/increase/models/beneficial_owner_update_params.rbs

Constant Summary collapse

OWNERSHIP =

A person with 25% or greater direct or indirect ownership of the entity.

Returns:

  • (:ownership)
:ownership
CONTROL =

A person who manages, directs, or has significant control of the entity.

Returns:

  • (:control)
:control

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/beneficial_owner_update_params.rb', line 350

Instance Method Details

#self?.values::Array[Increase::Models::BeneficialOwnerUpdateParams::prong]

Returns:

  • (::Array[Increase::Models::BeneficialOwnerUpdateParams::prong])


300
# File 'sig/increase/models/beneficial_owner_update_params.rbs', line 300

def self?.values: -> ::Array[Increase::Models::BeneficialOwnerUpdateParams::prong]