Class: Increase::Models::Card::AuthorizationControls::MerchantAcceptorIdentifier::Allowed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Card::AuthorizationControls::MerchantAcceptorIdentifier::Allowed
- Defined in:
- lib/increase/models/card.rb
Instance Attribute Summary collapse
-
#identifier ⇒ String
The Merchant Acceptor ID.
Instance Method Summary collapse
-
#initialize(allowed:, blocked:) ⇒ Object
constructor
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allowed:, blocked:) ⇒ Object
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/increase/models/card.rb', line 212 class Allowed < Increase::Internal::Type::BaseModel # @!attribute identifier # The Merchant Acceptor ID. # # @return [String] required :identifier, String # @!method initialize(identifier:) # @param identifier [String] The Merchant Acceptor ID. end |
Instance Attribute Details
#identifier ⇒ String
The Merchant Acceptor ID.
217 |
# File 'lib/increase/models/card.rb', line 217 required :identifier, String |