Class: Increase::Models::Card::AuthorizationControls::MerchantCategoryCode

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card.rb,
sig/increase/models/card.rbs

Overview

See Also:

  • Increase::Models::Card::AuthorizationControls#merchant_category_code

Defined Under Namespace

Classes: Allowed, Blocked

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code:) ⇒ Object

Parameters:

  • code (String)

    The Merchant Category Code (MCC).



# File 'lib/increase/models/card.rb', line 280

Instance Attribute Details

#allowedArray<Increase::Models::Card::AuthorizationControls::MerchantCategoryCode::Allowed>?

The Merchant Category Codes that are allowed for authorizations on this card.

Parameters:

  • value (::Array[Increase::Card::AuthorizationControls::MerchantCategoryCode::Allowed], nil)

Returns:



249
250
251
252
253
# File 'lib/increase/models/card.rb', line 249

required :allowed,
-> {
  Increase::Internal::Type::ArrayOf[Increase::Card::AuthorizationControls::MerchantCategoryCode::Allowed]
},
nil?: true

#blockedArray<Increase::Models::Card::AuthorizationControls::MerchantCategoryCode::Blocked>?

The Merchant Category Codes that are blocked for authorizations on this card.

Parameters:

  • value (::Array[Increase::Card::AuthorizationControls::MerchantCategoryCode::Blocked], nil)

Returns:



259
260
261
262
263
# File 'lib/increase/models/card.rb', line 259

required :blocked,
-> {
  Increase::Internal::Type::ArrayOf[Increase::Card::AuthorizationControls::MerchantCategoryCode::Blocked]
},
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


178
# File 'sig/increase/models/card.rbs', line 178

def to_hash: -> {