Class: Increase::Models::Card::AuthorizationControls::MerchantCountry::Allowed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Card::AuthorizationControls::MerchantCountry::Allowed
- Defined in:
- lib/increase/models/card.rb
Instance Attribute Summary collapse
-
#country ⇒ String
The ISO 3166-1 alpha-2 country code.
Instance Method Summary collapse
-
#initialize(allowed:, blocked:) ⇒ Object
constructor
Restricts which merchant countries are allowed or blocked for authorizations on this card.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allowed:, blocked:) ⇒ Object
Restricts which merchant countries are allowed or blocked for authorizations on this card.
318 319 320 321 322 323 324 325 326 327 |
# File 'lib/increase/models/card.rb', line 318 class Allowed < Increase::Internal::Type::BaseModel # @!attribute country # The ISO 3166-1 alpha-2 country code. # # @return [String] required :country, String # @!method initialize(country:) # @param country [String] The ISO 3166-1 alpha-2 country code. end |
Instance Attribute Details
#country ⇒ String
The ISO 3166-1 alpha-2 country code.
323 |
# File 'lib/increase/models/card.rb', line 323 required :country, String |