Module: Increase::Models::Card::AuthorizationControls::Usage::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card.rb,
sig/increase/models/card.rbs

Overview

Whether the card is for a single use or multiple uses.

See Also:

  • Increase::Models::Card::AuthorizationControls::Usage#category

Constant Summary collapse

SINGLE_USE =

The card can only be used for a single authorization.

Returns:

  • (:single_use)
:single_use
MULTI_USE =

The card can be used for multiple authorizations.

Returns:

  • (:multi_use)
:multi_use

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Card::AuthorizationControls::Usage::category]

Returns:

  • (::Array[Increase::Models::Card::AuthorizationControls::Usage::category])


283
# File 'sig/increase/models/card.rbs', line 283

def self?.values: -> ::Array[Increase::Models::Card::AuthorizationControls::Usage::category]