Class: Increase::Models::Card::DigitalWallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Card::DigitalWallet
- Defined in:
- lib/increase/models/card.rb,
sig/increase/models/card.rbs
Overview
Instance Attribute Summary collapse
-
#digital_card_profile_id ⇒ String?
The digital card profile assigned to this digital card.
-
#email ⇒ String?
An email address that can be used to verify the cardholder via one-time passcode over email.
-
#phone ⇒ String?
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
466 |
# File 'sig/increase/models/card.rbs', line 466
def initialize: (
|
Instance Attribute Details
#digital_card_profile_id ⇒ String?
The digital card profile assigned to this digital card. Card profiles may also be assigned at the program level.
604 |
# File 'lib/increase/models/card.rb', line 604 required :digital_card_profile_id, String, nil?: true |
#email ⇒ String?
An email address that can be used to verify the cardholder via one-time passcode over email.
611 |
# File 'lib/increase/models/card.rb', line 611 required :email, String, nil?: true |
#phone ⇒ String?
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
618 |
# File 'lib/increase/models/card.rb', line 618 required :phone, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
472 |
# File 'sig/increase/models/card.rbs', line 472
def to_hash: -> {
|