Class: Increase::Models::CardCreateParams::AuthorizationControls::MerchantAcceptorIdentifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_create_params.rb

Overview

Defined Under Namespace

Classes: Allowed, Blocked

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(identifier:) ⇒ Object

Parameters:

  • identifier (String)

    The Merchant Acceptor ID.



# File 'lib/increase/models/card_create_params.rb', line 150

Instance Attribute Details

#allowedArray<Increase::Models::CardCreateParams::AuthorizationControls::MerchantAcceptorIdentifier::Allowed>?

The Merchant Acceptor IDs that are allowed for authorizations on this card. Authorizations with Merchant Acceptor IDs not in this list will be declined.



120
121
# File 'lib/increase/models/card_create_params.rb', line 120

optional :allowed,
-> { Increase::Internal::Type::ArrayOf[Increase::CardCreateParams::AuthorizationControls::MerchantAcceptorIdentifier::Allowed] }

#blockedArray<Increase::Models::CardCreateParams::AuthorizationControls::MerchantAcceptorIdentifier::Blocked>?

The Merchant Acceptor IDs that are blocked for authorizations on this card. Authorizations with Merchant Acceptor IDs in this list will be declined.



128
129
# File 'lib/increase/models/card_create_params.rb', line 128

optional :blocked,
-> { Increase::Internal::Type::ArrayOf[Increase::CardCreateParams::AuthorizationControls::MerchantAcceptorIdentifier::Blocked] }