Class: Increase::Models::CardCreateParams::AuthorizationControls::MerchantCategoryCode

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_create_params.rb

Overview

Defined Under Namespace

Classes: Allowed, Blocked

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code:) ⇒ Object

Parameters:

  • code (String)

    The Merchant Category Code.



# File 'lib/increase/models/card_create_params.rb', line 203

Instance Attribute Details

#allowedArray<Increase::Models::CardCreateParams::AuthorizationControls::MerchantCategoryCode::Allowed>?

The Merchant Category Codes that are allowed for authorizations on this card. Authorizations with Merchant Category Codes not in this list will be declined.



173
174
# File 'lib/increase/models/card_create_params.rb', line 173

optional :allowed,
-> { Increase::Internal::Type::ArrayOf[Increase::CardCreateParams::AuthorizationControls::MerchantCategoryCode::Allowed] }

#blockedArray<Increase::Models::CardCreateParams::AuthorizationControls::MerchantCategoryCode::Blocked>?

The Merchant Category Codes that are blocked for authorizations on this card. Authorizations with Merchant Category Codes in this list will be declined.



181
182
# File 'lib/increase/models/card_create_params.rb', line 181

optional :blocked,
-> { Increase::Internal::Type::ArrayOf[Increase::CardCreateParams::AuthorizationControls::MerchantCategoryCode::Blocked] }