Class: Increase::Models::CardCreateParams::AuthorizationControls::MerchantCategoryCode::Allowed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_create_params.rb,
sig/increase/models/card_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed: nil, blocked: nil) ⇒ Allowed

Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.

Parameters:

  • (defaults to: nil)

    The Merchant Category Codes that are allowed for authorizations on this card. Authorizations with Merchant Category Codes not in this list will be declined.

  • (defaults to: nil)

    The Merchant Category Codes that are blocked for authorizations on this card. Authorizations with Merchant Category Codes in this list will be declined.



216
217
218
219
220
221
222
223
224
225
# File 'lib/increase/models/card_create_params.rb', line 216

class Allowed < Increase::Internal::Type::BaseModel
  # @!attribute code
  #   The Merchant Category Code.
  #
  #   @return [String]
  required :code, String

  # @!method initialize(code:)
  #   @param code [String] The Merchant Category Code.
end

Instance Attribute Details

#codeString

The Merchant Category Code.

Parameters:

Returns:



221
# File 'lib/increase/models/card_create_params.rb', line 221

required :code, String

Instance Method Details

#to_hash{ code: String }

Returns:



208
# File 'sig/increase/models/card_create_params.rbs', line 208

def to_hash: -> { code: String }