Module: Increase::Models::CardCreateParams::AuthorizationControls::Usage::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_create_params.rb

Overview

Whether the card is for a single use or multiple uses.

See Also:

Constant Summary collapse

SINGLE_USE =

The card can only be used for a single authorization.

:single_use
MULTI_USE =

The card can be used for multiple authorizations.

:multi_use

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info