Module: Increase::Models::CardCreateParams::AuthorizationControls::Usage::MultiUse::SpendingLimit::Interval
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_create_params.rb,
sig/increase/models/card_create_params.rbs
Overview
The interval at which the spending limit is enforced.
Constant Summary collapse
- ALL_TIME =
The spending limit applies over the lifetime of the card.
:all_time- PER_TRANSACTION =
The spending limit applies per transaction.
:per_transaction- PER_DAY =
The spending limit applies per day. Resets nightly at midnight UTC.
:per_day- PER_WEEK =
The spending limit applies per week. Resets weekly on Mondays at midnight UTC.
:per_week- PER_MONTH =
The spending limit applies per month. Resets on the first of the month, midnight UTC.
:per_month
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardCreateParams::AuthorizationControls::Usage::MultiUse::SpendingLimit::interval]
382 |
# File 'sig/increase/models/card_create_params.rbs', line 382
def self?.values: -> ::Array[Increase::Models::CardCreateParams::AuthorizationControls::Usage::MultiUse::SpendingLimit::interval]
|