Class: Increase::Models::CardDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_details.rb,
sig/increase/models/card_details.rbs

Overview

See Also:

  • Increase::Resources::Cards#details

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_id:, expiration_month:, expiration_year:, pin:, primary_account_number:, type:, verification_code:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardDetails for more details.

An object containing the sensitive details (card number, CVC, PIN, etc) for a Card. These details are not included in the Card object. If you'd prefer to never access these details directly, you can use the embedded iframe to display the information to your users.

Parameters:

  • card_id (String)

    The identifier for the Card for which sensitive details have been returned.

  • expiration_month (Integer)

    The month the card expires in M format (e.g., August is 8).

  • expiration_year (Integer)

    The year the card expires in YYYY format (e.g., 2025).

  • pin (String)

    The 4-digit PIN for the card, for use with ATMs.

  • primary_account_number (String)

    The card number.

  • type (Symbol, Increase::Models::CardDetails::Type)

    A constant representing the object's type. For this resource it will always be `

  • verification_code (String)

    The three-digit verification code for the card. It's also known as the Card Veri



# File 'lib/increase/models/card_details.rb', line 52

Instance Attribute Details

#card_idString

The identifier for the Card for which sensitive details have been returned.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/card_details.rb', line 11

required :card_id, String

#expiration_monthInteger

The month the card expires in M format (e.g., August is 8).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


17
# File 'lib/increase/models/card_details.rb', line 17

required :expiration_month, Integer

#expiration_yearInteger

The year the card expires in YYYY format (e.g., 2025).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


23
# File 'lib/increase/models/card_details.rb', line 23

required :expiration_year, Integer

#pinString

The 4-digit PIN for the card, for use with ATMs.

Parameters:

  • value (String)

Returns:

  • (String)


29
# File 'lib/increase/models/card_details.rb', line 29

required :pin, String

#primary_account_numberString

The card number.

Parameters:

  • value (String)

Returns:

  • (String)


35
# File 'lib/increase/models/card_details.rb', line 35

required :primary_account_number, String

#typeSymbol, Increase::Models::CardDetails::Type

A constant representing the object's type. For this resource it will always be card_details.

Parameters:

  • value (Increase::Models::CardDetails::type_)

Returns:



42
# File 'lib/increase/models/card_details.rb', line 42

required :type, enum: -> { Increase::CardDetails::Type }

#verification_codeString

The three-digit verification code for the card. It's also known as the Card Verification Code (CVC), the Card Verification Value (CVV), or the Card Identification (CID).

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/increase/models/card_details.rb', line 50

required :verification_code, String

Instance Method Details

#to_hash{

Returns:

  • ({)


39
# File 'sig/increase/models/card_details.rbs', line 39

def to_hash: -> {