Class: Increase::Models::CardDispute

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

See Also:

  • Increase::Resources::CardDisputes#create

Defined Under Namespace

Modules: Network, Status, Type Classes: Loss, Rejection, Visa, Win, Withdrawal

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(won_at:) ⇒ Object

If the Card Dispute's status is won, this will contain details of the won dispute.



# File 'lib/increase/models/card_dispute.rb', line 116

Instance Attribute Details

#account_idString

The Account that the Card Dispute is associated with.



17
# File 'lib/increase/models/card_dispute.rb', line 17

required :account_id, String

#amountInteger

The amount of the dispute.



23
# File 'lib/increase/models/card_dispute.rb', line 23

required :amount, Integer

#card_idString

The Card that the Card Dispute is associated with.



29
# File 'lib/increase/models/card_dispute.rb', line 29

required :card_id, String

#created_atTime

The ISO 8601 date and time at which the Card Dispute was created.



36
# File 'lib/increase/models/card_dispute.rb', line 36

required :created_at, Time

#disputed_transaction_idString

The identifier of the Transaction that was disputed.



42
# File 'lib/increase/models/card_dispute.rb', line 42

required :disputed_transaction_id, String

#idString

The Card Dispute identifier.



11
# File 'lib/increase/models/card_dispute.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.



50
# File 'lib/increase/models/card_dispute.rb', line 50

required :idempotency_key, String, nil?: true

#lossIncrease::Models::CardDispute::Loss?

If the Card Dispute's status is lost, this will contain details of the lost dispute.



57
# File 'lib/increase/models/card_dispute.rb', line 57

required :loss, -> { Increase::CardDispute::Loss }, nil?: true

#networkSymbol, Increase::Models::CardDispute::Network

The network that the Card Dispute is associated with.



63
# File 'lib/increase/models/card_dispute.rb', line 63

required :network, enum: -> { Increase::CardDispute::Network }

#rejectionIncrease::Models::CardDispute::Rejection?

If the Card Dispute has been rejected, this will contain details of the rejection.



70
# File 'lib/increase/models/card_dispute.rb', line 70

required :rejection, -> { Increase::CardDispute::Rejection }, nil?: true

#statusSymbol, Increase::Models::CardDispute::Status

The status of the Card Dispute.



76
# File 'lib/increase/models/card_dispute.rb', line 76

required :status, enum: -> { Increase::CardDispute::Status }

#typeSymbol, Increase::Models::CardDispute::Type

A constant representing the object's type. For this resource it will always be card_dispute.



83
# File 'lib/increase/models/card_dispute.rb', line 83

required :type, enum: -> { Increase::CardDispute::Type }

#user_submission_required_byTime?

The ISO 8601 date and time at which the user submission is required by. Present only if status is user_submission_required and a user submission is required by a certain time. Otherwise, this will be nil.



92
# File 'lib/increase/models/card_dispute.rb', line 92

required :user_submission_required_by, Time, nil?: true

#visaIncrease::Models::CardDispute::Visa?

Card Dispute information for card payments processed over Visa's network. This field will be present in the JSON response if and only if network is equal to visa.



100
# File 'lib/increase/models/card_dispute.rb', line 100

required :visa, -> { Increase::CardDispute::Visa }, nil?: true

#winIncrease::Models::CardDispute::Win?

If the Card Dispute's status is won, this will contain details of the won dispute.



107
# File 'lib/increase/models/card_dispute.rb', line 107

required :win, -> { Increase::CardDispute::Win }, nil?: true

#withdrawalIncrease::Models::CardDispute::Withdrawal?

If the Card Dispute has been withdrawn, this will contain details of the withdrawal.



114
# File 'lib/increase/models/card_dispute.rb', line 114

required :withdrawal, -> { Increase::CardDispute::Withdrawal }, nil?: true

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/card_dispute.rb', line 212

Instance Method Details

#to_hash{



75
# File 'sig/increase/models/card_dispute.rbs', line 75

def to_hash: -> {