Class: Increase::Models::CardDispute::Loss

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

See Also:

  • Increase::Models::CardDispute#loss

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(lost_at:, reason:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardDispute::Loss for more details.

If the Card Dispute's status is lost, this will contain details of the lost dispute.

Parameters:



# File 'lib/increase/models/card_dispute.rb', line 162

Instance Attribute Details

#lost_atTime

The ISO 8601 date and time at which the Card Dispute was lost.

Parameters:

  • value (Time)

Returns:

  • (Time)


154
# File 'lib/increase/models/card_dispute.rb', line 154

required :lost_at, Time

#reasonSymbol, Increase::Models::CardDispute::Loss::Reason

The reason the Card Dispute was lost.

Parameters:

  • value (Increase::Models::CardDispute::Loss::reason)

Returns:



160
# File 'lib/increase/models/card_dispute.rb', line 160

required :reason, enum: -> { Increase::CardDispute::Loss::Reason }

Instance Method Details

#to_hash{

Returns:

  • ({)


102
# File 'sig/increase/models/card_dispute.rbs', line 102

def to_hash: -> {