Module: Increase::Models::CardDispute::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
The status of the Card Dispute.
Constant Summary collapse
- USER_SUBMISSION_REQUIRED =
A User Submission is required to continue with the Card Dispute.
:user_submission_required- PENDING_USER_SUBMISSION_REVIEWING =
The most recent User Submission is being reviewed.
:pending_user_submission_reviewing- PENDING_USER_SUBMISSION_SUBMITTING =
The most recent User Submission is being submitted to the network.
:pending_user_submission_submitting- PENDING_USER_WITHDRAWAL_SUBMITTING =
The user's withdrawal of the Card Dispute is being submitted to the network.
:pending_user_withdrawal_submitting- PENDING_RESPONSE =
The Card Dispute is pending a response from the network.
:pending_response- LOST =
The Card Dispute has been lost and funds previously credited from the acceptance have been debited.
:lost- WON =
The Card Dispute has been won and no further action can be taken.
:won- REJECTED =
The Card Dispute has been reviewed and rejected, please review the explanation for more details.
:rejected
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardDispute::status]
185 |
# File 'sig/increase/models/card_dispute.rbs', line 185
def self?.values: -> ::Array[Increase::Models::CardDispute::status]
|