Class: Increase::Models::CardDispute::Visa

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

See Also:

  • Increase::Models::CardDispute#visa

Defined Under Namespace

Modules: RequiredUserSubmissionCategory Classes: NetworkEvent, UserSubmission

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

A Card Dispute User Withdrawal Submitted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to user_withdrawal_submitted. Contains the details specific to a user withdrawal submitted Visa Card Dispute Network Event, which represents that the user's request to withdraw the dispute has been submitted to the network.



# File 'lib/increase/models/card_dispute.rb', line 1551

Instance Attribute Details

#network_eventsArray<Increase::Models::CardDispute::Visa::NetworkEvent>

The network events for the Card Dispute.

Parameters:

  • value (::Array[Increase::CardDispute::Visa::NetworkEvent])

Returns:



286
287
# File 'lib/increase/models/card_dispute.rb', line 286

required :network_events,
-> { Increase::Internal::Type::ArrayOf[Increase::CardDispute::Visa::NetworkEvent] }

#required_user_submission_categorySymbol, ...

The category of the currently required user submission if the user wishes to proceed with the dispute. Present if and only if status is user_submission_required. Otherwise, this will be nil.

Parameters:

  • value (Increase::Models::CardDispute::Visa::required_user_submission_category, nil)

Returns:



295
296
297
# File 'lib/increase/models/card_dispute.rb', line 295

required :required_user_submission_category,
enum: -> { Increase::CardDispute::Visa::RequiredUserSubmissionCategory },
nil?: true

#user_submissionsArray<Increase::Models::CardDispute::Visa::UserSubmission>

The user submissions for the Card Dispute.

Parameters:

  • value (::Array[Increase::CardDispute::Visa::UserSubmission])

Returns:



303
304
# File 'lib/increase/models/card_dispute.rb', line 303

required :user_submissions,
-> { Increase::Internal::Type::ArrayOf[Increase::CardDispute::Visa::UserSubmission] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_dispute.rb', line 1577

Instance Method Details

#to_hash{

Returns:

  • ({)


218
# File 'sig/increase/models/card_dispute.rbs', line 218

def to_hash: -> {