Class: Increase::Models::CardDispute::Visa::NetworkEvent::AttachmentFile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(attachment_files:, category:, created_at:, dispute_financial_transaction_id:, chargeback_accepted: nil, chargeback_submitted: nil, chargeback_timed_out: nil, merchant_prearbitration_decline_submitted: nil, merchant_prearbitration_received: nil, merchant_prearbitration_timed_out: nil, represented: nil, representment_timed_out: nil, user_prearbitration_accepted: nil, user_prearbitration_declined: nil, user_prearbitration_submitted: nil, user_prearbitration_timed_out: nil, user_withdrawal_submitted: nil) ⇒ AttachmentFile

Returns a new instance of AttachmentFile.

Parameters:

  • attachment_files (Array<Increase::Models::CardDispute::Visa::NetworkEvent::AttachmentFile>)

    The files attached to the Visa Card Dispute User Submission.

  • category (Symbol, Increase::Models::CardDispute::Visa::NetworkEvent::Category)

    The category of the user submission. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

  • created_at (Time)

    The ISO 8601 date and time at which the Visa Card Dispute Network Event was created.

  • dispute_financial_transaction_id (String, nil)

    The dispute financial transaction that resulted from the network event, if any.

  • chargeback_accepted (Increase::Models::CardDispute::Visa::NetworkEvent::ChargebackAccepted, nil) (defaults to: nil)

    A Card Dispute Chargeback Accepted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to chargeback_accepted. Contains the details specific to a chargeback accepted Visa Card Dispute Network Event, which represents that a chargeback has been accepted by the merchant.

  • chargeback_submitted (Increase::Models::CardDispute::Visa::NetworkEvent::ChargebackSubmitted, nil) (defaults to: nil)

    A Card Dispute Chargeback Submitted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to chargeback_submitted. Contains the details specific to a chargeback submitted Visa Card Dispute Network Event, which represents that a chargeback has been submitted to the network.

  • chargeback_timed_out (Increase::Models::CardDispute::Visa::NetworkEvent::ChargebackTimedOut, nil) (defaults to: nil)

    A Card Dispute Chargeback Timed Out Visa Network Event object. This field will be present in the JSON response if and only if category is equal to chargeback_timed_out. Contains the details specific to a chargeback timed out Visa Card Dispute Network Event, which represents that the chargeback has timed out in the user's favor.

  • merchant_prearbitration_decline_submitted (Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationDeclineSubmitted, nil) (defaults to: nil)

    A Card Dispute Merchant Pre-Arbitration Decline Submitted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to merchant_prearbitration_decline_submitted. Contains the details specific to a merchant prearbitration decline submitted Visa Card Dispute Network Event, which represents that the user has declined the merchant's request for a prearbitration request decision in their favor.

  • merchant_prearbitration_received (Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationReceived, nil) (defaults to: nil)

    A Card Dispute Merchant Pre-Arbitration Received Visa Network Event object. This field will be present in the JSON response if and only if category is equal to merchant_prearbitration_received. Contains the details specific to a merchant prearbitration received Visa Card Dispute Network Event, which represents that the merchant has issued a prearbitration request in the user's favor.

  • merchant_prearbitration_timed_out (Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationTimedOut, nil) (defaults to: nil)

    A Card Dispute Merchant Pre-Arbitration Timed Out Visa Network Event object. This field will be present in the JSON response if and only if category is equal to merchant_prearbitration_timed_out. Contains the details specific to a merchant prearbitration timed out Visa Card Dispute Network Event, which represents that the user has timed out responding to the merchant's prearbitration request.

  • represented (Increase::Models::CardDispute::Visa::NetworkEvent::Represented, nil) (defaults to: nil)

    A Card Dispute Re-presented Visa Network Event object. This field will be present in the JSON response if and only if category is equal to represented. Contains the details specific to a re-presented Visa Card Dispute Network Event, which represents that the merchant has declined the user's chargeback and has re-presented the payment.

  • representment_timed_out (Increase::Models::CardDispute::Visa::NetworkEvent::RepresentmentTimedOut, nil) (defaults to: nil)

    A Card Dispute Re-presentment Timed Out Visa Network Event object. This field will be present in the JSON response if and only if category is equal to representment_timed_out. Contains the details specific to a re-presentment time-out Visa Card Dispute Network Event, which represents that the user did not respond to the re-presentment by the merchant within the time limit.

  • user_prearbitration_accepted (Increase::Models::CardDispute::Visa::NetworkEvent::UserPrearbitrationAccepted, nil) (defaults to: nil)

    A Card Dispute User Pre-Arbitration Accepted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to user_prearbitration_accepted. Contains the details specific to a user prearbitration accepted Visa Card Dispute Network Event, which represents that the merchant has accepted the user's prearbitration request in the user's favor.

  • user_prearbitration_declined (Increase::Models::CardDispute::Visa::NetworkEvent::UserPrearbitrationDeclined, nil) (defaults to: nil)

    A Card Dispute User Pre-Arbitration Declined Visa Network Event object. This field will be present in the JSON response if and only if category is equal to user_prearbitration_declined. Contains the details specific to a user prearbitration declined Visa Card Dispute Network Event, which represents that the merchant has declined the user's prearbitration request.

  • user_prearbitration_submitted (Increase::Models::CardDispute::Visa::NetworkEvent::UserPrearbitrationSubmitted, nil) (defaults to: nil)

    A Card Dispute User Pre-Arbitration Submitted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to user_prearbitration_submitted. Contains the details specific to a user prearbitration submitted Visa Card Dispute Network Event, which represents that the user's request for prearbitration has been submitted to the network.

  • user_prearbitration_timed_out (Increase::Models::CardDispute::Visa::NetworkEvent::UserPrearbitrationTimedOut, nil) (defaults to: nil)

    A Card Dispute User Pre-Arbitration Timed Out Visa Network Event object. This field will be present in the JSON response if and only if category is equal to user_prearbitration_timed_out. Contains the details specific to a user prearbitration timed out Visa Card Dispute Network Event, which represents that the merchant has timed out responding to the user's prearbitration request.

  • user_withdrawal_submitted (Increase::Models::CardDispute::Visa::NetworkEvent::UserWithdrawalSubmitted, nil) (defaults to: nil)

    A Card Dispute User Withdrawal Submitted Visa Network Event object. This field will be present in the JSON response if and only if category is equal to user_withdrawal_submitted. Contains the details specific to a user withdrawal submitted Visa Card Dispute Network Event, which represents that the user's request to withdraw the dispute has been submitted to the network.

  • file_id: (String)


634
635
636
637
638
639
640
641
642
643
# File 'lib/increase/models/card_dispute.rb', line 634

class AttachmentFile < Increase::Internal::Type::BaseModel
  # @!attribute file_id
  #   The ID of the file attached to the Card Dispute.
  #
  #   @return [String]
  required :file_id, String

  # @!method initialize(file_id:)
  #   @param file_id [String] The ID of the file attached to the Card Dispute.
end

Instance Attribute Details

#file_idString

The ID of the file attached to the Card Dispute.

Parameters:

  • value (String)

Returns:

  • (String)


639
# File 'lib/increase/models/card_dispute.rb', line 639

required :file_id, String

Instance Method Details

#to_hash{ file_id: String }

Returns:

  • ({ file_id: String })


327
# File 'sig/increase/models/card_dispute.rbs', line 327

def to_hash: -> { file_id: String }