Module: Increase::Models::CardDispute::Visa::NetworkEvent::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

The category of the user submission. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

See Also:

  • Increase::Models::CardDispute::Visa::NetworkEvent#category

Constant Summary collapse

CHARGEBACK_ACCEPTED =

Card Dispute Chargeback Accepted Visa Network Event: details will be under the chargeback_accepted object.

Returns:

  • (:chargeback_accepted)
:chargeback_accepted
CHARGEBACK_SUBMITTED =

Card Dispute Chargeback Submitted Visa Network Event: details will be under the chargeback_submitted object.

Returns:

  • (:chargeback_submitted)
:chargeback_submitted
CHARGEBACK_TIMED_OUT =

Card Dispute Chargeback Timed Out Visa Network Event: details will be under the chargeback_timed_out object.

Returns:

  • (:chargeback_timed_out)
:chargeback_timed_out
MERCHANT_PREARBITRATION_DECLINE_SUBMITTED =

Card Dispute Merchant Pre-Arbitration Decline Submitted Visa Network Event: details will be under the merchant_prearbitration_decline_submitted object.

Returns:

  • (:merchant_prearbitration_decline_submitted)
:merchant_prearbitration_decline_submitted
MERCHANT_PREARBITRATION_RECEIVED =

Card Dispute Merchant Pre-Arbitration Received Visa Network Event: details will be under the merchant_prearbitration_received object.

Returns:

  • (:merchant_prearbitration_received)
:merchant_prearbitration_received
MERCHANT_PREARBITRATION_TIMED_OUT =

Card Dispute Merchant Pre-Arbitration Timed Out Visa Network Event: details will be under the merchant_prearbitration_timed_out object.

Returns:

  • (:merchant_prearbitration_timed_out)
:merchant_prearbitration_timed_out
REPRESENTED =

Card Dispute Re-presented Visa Network Event: details will be under the represented object.

Returns:

  • (:represented)
:represented
REPRESENTMENT_TIMED_OUT =

Card Dispute Re-presentment Timed Out Visa Network Event: details will be under the representment_timed_out object.

Returns:

  • (:representment_timed_out)
:representment_timed_out
USER_PREARBITRATION_ACCEPTED =

Card Dispute User Pre-Arbitration Accepted Visa Network Event: details will be under the user_prearbitration_accepted object.

Returns:

  • (:user_prearbitration_accepted)
:user_prearbitration_accepted
USER_PREARBITRATION_DECLINED =

Card Dispute User Pre-Arbitration Declined Visa Network Event: details will be under the user_prearbitration_declined object.

Returns:

  • (:user_prearbitration_declined)
:user_prearbitration_declined
USER_PREARBITRATION_SUBMITTED =

Card Dispute User Pre-Arbitration Submitted Visa Network Event: details will be under the user_prearbitration_submitted object.

Returns:

  • (:user_prearbitration_submitted)
:user_prearbitration_submitted
USER_PREARBITRATION_TIMED_OUT =

Card Dispute User Pre-Arbitration Timed Out Visa Network Event: details will be under the user_prearbitration_timed_out object.

Returns:

  • (:user_prearbitration_timed_out)
:user_prearbitration_timed_out
USER_WITHDRAWAL_SUBMITTED =

Card Dispute User Withdrawal Submitted Visa Network Event: details will be under the user_withdrawal_submitted object.

Returns:

  • (:user_withdrawal_submitted)
:user_withdrawal_submitted

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardDispute::Visa::NetworkEvent::category]

Returns:

  • (::Array[Increase::Models::CardDispute::Visa::NetworkEvent::category])


387
# File 'sig/increase/models/card_dispute.rbs', line 387

def self?.values: -> ::Array[Increase::Models::CardDispute::Visa::NetworkEvent::category]