Class: Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationReceived::CompellingEvidence

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/card_dispute.rb

Overview

Defined Under Namespace

Modules: Category

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(category:, explanation:) ⇒ Object

Compelling evidence details. Present if and only if ‘reason` is `compelling_evidence`.

Parameters:



# File 'lib/increase/models/card_dispute.rb', line 768

Instance Attribute Details

#categorySymbol, Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationReceived::CompellingEvidence::Category

The category of compelling evidence provided by the merchant.



759
760
# File 'lib/increase/models/card_dispute.rb', line 759

required :category,
enum: -> { Increase::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationReceived::CompellingEvidence::Category }

#explanationString?

Explanation of the compelling evidence provided by the merchant.

Returns:

  • (String, nil)


766
# File 'lib/increase/models/card_dispute.rb', line 766

required :explanation, String, nil?: true