Class: Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationReceived::CreditOrReversalProcessed
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute::Visa::NetworkEvent::MerchantPrearbitrationReceived::CreditOrReversalProcessed
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount of the credit or reversal in the minor unit of its currency.
-
#currency ⇒ String
The ISO 4217 code for the credit or reversal's currency.
-
#explanation ⇒ String?
Explanation for why the merchant believes the credit or reversal was processed.
-
#processed_at ⇒ Date
The date the credit or reversal was processed.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
595 |
# File 'sig/increase/models/card_dispute.rbs', line 595
def initialize: (
|
Instance Attribute Details
#amount ⇒ Integer
The amount of the credit or reversal in the minor unit of its currency. For dollars, for example, this is cents.
880 |
# File 'lib/increase/models/card_dispute.rb', line 880 required :amount, Integer |
#currency ⇒ String
The ISO 4217 code for the credit or reversal's currency.
887 |
# File 'lib/increase/models/card_dispute.rb', line 887 required :currency, String |
#explanation ⇒ String?
Explanation for why the merchant believes the credit or reversal was processed.
893 |
# File 'lib/increase/models/card_dispute.rb', line 893 required :explanation, String, nil?: true |
#processed_at ⇒ Date
The date the credit or reversal was processed.
899 |
# File 'lib/increase/models/card_dispute.rb', line 899 required :processed_at, Date |
Instance Method Details
#to_hash ⇒ {
602 |
# File 'sig/increase/models/card_dispute.rbs', line 602
def to_hash: -> {
|