Class: Increase::Models::CardDispute::Visa::NetworkEvent::Represented::CardholderNoLongerDisputes
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute::Visa::NetworkEvent::Represented::CardholderNoLongerDisputes
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
Instance Attribute Summary collapse
-
#explanation ⇒ String?
Explanation for why the merchant believes the cardholder no longer disputes the transaction.
Instance Method Summary collapse
-
#initialize ⇒ CardholderNoLongerDisputes
constructor
A new instance of CardholderNoLongerDisputes.
- #to_hash ⇒ { explanation: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ CardholderNoLongerDisputes
Returns a new instance of CardholderNoLongerDisputes.
809 |
# File 'sig/increase/models/card_dispute.rbs', line 809
def initialize: (explanation: String?) -> void
|
Instance Attribute Details
#explanation ⇒ String?
Explanation for why the merchant believes the cardholder no longer disputes the transaction.
1194 |
# File 'lib/increase/models/card_dispute.rb', line 1194 required :explanation, String, nil?: true |
Instance Method Details
#to_hash ⇒ { explanation: String? }
811 |
# File 'sig/increase/models/card_dispute.rbs', line 811
def to_hash: -> { explanation: String? }
|