Module: Increase::Models::CardDispute::Visa::NetworkEvent::Represented::InvalidDispute::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

The reason a merchant considers the dispute invalid.

See Also:

  • Increase::Models::CardDispute::Visa::NetworkEvent::Represented::InvalidDispute#reason

Constant Summary collapse

AUTOMATIC_TELLER_MACHINE_TRANSACTION_PROOF_PROVIDED =

Automatic Teller Machine (ATM) transaction proof provided.

Returns:

  • (:automatic_teller_machine_transaction_proof_provided)
:automatic_teller_machine_transaction_proof_provided
BALANCE_OF_PARTIAL_PREPAYMENT_NOT_PAID =

Balance of partial prepayment not paid.

Returns:

  • (:balance_of_partial_prepayment_not_paid)
:balance_of_partial_prepayment_not_paid
CARDHOLDER_CANCELED_BEFORE_EXPECTED_MERCHANDISE_RECEIPT_DATE =

Cardholder canceled before expected receipt date of the merchandise.

Returns:

  • (:cardholder_canceled_before_expected_merchandise_receipt_date)
:cardholder_canceled_before_expected_merchandise_receipt_date
CARDHOLDER_CANCELED_BEFORE_EXPECTED_SERVICES_RECEIPT_DATE =

Cardholder canceled before expected receipt date of the services.

Returns:

  • (:cardholder_canceled_before_expected_services_receipt_date)
:cardholder_canceled_before_expected_services_receipt_date
CARDHOLDER_CANCELED_DIFFERENT_DATE =

Cardholder canceled on a different date than claimed.

Returns:

  • (:cardholder_canceled_different_date)
:cardholder_canceled_different_date
CARDHOLDER_DID_NOT_CANCEL_ACCORDING_TO_POLICY =

Cardholder received did not cancel according to policy.

Returns:

  • (:cardholder_did_not_cancel_according_to_policy)
:cardholder_did_not_cancel_according_to_policy
CARDHOLDER_RECEIVED_MERCHANDISE =

Cardholder received the merchandise.

Returns:

  • (:cardholder_received_merchandise)
:cardholder_received_merchandise
COUNTRY_CODE_CORRECT =

Country code is correct.

Returns:

  • (:country_code_correct)
:country_code_correct
CREDIT_PROCESSED_CORRECTLY =

Credit was processed correctly.

Returns:

  • (:credit_processed_correctly)
:credit_processed_correctly
CURRENCY_CORRECT =

Currency is correct.

Returns:

  • (:currency_correct)
:currency_correct
DISPUTE_IS_FOR_QUALITY =

Dispute is for quality.

Returns:

  • (:dispute_is_for_quality)
:dispute_is_for_quality
DISPUTE_IS_FOR_VISA_CASH_BACK_TRANSACTION_PORTION =

Dispute is for Visa Cash Back transaction portion.

Returns:

  • (:dispute_is_for_visa_cash_back_transaction_portion)
:dispute_is_for_visa_cash_back_transaction_portion
DISPUTED_AMOUNT_IS_VALUE_ADDED_TAX =

Disputed amount is Value Added Tax (VAT).

Returns:

  • (:disputed_amount_is_value_added_tax)
:disputed_amount_is_value_added_tax
DISPUTED_AMOUNT_IS_VALUE_ADDED_TAX_NO_CREDIT_RECEIPT_PROVIDED =

Disputed amount is Value Added Tax (VAT) but no credit receipt was provided by the cardholder.

Returns:

  • (:disputed_amount_is_value_added_tax_no_credit_receipt_provided)
:disputed_amount_is_value_added_tax_no_credit_receipt_provided
LIMITED_RETURN_OR_CANCELLATION_POLICY_PROPERLY_DISCLOSED =

Limited return or cancellation policy was properly disclosed.

Returns:

  • (:limited_return_or_cancellation_policy_properly_disclosed)
:limited_return_or_cancellation_policy_properly_disclosed
MERCHANDISE_HELD_AT_CARDHOLDER_CUSTOMS_AGENCY =

Merchandise held at cardholder customs agency.

Returns:

  • (:merchandise_held_at_cardholder_customs_agency)
:merchandise_held_at_cardholder_customs_agency
MERCHANDISE_MATCHES_DESCRIPTION =

Merchandise matches the merchant's description.

Returns:

  • (:merchandise_matches_description)
:merchandise_matches_description
MERCHANDISE_NOT_COUNTERFEIT =

Merchandise is not counterfeit.

Returns:

  • (:merchandise_not_counterfeit)
:merchandise_not_counterfeit
MERCHANDISE_NOT_DAMAGED =

Merchandise is not damaged.

Returns:

  • (:merchandise_not_damaged)
:merchandise_not_damaged
MERCHANDISE_NOT_DEFECTIVE =

Merchandise is not defective.

Returns:

  • (:merchandise_not_defective)
:merchandise_not_defective
MERCHANDISE_PROVIDED_PRIOR_TO_CANCELLATION_DATE =

Merchandise was provided prior to the cancellation date.

Returns:

  • (:merchandise_provided_prior_to_cancellation_date)
:merchandise_provided_prior_to_cancellation_date
MERCHANDISE_QUALITY_MATCHES_DESCRIPTION =

Merchandise quality matches the merchant's description.

Returns:

  • (:merchandise_quality_matches_description)
:merchandise_quality_matches_description
MERCHANDISE_RETURN_NOT_ATTEMPTED =

Merchandise was not attempted returned to the merchant.

Returns:

  • (:merchandise_return_not_attempted)
:merchandise_return_not_attempted
MERCHANT_NOT_NOTIFIED_OF_CLOSED_ACCOUNT =

Merchant was not notified of the closed account.

Returns:

  • (:merchant_not_notified_of_closed_account)
:merchant_not_notified_of_closed_account
NAME_ON_FLIGHT_MANIFEST_MATCHES_PURCHASE =

Name on manifest of departed flight matches name on purchased itinerary.

Returns:

  • (:name_on_flight_manifest_matches_purchase)
:name_on_flight_manifest_matches_purchase
NO_CREDIT_RECEIPT_PROVIDED =

No credit receipt was provided by the cardholder.

Returns:

  • (:no_credit_receipt_provided)
:no_credit_receipt_provided
OTHER =

Other.

Returns:

  • (:other)
:other
PROCESSING_ERROR_INCORRECT =

The claimed processing error did not occur.

Returns:

  • (:processing_error_incorrect)
:processing_error_incorrect
RETURNED_MECHANDISE_HELD_AT_CUSTOMS_AGENCY_OUTSIDE_MERCHANT_COUNTRY =

Returned merchandise held at customs agency outside the merchant's country.

Returns:

  • (:returned_mechandise_held_at_customs_agency_outside_merchant_country)
:returned_mechandise_held_at_customs_agency_outside_merchant_country
SERVICES_MATCH_DESCRIPTION =

Services match the merchant's description.

Returns:

  • (:services_match_description)
:services_match_description
SERVICES_PROVIDED_PRIOR_TO_CANCELLATION_DATE =

Services were provided prior to the cancellation date.

Returns:

  • (:services_provided_prior_to_cancellation_date)
:services_provided_prior_to_cancellation_date
SERVICES_USED_AFTER_CANCELLATION_DATE =

Services were used after the cancellation date and prior to the dispute submission date.

Returns:

  • (:services_used_after_cancellation_date)
:services_used_after_cancellation_date
TERMS_OF_SERVICE_NOT_MISREPRESENTED =

Terms of service were not misrepresented.

Returns:

  • (:terms_of_service_not_misrepresented)
:terms_of_service_not_misrepresented
TRANSACTION_CODE_CORRECT =

Transaction code is correct.

Returns:

  • (:transaction_code_correct)
:transaction_code_correct

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardDispute::Visa::NetworkEvent::Represented::InvalidDispute::reason]

Returns:

  • (::Array[Increase::Models::CardDispute::Visa::NetworkEvent::Represented::InvalidDispute::reason])


1008
# File 'sig/increase/models/card_dispute.rbs', line 1008

def self?.values: -> ::Array[Increase::Models::CardDispute::Visa::NetworkEvent::Represented::InvalidDispute::reason]