Class: Increase::Models::CardDispute::Visa::NetworkEvent::Represented::ProofOfCashDisbursement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute::Visa::NetworkEvent::Represented::ProofOfCashDisbursement
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
Instance Attribute Summary collapse
-
#explanation ⇒ String?
Explanation for why the merchant believes the evidence provides proof of cash disbursement.
Instance Method Summary collapse
-
#initialize ⇒ ProofOfCashDisbursement
constructor
A new instance of ProofOfCashDisbursement.
- #to_hash ⇒ { explanation: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ProofOfCashDisbursement
Returns a new instance of ProofOfCashDisbursement.
1052 |
# File 'sig/increase/models/card_dispute.rbs', line 1052
def initialize: (explanation: String?) -> void
|
Instance Attribute Details
#explanation ⇒ String?
Explanation for why the merchant believes the evidence provides proof of cash disbursement.
1438 |
# File 'lib/increase/models/card_dispute.rb', line 1438 required :explanation, String, nil?: true |
Instance Method Details
#to_hash ⇒ { explanation: String? }
1054 |
# File 'sig/increase/models/card_dispute.rbs', line 1054
def to_hash: -> { explanation: String? }
|