Module: Increase::Models::CardDispute::Visa::RequiredUserSubmissionCategory
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
The category of the currently required user submission if the user wishes to
proceed with the dispute. Present if and only if status is
user_submission_required. Otherwise, this will be nil.
Constant Summary collapse
- CHARGEBACK =
A Chargeback User Submission is required.
:chargeback- MERCHANT_PREARBITRATION_DECLINE =
A Merchant Pre Arbitration Decline User Submission is required.
:merchant_prearbitration_decline- USER_PREARBITRATION =
A User Initiated Pre Arbitration User Submission is required.
:user_prearbitration
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardDispute::Visa::required_user_submission_category]
1168 |
# File 'sig/increase/models/card_dispute.rbs', line 1168
def self?.values: -> ::Array[Increase::Models::CardDispute::Visa::required_user_submission_category]
|