Class: Increase::Models::CardDispute::Visa::UserSubmission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute::Visa::UserSubmission
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Defined Under Namespace
Modules: Category, Status Classes: AttachmentFile, Chargeback, MerchantPrearbitrationDecline, UserPrearbitration
Instance Attribute Summary collapse
-
#accepted_at ⇒ Time?
The date and time at which the Visa Card Dispute User Submission was reviewed and accepted.
-
#amount ⇒ Integer?
The amount of the dispute if it is different from the amount of a prior user submission or the disputed transaction.
-
#attachment_files ⇒ Array<Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile>
The files attached to the Visa Card Dispute User Submission.
-
#category ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Category
The category of the user submission.
-
#chargeback ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback?
A Visa Card Dispute Chargeback User Submission Chargeback Details object.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was created.
-
#explanation ⇒ String?
The free-form explanation provided to Increase to provide more context for the user submission.
-
#further_information_requested_at ⇒ Time?
The date and time at which Increase requested further information from the user for the Visa Card Dispute.
-
#further_information_requested_reason ⇒ String?
The reason for Increase requesting further information from the user for the Visa Card Dispute.
-
#merchant_prearbitration_decline ⇒ Increase::Models::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline?
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
-
#status ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Status
The status of the Visa Card Dispute User Submission.
-
#updated_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was updated.
-
#user_prearbitration ⇒ Increase::Models::CardDispute::Visa::UserSubmission::UserPrearbitration?
A Visa Card Dispute User-Initiated Pre-Arbitration User Submission object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(reason:) ⇒ Object
constructor
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reason:) ⇒ Object
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
This field will be present in the JSON response if and only if category is
equal to merchant_prearbitration_decline. Contains the details specific to a
merchant prearbitration decline Visa Card Dispute User Submission.
|
|
# File 'lib/increase/models/card_dispute.rb', line 1865
|
Instance Attribute Details
#accepted_at ⇒ Time?
The date and time at which the Visa Card Dispute User Submission was reviewed and accepted.
1704 |
# File 'lib/increase/models/card_dispute.rb', line 1704 required :accepted_at, Time, nil?: true |
#amount ⇒ Integer?
The amount of the dispute if it is different from the amount of a prior user submission or the disputed transaction.
1711 |
# File 'lib/increase/models/card_dispute.rb', line 1711 required :amount, Integer, nil?: true |
#attachment_files ⇒ Array<Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile>
The files attached to the Visa Card Dispute User Submission.
1717 1718 |
# File 'lib/increase/models/card_dispute.rb', line 1717 required :attachment_files, -> { Increase::Internal::Type::ArrayOf[Increase::CardDispute::Visa::UserSubmission::AttachmentFile] } |
#category ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Category
The category of the user submission. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
1726 |
# File 'lib/increase/models/card_dispute.rb', line 1726 required :category, enum: -> { Increase::CardDispute::Visa::UserSubmission::Category } |
#chargeback ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback?
A Visa Card Dispute Chargeback User Submission Chargeback Details object. This
field will be present in the JSON response if and only if category is equal to
chargeback. Contains the details specific to a Visa chargeback User Submission
for a Card Dispute.
1776 |
# File 'lib/increase/models/card_dispute.rb', line 1776 optional :chargeback, -> { Increase::CardDispute::Visa::UserSubmission::Chargeback }, nil?: true |
#created_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was created.
1733 |
# File 'lib/increase/models/card_dispute.rb', line 1733 required :created_at, Time |
#explanation ⇒ String?
The free-form explanation provided to Increase to provide more context for the user submission. This field is not sent directly to the card networks.
1740 |
# File 'lib/increase/models/card_dispute.rb', line 1740 required :explanation, String, nil?: true |
#further_information_requested_at ⇒ Time?
The date and time at which Increase requested further information from the user for the Visa Card Dispute.
1747 |
# File 'lib/increase/models/card_dispute.rb', line 1747 required :further_information_requested_at, Time, nil?: true |
#further_information_requested_reason ⇒ String?
The reason for Increase requesting further information from the user for the Visa Card Dispute.
1754 |
# File 'lib/increase/models/card_dispute.rb', line 1754 required :further_information_requested_reason, String, nil?: true |
#merchant_prearbitration_decline ⇒ Increase::Models::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline?
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
This field will be present in the JSON response if and only if category is
equal to merchant_prearbitration_decline. Contains the details specific to a
merchant prearbitration decline Visa Card Dispute User Submission.
1785 1786 1787 |
# File 'lib/increase/models/card_dispute.rb', line 1785 optional :merchant_prearbitration_decline, -> { Increase::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline }, nil?: true |
#status ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Status
The status of the Visa Card Dispute User Submission.
1760 |
# File 'lib/increase/models/card_dispute.rb', line 1760 required :status, enum: -> { Increase::CardDispute::Visa::UserSubmission::Status } |
#updated_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was updated.
1767 |
# File 'lib/increase/models/card_dispute.rb', line 1767 required :updated_at, Time |
#user_prearbitration ⇒ Increase::Models::CardDispute::Visa::UserSubmission::UserPrearbitration?
A Visa Card Dispute User-Initiated Pre-Arbitration User Submission object. This
field will be present in the JSON response if and only if category is equal to
user_prearbitration. Contains the details specific to a user-initiated
pre-arbitration Visa Card Dispute User Submission.
1796 1797 1798 |
# File 'lib/increase/models/card_dispute.rb', line 1796 optional :user_prearbitration, -> { Increase::CardDispute::Visa::UserSubmission::UserPrearbitration }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute.rb', line 1886
|
Instance Method Details
#to_hash ⇒ {
1236 |
# File 'sig/increase/models/card_dispute.rbs', line 1236 def to_hash: -> { |