Class: Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accepted_at:, amount:, attachment_files:, category:, created_at:, explanation:, further_information_requested_at:, further_information_requested_reason:, status:, updated_at:, chargeback: nil, merchant_prearbitration_decline: nil, user_prearbitration: nil) ⇒ AttachmentFile

Returns a new instance of AttachmentFile.

Parameters:

  • accepted_at (Time, nil)

    The date and time at which the Visa Card Dispute User Submission was reviewed and accepted.

  • amount (Integer, nil)

    The amount of the dispute if it is different from the amount of a prior user submission or the disputed transaction.

  • attachment_files (Array<Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile>)

    The files attached to the Visa Card Dispute User Submission.

  • category (Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Category)

    The category of the user submission. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

  • created_at (Time)

    The ISO 8601 date and time at which the Visa Card Dispute User Submission was created.

  • explanation (String, nil)

    The free-form explanation provided to Increase to provide more context for the user submission. This field is not sent directly to the card networks.

  • further_information_requested_at (Time, nil)

    The date and time at which Increase requested further information from the user for the Visa Card Dispute.

  • further_information_requested_reason (String, nil)

    The reason for Increase requesting further information from the user for the Visa Card Dispute.

  • status (Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Status)

    The status of the Visa Card Dispute User Submission.

  • updated_at (Time)

    The ISO 8601 date and time at which the Visa Card Dispute User Submission was updated.

  • chargeback (Increase::Models::CardDispute::Visa::UserSubmission::Chargeback, nil) (defaults to: nil)

    A Visa Card Dispute Chargeback User Submission Chargeback Details object. This field will be present in the JSON response if and only if category is equal to chargeback. Contains the details specific to a Visa chargeback User Submission for a Card Dispute.

  • merchant_prearbitration_decline (Increase::Models::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline, nil) (defaults to: nil)

    A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object. This field will be present in the JSON response if and only if category is equal to merchant_prearbitration_decline. Contains the details specific to a merchant prearbitration decline Visa Card Dispute User Submission.

  • user_prearbitration (Increase::Models::CardDispute::Visa::UserSubmission::UserPrearbitration, nil) (defaults to: nil)

    A Visa Card Dispute User-Initiated Pre-Arbitration User Submission object. This field will be present in the JSON response if and only if category is equal to user_prearbitration. Contains the details specific to a user-initiated pre-arbitration Visa Card Dispute User Submission.

  • file_id: (String)


1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
# File 'lib/increase/models/card_dispute.rb', line 1850

class AttachmentFile < Increase::Internal::Type::BaseModel
  # @!attribute file_id
  #   The ID of the file attached to the Card Dispute.
  #
  #   @return [String]
  required :file_id, String

  # @!method initialize(file_id:)
  #   @param file_id [String] The ID of the file attached to the Card Dispute.
end

Instance Attribute Details

#file_idString

The ID of the file attached to the Card Dispute.

Parameters:

  • value (String)

Returns:

  • (String)


1855
# File 'lib/increase/models/card_dispute.rb', line 1855

required :file_id, String

Instance Method Details

#to_hash{ file_id: String }

Returns:

  • ({ file_id: String })


1254
# File 'sig/increase/models/card_dispute.rbs', line 1254

def to_hash: -> { file_id: String }