Module: Increase::Models::CardDispute::Visa::UserSubmission::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

The category of the user submission. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

See Also:

  • Increase::Models::CardDispute::Visa::UserSubmission#category

Constant Summary collapse

CHARGEBACK =

Visa Card Dispute Chargeback User Submission Chargeback Details: details will be under the chargeback object.

Returns:

  • (:chargeback)
:chargeback
MERCHANT_PREARBITRATION_DECLINE =

Visa Card Dispute Merchant Pre-Arbitration Decline User Submission: details will be under the merchant_prearbitration_decline object.

Returns:

  • (:merchant_prearbitration_decline)
:merchant_prearbitration_decline
USER_PREARBITRATION =

Visa Card Dispute User-Initiated Pre-Arbitration User Submission: details will be under the user_prearbitration object.

Returns:

  • (:user_prearbitration)
:user_prearbitration

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardDispute::Visa::UserSubmission::category]

Returns:

  • (::Array[Increase::Models::CardDispute::Visa::UserSubmission::category])


1274
# File 'sig/increase/models/card_dispute.rbs', line 1274

def self?.values: -> ::Array[Increase::Models::CardDispute::Visa::UserSubmission::category]