Class: Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
Defined Under Namespace
Modules: CardholderPaidToHaveWorkRedone, NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription, RestaurantFoodRelated Classes: CardholderCancellation, OngoingNegotiations
Instance Attribute Summary collapse
-
#cardholder_cancellation ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::CardholderCancellation
Cardholder cancellation.
-
#cardholder_paid_to_have_work_redone ⇒ Symbol, ...
Cardholder paid to have work redone.
-
#non_fiat_currency_or_non_fungible_token_related_and_not_matching_description ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription
Non-fiat currency or non-fungible token related and not matching description.
-
#ongoing_negotiations ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::OngoingNegotiations?
Ongoing negotiations.
-
#purchase_info_and_quality_issue ⇒ String
Purchase information and quality issue.
-
#restaurant_food_related ⇒ Symbol, ...
Whether the dispute is related to the quality of food from an eating place or restaurant.
-
#services_received_at ⇒ Date
Services received at.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(explanation:, issuer_first_notified_at:, started_at:) ⇒ Object
constructor
Ongoing negotiations.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(explanation:, issuer_first_notified_at:, started_at:) ⇒ Object
Ongoing negotiations. Exclude if there is no evidence of ongoing negotiations.
|
|
# File 'lib/increase/models/card_dispute.rb', line 4613
|
Instance Attribute Details
#cardholder_cancellation ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::CardholderCancellation
Cardholder cancellation.
4559 4560 |
# File 'lib/increase/models/card_dispute.rb', line 4559 required :cardholder_cancellation, -> { Increase::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::CardholderCancellation } |
#cardholder_paid_to_have_work_redone ⇒ Symbol, ...
Cardholder paid to have work redone.
4566 4567 4568 4569 4570 |
# File 'lib/increase/models/card_dispute.rb', line 4566 required :cardholder_paid_to_have_work_redone, enum: -> { Increase::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::CardholderPaidToHaveWorkRedone }, nil?: true |
#non_fiat_currency_or_non_fungible_token_related_and_not_matching_description ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription
Non-fiat currency or non-fungible token related and not matching description.
4576 4577 |
# File 'lib/increase/models/card_dispute.rb', line 4576 required :non_fiat_currency_or_non_fungible_token_related_and_not_matching_description, enum: -> { Increase::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices:: } |
#ongoing_negotiations ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::OngoingNegotiations?
Ongoing negotiations. Exclude if there is no evidence of ongoing negotiations.
4583 4584 4585 4586 4587 |
# File 'lib/increase/models/card_dispute.rb', line 4583 required :ongoing_negotiations, -> { Increase::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices::OngoingNegotiations }, nil?: true |
#purchase_info_and_quality_issue ⇒ String
Purchase information and quality issue.
4593 |
# File 'lib/increase/models/card_dispute.rb', line 4593 required :purchase_info_and_quality_issue, String |
#restaurant_food_related ⇒ Symbol, ...
Whether the dispute is related to the quality of food from an eating place or restaurant. Must be provided when Merchant Category Code (MCC) is 5812, 5813 or 5814.
4601 4602 4603 4604 4605 |
# File 'lib/increase/models/card_dispute.rb', line 4601 required :restaurant_food_related, enum: -> { Increase::CardDispute::Visa::UserSubmission::Chargeback::ConsumerQualityServices:: }, nil?: true |
#services_received_at ⇒ Date
Services received at.
4611 |
# File 'lib/increase/models/card_dispute.rb', line 4611 required :services_received_at, Date |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute.rb', line 4681
|
Instance Method Details
#to_hash ⇒ {
3349 |
# File 'sig/increase/models/card_dispute.rbs', line 3349 def to_hash: -> { |