Module: Increase::Models::CardDispute::Visa::UserSubmission::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
The status of the Visa Card Dispute User Submission.
Constant Summary collapse
- ABANDONED =
The User Submission was abandoned.
:abandoned- ACCEPTED =
The User Submission was accepted.
:accepted- FURTHER_INFORMATION_REQUESTED =
Further information is requested, please resubmit with the requested information.
:further_information_requested- PENDING_REVIEWING =
The User Submission is pending review.
:pending_reviewing
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardDispute::Visa::UserSubmission::status]
1298 |
# File 'sig/increase/models/card_dispute.rbs', line 1298
def self?.values: -> ::Array[Increase::Models::CardDispute::Visa::UserSubmission::status]
|