Class: Increase::Models::CardDispute::Withdrawal

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(explanation:) ⇒ Object

If the Card Dispute has been withdrawn, this will contain details of the withdrawal.

Parameters:

  • explanation (String, nil)

    The explanation for the withdrawal of the Card Dispute.



# File 'lib/increase/models/card_dispute.rb', line 5302

Instance Attribute Details

#explanationString?

The explanation for the withdrawal of the Card Dispute.

Returns:

  • (String, nil)


5300
# File 'lib/increase/models/card_dispute.rb', line 5300

required :explanation, String, nil?: true