Class: Increase::Models::CardDisputeCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDisputeCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/card_dispute_create_params.rb
Overview
Defined Under Namespace
Modules: Network Classes: AttachmentFile, Visa
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The monetary amount of the part of the transaction that is being disputed.
-
#attachment_files ⇒ Array<Increase::Models::CardDisputeCreateParams::AttachmentFile>?
The files to be attached to the initial dispute submission.
-
#disputed_transaction_id ⇒ String
The Transaction you wish to dispute.
-
#explanation ⇒ String?
The free-form explanation provided to Increase to provide more context for the user submission.
-
#network ⇒ Symbol, Increase::Models::CardDisputeCreateParams::Network
The network of the disputed transaction.
-
#visa ⇒ Increase::Models::CardDisputeCreateParams::Visa?
The Visa-specific parameters for the dispute.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(file_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AttachmentFile for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_id:) ⇒ Object
Some parameter documentations has been truncated, see AttachmentFile for more details.
|
|
# File 'lib/increase/models/card_dispute_create_params.rb', line 54
|
Instance Attribute Details
#amount ⇒ Integer?
The monetary amount of the part of the transaction that is being disputed. This is optional and will default to the full amount of the transaction if not provided. If provided, the amount must be less than or equal to the amount of the transaction.
31 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 31 optional :amount, Integer |
#attachment_files ⇒ Array<Increase::Models::CardDisputeCreateParams::AttachmentFile>?
The files to be attached to the initial dispute submission.
37 38 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 37 optional :attachment_files, -> { Increase::Internal::Type::ArrayOf[Increase::CardDisputeCreateParams::AttachmentFile] } |
#disputed_transaction_id ⇒ String
The Transaction you wish to dispute. This Transaction must have a ‘source_type` of `card_settlement`.
15 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 15 required :disputed_transaction_id, String |
#explanation ⇒ String?
The free-form explanation provided to Increase to provide more context for the user submission. This field is not sent directly to the card networks.
45 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 45 optional :explanation, String |
#network ⇒ Symbol, Increase::Models::CardDisputeCreateParams::Network
The network of the disputed transaction. Details specific to the network are required under the sub-object with the same identifier as the network.
22 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 22 required :network, enum: -> { Increase::CardDisputeCreateParams::Network } |
#visa ⇒ Increase::Models::CardDisputeCreateParams::Visa?
The Visa-specific parameters for the dispute. Required if and only if ‘network` is `visa`.
52 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 52 optional :visa, -> { Increase::CardDisputeCreateParams::Visa } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute_create_params.rb', line 80
|