Class: Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityMerchandise::OngoingNegotiations

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/card_dispute_create_params.rb,
sig/increase/models/card_dispute_create_params.rbs

Overview

See Also:

  • Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityMerchandise#ongoing_negotiations

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



2149
# File 'sig/increase/models/card_dispute_create_params.rbs', line 2149

def initialize: (

Instance Attribute Details

#explanationString

Explanation of the previous ongoing negotiations between the cardholder and merchant.

Parameters:

  • value (String)

Returns:

  • (String)


2377
# File 'lib/increase/models/card_dispute_create_params.rb', line 2377

required :explanation, String

#issuer_first_notified_atDate

Date the cardholder first notified the issuer of the dispute.

Parameters:

  • value (Date)

Returns:

  • (Date)


2383
# File 'lib/increase/models/card_dispute_create_params.rb', line 2383

required :issuer_first_notified_at, Date

#started_atDate

Started at.

Parameters:

  • value (Date)

Returns:

  • (Date)


2389
# File 'lib/increase/models/card_dispute_create_params.rb', line 2389

required :started_at, Date

Instance Method Details

#to_hash{

Returns:

  • ({)


2155
# File 'sig/increase/models/card_dispute_create_params.rbs', line 2155

def to_hash: -> {