Class: Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices
- Defined in:
- lib/increase/models/card_dispute_create_params.rb,
sig/increase/models/card_dispute_create_params.rbs
Overview
Defined Under Namespace
Modules: CardholderPaidToHaveWorkRedone, NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription, RestaurantFoodRelated Classes: CardholderCancellation, OngoingNegotiations
Instance Attribute Summary collapse
-
#cardholder_cancellation ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderCancellation
Cardholder cancellation.
-
#cardholder_paid_to_have_work_redone ⇒ Symbol, ...
Cardholder paid to have work redone.
-
#non_fiat_currency_or_non_fungible_token_related_and_not_matching_description ⇒ Symbol, Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription
Non-fiat currency or non-fungible token related and not matching description.
-
#ongoing_negotiations ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::OngoingNegotiations?
Ongoing negotiations.
-
#purchase_info_and_quality_issue ⇒ String
Purchase information and quality issue.
-
#restaurant_food_related ⇒ Symbol, ...
Whether the dispute is related to the quality of food from an eating place or restaurant.
-
#services_received_at ⇒ Date
Services received at.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(explanation:, issuer_first_notified_at:, started_at:) ⇒ Object
constructor
Ongoing negotiations.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(explanation:, issuer_first_notified_at:, started_at:) ⇒ Object
Ongoing negotiations. Exclude if there is no evidence of ongoing negotiations.
|
|
# File 'lib/increase/models/card_dispute_create_params.rb', line 2677
|
Instance Attribute Details
#cardholder_cancellation ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderCancellation
Cardholder cancellation.
2632 2633 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2632 required :cardholder_cancellation, -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderCancellation } |
#cardholder_paid_to_have_work_redone ⇒ Symbol, ...
Cardholder paid to have work redone.
2658 2659 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2658 optional :cardholder_paid_to_have_work_redone, enum: -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderPaidToHaveWorkRedone } |
#non_fiat_currency_or_non_fungible_token_related_and_not_matching_description ⇒ Symbol, Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription
Non-fiat currency or non-fungible token related and not matching description.
2639 2640 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2639 required :non_fiat_currency_or_non_fungible_token_related_and_not_matching_description, enum: -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription } |
#ongoing_negotiations ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::OngoingNegotiations?
Ongoing negotiations. Exclude if there is no evidence of ongoing negotiations.
2665 2666 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2665 optional :ongoing_negotiations, -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::OngoingNegotiations } |
#purchase_info_and_quality_issue ⇒ String
Purchase information and quality issue.
2646 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2646 required :purchase_info_and_quality_issue, String |
#restaurant_food_related ⇒ Symbol, ...
Whether the dispute is related to the quality of food from an eating place or restaurant. Must be provided when Merchant Category Code (MCC) is 5812, 5813 or 5814.
2674 2675 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2674 optional :restaurant_food_related, enum: -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::RestaurantFoodRelated } |
#services_received_at ⇒ Date
Services received at.
2652 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2652 required :services_received_at, Date |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute_create_params.rb', line 2745
|
Instance Method Details
#to_hash ⇒ {
2341 |
# File 'sig/increase/models/card_dispute_create_params.rbs', line 2341
def to_hash: -> {
|