Class: Increase::Models::CardDisputeSubmitUserSubmissionParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/card_dispute_submit_user_submission_params.rb

Overview

Defined Under Namespace

Modules: Network Classes: AttachmentFile, Visa

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_id:) ⇒ Object

Some parameter documentations has been truncated, see AttachmentFile for more details.

Parameters:

  • file_id (String)

    The ID of the file to be attached. The file must have a ‘purpose` of `card_dispu



# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 53

Instance Attribute Details

#amountInteger?

The adjusted monetary amount of the part of the transaction that is being disputed. This is optional and will default to the most recent amount provided. If provided, the amount must be less than or equal to the amount of the transaction.

Returns:

  • (Integer, nil)


30
# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 30

optional :amount, Integer

#attachment_filesArray<Increase::Models::CardDisputeSubmitUserSubmissionParams::AttachmentFile>?

The files to be attached to the user submission.



36
37
# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 36

optional :attachment_files,
-> { Increase::Internal::Type::ArrayOf[Increase::CardDisputeSubmitUserSubmissionParams::AttachmentFile] }

#card_dispute_idString

The identifier of the Card Dispute to submit a user submission for.

Returns:

  • (String)


14
# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 14

required :card_dispute_id, String

#explanationString?

The free-form explanation provided to Increase to provide more context for the user submission. This field is not sent directly to the card networks.

Returns:

  • (String, nil)


44
# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 44

optional :explanation, String

#networkSymbol, Increase::Models::CardDisputeSubmitUserSubmissionParams::Network

The network of the Card Dispute. Details specific to the network are required under the sub-object with the same identifier as the network.



21
# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 21

required :network, enum: -> { Increase::CardDisputeSubmitUserSubmissionParams::Network }

#visaIncrease::Models::CardDisputeSubmitUserSubmissionParams::Visa?

The Visa-specific parameters for the dispute. Required if and only if ‘network` is `visa`.



51
# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 51

optional :visa, -> { Increase::CardDisputeSubmitUserSubmissionParams::Visa }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_dispute_submit_user_submission_params.rb', line 79