Class: Increase::Models::CardPayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

Defined Under Namespace

Modules: Type Classes: Element, State

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorized_amount:, fuel_confirmed_amount:, incremented_amount:, refund_authorized_amount:, refunded_amount:, reversed_amount:, settled_amount:) ⇒ Object

Some parameter documentations has been truncated, see State for more details.

The summarized state of this card payment.

Parameters:

  • authorized_amount (Integer)

    The total authorized amount in the minor unit of the transaction’s currency. For

  • fuel_confirmed_amount (Integer)

    The total amount from fuel confirmations in the minor unit of the transaction’s

  • incremented_amount (Integer)

    The total incrementally updated authorized amount in the minor unit of the trans

  • refund_authorized_amount (Integer)

    The total refund authorized amount in the minor unit of the transaction’s curren

  • refunded_amount (Integer)

    The total refunded amount in the minor unit of the transaction’s currency. For d

  • reversed_amount (Integer)

    The total reversed amount in the minor unit of the transaction’s currency. For d

  • settled_amount (Integer)

    The total settled amount in the minor unit of the transaction’s currency. For do



# File 'lib/increase/models/card_payment.rb', line 13258

Instance Attribute Details

#account_idString

The identifier for the Account the Transaction belongs to.

Returns:

  • (String)


17
# File 'lib/increase/models/card_payment.rb', line 17

required :account_id, String

#card_idString

The Card identifier for this payment.

Returns:

  • (String)


23
# File 'lib/increase/models/card_payment.rb', line 23

required :card_id, String

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Card Payment was created.

Returns:

  • (Time)


30
# File 'lib/increase/models/card_payment.rb', line 30

required :created_at, Time

#digital_wallet_token_idString?

The Digital Wallet Token identifier for this payment.

Returns:

  • (String, nil)


36
# File 'lib/increase/models/card_payment.rb', line 36

required :digital_wallet_token_id, String, nil?: true

#elementsArray<Increase::Models::CardPayment::Element>

The interactions related to this card payment.



42
# File 'lib/increase/models/card_payment.rb', line 42

required :elements, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element] }

#idString

The Card Payment identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/card_payment.rb', line 11

required :id, String

#physical_card_idString?

The Physical Card identifier for this payment.

Returns:

  • (String, nil)


48
# File 'lib/increase/models/card_payment.rb', line 48

required :physical_card_id, String, nil?: true

#stateIncrease::Models::CardPayment::State

The summarized state of this card payment.



54
# File 'lib/increase/models/card_payment.rb', line 54

required :state, -> { Increase::CardPayment::State }

#typeSymbol, Increase::Models::CardPayment::Type

A constant representing the object’s type. For this resource it will always be ‘card_payment`.



61
# File 'lib/increase/models/card_payment.rb', line 61

required :type, enum: -> { Increase::CardPayment::Type }