Class: Increase::Models::CardPayment::Element::CardAuthentication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_authentication

Defined Under Namespace

Modules: DenyReason, RequestorAuthenticationIndicator, RequestorChallengeIndicator, Status, Type Classes: Challenge, DeviceChannel, MessageCategory

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, access_control_server_transaction_identifier:, billing_address_city:, billing_address_country:, billing_address_line1:, billing_address_line2:, billing_address_line3:, billing_address_postal_code:, billing_address_state:, card_id:, card_payment_id:, cardholder_email:, cardholder_name:, challenge:, created_at:, deny_reason:, device_channel:, directory_server_transaction_identifier:, merchant_acceptor_id:, merchant_category_code:, merchant_country:, merchant_name:, message_category:, prior_authenticated_card_payment_id:, real_time_decision_id:, requestor_authentication_indicator:, requestor_challenge_indicator:, requestor_name:, requestor_url:, shipping_address_city:, shipping_address_country:, shipping_address_line1:, shipping_address_line2:, shipping_address_line3:, shipping_address_postal_code:, shipping_address_state:, status:, three_d_secure_server_transaction_identifier:, type:) ⇒ Object

A Card Authentication object. This field will be present in the JSON response if and only if category is equal to card_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.



# File 'lib/increase/models/card_payment.rb', line 626


Instance Attribute Details

#access_control_server_transaction_identifierString

A unique identifier assigned by the Access Control Server (us) for this transaction.



372
# File 'lib/increase/models/card_payment.rb', line 372

required :access_control_server_transaction_identifier, String

#billing_address_cityString?

The city of the cardholder billing address associated with the card used for this purchase.



379
# File 'lib/increase/models/card_payment.rb', line 379

required :billing_address_city, String, nil?: true

#billing_address_countryString?

The country of the cardholder billing address associated with the card used for this purchase.



386
# File 'lib/increase/models/card_payment.rb', line 386

required :billing_address_country, String, nil?: true

#billing_address_line1String?

The first line of the cardholder billing address associated with the card used for this purchase.



393
# File 'lib/increase/models/card_payment.rb', line 393

required :billing_address_line1, String, nil?: true

#billing_address_line2String?

The second line of the cardholder billing address associated with the card used for this purchase.



400
# File 'lib/increase/models/card_payment.rb', line 400

required :billing_address_line2, String, nil?: true

#billing_address_line3String?

The third line of the cardholder billing address associated with the card used for this purchase.



407
# File 'lib/increase/models/card_payment.rb', line 407

required :billing_address_line3, String, nil?: true

#billing_address_postal_codeString?

The postal code of the cardholder billing address associated with the card used for this purchase.



414
# File 'lib/increase/models/card_payment.rb', line 414

required :billing_address_postal_code, String, nil?: true

#billing_address_stateString?

The US state of the cardholder billing address associated with the card used for this purchase.



421
# File 'lib/increase/models/card_payment.rb', line 421

required :billing_address_state, String, nil?: true

#card_idString

The identifier of the Card.



427
# File 'lib/increase/models/card_payment.rb', line 427

required :card_id, String

#card_payment_idString

The ID of the Card Payment this transaction belongs to.



433
# File 'lib/increase/models/card_payment.rb', line 433

required :card_payment_id, String

#cardholder_emailString?

The email address of the cardholder.



439
# File 'lib/increase/models/card_payment.rb', line 439

required :cardholder_email, String, nil?: true

#cardholder_nameString?

The name of the cardholder.



445
# File 'lib/increase/models/card_payment.rb', line 445

required :cardholder_name, String, nil?: true

#challengeIncrease::Models::CardPayment::Element::CardAuthentication::Challenge?

Details about the challenge, if one was requested.



451
452
453
454
455
# File 'lib/increase/models/card_payment.rb', line 451

required :challenge,
-> {
  Increase::CardPayment::Element::CardAuthentication::Challenge
},
nil?: true

#created_atTime

The ISO 8601 time at which the Card Authentication was attempted.



462
# File 'lib/increase/models/card_payment.rb', line 462

required :created_at, Time

#deny_reasonSymbol, ...

The reason why this authentication attempt was denied, if it was.



468
469
470
# File 'lib/increase/models/card_payment.rb', line 468

required :deny_reason,
enum: -> { Increase::CardPayment::Element::CardAuthentication::DenyReason },
nil?: true

#device_channelIncrease::Models::CardPayment::Element::CardAuthentication::DeviceChannel

The device channel of the card authentication attempt.



476
# File 'lib/increase/models/card_payment.rb', line 476

required :device_channel, -> { Increase::CardPayment::Element::CardAuthentication::DeviceChannel }

#directory_server_transaction_identifierString

A unique identifier assigned by the Directory Server (the card network) for this transaction.



483
# File 'lib/increase/models/card_payment.rb', line 483

required :directory_server_transaction_identifier, String

#idString

The Card Authentication identifier.



365
# File 'lib/increase/models/card_payment.rb', line 365

required :id, String

#merchant_acceptor_idString?

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.



490
# File 'lib/increase/models/card_payment.rb', line 490

required :merchant_acceptor_id, String, nil?: true

#merchant_category_codeString?

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.



497
# File 'lib/increase/models/card_payment.rb', line 497

required :merchant_category_code, String, nil?: true

#merchant_countryString?

The country the merchant resides in.



503
# File 'lib/increase/models/card_payment.rb', line 503

required :merchant_country, String, nil?: true

#merchant_nameString?

The name of the merchant.



509
# File 'lib/increase/models/card_payment.rb', line 509

required :merchant_name, String, nil?: true

#message_categoryIncrease::Models::CardPayment::Element::CardAuthentication::MessageCategory

The message category of the card authentication attempt.



515
# File 'lib/increase/models/card_payment.rb', line 515

required :message_category, -> { Increase::CardPayment::Element::CardAuthentication::MessageCategory }

#prior_authenticated_card_payment_idString?

The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction.



522
# File 'lib/increase/models/card_payment.rb', line 522

required :prior_authenticated_card_payment_id, String, nil?: true

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.



529
# File 'lib/increase/models/card_payment.rb', line 529

required :real_time_decision_id, String, nil?: true

#requestor_authentication_indicatorSymbol, ...

The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.



536
537
538
539
540
# File 'lib/increase/models/card_payment.rb', line 536

required :requestor_authentication_indicator,
enum: -> {
  Increase::CardPayment::Element::CardAuthentication::RequestorAuthenticationIndicator
},
nil?: true

#requestor_challenge_indicatorSymbol, ...

Indicates whether a challenge is requested for this transaction.



546
547
548
549
550
# File 'lib/increase/models/card_payment.rb', line 546

required :requestor_challenge_indicator,
enum: -> {
  Increase::CardPayment::Element::CardAuthentication::RequestorChallengeIndicator
},
nil?: true

#requestor_nameString

The name of the 3DS requestor.



556
# File 'lib/increase/models/card_payment.rb', line 556

required :requestor_name, String

#requestor_urlString

The URL of the 3DS requestor.



562
# File 'lib/increase/models/card_payment.rb', line 562

required :requestor_url, String

#shipping_address_cityString?

The city of the shipping address associated with this purchase.



568
# File 'lib/increase/models/card_payment.rb', line 568

required :shipping_address_city, String, nil?: true

#shipping_address_countryString?

The country of the shipping address associated with this purchase.



574
# File 'lib/increase/models/card_payment.rb', line 574

required :shipping_address_country, String, nil?: true

#shipping_address_line1String?

The first line of the shipping address associated with this purchase.



580
# File 'lib/increase/models/card_payment.rb', line 580

required :shipping_address_line1, String, nil?: true

#shipping_address_line2String?

The second line of the shipping address associated with this purchase.



586
# File 'lib/increase/models/card_payment.rb', line 586

required :shipping_address_line2, String, nil?: true

#shipping_address_line3String?

The third line of the shipping address associated with this purchase.



592
# File 'lib/increase/models/card_payment.rb', line 592

required :shipping_address_line3, String, nil?: true

#shipping_address_postal_codeString?

The postal code of the shipping address associated with this purchase.



598
# File 'lib/increase/models/card_payment.rb', line 598

required :shipping_address_postal_code, String, nil?: true

#shipping_address_stateString?

The US state of the shipping address associated with this purchase.



604
# File 'lib/increase/models/card_payment.rb', line 604

required :shipping_address_state, String, nil?: true

#statusSymbol, Increase::Models::CardPayment::Element::CardAuthentication::Status

The status of the card authentication.



610
# File 'lib/increase/models/card_payment.rb', line 610

required :status, enum: -> { Increase::CardPayment::Element::CardAuthentication::Status }

#three_d_secure_server_transaction_identifierString

A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction.



617
# File 'lib/increase/models/card_payment.rb', line 617

required :three_d_secure_server_transaction_identifier, String

#typeSymbol, Increase::Models::CardPayment::Element::CardAuthentication::Type

A constant representing the object's type. For this resource it will always be card_authentication.



624
# File 'lib/increase/models/card_payment.rb', line 624

required :type, enum: -> { Increase::CardPayment::Element::CardAuthentication::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/card_payment.rb', line 874


Instance Method Details

#to_hash{



369
# File 'sig/increase/models/card_payment.rbs', line 369

def to_hash: -> {