Class: Increase::Models::CardPayment::Element::CardAuthentication::Challenge

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: VerificationMethod Classes: Attempt

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#attemptsArray<Increase::Models::CardPayment::Element::CardAuthentication::Challenge::Attempt>

Details about the challenge verification attempts, if any happened.



664
665
# File 'lib/increase/models/card_payment.rb', line 664

required :attempts,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardAuthentication::Challenge::Attempt] }

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Card Authentication Challenge was started.

Returns:

  • (Time)


672
# File 'lib/increase/models/card_payment.rb', line 672

required :created_at, Time

#one_time_codeString

The one-time code used for the Card Authentication Challenge.

Returns:

  • (String)


678
# File 'lib/increase/models/card_payment.rb', line 678

required :one_time_code, String

#real_time_decision_idString?

The identifier of the Real-Time Decision used to deliver this challenge.

Returns:

  • (String, nil)


684
# File 'lib/increase/models/card_payment.rb', line 684

required :real_time_decision_id, String, nil?: true

#verification_methodSymbol, Increase::Models::CardPayment::Element::CardAuthentication::Challenge::VerificationMethod

The method used to verify the Card Authentication Challenge.



690
691
# File 'lib/increase/models/card_payment.rb', line 690

required :verification_method,
enum: -> { Increase::CardPayment::Element::CardAuthentication::Challenge::VerificationMethod }

#verification_valueString?

E.g., the email address or phone number used for the Card Authentication Challenge.

Returns:

  • (String, nil)


698
# File 'lib/increase/models/card_payment.rb', line 698

required :verification_value, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 755