Class: Increase::Models::CardPayment::Element::CardAuthentication::MessageCategory::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthentication::MessageCategory::Payment
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: TransactionType
Instance Attribute Summary collapse
-
#purchase_amount ⇒ Integer
The purchase amount in minor units.
-
#purchase_amount_cardholder_estimated ⇒ Integer?
The purchase amount in the cardholder's currency (i.e., USD) estimated using daily conversion rates from the card network.
-
#purchase_currency ⇒ String
The ISO 4217 code for the authentication attempt's purchase currency.
-
#transaction_type ⇒ Symbol, ...
The type of transaction being authenticated.
Instance Method Summary collapse
-
#initialize(purchase_amount:, purchase_amount_cardholder_estimated:, purchase_currency:, transaction_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payment for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(purchase_amount:, purchase_amount_cardholder_estimated:, purchase_currency:, transaction_type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardAuthentication::MessageCategory::Payment for more details.
Fields specific to payment authentication attempts.
|
|
# File 'lib/increase/models/card_payment.rb', line 1102
|
Instance Attribute Details
#purchase_amount ⇒ Integer
The purchase amount in minor units.
1076 |
# File 'lib/increase/models/card_payment.rb', line 1076 required :purchase_amount, Integer |
#purchase_amount_cardholder_estimated ⇒ Integer?
The purchase amount in the cardholder's currency (i.e., USD) estimated using daily conversion rates from the card network.
1083 |
# File 'lib/increase/models/card_payment.rb', line 1083 required :purchase_amount_cardholder_estimated, Integer, nil?: true |
#purchase_currency ⇒ String
The ISO 4217 code for the authentication attempt's purchase currency.
1090 |
# File 'lib/increase/models/card_payment.rb', line 1090 required :purchase_currency, String |
#transaction_type ⇒ Symbol, ...
The type of transaction being authenticated.
1096 1097 1098 1099 1100 |
# File 'lib/increase/models/card_payment.rb', line 1096 required :transaction_type, enum: -> { Increase::CardPayment::Element::CardAuthentication::MessageCategory::Payment::TransactionType }, nil?: true |
Instance Method Details
#to_hash ⇒ {
807 |
# File 'sig/increase/models/card_payment.rbs', line 807
def to_hash: -> {
|