Module: Increase::Models::CardPayment::Element::CardAuthentication::RequestorAuthenticationIndicator

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.

See Also:

  • Increase::Models::CardPayment::Element::CardAuthentication#requestor_authentication_indicator

Constant Summary collapse

PAYMENT_TRANSACTION =

The authentication is for a payment transaction.

Returns:

  • (:payment_transaction)
:payment_transaction
RECURRING_TRANSACTION =

The authentication is for a recurring transaction.

Returns:

  • (:recurring_transaction)
:recurring_transaction
INSTALLMENT_TRANSACTION =

The authentication is for an installment transaction.

Returns:

  • (:installment_transaction)
:installment_transaction
ADD_CARD =

The authentication is for adding a card.

Returns:

  • (:add_card)
:add_card
MAINTAIN_CARD =

The authentication is for maintaining a card.

Returns:

  • (:maintain_card)
:maintain_card
EMV_TOKEN_CARDHOLDER_VERIFICATION =

The authentication is for EMV token cardholder verification.

Returns:

  • (:emv_token_cardholder_verification)
:emv_token_cardholder_verification
BILLING_AGREEMENT =

The authentication is for a billing agreement.

Returns:

  • (:billing_agreement)
:billing_agreement

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPayment::Element::CardAuthentication::requestor_authentication_indicator]

Returns:

  • (::Array[Increase::Models::CardPayment::Element::CardAuthentication::requestor_authentication_indicator])


877
# File 'sig/increase/models/card_payment.rbs', line 877

def self?.values: -> ::Array[Increase::Models::CardPayment::Element::CardAuthentication::requestor_authentication_indicator]