Class: Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision
Instance Attribute Summary collapse
-
#clinic ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
-
#dental ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
-
#original ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Original?
The original pre-authorized amount.
-
#prescription ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
-
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
-
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
-
#transit ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
-
#unknown ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Unknown?
An unknown additional amount.
-
#vision ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
Instance Method Summary collapse
-
#initialize(amount:, currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Unknown for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:) ⇒ Object
Some parameter documentations has been truncated, see Unknown for more details.
An unknown additional amount.
|
|
# File 'lib/increase/models/card_payment.rb', line 1654
|
Instance Attribute Details
#clinic ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
1572 1573 1574 |
# File 'lib/increase/models/card_payment.rb', line 1572 required :clinic, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Clinic }, nil?: true |
#dental ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
1580 1581 1582 |
# File 'lib/increase/models/card_payment.rb', line 1580 required :dental, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Dental }, nil?: true |
#original ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Original?
The original pre-authorized amount.
1588 1589 1590 |
# File 'lib/increase/models/card_payment.rb', line 1588 required :original, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Original }, nil?: true |
#prescription ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
1596 1597 1598 1599 1600 |
# File 'lib/increase/models/card_payment.rb', line 1596 required :prescription, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Prescription }, nil?: true |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
1606 1607 1608 |
# File 'lib/increase/models/card_payment.rb', line 1606 required :surcharge, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Surcharge }, nil?: true |
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
1614 1615 1616 1617 1618 |
# File 'lib/increase/models/card_payment.rb', line 1614 required :total_cumulative, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalCumulative }, nil?: true |
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
1624 1625 1626 1627 1628 |
# File 'lib/increase/models/card_payment.rb', line 1624 required :total_healthcare, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalHealthcare }, nil?: true |
#transit ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
1634 1635 1636 |
# File 'lib/increase/models/card_payment.rb', line 1634 required :transit, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Transit }, nil?: true |
#unknown ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Unknown?
An unknown additional amount.
1642 1643 1644 |
# File 'lib/increase/models/card_payment.rb', line 1642 required :unknown, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Unknown }, nil?: true |
#vision ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
1650 1651 1652 |
# File 'lib/increase/models/card_payment.rb', line 1650 required :vision, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Vision }, nil?: true |