Class: Increase::Models::CardPayment::Element::CardAuthorization::Healthcare
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthorization::Healthcare
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: MerchantNinetyPercentEligibility
Instance Attribute Summary collapse
-
#merchant_ninety_percent_eligibility ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Healthcare::MerchantNinetyPercentEligibility
The merchant's eligibility under the Internal Revenue Service's 90% Rule for Flexible Spending Account (FSA) and Health Savings Account (HSA) eligible products.
Instance Method Summary collapse
-
#initialize(merchant_ninety_percent_eligibility:) ⇒ Object
constructor
The healthcare-related fields for this authorization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(merchant_ninety_percent_eligibility:) ⇒ Object
The healthcare-related fields for this authorization. Only present for specific programs.
|
|
# File 'lib/increase/models/card_payment.rb', line 2180
|
Instance Attribute Details
#merchant_ninety_percent_eligibility ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Healthcare::MerchantNinetyPercentEligibility
The merchant's eligibility under the Internal Revenue Service's 90% Rule for Flexible Spending Account (FSA) and Health Savings Account (HSA) eligible products. The eligibility is determined based on the list of merchants maintained by the Special Interest Group for IIAS Standards (SIGIS).
2177 2178 |
# File 'lib/increase/models/card_payment.rb', line 2177 required :merchant_ninety_percent_eligibility, enum: -> { Increase::CardPayment::Element::CardAuthorization::Healthcare::MerchantNinetyPercentEligibility } |
Instance Method Details
#to_hash ⇒ {
1376 |
# File 'sig/increase/models/card_payment.rbs', line 1376
def to_hash: -> {
|