Module: Increase::Models::CardPayment::Element::CardAuthorization::Verification::CardholderAddress::Result

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

The address verification result returned to the card network.

See Also:

  • Increase::Models::CardPayment::Element::CardAuthorization::Verification::CardholderAddress#result

Constant Summary collapse

NOT_CHECKED =

No address information was provided in the authorization request.

Returns:

  • (:not_checked)
:not_checked
POSTAL_CODE_MATCH_ADDRESS_NO_MATCH =

Postal code matches, but the street address does not match or was not provided.

Returns:

  • (:postal_code_match_address_no_match)
:postal_code_match_address_no_match
POSTAL_CODE_NO_MATCH_ADDRESS_MATCH =

Postal code does not match, but the street address matches or was not provided.

Returns:

  • (:postal_code_no_match_address_match)
:postal_code_no_match_address_match
MATCH =

Postal code and street address match.

Returns:

  • (:match)
:match
NO_MATCH =

Postal code and street address do not match.

Returns:

  • (:no_match)
:no_match
POSTAL_CODE_MATCH_ADDRESS_NOT_CHECKED =

Postal code matches, but the street address was not verified. (deprecated)

Returns:

  • (:postal_code_match_address_not_checked)
:postal_code_match_address_not_checked

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPayment::Element::CardAuthorization::Verification::CardholderAddress::result]

Returns:

  • (::Array[Increase::Models::CardPayment::Element::CardAuthorization::Verification::CardholderAddress::result])


2040
# File 'sig/increase/models/card_payment.rbs', line 2040

def self?.values: -> ::Array[Increase::Models::CardPayment::Element::CardAuthorization::Verification::CardholderAddress::result]