Class: Increase::Models::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts::Prescription

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts#prescription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializePrescription

Returns a new instance of Prescription.

Parameters:

  • amount: (Integer)
  • currency: (String)


2375
# File 'sig/increase/models/card_payment.rbs', line 2375

def initialize: (amount: Integer, currency: String) -> void

Instance Attribute Details

#amountInteger

The amount in minor units of the currency field. The amount is positive if it is added to the amount (such as an ATM surcharge fee) and negative if it is subtracted from the amount (such as a discount).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


3312
# File 'lib/increase/models/card_payment.rb', line 3312

required :amount, Integer

#currencyString

The ISO 4217 code for the additional amount's currency.

Parameters:

  • value (String)

Returns:

  • (String)


3319
# File 'lib/increase/models/card_payment.rb', line 3319

required :currency, String

Instance Method Details

#to_hash{ amount: Integer, currency: String }

Returns:

  • ({ amount: Integer, currency: String })


2377
# File 'sig/increase/models/card_payment.rbs', line 2377

def to_hash: -> { amount: Integer, currency: String }