Module: Increase::Models::CardPayment::Element::CardBalanceInquiry::NetworkDetails::Visa::TerminalEntryCapability

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_payment.rb

Overview

The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.

Constant Summary collapse

UNKNOWN =

Unknown

:unknown
TERMINAL_NOT_USED =

No terminal was used for this transaction.

:terminal_not_used
MAGNETIC_STRIPE =

The terminal can only read magnetic stripes and does not have chip or contactless reading capability.

:magnetic_stripe
BARCODE =

The terminal can only read barcodes.

:barcode
OPTICAL_CHARACTER_RECOGNITION =

The terminal can only read cards via Optical Character Recognition.

:optical_character_recognition
CHIP_OR_CONTACTLESS =

The terminal supports contact chip cards and can also read the magnetic stripe. If contact chip is supported, this value is used regardless of whether contactless is also supported.

:chip_or_contactless
CONTACTLESS_ONLY =

The terminal supports contactless reads but does not support contact chip. Only used when the terminal lacks contact chip capability.

:contactless_only
NO_CAPABILITY =

The terminal has no card reading capability.

:no_capability

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info