Module: Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardVerificationCode::Result

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

The result of verifying the Card Verification Code.

See Also:

  • Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardVerificationCode#result

Constant Summary collapse

NOT_CHECKED =

No card verification code was provided in the authorization request.

Returns:

  • (:not_checked)
:not_checked
MATCH =

The card verification code matched the one on file.

Returns:

  • (:match)
:match
NO_MATCH =

The card verification code did not match the one on file.

Returns:

  • (:no_match)
:no_match

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardVerificationCode::result]

Returns:

  • (::Array[Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardVerificationCode::result])


2988
# File 'sig/increase/models/card_payment.rbs', line 2988

def self?.values: -> ::Array[Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardVerificationCode::result]