Class: Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardholderAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardholderAddress
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: Result
Instance Attribute Summary collapse
-
#actual_line1 ⇒ String?
Line 1 of the address on file for the cardholder.
-
#actual_postal_code ⇒ String?
The postal code of the address on file for the cardholder.
-
#provided_line1 ⇒ String?
The cardholder address line 1 provided for verification in the authorization request.
-
#provided_postal_code ⇒ String?
The postal code provided for verification in the authorization request.
-
#result ⇒ Symbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardholderAddress::Result
The address verification result returned to the card network.
Instance Method Summary collapse
-
#initialize(actual_line1:, actual_postal_code:, provided_line1:, provided_postal_code:, result:) ⇒ Object
constructor
Cardholder address provided in the authorization request and the address on file we verified it against.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(actual_line1:, actual_postal_code:, provided_line1:, provided_postal_code:, result:) ⇒ Object
Cardholder address provided in the authorization request and the address on file we verified it against.
|
|
# File 'lib/increase/models/card_payment.rb', line 4397
|
Instance Attribute Details
#actual_line1 ⇒ String?
Line 1 of the address on file for the cardholder.
4369 |
# File 'lib/increase/models/card_payment.rb', line 4369 required :actual_line1, String, nil?: true |
#actual_postal_code ⇒ String?
The postal code of the address on file for the cardholder.
4375 |
# File 'lib/increase/models/card_payment.rb', line 4375 required :actual_postal_code, String, nil?: true |
#provided_line1 ⇒ String?
The cardholder address line 1 provided for verification in the authorization request.
4382 |
# File 'lib/increase/models/card_payment.rb', line 4382 required :provided_line1, String, nil?: true |
#provided_postal_code ⇒ String?
The postal code provided for verification in the authorization request.
4388 |
# File 'lib/increase/models/card_payment.rb', line 4388 required :provided_postal_code, String, nil?: true |
#result ⇒ Symbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification::CardholderAddress::Result
The address verification result returned to the card network.
4394 4395 |
# File 'lib/increase/models/card_payment.rb', line 4394 required :result, enum: -> { Increase::CardPayment::Element::CardBalanceInquiry::Verification::CardholderAddress::Result } |
Instance Method Details
#to_hash ⇒ {
3020 |
# File 'sig/increase/models/card_payment.rbs', line 3020
def to_hash: -> {
|