Class: Increase::Models::CardPayment::Element::CardDecline

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_decline

Defined Under Namespace

Modules: Actioner, Currency, Direction, ProcessingCategory, RealTimeDecisionReason, Reason Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/card_payment.rb', line 4701

Instance Attribute Details

#actionerSymbol, Increase::Models::CardPayment::Element::CardDecline::Actioner

Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardDecline::actioner)

Returns:



4509
# File 'lib/increase/models/card_payment.rb', line 4509

required :actioner, enum: -> { Increase::CardPayment::Element::CardDecline::Actioner }

#additional_amountsIncrease::Models::CardPayment::Element::CardDecline::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardDecline::AdditionalAmounts)

Returns:



4517
# File 'lib/increase/models/card_payment.rb', line 4517

required :additional_amounts, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts }

#amountInteger

The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


4524
# File 'lib/increase/models/card_payment.rb', line 4524

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


4530
# File 'lib/increase/models/card_payment.rb', line 4530

required :card_payment_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardDecline::Currency

The ISO 4217 code for the destination account currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardDecline::currency)

Returns:



4537
# File 'lib/increase/models/card_payment.rb', line 4537

required :currency, enum: -> { Increase::CardPayment::Element::CardDecline::Currency }

#declined_transaction_idString

The identifier of the declined transaction created for this Card Decline.

Parameters:

  • value (String)

Returns:

  • (String)


4543
# File 'lib/increase/models/card_payment.rb', line 4543

required :declined_transaction_id, String

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4550
# File 'lib/increase/models/card_payment.rb', line 4550

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::CardPayment::Element::CardDecline::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardDecline::direction)

Returns:



4557
# File 'lib/increase/models/card_payment.rb', line 4557

required :direction, enum: -> { Increase::CardPayment::Element::CardDecline::Direction }

#idString

The Card Decline identifier.

Parameters:

  • value (String)

Returns:

  • (String)


4502
# File 'lib/increase/models/card_payment.rb', line 4502

required :id, String

#incremented_card_authorization_idString?

The identifier of the card authorization this request attempted to incrementally authorize.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4564
# File 'lib/increase/models/card_payment.rb', line 4564

required :incremented_card_authorization_id, String, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


4571
# File 'lib/increase/models/card_payment.rb', line 4571

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


4578
# File 'lib/increase/models/card_payment.rb', line 4578

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4584
# File 'lib/increase/models/card_payment.rb', line 4584

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


4590
# File 'lib/increase/models/card_payment.rb', line 4590

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


4596
# File 'lib/increase/models/card_payment.rb', line 4596

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4603
# File 'lib/increase/models/card_payment.rb', line 4603

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4609
# File 'lib/increase/models/card_payment.rb', line 4609

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::CardPayment::Element::CardDecline::NetworkDetails

Fields specific to the network.

Parameters:

  • value (Increase::CardPayment::Element::CardDecline::NetworkDetails)

Returns:



4615
# File 'lib/increase/models/card_payment.rb', line 4615

required :network_details, -> { Increase::CardPayment::Element::CardDecline::NetworkDetails }

#network_identifiersIncrease::Models::CardPayment::Element::CardDecline::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardDecline::NetworkIdentifiers)

Returns:



4621
# File 'lib/increase/models/card_payment.rb', line 4621

required :network_identifiers, -> { Increase::CardPayment::Element::CardDecline::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


4629
# File 'lib/increase/models/card_payment.rb', line 4629

required :network_risk_score, Integer, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4636
# File 'lib/increase/models/card_payment.rb', line 4636

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The declined amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


4642
# File 'lib/increase/models/card_payment.rb', line 4642

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


4649
# File 'lib/increase/models/card_payment.rb', line 4649

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::CardPayment::Element::CardDecline::ProcessingCategory

The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardDecline::processing_category)

Returns:



4656
4657
# File 'lib/increase/models/card_payment.rb', line 4656

required :processing_category,
enum: -> { Increase::CardPayment::Element::CardDecline::ProcessingCategory }

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4664
# File 'lib/increase/models/card_payment.rb', line 4664

required :real_time_decision_id, String, nil?: true

#real_time_decision_reasonSymbol, ...

This is present if a specific decline reason was given in the real-time decision.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardDecline::real_time_decision_reason, nil)

Returns:



4671
4672
4673
# File 'lib/increase/models/card_payment.rb', line 4671

required :real_time_decision_reason,
enum: -> { Increase::CardPayment::Element::CardDecline::RealTimeDecisionReason },
nil?: true

#reasonSymbol, Increase::Models::CardPayment::Element::CardDecline::Reason

Why the transaction was declined.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardDecline::reason)

Returns:



4679
# File 'lib/increase/models/card_payment.rb', line 4679

required :reason, enum: -> { Increase::CardPayment::Element::CardDecline::Reason }

#scheme_feesArray<Increase::Models::CardPayment::Element::CardDecline::SchemeFee>

The scheme fees associated with this card decline.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardDecline::SchemeFee])

Returns:



4685
4686
# File 'lib/increase/models/card_payment.rb', line 4685

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardDecline::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


4693
# File 'lib/increase/models/card_payment.rb', line 4693

required :terminal_id, String, nil?: true

#verificationIncrease::Models::CardPayment::Element::CardDecline::Verification

Fields related to verification of cardholder-provided values.

Parameters:

  • value (Increase::CardPayment::Element::CardDecline::Verification)

Returns:



4699
# File 'lib/increase/models/card_payment.rb', line 4699

required :verification, -> { Increase::CardPayment::Element::CardDecline::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 4824

Instance Method Details

#to_hash{

Returns:

  • ({)


3223
# File 'sig/increase/models/card_payment.rbs', line 3223

def to_hash: -> {