Class: Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision
Instance Attribute Summary collapse
-
#clinic ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
-
#dental ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
-
#original ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Original?
The original pre-authorized amount.
-
#prescription ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
-
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
-
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
-
#transit ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
-
#unknown ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Unknown?
An unknown additional amount.
-
#vision ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
Instance Method Summary collapse
-
#initialize(amount:, currency:) ⇒ Object
constructor
An unknown additional amount.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:) ⇒ Object
An unknown additional amount.
|
|
# File 'lib/increase/models/card_payment.rb', line 4893
|
Instance Attribute Details
#clinic ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
4817 4818 4819 |
# File 'lib/increase/models/card_payment.rb', line 4817 required :clinic, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Clinic }, nil?: true |
#dental ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
4825 4826 4827 |
# File 'lib/increase/models/card_payment.rb', line 4825 required :dental, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Dental }, nil?: true |
#original ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Original?
The original pre-authorized amount.
4833 4834 4835 |
# File 'lib/increase/models/card_payment.rb', line 4833 required :original, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Original }, nil?: true |
#prescription ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
4841 4842 4843 |
# File 'lib/increase/models/card_payment.rb', line 4841 required :prescription, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Prescription }, nil?: true |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
4849 4850 4851 |
# File 'lib/increase/models/card_payment.rb', line 4849 required :surcharge, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Surcharge }, nil?: true |
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
4857 4858 4859 |
# File 'lib/increase/models/card_payment.rb', line 4857 required :total_cumulative, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::TotalCumulative }, nil?: true |
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
4865 4866 4867 |
# File 'lib/increase/models/card_payment.rb', line 4865 required :total_healthcare, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::TotalHealthcare }, nil?: true |
#transit ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
4873 4874 4875 |
# File 'lib/increase/models/card_payment.rb', line 4873 required :transit, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Transit }, nil?: true |
#unknown ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Unknown?
An unknown additional amount.
4881 4882 4883 |
# File 'lib/increase/models/card_payment.rb', line 4881 required :unknown, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Unknown }, nil?: true |
#vision ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
4889 4890 4891 |
# File 'lib/increase/models/card_payment.rb', line 4889 required :vision, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts::Vision }, nil?: true |
Instance Method Details
#to_hash ⇒ {
3316 |
# File 'sig/increase/models/card_payment.rbs', line 3316
def to_hash: -> {
|