Class: Increase::Models::CardPayment::Element::CardDecline::Verification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Classes: CardVerificationCode, CardholderAddress, CardholderName

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_verification_code:, cardholder_address:, cardholder_name:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardDecline::Verification for more details.

Fields related to verification of cardholder-provided values.

Parameters:



# File 'lib/increase/models/card_payment.rb', line 5551

Instance Attribute Details

#card_verification_codeIncrease::Models::CardPayment::Element::CardDecline::Verification::CardVerificationCode

Fields related to verification of the Card Verification Code, a 3-digit code on the back of the card.



5532
5533
# File 'lib/increase/models/card_payment.rb', line 5532

required :card_verification_code,
-> { Increase::CardPayment::Element::CardDecline::Verification::CardVerificationCode }

#cardholder_addressIncrease::Models::CardPayment::Element::CardDecline::Verification::CardholderAddress

Cardholder address provided in the authorization request and the address on file we verified it against.



5540
5541
# File 'lib/increase/models/card_payment.rb', line 5540

required :cardholder_address,
-> { Increase::CardPayment::Element::CardDecline::Verification::CardholderAddress }

#cardholder_nameIncrease::Models::CardPayment::Element::CardDecline::Verification::CardholderName?

Cardholder name provided in the authorization request.



5547
5548
5549
# File 'lib/increase/models/card_payment.rb', line 5547

required :cardholder_name,
-> { Increase::CardPayment::Element::CardDecline::Verification::CardholderName },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 5594