Class: Increase::Models::CardPayment::Element::CardDecline::Verification::CardholderName

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#provided_first_nameString?

The first name provided for verification in the authorization request.

Returns:

  • (String, nil)


5686
# File 'lib/increase/models/card_payment.rb', line 5686

required :provided_first_name, String, nil?: true

#provided_last_nameString?

The last name provided for verification in the authorization request.

Returns:

  • (String, nil)


5692
# File 'lib/increase/models/card_payment.rb', line 5692

required :provided_last_name, String, nil?: true

#provided_middle_nameString?

The middle name provided for verification in the authorization request.

Returns:

  • (String, nil)


5698
# File 'lib/increase/models/card_payment.rb', line 5698

required :provided_middle_name, String, nil?: true