Class: Increase::Models::CardPayment::Element::CardFinancial
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardFinancial
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Actioner
Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The pending amount in the minor unit of the transaction's currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Currency
The ISO 4217 code for the transaction's currency.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#id ⇒ String
The Card Financial identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails
Fields specific to the
network. -
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardFinancial::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#processing_category ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::ProcessingCategory
The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardFinancial::SchemeFee>
The scheme fees associated with this card financial.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Type
A constant representing the object's type.
-
#verification ⇒ Increase::Models::CardPayment::Element::CardFinancial::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for a specific request or transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 6308
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Actioner
Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
6131 |
# File 'lib/increase/models/card_payment.rb', line 6131 required :actioner, enum: -> { Increase::CardPayment::Element::CardFinancial::Actioner } |
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM
surcharges fees. These are usually a subset of the amount field and are used
to provide more detailed information about the transaction.
6139 |
# File 'lib/increase/models/card_payment.rb', line 6139 required :additional_amounts, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts } |
#amount ⇒ Integer
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
6146 |
# File 'lib/increase/models/card_payment.rb', line 6146 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
6152 |
# File 'lib/increase/models/card_payment.rb', line 6152 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Currency
The ISO 4217 code for the transaction's currency.
6159 |
# File 'lib/increase/models/card_payment.rb', line 6159 required :currency, enum: -> { Increase::CardPayment::Element::CardFinancial::Currency } |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
6166 |
# File 'lib/increase/models/card_payment.rb', line 6166 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
6173 |
# File 'lib/increase/models/card_payment.rb', line 6173 required :direction, enum: -> { Increase::CardPayment::Element::CardFinancial::Direction } |
#id ⇒ String
The Card Financial identifier.
6124 |
# File 'lib/increase/models/card_payment.rb', line 6124 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
6180 |
# File 'lib/increase/models/card_payment.rb', line 6180 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
6187 |
# File 'lib/increase/models/card_payment.rb', line 6187 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
6193 |
# File 'lib/increase/models/card_payment.rb', line 6193 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
6199 |
# File 'lib/increase/models/card_payment.rb', line 6199 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
6205 |
# File 'lib/increase/models/card_payment.rb', line 6205 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
6212 |
# File 'lib/increase/models/card_payment.rb', line 6212 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
6218 |
# File 'lib/increase/models/card_payment.rb', line 6218 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails
Fields specific to the network.
6224 |
# File 'lib/increase/models/card_payment.rb', line 6224 required :network_details, -> { Increase::CardPayment::Element::CardFinancial::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardFinancial::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
6230 |
# File 'lib/increase/models/card_payment.rb', line 6230 required :network_identifiers, -> { Increase::CardPayment::Element::CardFinancial::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
6238 |
# File 'lib/increase/models/card_payment.rb', line 6238 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
6245 |
# File 'lib/increase/models/card_payment.rb', line 6245 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction's presentment currency.
6251 |
# File 'lib/increase/models/card_payment.rb', line 6251 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
6258 |
# File 'lib/increase/models/card_payment.rb', line 6258 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::ProcessingCategory
The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
6265 6266 |
# File 'lib/increase/models/card_payment.rb', line 6265 required :processing_category, enum: -> { Increase::CardPayment::Element::CardFinancial::ProcessingCategory } |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
6273 |
# File 'lib/increase/models/card_payment.rb', line 6273 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardFinancial::SchemeFee>
The scheme fees associated with this card financial.
6279 6280 |
# File 'lib/increase/models/card_payment.rb', line 6279 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardFinancial::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
6287 |
# File 'lib/increase/models/card_payment.rb', line 6287 required :terminal_id, String, nil?: true |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
6293 |
# File 'lib/increase/models/card_payment.rb', line 6293 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardFinancial::Type
A constant representing the object's type. For this resource it will always be
card_financial.
6300 |
# File 'lib/increase/models/card_payment.rb', line 6300 required :type, enum: -> { Increase::CardPayment::Element::CardFinancial::Type } |
#verification ⇒ Increase::Models::CardPayment::Element::CardFinancial::Verification
Fields related to verification of cardholder-provided values.
6306 |
# File 'lib/increase/models/card_payment.rb', line 6306 required :verification, -> { Increase::CardPayment::Element::CardFinancial::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 6426
|
Instance Method Details
#to_hash ⇒ {
4387 |
# File 'sig/increase/models/card_payment.rbs', line 4387
def to_hash: -> {
|