Class: Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element::CardFinancial#additional_amounts

Defined Under Namespace

Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:) ⇒ Object

An unknown additional amount.

Parameters:

  • amount (Integer)

    The amount in minor units of the currency field. The amount is positive if it is added to the amount (such as an ATM surcharge fee) and negative if it is subtracted from the amount (such as a discount).

  • currency (String)

    The ISO 4217 code for the additional amount's currency.



# File 'lib/increase/models/card_payment.rb', line 6529

Instance Attribute Details

#clinicIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Clinic?

The part of this transaction amount that was for clinic-related services.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Clinic, nil)

Returns:



6453
6454
6455
# File 'lib/increase/models/card_payment.rb', line 6453

required :clinic,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Clinic },
nil?: true

#dentalIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Dental?

The part of this transaction amount that was for dental-related services.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Dental, nil)

Returns:



6461
6462
6463
# File 'lib/increase/models/card_payment.rb', line 6461

required :dental,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Dental },
nil?: true

#originalIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Original?

The original pre-authorized amount.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Original, nil)

Returns:



6469
6470
6471
# File 'lib/increase/models/card_payment.rb', line 6469

required :original,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Original },
nil?: true

#prescriptionIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Prescription?

The part of this transaction amount that was for healthcare prescriptions.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Prescription, nil)

Returns:



6477
6478
6479
# File 'lib/increase/models/card_payment.rb', line 6477

required :prescription,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Prescription },
nil?: true

#surchargeIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Surcharge?

The surcharge amount charged for this transaction by the merchant.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Surcharge, nil)

Returns:



6485
6486
6487
# File 'lib/increase/models/card_payment.rb', line 6485

required :surcharge,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Surcharge },
nil?: true

#total_cumulativeIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalCumulative?

The total amount of a series of incremental authorizations, optionally provided.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalCumulative, nil)

Returns:



6493
6494
6495
# File 'lib/increase/models/card_payment.rb', line 6493

required :total_cumulative,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalCumulative },
nil?: true

#total_healthcareIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalHealthcare?

The total amount of healthcare-related additional amounts.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalHealthcare, nil)

Returns:



6501
6502
6503
# File 'lib/increase/models/card_payment.rb', line 6501

required :total_healthcare,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalHealthcare },
nil?: true

#transitIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Transit?

The part of this transaction amount that was for transit-related services.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Transit, nil)

Returns:



6509
6510
6511
# File 'lib/increase/models/card_payment.rb', line 6509

required :transit,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Transit },
nil?: true

#unknownIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Unknown?

An unknown additional amount.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Unknown, nil)

Returns:



6517
6518
6519
# File 'lib/increase/models/card_payment.rb', line 6517

required :unknown,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Unknown },
nil?: true

#visionIncrease::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Vision?

The part of this transaction amount that was for vision-related services.

Parameters:

  • value (Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Vision, nil)

Returns:



6525
6526
6527
# File 'lib/increase/models/card_payment.rb', line 6525

required :vision,
-> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Vision },
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


4488
# File 'sig/increase/models/card_payment.rbs', line 4488

def to_hash: -> {