Class: Increase::Models::CardPayment::Element::CardFinancial::SchemeFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Defined Under Namespace

Modules: Currency, FeeType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, created_at:, currency:, fee_type:, fixed_component:, variable_rate:) ⇒ Object



# File 'lib/increase/models/card_payment.rb', line 7323


Instance Attribute Details

#amountString

The fee amount given as a string containing a decimal number.



7287
# File 'lib/increase/models/card_payment.rb', line 7287

required :amount, String

#created_atTime

The ISO 8601 time at which the fee was created.



7294
# File 'lib/increase/models/card_payment.rb', line 7294

required :created_at, Time

#currencySymbol, Increase::Models::CardPayment::Element::CardFinancial::SchemeFee::Currency

The ISO 4217 code for the fee reimbursement.



7301
# File 'lib/increase/models/card_payment.rb', line 7301

required :currency, enum: -> { Increase::CardPayment::Element::CardFinancial::SchemeFee::Currency }

#fee_typeSymbol, Increase::Models::CardPayment::Element::CardFinancial::SchemeFee::FeeType

The type of fee being assessed.



7307
# File 'lib/increase/models/card_payment.rb', line 7307

required :fee_type, enum: -> { Increase::CardPayment::Element::CardFinancial::SchemeFee::FeeType }

#fixed_componentString?

The fixed component of the fee, if applicable, given in major units of the fee amount.



7314
# File 'lib/increase/models/card_payment.rb', line 7314

required :fixed_component, String, nil?: true

#variable_rateString?

The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).



7321
# File 'lib/increase/models/card_payment.rb', line 7321

required :variable_rate, String, nil?: true

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/card_payment.rb', line 7355


Instance Method Details

#to_hash{



5012
# File 'sig/increase/models/card_payment.rbs', line 5012

def to_hash: -> {