Class: Increase::Models::CardPayment::Element::CardIncrement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_increment

Defined Under Namespace

Modules: Actioner, Currency, Network, Type Classes: AdditionalAmounts, NetworkIdentifiers, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/card_payment.rb', line 8129

Instance Attribute Details

#actionerSymbol, Increase::Models::CardPayment::Element::CardIncrement::Actioner

Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardIncrement::actioner)

Returns:



8032
# File 'lib/increase/models/card_payment.rb', line 8032

required :actioner, enum: -> { Increase::CardPayment::Element::CardIncrement::Actioner }

#additional_amountsIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardIncrement::AdditionalAmounts)

Returns:



8040
# File 'lib/increase/models/card_payment.rb', line 8040

required :additional_amounts, -> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts }

#amountInteger

The amount of this increment in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


8047
# File 'lib/increase/models/card_payment.rb', line 8047

required :amount, Integer

#card_authorization_idString

The identifier for the Card Authorization this increments.

Parameters:

  • value (String)

Returns:

  • (String)


8053
# File 'lib/increase/models/card_payment.rb', line 8053

required :card_authorization_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardIncrement::Currency

The ISO 4217 code for the increment's currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardIncrement::currency)

Returns:



8060
# File 'lib/increase/models/card_payment.rb', line 8060

required :currency, enum: -> { Increase::CardPayment::Element::CardIncrement::Currency }

#idString

The Card Increment identifier.

Parameters:

  • value (String)

Returns:

  • (String)


8025
# File 'lib/increase/models/card_payment.rb', line 8025

required :id, String

#networkSymbol, Increase::Models::CardPayment::Element::CardIncrement::Network

The card network used to process this card authorization.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardIncrement::network)

Returns:



8066
# File 'lib/increase/models/card_payment.rb', line 8066

required :network, enum: -> { Increase::CardPayment::Element::CardIncrement::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardIncrement::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardIncrement::NetworkIdentifiers)

Returns:



8072
# File 'lib/increase/models/card_payment.rb', line 8072

required :network_identifiers, -> { Increase::CardPayment::Element::CardIncrement::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


8079
# File 'lib/increase/models/card_payment.rb', line 8079

required :network_risk_score, Integer, nil?: true

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Card Increment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


8085
# File 'lib/increase/models/card_payment.rb', line 8085

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount of this increment in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


8092
# File 'lib/increase/models/card_payment.rb', line 8092

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


8099
# File 'lib/increase/models/card_payment.rb', line 8099

required :presentment_currency, String

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


8106
# File 'lib/increase/models/card_payment.rb', line 8106

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardIncrement::SchemeFee>

The scheme fees associated with this card increment.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardIncrement::SchemeFee])

Returns:



8112
8113
# File 'lib/increase/models/card_payment.rb', line 8112

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardIncrement::SchemeFee] }

#typeSymbol, Increase::Models::CardPayment::Element::CardIncrement::Type

A constant representing the object's type. For this resource it will always be card_increment.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardIncrement::type_)

Returns:



8120
# File 'lib/increase/models/card_payment.rb', line 8120

required :type, enum: -> { Increase::CardPayment::Element::CardIncrement::Type }

#updated_authorization_amountInteger

The updated authorization amount after this increment, in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


8127
# File 'lib/increase/models/card_payment.rb', line 8127

required :updated_authorization_amount, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 8207

Instance Method Details

#to_hash{

Returns:

  • ({)


5693
# File 'sig/increase/models/card_payment.rbs', line 5693

def to_hash: -> {