Module: Increase::Models::CardPayment::Element::CardIncrement::Actioner

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.

See Also:

  • Increase::Models::CardPayment::Element::CardIncrement#actioner

Constant Summary collapse

USER =

This object was actioned by the user through a real-time decision.

Returns:

  • (:user)
:user
INCREASE =

This object was actioned by Increase without user intervention.

Returns:

  • (:increase)
:increase
NETWORK =

This object was actioned by the network, through stand-in processing.

Returns:

  • (:network)
:network

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPayment::Element::CardIncrement::actioner]

Returns:

  • (::Array[Increase::Models::CardPayment::Element::CardIncrement::actioner])


5726
# File 'sig/increase/models/card_payment.rbs', line 5726

def self?.values: -> ::Array[Increase::Models::CardPayment::Element::CardIncrement::actioner]