Class: Increase::Models::CardPayment::Element::CardIncrement::AdditionalAmounts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

Defined Under Namespace

Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:) ⇒ Object

Some parameter documentations has been truncated, see Unknown for more details.

An unknown additional amount.

Parameters:

  • amount (Integer)

    The amount in minor units of the ‘currency` field. The amount is positive if it

  • currency (String)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the additional a



# File 'lib/increase/models/card_payment.rb', line 7764

Instance Attribute Details

#clinicIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Clinic?

The part of this transaction amount that was for clinic-related services.



7688
7689
7690
# File 'lib/increase/models/card_payment.rb', line 7688

required :clinic,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Clinic },
nil?: true

#dentalIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Dental?

The part of this transaction amount that was for dental-related services.



7696
7697
7698
# File 'lib/increase/models/card_payment.rb', line 7696

required :dental,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Dental },
nil?: true

#originalIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Original?

The original pre-authorized amount.



7704
7705
7706
# File 'lib/increase/models/card_payment.rb', line 7704

required :original,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Original },
nil?: true

#prescriptionIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Prescription?

The part of this transaction amount that was for healthcare prescriptions.



7712
7713
7714
# File 'lib/increase/models/card_payment.rb', line 7712

required :prescription,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Prescription },
nil?: true

#surchargeIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Surcharge?

The surcharge amount charged for this transaction by the merchant.



7720
7721
7722
# File 'lib/increase/models/card_payment.rb', line 7720

required :surcharge,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Surcharge },
nil?: true

#total_cumulativeIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::TotalCumulative?

The total amount of a series of incremental authorizations, optionally provided.



7728
7729
7730
# File 'lib/increase/models/card_payment.rb', line 7728

required :total_cumulative,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::TotalCumulative },
nil?: true

#total_healthcareIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::TotalHealthcare?

The total amount of healthcare-related additional amounts.



7736
7737
7738
# File 'lib/increase/models/card_payment.rb', line 7736

required :total_healthcare,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::TotalHealthcare },
nil?: true

#transitIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Transit?

The part of this transaction amount that was for transit-related services.



7744
7745
7746
# File 'lib/increase/models/card_payment.rb', line 7744

required :transit,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Transit },
nil?: true

#unknownIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Unknown?

An unknown additional amount.



7752
7753
7754
# File 'lib/increase/models/card_payment.rb', line 7752

required :unknown,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Unknown },
nil?: true

#visionIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts::Vision?

The part of this transaction amount that was for vision-related services.



7760
7761
7762
# File 'lib/increase/models/card_payment.rb', line 7760

required :vision,
-> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts::Vision },
nil?: true