Class: Increase::Models::CardPayment::Element::CardRefund

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_refund

Defined Under Namespace

Modules: Currency, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object

Network-specific identifiers for this refund.

Parameters:

  • acquirer_business_id (String)

    A network assigned business ID that identifies the acquirer that processed this transaction.

  • acquirer_reference_number (String)

    A globally unique identifier for this settlement.

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/card_payment.rb', line 9037

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


8916
# File 'lib/increase/models/card_payment.rb', line 8916

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


8922
# File 'lib/increase/models/card_payment.rb', line 8922

required :card_payment_id, String

#cashbackIncrease::Models::CardPayment::Element::CardRefund::Cashback?

Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.

Parameters:

  • value (Increase::CardPayment::Element::CardRefund::Cashback, nil)

Returns:



8929
# File 'lib/increase/models/card_payment.rb', line 8929

required :cashback, -> { Increase::CardPayment::Element::CardRefund::Cashback }, nil?: true

#currencySymbol, Increase::Models::CardPayment::Element::CardRefund::Currency

The ISO 4217 code for the transaction's settlement currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardRefund::currency)

Returns:



8936
# File 'lib/increase/models/card_payment.rb', line 8936

required :currency, enum: -> { Increase::CardPayment::Element::CardRefund::Currency }

#idString

The Card Refund identifier.

Parameters:

  • value (String)

Returns:

  • (String)


8909
# File 'lib/increase/models/card_payment.rb', line 8909

required :id, String

#interchangeIncrease::Models::CardPayment::Element::CardRefund::Interchange?

Interchange assessed as a part of this transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardRefund::Interchange, nil)

Returns:



8942
# File 'lib/increase/models/card_payment.rb', line 8942

required :interchange, -> { Increase::CardPayment::Element::CardRefund::Interchange }, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


8949
# File 'lib/increase/models/card_payment.rb', line 8949

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant's business.

Parameters:

  • value (String)

Returns:

  • (String)


8955
# File 'lib/increase/models/card_payment.rb', line 8955

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


8961
# File 'lib/increase/models/card_payment.rb', line 8961

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


8967
# File 'lib/increase/models/card_payment.rb', line 8967

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Parameters:

  • value (String)

Returns:

  • (String)


8973
# File 'lib/increase/models/card_payment.rb', line 8973

required :merchant_name, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is always a 5-digit ZIP code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


8979
# File 'lib/increase/models/card_payment.rb', line 8979

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


8985
# File 'lib/increase/models/card_payment.rb', line 8985

required :merchant_state, String, nil?: true

#network_identifiersIncrease::Models::CardPayment::Element::CardRefund::NetworkIdentifiers

Network-specific identifiers for this refund.

Parameters:

  • value (Increase::CardPayment::Element::CardRefund::NetworkIdentifiers)

Returns:



8991
# File 'lib/increase/models/card_payment.rb', line 8991

required :network_identifiers, -> { Increase::CardPayment::Element::CardRefund::NetworkIdentifiers }

#presentment_amountInteger

The amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


8997
# File 'lib/increase/models/card_payment.rb', line 8997

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


9004
# File 'lib/increase/models/card_payment.rb', line 9004

required :presentment_currency, String

#purchase_detailsIncrease::Models::CardPayment::Element::CardRefund::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.

Parameters:

  • value (Increase::CardPayment::Element::CardRefund::PurchaseDetails, nil)

Returns:



9011
9012
9013
9014
9015
# File 'lib/increase/models/card_payment.rb', line 9011

required :purchase_details,
-> {
  Increase::CardPayment::Element::CardRefund::PurchaseDetails
},
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardRefund::SchemeFee>

The scheme fees associated with this card refund.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardRefund::SchemeFee])

Returns:



9021
9022
# File 'lib/increase/models/card_payment.rb', line 9021

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardRefund::SchemeFee] }

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


9028
# File 'lib/increase/models/card_payment.rb', line 9028

required :transaction_id, String

#typeSymbol, Increase::Models::CardPayment::Element::CardRefund::Type

A constant representing the object's type. For this resource it will always be card_refund.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardRefund::type_)

Returns:



9035
# File 'lib/increase/models/card_payment.rb', line 9035

required :type, enum: -> { Increase::CardPayment::Element::CardRefund::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 9140

Instance Method Details

#to_hash{

Returns:

  • ({)


6244
# File 'sig/increase/models/card_payment.rbs', line 6244

def to_hash: -> {