Class: Increase::Models::CardPayment::Element::CardRefund::NetworkIdentifiers

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element::CardRefund#network_identifiers

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



6366
# File 'sig/increase/models/card_payment.rbs', line 6366

def initialize: (

Instance Attribute Details

#acquirer_business_idString

A network assigned business ID that identifies the acquirer that processed this transaction.

Parameters:

  • value (String)

Returns:

  • (String)


8714
# File 'lib/increase/models/card_payment.rb', line 8714

required :acquirer_business_id, String

#acquirer_reference_numberString

A globally unique identifier for this settlement.

Parameters:

  • value (String)

Returns:

  • (String)


8720
# File 'lib/increase/models/card_payment.rb', line 8720

required :acquirer_reference_number, String

#authorization_identification_responseString?

The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


8727
# File 'lib/increase/models/card_payment.rb', line 8727

required :authorization_identification_response, String, nil?: true

#transaction_idString?

A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


8734
# File 'lib/increase/models/card_payment.rb', line 8734

required :transaction_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


6373
# File 'sig/increase/models/card_payment.rbs', line 6373

def to_hash: -> {