Class: Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: CreditReasonIndicator, RestrictedTicketIndicator, TicketChangeIndicator Classes: Ancillary, TripLeg
Instance Attribute Summary collapse
-
#ancillary ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
-
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
-
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
-
#departure_date ⇒ Date?
Date of departure.
-
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
-
#passenger_name ⇒ String?
Name of the passenger.
-
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
-
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
-
#ticket_number ⇒ String?
Ticket number.
-
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
-
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
-
#trip_legs ⇒ Array<Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
constructor
Fields specific to travel.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
Fields specific to travel.
|
|
# File 'lib/increase/models/card_payment.rb', line 9930
|
Instance Attribute Details
#ancillary ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
9844 9845 9846 |
# File 'lib/increase/models/card_payment.rb', line 9844 required :ancillary, -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Travel::Ancillary }, nil?: true |
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
9852 |
# File 'lib/increase/models/card_payment.rb', line 9852 required :computerized_reservation_system, String, nil?: true |
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
9858 9859 9860 9861 9862 |
# File 'lib/increase/models/card_payment.rb', line 9858 required :credit_reason_indicator, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Travel::CreditReasonIndicator }, nil?: true |
#departure_date ⇒ Date?
Date of departure.
9868 |
# File 'lib/increase/models/card_payment.rb', line 9868 required :departure_date, Date, nil?: true |
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
9874 |
# File 'lib/increase/models/card_payment.rb', line 9874 required :origination_city_airport_code, String, nil?: true |
#passenger_name ⇒ String?
Name of the passenger.
9880 |
# File 'lib/increase/models/card_payment.rb', line 9880 required :passenger_name, String, nil?: true |
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
9886 9887 9888 9889 9890 |
# File 'lib/increase/models/card_payment.rb', line 9886 required :restricted_ticket_indicator, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Travel::RestrictedTicketIndicator }, nil?: true |
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
9896 9897 9898 9899 9900 |
# File 'lib/increase/models/card_payment.rb', line 9896 required :ticket_change_indicator, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Travel::TicketChangeIndicator }, nil?: true |
#ticket_number ⇒ String?
Ticket number.
9906 |
# File 'lib/increase/models/card_payment.rb', line 9906 required :ticket_number, String, nil?: true |
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
9912 |
# File 'lib/increase/models/card_payment.rb', line 9912 required :travel_agency_code, String, nil?: true |
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
9918 |
# File 'lib/increase/models/card_payment.rb', line 9918 required :travel_agency_name, String, nil?: true |
#trip_legs ⇒ Array<Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
9924 9925 9926 9927 9928 |
# File 'lib/increase/models/card_payment.rb', line 9924 required :trip_legs, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardRefund::PurchaseDetails::Travel::TripLeg] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 10148
|
Instance Method Details
#to_hash ⇒ {
6812 |
# File 'sig/increase/models/card_payment.rbs', line 6812
def to_hash: -> {
|