Class: Increase::Models::CardPayment::Element::CardReversal

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_reversal

Defined Under Namespace

Modules: Currency, Network, ReversalReason, Type Classes: NetworkIdentifiers, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.



# File 'lib/increase/models/card_payment.rb', line 10636


Instance Attribute Details

#card_authorization_idString

The identifier for the Card Authorization this reverses.



10500
# File 'lib/increase/models/card_payment.rb', line 10500

required :card_authorization_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardReversal::Currency

The ISO 4217 code for the reversal's currency.



10507
# File 'lib/increase/models/card_payment.rb', line 10507

required :currency, enum: -> { Increase::CardPayment::Element::CardReversal::Currency }

#idString

The Card Reversal identifier.



10494
# File 'lib/increase/models/card_payment.rb', line 10494

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.



10514
# File 'lib/increase/models/card_payment.rb', line 10514

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.



10521
# File 'lib/increase/models/card_payment.rb', line 10521

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.



10527
# File 'lib/increase/models/card_payment.rb', line 10527

required :merchant_city, String, nil?: true

#merchant_countryString?

The country the merchant resides in.



10533
# File 'lib/increase/models/card_payment.rb', line 10533

required :merchant_country, String, nil?: true

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.



10539
# File 'lib/increase/models/card_payment.rb', line 10539

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.



10546
# File 'lib/increase/models/card_payment.rb', line 10546

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.



10552
# File 'lib/increase/models/card_payment.rb', line 10552

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::CardPayment::Element::CardReversal::Network

The card network used to process this card authorization.



10558
# File 'lib/increase/models/card_payment.rb', line 10558

required :network, enum: -> { Increase::CardPayment::Element::CardReversal::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardReversal::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.



10564
# File 'lib/increase/models/card_payment.rb', line 10564

required :network_identifiers, -> { Increase::CardPayment::Element::CardReversal::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Card Reversal.



10570
# File 'lib/increase/models/card_payment.rb', line 10570

required :pending_transaction_id, String, nil?: true

#presentment_currencyString

The ISO 4217 code for the reversal's presentment currency.



10577
# File 'lib/increase/models/card_payment.rb', line 10577

required :presentment_currency, String

#reversal_amountInteger

The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.



10584
# File 'lib/increase/models/card_payment.rb', line 10584

required :reversal_amount, Integer

#reversal_presentment_amountInteger

The amount of this reversal in the minor unit of the transaction's presentment currency. For dollars, for example, this is cents.



10591
# File 'lib/increase/models/card_payment.rb', line 10591

required :reversal_presentment_amount, Integer

#reversal_reasonSymbol, ...

Why this reversal was initiated.



10597
10598
10599
# File 'lib/increase/models/card_payment.rb', line 10597

required :reversal_reason,
enum: -> { Increase::CardPayment::Element::CardReversal::ReversalReason },
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardReversal::SchemeFee>

The scheme fees associated with this card reversal.



10605
10606
# File 'lib/increase/models/card_payment.rb', line 10605

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardReversal::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.



10613
# File 'lib/increase/models/card_payment.rb', line 10613

required :terminal_id, String, nil?: true

#typeSymbol, Increase::Models::CardPayment::Element::CardReversal::Type

A constant representing the object's type. For this resource it will always be card_reversal.



10620
# File 'lib/increase/models/card_payment.rb', line 10620

required :type, enum: -> { Increase::CardPayment::Element::CardReversal::Type }

#updated_authorization_amountInteger

The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.



10627
# File 'lib/increase/models/card_payment.rb', line 10627

required :updated_authorization_amount, Integer

#updated_authorization_presentment_amountInteger

The amount left pending on the Card Authorization in the minor unit of the transaction's presentment currency. For dollars, for example, this is cents.



10634
# File 'lib/increase/models/card_payment.rb', line 10634

required :updated_authorization_presentment_amount, Integer

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/card_payment.rb', line 10722


Instance Method Details

#to_hash{



7425
# File 'sig/increase/models/card_payment.rbs', line 7425

def to_hash: -> {