Class: Increase::Models::CardPayment::Element::CardSettlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_settlement

Defined Under Namespace

Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, presentment_amount:) ⇒ Object

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • amount (Integer)

    The surcharge amount in the minor unit of the transaction's settlement currency.

  • presentment_amount (Integer)

    The surcharge amount in the minor unit of the transaction's presentment currency.



# File 'lib/increase/models/card_payment.rb', line 11171

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11021
# File 'lib/increase/models/card_payment.rb', line 11021

required :amount, Integer

#card_authorizationString?

The Card Authorization that was created prior to this Card Settlement, if one exists.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11028
# File 'lib/increase/models/card_payment.rb', line 11028

required :card_authorization, String, nil?: true

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


11034
# File 'lib/increase/models/card_payment.rb', line 11034

required :card_payment_id, String

#cashbackIncrease::Models::CardPayment::Element::CardSettlement::Cashback?

Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::Cashback, nil)

Returns:



11041
# File 'lib/increase/models/card_payment.rb', line 11041

required :cashback, -> { Increase::CardPayment::Element::CardSettlement::Cashback }, nil?: true

#currencySymbol, Increase::Models::CardPayment::Element::CardSettlement::Currency

The ISO 4217 code for the transaction's settlement currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::currency)

Returns:



11048
# File 'lib/increase/models/card_payment.rb', line 11048

required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::Currency }

#idString

The Card Settlement identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11014
# File 'lib/increase/models/card_payment.rb', line 11014

required :id, String

#interchangeIncrease::Models::CardPayment::Element::CardSettlement::Interchange?

Interchange assessed as a part of this transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::Interchange, nil)

Returns:



11054
11055
11056
11057
11058
# File 'lib/increase/models/card_payment.rb', line 11054

required :interchange,
-> {
  Increase::CardPayment::Element::CardSettlement::Interchange
},
nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


11065
# File 'lib/increase/models/card_payment.rb', line 11065

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant's business.

Parameters:

  • value (String)

Returns:

  • (String)


11071
# File 'lib/increase/models/card_payment.rb', line 11071

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


11077
# File 'lib/increase/models/card_payment.rb', line 11077

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


11083
# File 'lib/increase/models/card_payment.rb', line 11083

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Parameters:

  • value (String)

Returns:

  • (String)


11089
# File 'lib/increase/models/card_payment.rb', line 11089

required :merchant_name, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is always a 5-digit ZIP code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11095
# File 'lib/increase/models/card_payment.rb', line 11095

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11101
# File 'lib/increase/models/card_payment.rb', line 11101

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::CardPayment::Element::CardSettlement::Network

The card network on which this transaction was processed.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::network)

Returns:



11107
# File 'lib/increase/models/card_payment.rb', line 11107

required :network, enum: -> { Increase::CardPayment::Element::CardSettlement::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers

Network-specific identifiers for this refund.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers)

Returns:



11113
# File 'lib/increase/models/card_payment.rb', line 11113

required :network_identifiers, -> { Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11119
# File 'lib/increase/models/card_payment.rb', line 11119

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11125
# File 'lib/increase/models/card_payment.rb', line 11125

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


11132
# File 'lib/increase/models/card_payment.rb', line 11132

required :presentment_currency, String

#purchase_detailsIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::PurchaseDetails, nil)

Returns:



11139
11140
11141
# File 'lib/increase/models/card_payment.rb', line 11139

required :purchase_details,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails },
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>

The scheme fees associated with this card settlement.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardSettlement::SchemeFee])

Returns:



11147
11148
# File 'lib/increase/models/card_payment.rb', line 11147

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardSettlement::SchemeFee] }

#surchargeIncrease::Models::CardPayment::Element::CardSettlement::Surcharge?

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::Surcharge, nil)

Returns:



11156
# File 'lib/increase/models/card_payment.rb', line 11156

required :surcharge, -> { Increase::CardPayment::Element::CardSettlement::Surcharge }, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


11162
# File 'lib/increase/models/card_payment.rb', line 11162

required :transaction_id, String

#typeSymbol, Increase::Models::CardPayment::Element::CardSettlement::Type

A constant representing the object's type. For this resource it will always be card_settlement.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::type_)

Returns:



11169
# File 'lib/increase/models/card_payment.rb', line 11169

required :type, enum: -> { Increase::CardPayment::Element::CardSettlement::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 11289

Instance Method Details

#to_hash{

Returns:

  • ({)


7823
# File 'sig/increase/models/card_payment.rbs', line 7823

def to_hash: -> {