Class: Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel
Instance Attribute Summary collapse
-
#car_rental ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::CarRental?
Fields specific to car rentals.
-
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
-
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
-
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#lodging ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging?
Fields specific to lodging.
-
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
-
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
-
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
-
#travel ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Travel?
Fields specific to travel.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
constructor
Additional details about the card purchase, such as tax and industry-specific fields.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
Additional details about the card purchase, such as tax and industry-specific fields.
|
|
# File 'lib/increase/models/card_payment.rb', line 11482
|
Instance Attribute Details
#car_rental ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::CarRental?
Fields specific to car rentals.
11414 11415 11416 |
# File 'lib/increase/models/card_payment.rb', line 11414 required :car_rental, -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::CarRental }, nil?: true |
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
11422 |
# File 'lib/increase/models/card_payment.rb', line 11422 required :customer_reference_identifier, String, nil?: true |
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
11428 |
# File 'lib/increase/models/card_payment.rb', line 11428 required :local_tax_amount, Integer, nil?: true |
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
11435 |
# File 'lib/increase/models/card_payment.rb', line 11435 required :local_tax_currency, String, nil?: true |
#lodging ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging?
Fields specific to lodging.
11441 11442 11443 |
# File 'lib/increase/models/card_payment.rb', line 11441 required :lodging, -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging }, nil?: true |
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
11449 |
# File 'lib/increase/models/card_payment.rb', line 11449 required :national_tax_amount, Integer, nil?: true |
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
11456 |
# File 'lib/increase/models/card_payment.rb', line 11456 required :national_tax_currency, String, nil?: true |
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
11462 |
# File 'lib/increase/models/card_payment.rb', line 11462 required :purchase_identifier, String, nil?: true |
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
11468 11469 11470 11471 11472 |
# File 'lib/increase/models/card_payment.rb', line 11468 required :purchase_identifier_format, enum: -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::PurchaseIdentifierFormat }, nil?: true |
#travel ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Travel?
Fields specific to travel.
11478 11479 11480 |
# File 'lib/increase/models/card_payment.rb', line 11478 required :travel, -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Travel }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 11723
|
Instance Method Details
#to_hash ⇒ {
8021 |
# File 'sig/increase/models/card_payment.rbs', line 8021
def to_hash: -> {
|