Class: Increase::Models::CardPayment::Element::CardSettlement::SchemeFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Defined Under Namespace

Modules: Currency, FeeType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, created_at:, currency:, fee_type:, fixed_component:, variable_rate:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardSettlement::SchemeFee for more details.

Parameters:



# File 'lib/increase/models/card_payment.rb', line 11740

Instance Attribute Details

#amountString

The fee amount given as a string containing a decimal number.

Returns:

  • (String)


11704
# File 'lib/increase/models/card_payment.rb', line 11704

required :amount, String

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the fee was created.

Returns:

  • (Time)


11711
# File 'lib/increase/models/card_payment.rb', line 11711

required :created_at, Time

#currencySymbol, Increase::Models::CardPayment::Element::CardSettlement::SchemeFee::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fee reimbursement.



11718
# File 'lib/increase/models/card_payment.rb', line 11718

required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::SchemeFee::Currency }

#fee_typeSymbol, Increase::Models::CardPayment::Element::CardSettlement::SchemeFee::FeeType

The type of fee being assessed.



11724
# File 'lib/increase/models/card_payment.rb', line 11724

required :fee_type, enum: -> { Increase::CardPayment::Element::CardSettlement::SchemeFee::FeeType }

#fixed_componentString?

The fixed component of the fee, if applicable, given in major units of the fee amount.

Returns:

  • (String, nil)


11731
# File 'lib/increase/models/card_payment.rb', line 11731

required :fixed_component, String, nil?: true

#variable_rateString?

The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).

Returns:

  • (String, nil)


11738
# File 'lib/increase/models/card_payment.rb', line 11738

required :variable_rate, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 11767