Class: Increase::Models::CardPayment::Element::CardSettlement::Surcharge

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element::CardSettlement#surcharge

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



8912
# File 'sig/increase/models/card_payment.rbs', line 8912

def initialize: (

Instance Attribute Details

#amountInteger

The surcharge amount in the minor unit of the transaction's settlement currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11946
# File 'lib/increase/models/card_payment.rb', line 11946

required :amount, Integer

#presentment_amountInteger

The surcharge amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11953
# File 'lib/increase/models/card_payment.rb', line 11953

required :presentment_amount, Integer

Instance Method Details

#to_hash{ amount: Integer, presentment_amount: Integer }

Returns:

  • ({ amount: Integer, presentment_amount: Integer })


8917
# File 'sig/increase/models/card_payment.rbs', line 8917

def to_hash: -> { amount: Integer, presentment_amount: Integer }