Module: Increase::Models::CardPayment::Element::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

See Also:

  • Increase::Models::CardPayment::Element#category

Constant Summary collapse

CARD_AUTHORIZATION =

Card Authorization: details will be under the card_authorization object.

Returns:

  • (:card_authorization)
:card_authorization
CARD_AUTHENTICATION =

Card Authentication: details will be under the card_authentication object.

Returns:

  • (:card_authentication)
:card_authentication
CARD_BALANCE_INQUIRY =

Card Balance Inquiry: details will be under the card_balance_inquiry object.

Returns:

  • (:card_balance_inquiry)
:card_balance_inquiry
CARD_VALIDATION =

Inbound Card Validation: details will be under the card_validation object.

Returns:

  • (:card_validation)
:card_validation
CARD_DECLINE =

Card Decline: details will be under the card_decline object.

Returns:

  • (:card_decline)
:card_decline
CARD_REVERSAL =

Card Reversal: details will be under the card_reversal object.

Returns:

  • (:card_reversal)
:card_reversal
CARD_AUTHORIZATION_EXPIRATION =

Card Authorization Expiration: details will be under the card_authorization_expiration object.

Returns:

  • (:card_authorization_expiration)
:card_authorization_expiration
CARD_INCREMENT =

Card Increment: details will be under the card_increment object.

Returns:

  • (:card_increment)
:card_increment
CARD_SETTLEMENT =

Card Settlement: details will be under the card_settlement object.

Returns:

  • (:card_settlement)
:card_settlement
CARD_REFUND =

Card Refund: details will be under the card_refund object.

Returns:

  • (:card_refund)
:card_refund
CARD_FUEL_CONFIRMATION =

Card Fuel Confirmation: details will be under the card_fuel_confirmation object.

Returns:

  • (:card_fuel_confirmation)
:card_fuel_confirmation
CARD_FINANCIAL =

Card Financial: details will be under the card_financial object.

Returns:

  • (:card_financial)
:card_financial
OTHER =

Unknown card payment element.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPayment::Element::category]

Returns:

  • (::Array[Increase::Models::CardPayment::Element::category])


202
# File 'sig/increase/models/card_payment.rbs', line 202

def self?.values: -> ::Array[Increase::Models::CardPayment::Element::category]