Class: Increase::Models::CardPayment::State

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment#state

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



9928
# File 'sig/increase/models/card_payment.rbs', line 9928

def initialize: (

Instance Attribute Details

#authorized_amountInteger

The total authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14086
# File 'lib/increase/models/card_payment.rb', line 14086

required :authorized_amount, Integer

#fuel_confirmed_amountInteger

The total amount from fuel confirmations in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14093
# File 'lib/increase/models/card_payment.rb', line 14093

required :fuel_confirmed_amount, Integer

#incremented_amountInteger

The total incrementally updated authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14100
# File 'lib/increase/models/card_payment.rb', line 14100

required :incremented_amount, Integer

#refund_authorized_amountInteger

The total refund authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14107
# File 'lib/increase/models/card_payment.rb', line 14107

required :refund_authorized_amount, Integer

#refunded_amountInteger

The total refunded amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14114
# File 'lib/increase/models/card_payment.rb', line 14114

required :refunded_amount, Integer

#reversed_amountInteger

The total reversed amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14121
# File 'lib/increase/models/card_payment.rb', line 14121

required :reversed_amount, Integer

#settled_amountInteger

The total settled amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14128
# File 'lib/increase/models/card_payment.rb', line 14128

required :settled_amount, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


9938
# File 'sig/increase/models/card_payment.rbs', line 9938

def to_hash: -> {