Class: Increase::Models::CardPurchaseSupplement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_purchase_supplement.rb,
sig/increase/models/card_purchase_supplement.rbs

Overview

See Also:

  • Increase::Resources::CardPurchaseSupplements#retrieve

Defined Under Namespace

Modules: Type Classes: Invoice, LineItem, Shipping

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(customer_reference_number:, destination_address:, destination_country_code:, destination_postal_code:, destination_receiver_name:, discount_amount:, net_amount:, number_of_packages:, origin_address:, origin_country_code:, origin_postal_code:, origin_sender_name:, pick_up_date:, service_description:, service_level_code:, shipping_courier_name:, tax_amount:, tracking_number:, unit_of_measure:, weight:) ⇒ Object

Shipping information for the purchase.

Parameters:

  • The customer reference number.

  • Address of the destination.

  • Country code of the destination.

  • Postal code of the destination.

  • Name of the receiver at the destination.

  • Discount amount for the shipment.

  • Net shipping amount.

  • Number of packages shipped.

  • Address of the origin.

  • Country code of the origin.

  • Postal code of the origin.

  • Name of the sender at the origin.

  • Date the shipment should be picked up.

  • Description of the shipping service.

  • Service level code for the shipment.

  • Name of the shipping courier.

  • Tax amount for the shipment.

  • Tracking number for the shipment.

  • Unit of measure for the shipment weight.

  • Weight of the shipment.



# File 'lib/increase/models/card_purchase_supplement.rb', line 58


Instance Attribute Details

#account_idString

The identifier for the Account the Card Purchase Supplement belongs to.

Parameters:

Returns:



17
# File 'lib/increase/models/card_purchase_supplement.rb', line 17

required :account_id, String

#card_payment_idString?

The ID of the Card Payment this transaction belongs to.

Parameters:

Returns:



23
# File 'lib/increase/models/card_purchase_supplement.rb', line 23

required :card_payment_id, String, nil?: true

#idString

The Card Purchase Supplement identifier.

Parameters:

Returns:



11
# File 'lib/increase/models/card_purchase_supplement.rb', line 11

required :id, String

#invoiceIncrease::Models::CardPurchaseSupplement::Invoice?

Invoice-level information about the payment.

Parameters:

Returns:



29
# File 'lib/increase/models/card_purchase_supplement.rb', line 29

required :invoice, -> { Increase::CardPurchaseSupplement::Invoice }, nil?: true

#line_itemsArray<Increase::Models::CardPurchaseSupplement::LineItem>?

Line item information, such as individual products purchased.

Parameters:

Returns:



35
36
37
# File 'lib/increase/models/card_purchase_supplement.rb', line 35

required :line_items,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPurchaseSupplement::LineItem] },
nil?: true

#shippingIncrease::Models::CardPurchaseSupplement::Shipping?

Shipping information for the purchase.

Parameters:

Returns:



43
# File 'lib/increase/models/card_purchase_supplement.rb', line 43

required :shipping, -> { Increase::CardPurchaseSupplement::Shipping }, nil?: true

#transaction_idString

The ID of the transaction.

Parameters:

Returns:



49
# File 'lib/increase/models/card_purchase_supplement.rb', line 49

required :transaction_id, String

#typeSymbol, Increase::Models::CardPurchaseSupplement::Type

A constant representing the object's type. For this resource it will always be card_purchase_supplement.

Parameters:

Returns:



56
# File 'lib/increase/models/card_purchase_supplement.rb', line 56

required :type, enum: -> { Increase::CardPurchaseSupplement::Type }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/increase/models/card_purchase_supplement.rb', line 270


Instance Method Details

#to_hash{

Returns:



43
# File 'sig/increase/models/card_purchase_supplement.rbs', line 43

def to_hash: -> {