Class: Increase::Models::CardPushTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPushTransfer
- Defined in:
- lib/increase/models/card_push_transfer.rb
Overview
Defined Under Namespace
Modules: BusinessApplicationIdentifier, Route, Status, Type Classes: Acceptance, Approval, Cancellation, CreatedBy, Decline, PresentmentAmount, Submission
Instance Attribute Summary collapse
-
#acceptance ⇒ Increase::Models::CardPushTransfer::Acceptance?
If the transfer is accepted by the recipient bank, this will contain supplemental details.
-
#account_id ⇒ String
The Account from which the transfer was sent.
-
#approval ⇒ Increase::Models::CardPushTransfer::Approval?
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
#business_application_identifier ⇒ Symbol, Increase::Models::CardPushTransfer::BusinessApplicationIdentifier
The Business Application Identifier describes the type of transaction being performed.
-
#cancellation ⇒ Increase::Models::CardPushTransfer::Cancellation?
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
#card_token_id ⇒ String
The ID of the Card Token that was used to validate the card.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
-
#created_by ⇒ Increase::Models::CardPushTransfer::CreatedBy?
What object created the transfer, either via the API or the dashboard.
-
#decline ⇒ Increase::Models::CardPushTransfer::Decline?
If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.
-
#id ⇒ String
The Card Push Transfer’s identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#merchant_category_code ⇒ String
The merchant category code (MCC) of the merchant (generally your business) sending the transfer.
-
#merchant_city_name ⇒ String
The city name of the merchant (generally your business) sending the transfer.
-
#merchant_legal_business_name ⇒ String?
The legal business name of the merchant (generally your business) sending the transfer.
-
#merchant_name ⇒ String
The merchant name shows up as the statement descriptor for the transfer.
-
#merchant_name_prefix ⇒ String
For certain Business Application Identifiers, the statement descriptor is ‘merchant_name_prefix*sender_name`, where the `merchant_name_prefix` is a one to four character prefix that identifies the merchant.
-
#merchant_postal_code ⇒ String
The postal code of the merchant (generally your business) sending the transfer.
-
#merchant_state ⇒ String
The state of the merchant (generally your business) sending the transfer.
-
#merchant_street_address ⇒ String?
The street address of the merchant (generally your business) sending the transfer.
-
#presentment_amount ⇒ Increase::Models::CardPushTransfer::PresentmentAmount
The amount that was transferred.
-
#recipient_address_city ⇒ String?
The city of the recipient.
-
#recipient_address_line1 ⇒ String?
The first line of the recipient’s address.
-
#recipient_address_postal_code ⇒ String?
The postal code of the recipient.
-
#recipient_address_state ⇒ String?
The state or province of the recipient.
-
#recipient_name ⇒ String
The name of the funds recipient.
-
#route ⇒ Symbol, Increase::Models::CardPushTransfer::Route
The card network route used for the transfer.
-
#sender_address_city ⇒ String
The city of the sender.
-
#sender_address_line1 ⇒ String
The address line 1 of the sender.
-
#sender_address_postal_code ⇒ String
The postal code of the sender.
-
#sender_address_state ⇒ String
The state of the sender.
-
#sender_name ⇒ String
The name of the funds originator.
-
#source_account_number_id ⇒ String
The Account Number the recipient will see as having sent the transfer.
-
#status ⇒ Symbol, Increase::Models::CardPushTransfer::Status
The lifecycle status of the transfer.
-
#submission ⇒ Increase::Models::CardPushTransfer::Submission?
After the transfer is submitted to the card network, this will contain supplemental details.
-
#type ⇒ Symbol, Increase::Models::CardPushTransfer::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(retrieval_reference_number:, sender_reference:, submitted_at:, trace_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Submission for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(retrieval_reference_number:, sender_reference:, submitted_at:, trace_number:) ⇒ Object
Some parameter documentations has been truncated, see Submission for more details.
After the transfer is submitted to the card network, this will contain supplemental details.
|
|
# File 'lib/increase/models/card_push_transfer.rb', line 241
|
Instance Attribute Details
#acceptance ⇒ Increase::Models::CardPushTransfer::Acceptance?
If the transfer is accepted by the recipient bank, this will contain supplemental details.
18 |
# File 'lib/increase/models/card_push_transfer.rb', line 18 required :acceptance, -> { Increase::CardPushTransfer::Acceptance }, nil?: true |
#account_id ⇒ String
The Account from which the transfer was sent.
24 |
# File 'lib/increase/models/card_push_transfer.rb', line 24 required :account_id, String |
#approval ⇒ Increase::Models::CardPushTransfer::Approval?
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
31 |
# File 'lib/increase/models/card_push_transfer.rb', line 31 required :approval, -> { Increase::CardPushTransfer::Approval }, nil?: true |
#business_application_identifier ⇒ Symbol, Increase::Models::CardPushTransfer::BusinessApplicationIdentifier
The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
39 40 |
# File 'lib/increase/models/card_push_transfer.rb', line 39 required :business_application_identifier, enum: -> { Increase::CardPushTransfer::BusinessApplicationIdentifier } |
#cancellation ⇒ Increase::Models::CardPushTransfer::Cancellation?
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
47 |
# File 'lib/increase/models/card_push_transfer.rb', line 47 required :cancellation, -> { Increase::CardPushTransfer::Cancellation }, nil?: true |
#card_token_id ⇒ String
The ID of the Card Token that was used to validate the card.
53 |
# File 'lib/increase/models/card_push_transfer.rb', line 53 required :card_token_id, String |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
60 |
# File 'lib/increase/models/card_push_transfer.rb', line 60 required :created_at, Time |
#created_by ⇒ Increase::Models::CardPushTransfer::CreatedBy?
What object created the transfer, either via the API or the dashboard.
66 |
# File 'lib/increase/models/card_push_transfer.rb', line 66 required :created_by, -> { Increase::CardPushTransfer::CreatedBy }, nil?: true |
#decline ⇒ Increase::Models::CardPushTransfer::Decline?
If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.
73 |
# File 'lib/increase/models/card_push_transfer.rb', line 73 required :decline, -> { Increase::CardPushTransfer::Decline }, nil?: true |
#id ⇒ String
The Card Push Transfer’s identifier.
11 |
# File 'lib/increase/models/card_push_transfer.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
81 |
# File 'lib/increase/models/card_push_transfer.rb', line 81 required :idempotency_key, String, nil?: true |
#merchant_category_code ⇒ String
The merchant category code (MCC) of the merchant (generally your business) sending the transfer. This is a four-digit code that describes the type of business or service provided by the merchant. Your program must be approved for the specified MCC in order to use it.
90 |
# File 'lib/increase/models/card_push_transfer.rb', line 90 required :merchant_category_code, String |
#merchant_city_name ⇒ String
The city name of the merchant (generally your business) sending the transfer.
96 |
# File 'lib/increase/models/card_push_transfer.rb', line 96 required :merchant_city_name, String |
#merchant_legal_business_name ⇒ String?
The legal business name of the merchant (generally your business) sending the transfer.
103 |
# File 'lib/increase/models/card_push_transfer.rb', line 103 required :merchant_legal_business_name, String, nil?: true |
#merchant_name ⇒ String
The merchant name shows up as the statement descriptor for the transfer. This is typically the name of your business or organization.
110 |
# File 'lib/increase/models/card_push_transfer.rb', line 110 required :merchant_name, String |
#merchant_name_prefix ⇒ String
For certain Business Application Identifiers, the statement descriptor is ‘merchant_name_prefix*sender_name`, where the `merchant_name_prefix` is a one to four character prefix that identifies the merchant.
118 |
# File 'lib/increase/models/card_push_transfer.rb', line 118 required :merchant_name_prefix, String |
#merchant_postal_code ⇒ String
The postal code of the merchant (generally your business) sending the transfer.
124 |
# File 'lib/increase/models/card_push_transfer.rb', line 124 required :merchant_postal_code, String |
#merchant_state ⇒ String
The state of the merchant (generally your business) sending the transfer.
130 |
# File 'lib/increase/models/card_push_transfer.rb', line 130 required :merchant_state, String |
#merchant_street_address ⇒ String?
The street address of the merchant (generally your business) sending the transfer.
137 |
# File 'lib/increase/models/card_push_transfer.rb', line 137 required :merchant_street_address, String, nil?: true |
#presentment_amount ⇒ Increase::Models::CardPushTransfer::PresentmentAmount
The amount that was transferred. The receiving bank will have converted this to the cardholder’s currency. The amount that is applied to your Increase account matches the currency of your account.
145 |
# File 'lib/increase/models/card_push_transfer.rb', line 145 required :presentment_amount, -> { Increase::CardPushTransfer::PresentmentAmount } |
#recipient_address_city ⇒ String?
The city of the recipient. Required if the card is issued in Canada.
151 |
# File 'lib/increase/models/card_push_transfer.rb', line 151 required :recipient_address_city, String, nil?: true |
#recipient_address_line1 ⇒ String?
The first line of the recipient’s address. Required if the card is issued in Canada.
158 |
# File 'lib/increase/models/card_push_transfer.rb', line 158 required :recipient_address_line1, String, nil?: true |
#recipient_address_postal_code ⇒ String?
The postal code of the recipient. Required if the card is issued in Canada.
164 |
# File 'lib/increase/models/card_push_transfer.rb', line 164 required :recipient_address_postal_code, String, nil?: true |
#recipient_address_state ⇒ String?
The state or province of the recipient. Required if the card is issued in Canada.
171 |
# File 'lib/increase/models/card_push_transfer.rb', line 171 required :recipient_address_state, String, nil?: true |
#recipient_name ⇒ String
The name of the funds recipient.
177 |
# File 'lib/increase/models/card_push_transfer.rb', line 177 required :recipient_name, String |
#route ⇒ Symbol, Increase::Models::CardPushTransfer::Route
The card network route used for the transfer.
183 |
# File 'lib/increase/models/card_push_transfer.rb', line 183 required :route, enum: -> { Increase::CardPushTransfer::Route } |
#sender_address_city ⇒ String
The city of the sender.
189 |
# File 'lib/increase/models/card_push_transfer.rb', line 189 required :sender_address_city, String |
#sender_address_line1 ⇒ String
The address line 1 of the sender.
195 |
# File 'lib/increase/models/card_push_transfer.rb', line 195 required :sender_address_line1, String |
#sender_address_postal_code ⇒ String
The postal code of the sender.
201 |
# File 'lib/increase/models/card_push_transfer.rb', line 201 required :sender_address_postal_code, String |
#sender_address_state ⇒ String
The state of the sender.
207 |
# File 'lib/increase/models/card_push_transfer.rb', line 207 required :sender_address_state, String |
#sender_name ⇒ String
The name of the funds originator.
213 |
# File 'lib/increase/models/card_push_transfer.rb', line 213 required :sender_name, String |
#source_account_number_id ⇒ String
The Account Number the recipient will see as having sent the transfer.
219 |
# File 'lib/increase/models/card_push_transfer.rb', line 219 required :source_account_number_id, String |
#status ⇒ Symbol, Increase::Models::CardPushTransfer::Status
The lifecycle status of the transfer.
225 |
# File 'lib/increase/models/card_push_transfer.rb', line 225 required :status, enum: -> { Increase::CardPushTransfer::Status } |
#submission ⇒ Increase::Models::CardPushTransfer::Submission?
After the transfer is submitted to the card network, this will contain supplemental details.
232 |
# File 'lib/increase/models/card_push_transfer.rb', line 232 required :submission, -> { Increase::CardPushTransfer::Submission }, nil?: true |
#type ⇒ Symbol, Increase::Models::CardPushTransfer::Type
A constant representing the object’s type. For this resource it will always be ‘card_push_transfer`.
239 |
# File 'lib/increase/models/card_push_transfer.rb', line 239 required :type, enum: -> { Increase::CardPushTransfer::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_push_transfer.rb', line 381
|