Class: Increase::Models::CardPushTransfer::Acceptance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_push_transfer.rb,
sig/increase/models/card_push_transfer.rbs

Overview

See Also:

  • Increase::Models::CardPushTransfer#acceptance

Defined Under Namespace

Modules: CardVerificationValue2Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accepted_at:, authorization_identification_response:, card_verification_value2_result:, network_transaction_identifier:, settlement_amount:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPushTransfer::Acceptance for more details.

If the transfer is accepted by the recipient bank, this will contain supplemental details.

Parameters:

  • accepted_at (Time)

    The ISO 8601 date and time at which th

  • authorization_identification_response (String)

    The authorization identification response from the issuing bank.

  • card_verification_value2_result (Symbol, Increase::Models::CardPushTransfer::Acceptance::CardVerificationValue2Result, nil)

    The result of the Card Verification Value 2 match.

  • network_transaction_identifier (String, nil)

    A unique identifier for the transaction on the card network.

  • settlement_amount (Integer)

    The transfer amount in USD cents.



# File 'lib/increase/models/card_push_transfer.rb', line 352

Instance Attribute Details

#accepted_atTime

The ISO 8601 date and time at which the transfer was accepted by the issuing bank.

Parameters:

  • value (Time)

Returns:

  • (Time)


324
# File 'lib/increase/models/card_push_transfer.rb', line 324

required :accepted_at, Time

#authorization_identification_responseString

The authorization identification response from the issuing bank.

Parameters:

  • value (String)

Returns:

  • (String)


330
# File 'lib/increase/models/card_push_transfer.rb', line 330

required :authorization_identification_response, String

#card_verification_value2_resultSymbol, ...

The result of the Card Verification Value 2 match.

Parameters:

  • value (Increase::Models::CardPushTransfer::Acceptance::card_verification_value2_result, nil)

Returns:



336
337
338
# File 'lib/increase/models/card_push_transfer.rb', line 336

required :card_verification_value2_result,
enum: -> { Increase::CardPushTransfer::Acceptance::CardVerificationValue2Result },
nil?: true

#network_transaction_identifierString?

A unique identifier for the transaction on the card network.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


344
# File 'lib/increase/models/card_push_transfer.rb', line 344

required :network_transaction_identifier, String, nil?: true

#settlement_amountInteger

The transfer amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


350
# File 'lib/increase/models/card_push_transfer.rb', line 350

required :settlement_amount, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


217
# File 'sig/increase/models/card_push_transfer.rbs', line 217

def to_hash: -> {