Module: Increase::Models::CardPushTransfer::BusinessApplicationIdentifier
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_push_transfer.rb,
sig/increase/models/card_push_transfer.rbs
Overview
The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
Constant Summary collapse
- ACCOUNT_TO_ACCOUNT =
Account to Account
:account_to_account- BUSINESS_TO_BUSINESS =
Business to Business
:business_to_business- MONEY_TRANSFER_BANK_INITIATED =
Money Transfer Bank Initiated
:money_transfer_bank_initiated- NON_CARD_BILL_PAYMENT =
Non-Card Bill Payment
:non_card_bill_payment- CONSUMER_BILL_PAYMENT =
Consumer Bill Payment
:consumer_bill_payment- CARD_BILL_PAYMENT =
Card Bill Payment
:card_bill_payment- FUNDS_DISBURSEMENT =
Funds Disbursement
:funds_disbursement- FUNDS_TRANSFER =
Funds Transfer
:funds_transfer- LOYALTY_AND_OFFERS =
Loyalty and Offers
:loyalty_and_offers- MERCHANT_DISBURSEMENT =
Merchant Disbursement
:merchant_disbursement- MERCHANT_PAYMENT =
Merchant Payment
:merchant_payment- PERSON_TO_PERSON =
Person to Person
:person_to_person- TOP_UP =
Top Up
:top_up- WALLET_TRANSFER =
Wallet Transfer
:wallet_transfer
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardPushTransfer::business_application_identifier]
313 |
# File 'sig/increase/models/card_push_transfer.rbs', line 313
def self?.values: -> ::Array[Increase::Models::CardPushTransfer::business_application_identifier]
|