Class: Increase::Models::CardPushTransfer::Decline

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_push_transfer.rb,
sig/increase/models/card_push_transfer.rbs

Overview

See Also:

  • Increase::Models::CardPushTransfer#decline

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(declined_at:, network_transaction_identifier:, reason:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPushTransfer::Decline for more details.

If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.

Parameters:



# File 'lib/increase/models/card_push_transfer.rb', line 620

Instance Attribute Details

#declined_atTime

The ISO 8601 date and time at which the transfer declined.

Parameters:

  • value (Time)

Returns:

  • (Time)


606
# File 'lib/increase/models/card_push_transfer.rb', line 606

required :declined_at, Time

#network_transaction_identifierString?

A unique identifier for the transaction on the card network.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


612
# File 'lib/increase/models/card_push_transfer.rb', line 612

required :network_transaction_identifier, String, nil?: true

#reasonSymbol, Increase::Models::CardPushTransfer::Decline::Reason

The reason why the transfer was declined.

Parameters:

  • value (Increase::Models::CardPushTransfer::Decline::reason)

Returns:



618
# File 'lib/increase/models/card_push_transfer.rb', line 618

required :reason, enum: -> { Increase::CardPushTransfer::Decline::Reason }

Instance Method Details

#to_hash{

Returns:

  • ({)


427
# File 'sig/increase/models/card_push_transfer.rbs', line 427

def to_hash: -> {