Module: Increase::Models::CardPushTransfer::Decline::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_push_transfer.rb,
sig/increase/models/card_push_transfer.rbs

Overview

The reason why the transfer was declined.

See Also:

  • Increase::Models::CardPushTransfer::Decline#reason

Constant Summary collapse

DO_NOT_HONOR =

The card issuer has declined the transaction without providing a specific reason.

Returns:

  • (:do_not_honor)
:do_not_honor
ACTIVITY_COUNT_LIMIT_EXCEEDED =

The number of transactions for the card has exceeded the limit set by the issuer.

Returns:

  • (:activity_count_limit_exceeded)
:activity_count_limit_exceeded
REFER_TO_CARD_ISSUER =

The card issuer requires the cardholder to contact them for further information regarding the transaction.

Returns:

  • (:refer_to_card_issuer)
:refer_to_card_issuer
REFER_TO_CARD_ISSUER_SPECIAL_CONDITION =

The card issuer requires the cardholder to contact them due to a special condition related to the transaction.

Returns:

  • (:refer_to_card_issuer_special_condition)
:refer_to_card_issuer_special_condition
INVALID_MERCHANT =

The merchant is not valid for this transaction.

Returns:

  • (:invalid_merchant)
:invalid_merchant
PICK_UP_CARD =

The card should be retained by the terminal.

Returns:

  • (:pick_up_card)
:pick_up_card
ERROR =

An error occurred during processing of the transaction.

Returns:

  • (:error)
:error
PICK_UP_CARD_SPECIAL =

The card should be retained by the terminal due to a special condition.

Returns:

  • (:pick_up_card_special)
:pick_up_card_special
INVALID_TRANSACTION =

The transaction is invalid and cannot be processed.

Returns:

  • (:invalid_transaction)
:invalid_transaction
INVALID_AMOUNT =

The amount of the transaction is invalid.

Returns:

  • (:invalid_amount)
:invalid_amount
INVALID_ACCOUNT_NUMBER =

The account number provided is invalid.

Returns:

  • (:invalid_account_number)
:invalid_account_number
NO_SUCH_ISSUER =

The issuer of the card could not be found.

Returns:

  • (:no_such_issuer)
:no_such_issuer
RE_ENTER_TRANSACTION =

The transaction should be re-entered for processing.

Returns:

  • (:re_enter_transaction)
:re_enter_transaction
NO_CREDIT_ACCOUNT =

There is no credit account associated with the card.

Returns:

  • (:no_credit_account)
:no_credit_account
PICK_UP_CARD_LOST =

The card should be retained by the terminal because it has been reported lost.

Returns:

  • (:pick_up_card_lost)
:pick_up_card_lost
PICK_UP_CARD_STOLEN =

The card should be retained by the terminal because it has been reported stolen.

Returns:

  • (:pick_up_card_stolen)
:pick_up_card_stolen
CLOSED_ACCOUNT =

The account associated with the card has been closed.

Returns:

  • (:closed_account)
:closed_account
INSUFFICIENT_FUNDS =

There are insufficient funds in the account to complete the transaction.

Returns:

  • (:insufficient_funds)
:insufficient_funds
NO_CHECKING_ACCOUNT =

There is no checking account associated with the card.

Returns:

  • (:no_checking_account)
:no_checking_account
NO_SAVINGS_ACCOUNT =

There is no savings account associated with the card.

Returns:

  • (:no_savings_account)
:no_savings_account
EXPIRED_CARD =

The card has expired and cannot be used for transactions.

Returns:

  • (:expired_card)
:expired_card
TRANSACTION_NOT_PERMITTED_TO_CARDHOLDER =

The transaction is not permitted for this cardholder.

Returns:

  • (:transaction_not_permitted_to_cardholder)
:transaction_not_permitted_to_cardholder
TRANSACTION_NOT_ALLOWED_AT_TERMINAL =

The transaction is not allowed at this terminal.

Returns:

  • (:transaction_not_allowed_at_terminal)
:transaction_not_allowed_at_terminal
TRANSACTION_NOT_SUPPORTED_OR_BLOCKED_BY_ISSUER =

The transaction is not supported or has been blocked by the issuer.

Returns:

  • (:transaction_not_supported_or_blocked_by_issuer)
:transaction_not_supported_or_blocked_by_issuer
SUSPECTED_FRAUD =

The transaction has been flagged as suspected fraud and cannot be processed.

Returns:

  • (:suspected_fraud)
:suspected_fraud
ACTIVITY_AMOUNT_LIMIT_EXCEEDED =

The amount of activity on the card has exceeded the limit set by the issuer.

Returns:

  • (:activity_amount_limit_exceeded)
:activity_amount_limit_exceeded
RESTRICTED_CARD =

The card has restrictions that prevent it from being used for this transaction.

Returns:

  • (:restricted_card)
:restricted_card
SECURITY_VIOLATION =

A security violation has occurred, preventing the transaction from being processed.

Returns:

  • (:security_violation)
:security_violation
TRANSACTION_DOES_NOT_FULFILL_ANTI_MONEY_LAUNDERING_REQUIREMENT =

The transaction does not meet the anti-money laundering requirements set by the issuer.

Returns:

  • (:transaction_does_not_fulfill_anti_money_laundering_requirement)
:transaction_does_not_fulfill_anti_money_laundering_requirement
BLOCKED_BY_CARDHOLDER =

The transaction was blocked by the cardholder.

Returns:

  • (:blocked_by_cardholder)
:blocked_by_cardholder
BLOCKED_FIRST_USE =

The first use of the card has been blocked by the issuer.

Returns:

  • (:blocked_first_use)
:blocked_first_use
CREDIT_ISSUER_UNAVAILABLE =

The credit issuer is currently unavailable to process the transaction.

Returns:

  • (:credit_issuer_unavailable)
:credit_issuer_unavailable
NEGATIVE_CARD_VERIFICATION_VALUE_RESULTS =

The card verification value (CVV) results were negative, indicating a potential issue with the card.

Returns:

  • (:negative_card_verification_value_results)
:negative_card_verification_value_results
ISSUER_UNAVAILABLE =

The issuer of the card is currently unavailable to process the transaction.

Returns:

  • (:issuer_unavailable)
:issuer_unavailable
FINANCIAL_INSTITUTION_CANNOT_BE_FOUND =

The financial institution associated with the card could not be found.

Returns:

  • (:financial_institution_cannot_be_found)
:financial_institution_cannot_be_found
TRANSACTION_CANNOT_BE_COMPLETED =

The transaction cannot be completed due to an unspecified reason.

Returns:

  • (:transaction_cannot_be_completed)
:transaction_cannot_be_completed
DUPLICATE_TRANSACTION =

The transaction is a duplicate of a previous transaction and cannot be processed again.

Returns:

  • (:duplicate_transaction)
:duplicate_transaction
SYSTEM_MALFUNCTION =

A system malfunction occurred, preventing the transaction from being processed.

Returns:

  • (:system_malfunction)
:system_malfunction
ADDITIONAL_CUSTOMER_AUTHENTICATION_REQUIRED =

Additional customer authentication is required to complete the transaction.

Returns:

  • (:additional_customer_authentication_required)
:additional_customer_authentication_required
SURCHARGE_AMOUNT_NOT_PERMITTED =

The surcharge amount applied to the transaction is not permitted by the issuer.

Returns:

  • (:surcharge_amount_not_permitted)
:surcharge_amount_not_permitted
DECLINE_FOR_CVV2_FAILURE =

The transaction was declined due to a failure in verifying the CVV2 code.

Returns:

  • (:decline_for_cvv2_failure)
:decline_for_cvv2_failure
STOP_PAYMENT_ORDER =

A stop payment order has been placed on this transaction.

Returns:

  • (:stop_payment_order)
:stop_payment_order
REVOCATION_OF_AUTHORIZATION_ORDER =

An order has been placed to revoke authorization for this transaction.

Returns:

  • (:revocation_of_authorization_order)
:revocation_of_authorization_order
REVOCATION_OF_ALL_AUTHORIZATIONS_ORDER =

An order has been placed to revoke all authorizations for this cardholder.

Returns:

  • (:revocation_of_all_authorizations_order)
:revocation_of_all_authorizations_order
UNABLE_TO_LOCATE_RECORD =

The record associated with the transaction could not be located.

Returns:

  • (:unable_to_locate_record)
:unable_to_locate_record
FILE_IS_TEMPORARILY_UNAVAILABLE =

The file needed for the transaction is temporarily unavailable.

Returns:

  • (:file_is_temporarily_unavailable)
:file_is_temporarily_unavailable
INCORRECT_PIN =

The PIN entered for the transaction is incorrect.

Returns:

  • (:incorrect_pin)
:incorrect_pin
ALLOWABLE_NUMBER_OF_PIN_ENTRY_TRIES_EXCEEDED =

The allowable number of PIN entry tries has been exceeded.

Returns:

  • (:allowable_number_of_pin_entry_tries_exceeded)
:allowable_number_of_pin_entry_tries_exceeded
UNABLE_TO_LOCATE_PREVIOUS_MESSAGE =

The previous message associated with the transaction could not be located.

Returns:

  • (:unable_to_locate_previous_message)
:unable_to_locate_previous_message
PIN_ERROR_FOUND =

An error was found with the PIN associated with the transaction.

Returns:

  • (:pin_error_found)
:pin_error_found
CANNOT_VERIFY_PIN =

The PIN associated with the transaction could not be verified.

Returns:

  • (:cannot_verify_pin)
:cannot_verify_pin
VERIFICATION_DATA_FAILED =

The verification data associated with the transaction has failed.

Returns:

  • (:verification_data_failed)
:verification_data_failed
SURCHARGE_AMOUNT_NOT_SUPPORTED_BY_DEBIT_NETWORK_ISSUER =

The surcharge amount is not supported by the debit network issuer.

Returns:

  • (:surcharge_amount_not_supported_by_debit_network_issuer)
:surcharge_amount_not_supported_by_debit_network_issuer
CASH_SERVICE_NOT_AVAILABLE =

Cash service is not available for this transaction.

Returns:

  • (:cash_service_not_available)
:cash_service_not_available
CASHBACK_REQUEST_EXCEEDS_ISSUER_LIMIT =

The cashback request exceeds the issuer limit.

Returns:

  • (:cashback_request_exceeds_issuer_limit)
:cashback_request_exceeds_issuer_limit
TRANSACTION_AMOUNT_EXCEEDS_PRE_AUTHORIZED_APPROVAL_AMOUNT =

The transaction amount exceeds the pre-authorized approval amount.

Returns:

  • (:transaction_amount_exceeds_pre_authorized_approval_amount)
:transaction_amount_exceeds_pre_authorized_approval_amount
TRANSACTION_DOES_NOT_QUALIFY_FOR_VISA_PIN =

The transaction does not qualify for Visa PIN processing.

Returns:

  • (:transaction_does_not_qualify_for_visa_pin)
:transaction_does_not_qualify_for_visa_pin
OFFLINE_DECLINED =

The transaction was declined offline.

Returns:

  • (:offline_declined)
:offline_declined
UNABLE_TO_GO_ONLINE =

The terminal was unable to go online to process the transaction.

Returns:

  • (:unable_to_go_online)
:unable_to_go_online
VALID_ACCOUNT_BUT_AMOUNT_NOT_SUPPORTED =

The account is valid but the transaction amount is not supported.

Returns:

  • (:valid_account_but_amount_not_supported)
:valid_account_but_amount_not_supported
INVALID_USE_OF_MERCHANT_CATEGORY_CODE_CORRECT_AND_REATTEMPT =

The merchant category code was used incorrectly; correct it and reattempt the transaction.

Returns:

  • (:invalid_use_of_merchant_category_code_correct_and_reattempt)
:invalid_use_of_merchant_category_code_correct_and_reattempt
CARD_AUTHENTICATION_FAILED =

The card authentication process has failed.

Returns:

  • (:card_authentication_failed)
:card_authentication_failed

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPushTransfer::Decline::reason]

Returns:

  • (::Array[Increase::Models::CardPushTransfer::Decline::reason])


686
# File 'sig/increase/models/card_push_transfer.rbs', line 686

def self?.values: -> ::Array[Increase::Models::CardPushTransfer::Decline::reason]