Module: Increase::Models::CardPushTransfer::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_push_transfer.rb,
sig/increase/models/card_push_transfer.rbs

Overview

The lifecycle status of the transfer.

See Also:

  • Increase::Models::CardPushTransfer#status

Constant Summary collapse

PENDING_APPROVAL =

The transfer is pending approval.

Returns:

  • (:pending_approval)
:pending_approval
CANCELED =

The transfer has been canceled.

Returns:

  • (:canceled)
:canceled
PENDING_SUBMISSION =

The transfer is queued to be submitted to the card network.

Returns:

  • (:pending_submission)
:pending_submission
PENDING_REVIEWING =

The transfer is pending review by Increase.

Returns:

  • (:pending_reviewing)
:pending_reviewing
REQUIRES_ATTENTION =

The transfer requires attention from an Increase operator.

Returns:

  • (:requires_attention)
:requires_attention
SUBMITTED =

The transfer has been submitted and is pending a response from the card network.

Returns:

  • (:submitted)
:submitted
COMPLETE =

The transfer has been sent successfully and is complete.

Returns:

  • (:complete)
:complete
DECLINED =

The transfer was declined by the network or the recipient's bank.

Returns:

  • (:declined)
:declined

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPushTransfer::status]

Returns:

  • (::Array[Increase::Models::CardPushTransfer::status])


1414
# File 'sig/increase/models/card_push_transfer.rbs', line 1414

def self?.values: -> ::Array[Increase::Models::CardPushTransfer::status]