Class: Increase::Models::CardPushTransferCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/card_push_transfer_create_params.rb

Overview

Defined Under Namespace

Modules: BusinessApplicationIdentifier Classes: PresentmentAmount

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(business_application_identifier:, card_token_id:, merchant_category_code:, merchant_city_name:, merchant_name:, merchant_name_prefix:, merchant_postal_code:, merchant_state:, presentment_amount:, recipient_name:, sender_address_city:, sender_address_line1:, sender_address_postal_code:, sender_address_state:, sender_name:, source_account_number_id:, merchant_legal_business_name: nil, merchant_street_address: nil, recipient_address_city: nil, recipient_address_line1: nil, recipient_address_postal_code: nil, recipient_address_state: nil, require_approval: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPushTransferCreateParams for more details.

Parameters:

  • business_application_identifier (Symbol, Increase::Models::CardPushTransferCreateParams::BusinessApplicationIdentifier)

    The Business Application Identifier describes the type of transaction being perf

  • card_token_id (String)

    The Increase identifier for the Card Token that represents the card number you’r

  • merchant_category_code (String)

    The merchant category code (MCC) of the merchant (generally your business) sendi

  • merchant_city_name (String)

    The city name of the merchant (generally your business) sending the transfer.

  • merchant_name (String)

    The merchant name shows up as the statement descriptor for the transfer. This is

  • merchant_name_prefix (String)

    For certain Business Application Identifiers, the statement descriptor is ‘merch

  • merchant_postal_code (String)

    The postal code of the merchant (generally your business) sending the transfer.

  • merchant_state (String)

    The state of the merchant (generally your business) sending the transfer.

  • presentment_amount (Increase::Models::CardPushTransferCreateParams::PresentmentAmount)

    The amount to transfer. The receiving bank will convert this to the cardholder’s

  • recipient_name (String)

    The name of the funds recipient.

  • sender_address_city (String)

    The city of the sender.

  • sender_address_line1 (String)

    The address line 1 of the sender.

  • sender_address_postal_code (String)

    The postal code of the sender.

  • sender_address_state (String)

    The state of the sender.

  • sender_name (String)

    The name of the funds originator.

  • source_account_number_id (String)

    The identifier of the Account Number from which to send the transfer.

  • merchant_legal_business_name (String) (defaults to: nil)

    The legal business name of the merchant (generally your business) sending the tr

  • merchant_street_address (String) (defaults to: nil)

    The street address of the merchant (generally your business) sending the transfe

  • recipient_address_city (String) (defaults to: nil)

    The city of the recipient. Required if the card is issued in Canada.

  • recipient_address_line1 (String) (defaults to: nil)

    The first line of the recipient’s address. Required if the card is issued in Can

  • recipient_address_postal_code (String) (defaults to: nil)

    The postal code of the recipient. Required if the card is issued in Canada.

  • recipient_address_state (String) (defaults to: nil)

    The state or province of the recipient. Required if the card is issued in Canada

  • require_approval (Boolean) (defaults to: nil)

    Whether the transfer requires explicit approval via the dashboard or API.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/increase/models/card_push_transfer_create_params.rb', line 164

Instance Attribute Details

#business_application_identifierSymbol, Increase::Models::CardPushTransferCreateParams::BusinessApplicationIdentifier

The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.



16
17
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 16

required :business_application_identifier,
enum: -> { Increase::CardPushTransferCreateParams::BusinessApplicationIdentifier }

#card_token_idString

The Increase identifier for the Card Token that represents the card number you’re pushing funds to.

Returns:

  • (String)


24
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 24

required :card_token_id, String

#merchant_category_codeString

The merchant category code (MCC) of the merchant (generally your business) sending the transfer. This is a four-digit code that describes the type of business or service provided by the merchant. Your program must be approved for the specified MCC in order to use it.

Returns:

  • (String)


33
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 33

required :merchant_category_code, String

#merchant_city_nameString

The city name of the merchant (generally your business) sending the transfer.

Returns:

  • (String)


39
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 39

required :merchant_city_name, String

The legal business name of the merchant (generally your business) sending the transfer. Required if the card is issued in Canada.

Returns:

  • (String, nil)


123
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 123

optional :merchant_legal_business_name, String

#merchant_nameString

The merchant name shows up as the statement descriptor for the transfer. This is typically the name of your business or organization.

Returns:

  • (String)


46
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 46

required :merchant_name, String

#merchant_name_prefixString

For certain Business Application Identifiers, the statement descriptor is ‘merchant_name_prefix*sender_name`, where the `merchant_name_prefix` is a one to four character prefix that identifies the merchant.

Returns:

  • (String)


54
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 54

required :merchant_name_prefix, String

#merchant_postal_codeString

The postal code of the merchant (generally your business) sending the transfer.

Returns:

  • (String)


60
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 60

required :merchant_postal_code, String

#merchant_stateString

The state of the merchant (generally your business) sending the transfer.

Returns:

  • (String)


66
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 66

required :merchant_state, String

#merchant_street_addressString?

The street address of the merchant (generally your business) sending the transfer. Required if the card is issued in Canada.

Returns:

  • (String, nil)


130
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 130

optional :merchant_street_address, String

#presentment_amountIncrease::Models::CardPushTransferCreateParams::PresentmentAmount

The amount to transfer. The receiving bank will convert this to the cardholder’s currency. The amount that is applied to your Increase account matches the currency of your account.



74
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 74

required :presentment_amount, -> { Increase::CardPushTransferCreateParams::PresentmentAmount }

#recipient_address_cityString?

The city of the recipient. Required if the card is issued in Canada.

Returns:

  • (String, nil)


136
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 136

optional :recipient_address_city, String

#recipient_address_line1String?

The first line of the recipient’s address. Required if the card is issued in Canada.

Returns:

  • (String, nil)


143
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 143

optional :recipient_address_line1, String

#recipient_address_postal_codeString?

The postal code of the recipient. Required if the card is issued in Canada.

Returns:

  • (String, nil)


149
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 149

optional :recipient_address_postal_code, String

#recipient_address_stateString?

The state or province of the recipient. Required if the card is issued in Canada.

Returns:

  • (String, nil)


156
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 156

optional :recipient_address_state, String

#recipient_nameString

The name of the funds recipient.

Returns:

  • (String)


80
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 80

required :recipient_name, String

#require_approvalBoolean?

Whether the transfer requires explicit approval via the dashboard or API.

Returns:

  • (Boolean, nil)


162
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 162

optional :require_approval, Increase::Internal::Type::Boolean

#sender_address_cityString

The city of the sender.

Returns:

  • (String)


86
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 86

required :sender_address_city, String

#sender_address_line1String

The address line 1 of the sender.

Returns:

  • (String)


92
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 92

required :sender_address_line1, String

#sender_address_postal_codeString

The postal code of the sender.

Returns:

  • (String)


98
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 98

required :sender_address_postal_code, String

#sender_address_stateString

The state of the sender.

Returns:

  • (String)


104
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 104

required :sender_address_state, String

#sender_nameString

The name of the funds originator.

Returns:

  • (String)


110
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 110

required :sender_name, String

#source_account_number_idString

The identifier of the Account Number from which to send the transfer.

Returns:

  • (String)


116
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 116

required :source_account_number_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_push_transfer_create_params.rb', line 264