Module: Increase::Models::CardPushTransferCreateParams::BusinessApplicationIdentifier

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_push_transfer_create_params.rb,
sig/increase/models/card_push_transfer_create_params.rbs

Overview

The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.

Constant Summary collapse

ACCOUNT_TO_ACCOUNT =

Account to Account

Returns:

  • (:account_to_account)
:account_to_account
BUSINESS_TO_BUSINESS =

Business to Business

Returns:

  • (:business_to_business)
:business_to_business
MONEY_TRANSFER_BANK_INITIATED =

Money Transfer Bank Initiated

Returns:

  • (:money_transfer_bank_initiated)
:money_transfer_bank_initiated
NON_CARD_BILL_PAYMENT =

Non-Card Bill Payment

Returns:

  • (:non_card_bill_payment)
:non_card_bill_payment
CONSUMER_BILL_PAYMENT =

Consumer Bill Payment

Returns:

  • (:consumer_bill_payment)
:consumer_bill_payment
CARD_BILL_PAYMENT =

Card Bill Payment

Returns:

  • (:card_bill_payment)
:card_bill_payment
FUNDS_DISBURSEMENT =

Funds Disbursement

Returns:

  • (:funds_disbursement)
:funds_disbursement
FUNDS_TRANSFER =

Funds Transfer

Returns:

  • (:funds_transfer)
:funds_transfer
LOYALTY_AND_OFFERS =

Loyalty and Offers

Returns:

  • (:loyalty_and_offers)
:loyalty_and_offers
MERCHANT_DISBURSEMENT =

Merchant Disbursement

Returns:

  • (:merchant_disbursement)
:merchant_disbursement
MERCHANT_PAYMENT =

Merchant Payment

Returns:

  • (:merchant_payment)
:merchant_payment
PERSON_TO_PERSON =

Person to Person

Returns:

  • (:person_to_person)
:person_to_person
TOP_UP =

Top Up

Returns:

  • (:top_up)
:top_up
WALLET_TRANSFER =

Wallet Transfer

Returns:

  • (:wallet_transfer)
:wallet_transfer

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardPushTransferCreateParams::business_application_identifier]

Returns:

  • (::Array[Increase::Models::CardPushTransferCreateParams::business_application_identifier])


210
# File 'sig/increase/models/card_push_transfer_create_params.rbs', line 210

def self?.values: -> ::Array[Increase::Models::CardPushTransferCreateParams::business_application_identifier]