Class: Increase::Models::CardPushTransferCreateParams::PresentmentAmount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_push_transfer_create_params.rb,
sig/increase/models/card_push_transfer_create_params.rbs

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(currency:, value:) ⇒ Object

The amount to transfer. The receiving bank will convert this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.



# File 'lib/increase/models/card_push_transfer_create_params.rb', line 313

Instance Attribute Details

#currencySymbol, Increase::Models::CardPushTransferCreateParams::PresentmentAmount::Currency

The ISO 4217 currency code representing the currency of the amount.



301
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 301

required :currency, enum: -> { Increase::CardPushTransferCreateParams::PresentmentAmount::Currency }

#valueString

The amount value as a decimal string in the currency's major unit. For example, for USD, '1234.56' represents 1234 dollars and 56 cents. For JPY, '1234' represents 1234 yen. A currency with minor units requires at least one decimal place and supports up to the number of decimal places defined by the currency's minor units. A currency without minor units does not support any decimal places.



311
# File 'lib/increase/models/card_push_transfer_create_params.rb', line 311

required :value, String

Instance Method Details

#to_hash{



229
# File 'sig/increase/models/card_push_transfer_create_params.rbs', line 229

def to_hash: -> {