Class: Increase::Models::CardToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_token.rb,
sig/increase/models/card_token.rbs

Overview

See Also:

  • Increase::Resources::CardTokens#retrieve

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, expiration_date:, last4:, length:, prefix:, type:) ⇒ Object

Card Tokens represent a tokenized card number that can be used for Card Push Transfers and Card Validations.



# File 'lib/increase/models/card_token.rb', line 52


Instance Attribute Details

#created_atTime

The ISO 8601 date and time at which the card token was created.



18
# File 'lib/increase/models/card_token.rb', line 18

required :created_at, Time

#expiration_dateDate

The ISO 8601 date when the card expires.



25
# File 'lib/increase/models/card_token.rb', line 25

required :expiration_date, Date

#idString

The Card Token's identifier.



11
# File 'lib/increase/models/card_token.rb', line 11

required :id, String

#last4String

The last 4 digits of the card number.



31
# File 'lib/increase/models/card_token.rb', line 31

required :last4, String

#lengthInteger

The length of the card number.



37
# File 'lib/increase/models/card_token.rb', line 37

required :length, Integer

#prefixString

The prefix of the card number, usually 8 digits.



43
# File 'lib/increase/models/card_token.rb', line 43

required :prefix, String

#typeSymbol, Increase::Models::CardToken::Type

A constant representing the object's type. For this resource it will always be card_token.



50
# File 'lib/increase/models/card_token.rb', line 50

required :type, enum: -> { Increase::CardToken::Type }

Instance Method Details

#to_hash{



39
# File 'sig/increase/models/card_token.rbs', line 39

def to_hash: -> {