Class: Increase::Models::CardUpdateParams::AuthorizationControls::MerchantAcceptorIdentifier::Allowed

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/card_update_params.rb,
sig/increase/models/card_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed: nil, blocked: nil) ⇒ Allowed

Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.

Parameters:

  • (defaults to: nil)

    The Merchant Acceptor IDs that are allowed for authorizations on this card. Authorizations with Merchant Acceptor IDs not in this list will be declined.

  • (defaults to: nil)

    The Merchant Acceptor IDs that are blocked for authorizations on this card. Authorizations with Merchant Acceptor IDs in this list will be declined.



157
158
159
160
161
162
163
164
165
166
# File 'lib/increase/models/card_update_params.rb', line 157

class Allowed < Increase::Internal::Type::BaseModel
  # @!attribute identifier
  #   The Merchant Acceptor ID.
  #
  #   @return [String]
  required :identifier, String

  # @!method initialize(identifier:)
  #   @param identifier [String] The Merchant Acceptor ID.
end

Instance Attribute Details

#identifierString

The Merchant Acceptor ID.

Parameters:

Returns:



162
# File 'lib/increase/models/card_update_params.rb', line 162

required :identifier, String

Instance Method Details

#to_hash{ identifier: String }

Returns:



158
# File 'sig/increase/models/card_update_params.rbs', line 158

def to_hash: -> { identifier: String }