Class: Increase::Models::CardUpdateParams::AuthorizationControls::MerchantCountry::Allowed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_update_params.rb,
sig/increase/models/card_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed: nil, blocked: nil) ⇒ Allowed

Restricts which merchant countries are allowed or blocked for authorizations on this card.

Parameters:

  • (defaults to: nil)

    The merchant countries that are allowed for authorizations on this card. Authorizations with merchant countries not in this list will be declined.

  • (defaults to: nil)

    The merchant countries that are blocked for authorizations on this card. Authorizations with merchant countries in this list will be declined.



263
264
265
266
267
268
269
270
271
272
# File 'lib/increase/models/card_update_params.rb', line 263

class Allowed < Increase::Internal::Type::BaseModel
  # @!attribute country
  #   The ISO 3166-1 alpha-2 country code.
  #
  #   @return [String]
  required :country, String

  # @!method initialize(country:)
  #   @param country [String] The ISO 3166-1 alpha-2 country code.
end

Instance Attribute Details

#countryString

The ISO 3166-1 alpha-2 country code.

Parameters:

Returns:



268
# File 'lib/increase/models/card_update_params.rb', line 268

required :country, String

Instance Method Details

#to_hash{ country: String }

Returns:



258
# File 'sig/increase/models/card_update_params.rbs', line 258

def to_hash: -> { country: String }