Module: Increase::Models::CardUpdateParams::AuthorizationControls::Usage::SingleUse::SettlementAmount::Comparison
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_update_params.rb,
sig/increase/models/card_update_params.rbs
Overview
The operator used to compare the settlement amount.
Constant Summary collapse
- EQUALS =
The settlement amount must be exactly the specified value.
:equals- LESS_THAN_OR_EQUALS =
The settlement amount must be less than or equal to the specified value.
:less_than_or_equals
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardUpdateParams::AuthorizationControls::Usage::SingleUse::SettlementAmount::comparison]
454 |
# File 'sig/increase/models/card_update_params.rbs', line 454
def self?.values: -> ::Array[Increase::Models::CardUpdateParams::AuthorizationControls::Usage::SingleUse::SettlementAmount::comparison]
|