Class: Increase::Models::CardUpdateParams::DigitalWallet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardUpdateParams::DigitalWallet
- Defined in:
- lib/increase/models/card_update_params.rb,
sig/increase/models/card_update_params.rbs
Instance Attribute Summary collapse
-
#digital_card_profile_id ⇒ String?
The digital card profile assigned to this digital card.
-
#email ⇒ String?
An email address that can be used to verify the cardholder via one-time passcode over email.
-
#phone ⇒ String?
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
516 |
# File 'sig/increase/models/card_update_params.rbs', line 516
def initialize: (
|
Instance Attribute Details
#digital_card_profile_id ⇒ String?
The digital card profile assigned to this digital card.
525 |
# File 'lib/increase/models/card_update_params.rb', line 525 optional :digital_card_profile_id, String |
#email ⇒ String?
An email address that can be used to verify the cardholder via one-time passcode over email.
532 |
# File 'lib/increase/models/card_update_params.rb', line 532 optional :email, String |
#phone ⇒ String?
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
539 |
# File 'lib/increase/models/card_update_params.rb', line 539 optional :phone, String |
Instance Method Details
#to_hash ⇒ {
522 |
# File 'sig/increase/models/card_update_params.rbs', line 522
def to_hash: -> {
|