Module: Increase::Models::CardValidation::Acceptance::CardholderFirstNameResult

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_validation.rb,
sig/increase/models/card_validation.rbs

Overview

The result of the cardholder first name match.

See Also:

  • Increase::Models::CardValidation::Acceptance#cardholder_first_name_result

Constant Summary collapse

MATCH =

The cardholder name component matches the expected value.

Returns:

  • (:match)
:match
NO_MATCH =

The cardholder name component does not match the expected value.

Returns:

  • (:no_match)
:no_match
PARTIAL_MATCH =

The cardholder name component partially matches the expected value.

Returns:

  • (:partial_match)
:partial_match

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CardValidation::Acceptance::cardholder_first_name_result]

Returns:

  • (::Array[Increase::Models::CardValidation::Acceptance::cardholder_first_name_result])


213
# File 'sig/increase/models/card_validation.rbs', line 213

def self?.values: -> ::Array[Increase::Models::CardValidation::Acceptance::cardholder_first_name_result]