Class: Increase::Models::CardValidation::Submission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardValidation::Submission
- Defined in:
- lib/increase/models/card_validation.rb,
sig/increase/models/card_validation.rbs
Overview
Instance Attribute Summary collapse
-
#retrieval_reference_number ⇒ String
A 12-digit retrieval reference number that identifies the validation.
-
#submitted_at ⇒ Time
The ISO 8601 date and time at which the validation was submitted to the card network.
-
#trace_number ⇒ String
A 6-digit trace number that identifies the validation within a short time window.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
717 |
# File 'sig/increase/models/card_validation.rbs', line 717
def initialize: (
|
Instance Attribute Details
#retrieval_reference_number ⇒ String
A 12-digit retrieval reference number that identifies the validation. Usually a combination of a timestamp and the trace number.
813 |
# File 'lib/increase/models/card_validation.rb', line 813 required :retrieval_reference_number, String |
#submitted_at ⇒ Time
The ISO 8601 date and time at which the validation was submitted to the card network.
820 |
# File 'lib/increase/models/card_validation.rb', line 820 required :submitted_at, Time |
#trace_number ⇒ String
A 6-digit trace number that identifies the validation within a short time window.
827 |
# File 'lib/increase/models/card_validation.rb', line 827 required :trace_number, String |
Instance Method Details
#to_hash ⇒ {
723 |
# File 'sig/increase/models/card_validation.rbs', line 723
def to_hash: -> {
|