Module: Increase::Models::CardValidationListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_validation_list_params.rb,
sig/increase/models/card_validation_list_params.rbs

Constant Summary collapse

REQUIRES_ATTENTION =

The validation requires attention from an Increase operator.

:requires_attention
PENDING_SUBMISSION =

The validation is queued to be submitted to the card network.

:pending_submission
SUBMITTED =

The validation has been submitted and is pending a response from the card network.

:submitted
COMPLETE =

The validation has been sent successfully and is complete.

:complete
DECLINED =

The validation was declined by the network or the recipient's bank.

:declined

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/card_validation_list_params.rb', line 155


Instance Method Details

#initialize(in_: nil) ⇒ Object



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/increase/models/card_validation_list_params.rb', line 137

module In
  extend Increase::Internal::Type::Enum

  # The validation requires attention from an Increase operator.
  REQUIRES_ATTENTION = :requires_attention

  # The validation is queued to be submitted to the card network.
  PENDING_SUBMISSION = :pending_submission

  # The validation has been submitted and is pending a response from the card network.
   = :submitted

  # The validation has been sent successfully and is complete.
  COMPLETE = :complete

  # The validation was declined by the network or the recipient's bank.
  DECLINED = :declined

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::CardValidationListParams::Status::in_]



146
# File 'sig/increase/models/card_validation_list_params.rbs', line 146

def self?.values: -> ::Array[Increase::Models::CardValidationListParams::Status::in_]