Class: Increase::Models::CheckDeposit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs

Overview

See Also:

  • Increase::Resources::CheckDeposits#create

Defined Under Namespace

Modules: Status, Type Classes: DepositAcceptance, DepositAdjustment, DepositRejection, DepositReturn, DepositSubmission, InboundFundsHold

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(back_file_id:, front_file_id:, submitted_at:) ⇒ Object

After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.

Parameters:

  • back_file_id (String)

    The ID for the File containing the check back image that was submitted to the Check21 network.

  • front_file_id (String)

    The ID for the File containing the check front image that was submitted to the Check21 network.

  • submitted_at (Time)

    When the check deposit was submitted to the Check21 network for processing. During business days, this happens within a few hours of the check being accepted by Increase.



# File 'lib/increase/models/check_deposit.rb', line 135

Instance Attribute Details

#account_idString

The Account the check was deposited into.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/increase/models/check_deposit.rb', line 17

required :account_id, String

#amountInteger

The deposited amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


23
# File 'lib/increase/models/check_deposit.rb', line 23

required :amount, Integer

#back_image_file_idString?

The ID for the File containing the image of the back of the check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


29
# File 'lib/increase/models/check_deposit.rb', line 29

required :back_image_file_id, String, nil?: true

#created_atTime

The ISO 8601 date and time at which the transfer was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


36
# File 'lib/increase/models/check_deposit.rb', line 36

required :created_at, Time

#deposit_acceptanceIncrease::Models::CheckDeposit::DepositAcceptance?

Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.

Parameters:

  • value (Increase::CheckDeposit::DepositAcceptance, nil)

Returns:



43
# File 'lib/increase/models/check_deposit.rb', line 43

required :deposit_acceptance, -> { Increase::CheckDeposit::DepositAcceptance }, nil?: true

#deposit_adjustmentsArray<Increase::Models::CheckDeposit::DepositAdjustment>

If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments.

Parameters:

  • value (::Array[Increase::CheckDeposit::DepositAdjustment])

Returns:



50
51
# File 'lib/increase/models/check_deposit.rb', line 50

required :deposit_adjustments,
-> { Increase::Internal::Type::ArrayOf[Increase::CheckDeposit::DepositAdjustment] }

#deposit_rejectionIncrease::Models::CheckDeposit::DepositRejection?

If your deposit is rejected by Increase, this will contain details as to why it was rejected.

Parameters:

  • value (Increase::CheckDeposit::DepositRejection, nil)

Returns:



58
# File 'lib/increase/models/check_deposit.rb', line 58

required :deposit_rejection, -> { Increase::CheckDeposit::DepositRejection }, nil?: true

#deposit_returnIncrease::Models::CheckDeposit::DepositReturn?

If your deposit is returned, this will contain details as to why it was returned.

Parameters:

  • value (Increase::CheckDeposit::DepositReturn, nil)

Returns:



65
# File 'lib/increase/models/check_deposit.rb', line 65

required :deposit_return, -> { Increase::CheckDeposit::DepositReturn }, nil?: true

#deposit_submissionIncrease::Models::CheckDeposit::DepositSubmission?

After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.

Parameters:

  • value (Increase::CheckDeposit::DepositSubmission, nil)

Returns:



72
# File 'lib/increase/models/check_deposit.rb', line 72

required :deposit_submission, -> { Increase::CheckDeposit::DepositSubmission }, nil?: true

#descriptionString?

The description of the Check Deposit, for display purposes only.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


78
# File 'lib/increase/models/check_deposit.rb', line 78

required :description, String, nil?: true

#front_image_file_idString

The ID for the File containing the image of the front of the check.

Parameters:

  • value (String)

Returns:

  • (String)


84
# File 'lib/increase/models/check_deposit.rb', line 84

required :front_image_file_id, String

#idString

The deposit's identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/check_deposit.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


92
# File 'lib/increase/models/check_deposit.rb', line 92

required :idempotency_key, String, nil?: true

#inbound_funds_holdIncrease::Models::CheckDeposit::InboundFundsHold?

Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.

Parameters:

  • value (Increase::CheckDeposit::InboundFundsHold, nil)

Returns:



99
# File 'lib/increase/models/check_deposit.rb', line 99

required :inbound_funds_hold, -> { Increase::CheckDeposit::InboundFundsHold }, nil?: true

#inbound_mail_item_idString?

If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


106
# File 'lib/increase/models/check_deposit.rb', line 106

required :inbound_mail_item_id, String, nil?: true

#lockbox_recipient_idString?

If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


114
# File 'lib/increase/models/check_deposit.rb', line 114

required :lockbox_recipient_id, String, nil?: true

#statusSymbol, Increase::Models::CheckDeposit::Status

The status of the Check Deposit.

Parameters:

  • value (Increase::Models::CheckDeposit::status)

Returns:



120
# File 'lib/increase/models/check_deposit.rb', line 120

required :status, enum: -> { Increase::CheckDeposit::Status }

#transaction_idString?

The ID for the Transaction created by the deposit.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


126
# File 'lib/increase/models/check_deposit.rb', line 126

required :transaction_id, String, nil?: true

#typeSymbol, Increase::Models::CheckDeposit::Type

A constant representing the object's type. For this resource it will always be check_deposit.

Parameters:

  • value (Increase::Models::CheckDeposit::type_)

Returns:



133
# File 'lib/increase/models/check_deposit.rb', line 133

required :type, enum: -> { Increase::CheckDeposit::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/check_deposit.rb', line 290

Instance Method Details

#to_hash{

Returns:

  • ({)


87
# File 'sig/increase/models/check_deposit.rbs', line 87

def to_hash: -> {