Class: Increase::Models::CheckDeposit::DepositAcceptance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs

Overview

See Also:

  • Increase::Models::CheckDeposit#deposit_acceptance

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, amount:, auxiliary_on_us:, check_deposit_id:, currency:, routing_number:, serial_number:) ⇒ Object

Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.



# File 'lib/increase/models/check_deposit.rb', line 250


Instance Attribute Details

#account_numberString

The account number printed on the check. This is an account at the bank that issued the check.



207
# File 'lib/increase/models/check_deposit.rb', line 207

required :account_number, String

#amountInteger

The amount to be deposited in the minor unit of the transaction's currency. For dollars, for example, this is cents.



214
# File 'lib/increase/models/check_deposit.rb', line 214

required :amount, Integer

#auxiliary_on_usString?

An additional line of metadata printed on the check. This typically includes the check number for business checks.



221
# File 'lib/increase/models/check_deposit.rb', line 221

required :auxiliary_on_us, String, nil?: true

#check_deposit_idString

The ID of the Check Deposit that was accepted.



227
# File 'lib/increase/models/check_deposit.rb', line 227

required :check_deposit_id, String

#currencySymbol, Increase::Models::CheckDeposit::DepositAcceptance::Currency

The ISO 4217 code for the transaction's currency.



234
# File 'lib/increase/models/check_deposit.rb', line 234

required :currency, enum: -> { Increase::CheckDeposit::DepositAcceptance::Currency }

#routing_numberString

The routing number printed on the check. This is a routing number for the bank that issued the check.



241
# File 'lib/increase/models/check_deposit.rb', line 241

required :routing_number, String

#serial_numberString?

The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the auxiliary_on_us field.



248
# File 'lib/increase/models/check_deposit.rb', line 248

required :serial_number, String, nil?: true

Instance Method Details

#to_hash{



145
# File 'sig/increase/models/check_deposit.rbs', line 145

def to_hash: -> {