Module: Increase::Models::CheckDeposit::DepositAdjustment::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs

Overview

The reason for the adjustment.

See Also:

  • Increase::Models::CheckDeposit::DepositAdjustment#reason

Constant Summary collapse

ADJUSTED_AMOUNT =

The check was deposited with a different amount than what was written on the check.

Returns:

  • (:adjusted_amount)
:adjusted_amount
NON_CONFORMING_ITEM =

The recipient was not able to process the check. This usually happens for e.g., low quality images.

Returns:

  • (:non_conforming_item)
:non_conforming_item
:paid

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CheckDeposit::DepositAdjustment::reason]

Returns:

  • (::Array[Increase::Models::CheckDeposit::DepositAdjustment::reason])


212
# File 'sig/increase/models/check_deposit.rbs', line 212

def self?.values: -> ::Array[Increase::Models::CheckDeposit::DepositAdjustment::reason]