Class: Increase::Models::CheckDeposit::DepositRejection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckDeposit::DepositRejection
- Defined in:
- lib/increase/models/check_deposit.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The rejected amount in the minor unit of check’s currency.
-
#check_deposit_id ⇒ String
The identifier of the Check Deposit that was rejected.
-
#currency ⇒ Symbol, Increase::Models::CheckDeposit::DepositRejection::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.
-
#declined_transaction_id ⇒ String
The identifier of the associated declined transaction.
-
#reason ⇒ Symbol, Increase::Models::CheckDeposit::DepositRejection::Reason
Why the check deposit was rejected.
-
#rejected_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the check deposit was rejected.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, check_deposit_id:, currency:, declined_transaction_id:, reason:, rejected_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DepositRejection for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, check_deposit_id:, currency:, declined_transaction_id:, reason:, rejected_at:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CheckDeposit::DepositRejection for more details.
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
|
|
# File 'lib/increase/models/check_deposit.rb', line 359
|
Instance Attribute Details
#amount ⇒ Integer
The rejected amount in the minor unit of check’s currency. For dollars, for example, this is cents.
325 |
# File 'lib/increase/models/check_deposit.rb', line 325 required :amount, Integer |
#check_deposit_id ⇒ String
The identifier of the Check Deposit that was rejected.
331 |
# File 'lib/increase/models/check_deposit.rb', line 331 required :check_deposit_id, String |
#currency ⇒ Symbol, Increase::Models::CheckDeposit::DepositRejection::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.
338 |
# File 'lib/increase/models/check_deposit.rb', line 338 required :currency, enum: -> { Increase::CheckDeposit::DepositRejection::Currency } |
#declined_transaction_id ⇒ String
The identifier of the associated declined transaction.
344 |
# File 'lib/increase/models/check_deposit.rb', line 344 required :declined_transaction_id, String |
#reason ⇒ Symbol, Increase::Models::CheckDeposit::DepositRejection::Reason
Why the check deposit was rejected.
350 |
# File 'lib/increase/models/check_deposit.rb', line 350 required :reason, enum: -> { Increase::CheckDeposit::DepositRejection::Reason } |
#rejected_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the check deposit was rejected.
357 |
# File 'lib/increase/models/check_deposit.rb', line 357 required :rejected_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_deposit.rb', line 388
|