Class: Increase::Models::CheckDeposit::DepositReturn
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckDeposit::DepositReturn
- Defined in:
- lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs
Overview
Defined Under Namespace
Modules: Currency, ReturnReason
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The returned amount in USD cents.
-
#check_deposit_id ⇒ String
The identifier of the Check Deposit that was returned.
-
#currency ⇒ Symbol, Increase::Models::CheckDeposit::DepositReturn::Currency
The ISO 4217 code for the transaction's currency.
-
#return_reason ⇒ Symbol, Increase::Models::CheckDeposit::DepositReturn::ReturnReason
Why this check was returned by the bank holding the account it was drawn against.
-
#returned_at ⇒ Time
The ISO 8601 date and time at which the check deposit was returned.
-
#transaction_id ⇒ String
The identifier of the transaction that reversed the original check deposit transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, check_deposit_id:, currency:, return_reason:, returned_at:, transaction_id:) ⇒ Object
constructor
If your deposit is returned, this will contain details as to why it was returned.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, check_deposit_id:, currency:, return_reason:, returned_at:, transaction_id:) ⇒ Object
If your deposit is returned, this will contain details as to why it was returned.
|
|
# File 'lib/increase/models/check_deposit.rb', line 517
|
Instance Attribute Details
#amount ⇒ Integer
The returned amount in USD cents.
481 |
# File 'lib/increase/models/check_deposit.rb', line 481 required :amount, Integer |
#check_deposit_id ⇒ String
The identifier of the Check Deposit that was returned.
487 |
# File 'lib/increase/models/check_deposit.rb', line 487 required :check_deposit_id, String |
#currency ⇒ Symbol, Increase::Models::CheckDeposit::DepositReturn::Currency
The ISO 4217 code for the transaction's currency.
494 |
# File 'lib/increase/models/check_deposit.rb', line 494 required :currency, enum: -> { Increase::CheckDeposit::DepositReturn::Currency } |
#return_reason ⇒ Symbol, Increase::Models::CheckDeposit::DepositReturn::ReturnReason
Why this check was returned by the bank holding the account it was drawn against.
501 |
# File 'lib/increase/models/check_deposit.rb', line 501 required :return_reason, enum: -> { Increase::CheckDeposit::DepositReturn::ReturnReason } |
#returned_at ⇒ Time
The ISO 8601 date and time at which the check deposit was returned.
508 |
# File 'lib/increase/models/check_deposit.rb', line 508 required :returned_at, Time |
#transaction_id ⇒ String
The identifier of the transaction that reversed the original check deposit transaction.
515 |
# File 'lib/increase/models/check_deposit.rb', line 515 required :transaction_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_deposit.rb', line 551
|
Instance Method Details
#to_hash ⇒ {
357 |
# File 'sig/increase/models/check_deposit.rbs', line 357
def to_hash: -> {
|