Module: Increase::Models::CheckDeposit::DepositReturn::ReturnReason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs

Overview

Why this check was returned by the bank holding the account it was drawn against.

See Also:

  • Increase::Models::CheckDeposit::DepositReturn#return_reason

Constant Summary collapse

ACH_CONVERSION_NOT_SUPPORTED =

The check doesn't allow ACH conversion.

Returns:

  • (:ach_conversion_not_supported)
:ach_conversion_not_supported
CLOSED_ACCOUNT =

The account is closed. (Check21 return code D)

Returns:

  • (:closed_account)
:closed_account
DUPLICATE_SUBMISSION =

The check has already been deposited. (Check21 return code Y)

Returns:

  • (:duplicate_submission)
:duplicate_submission
INSUFFICIENT_FUNDS =

Insufficient funds (Check21 return code A)

Returns:

  • (:insufficient_funds)
:insufficient_funds
NO_ACCOUNT =

No account was found matching the check details. (Check21 return code E)

Returns:

  • (:no_account)
:no_account
NOT_AUTHORIZED =

The check was not authorized. (Check21 return code Q)

Returns:

  • (:not_authorized)
:not_authorized
STALE_DATED =

The check is too old. (Check21 return code G)

Returns:

  • (:stale_dated)
:stale_dated
STOP_PAYMENT =

The payment has been stopped by the account holder. (Check21 return code C)

Returns:

  • (:stop_payment)
:stop_payment
UNKNOWN_REASON =

The reason for the return is unknown.

Returns:

  • (:unknown_reason)
:unknown_reason
UNMATCHED_DETAILS =

The image doesn't match the details submitted.

Returns:

  • (:unmatched_details)
:unmatched_details
UNREADABLE_IMAGE =

The image could not be read. (Check21 return code U)

Returns:

  • (:unreadable_image)
:unreadable_image
ENDORSEMENT_IRREGULAR =

The check endorsement was irregular. (Check21 return code J)

Returns:

  • (:endorsement_irregular)
:endorsement_irregular
ALTERED_OR_FICTITIOUS_ITEM =

The check present was either altered or fake. (Check21 return code N)

Returns:

  • (:altered_or_fictitious_item)
:altered_or_fictitious_item
FROZEN_OR_BLOCKED_ACCOUNT =

The account this check is drawn on is frozen. (Check21 return code F)

Returns:

  • (:frozen_or_blocked_account)
:frozen_or_blocked_account
POST_DATED =

The check is post dated. (Check21 return code H)

Returns:

  • (:post_dated)
:post_dated
ENDORSEMENT_MISSING =

The endorsement was missing. (Check21 return code I)

Returns:

  • (:endorsement_missing)
:endorsement_missing
SIGNATURE_MISSING =

The check signature was missing. (Check21 return code K)

Returns:

  • (:signature_missing)
:signature_missing
STOP_PAYMENT_SUSPECT =

The bank suspects a stop payment will be placed. (Check21 return code T)

Returns:

  • (:stop_payment_suspect)
:stop_payment_suspect
UNUSABLE_IMAGE =

The bank cannot read the image. (Check21 return code U)

Returns:

  • (:unusable_image)
:unusable_image
IMAGE_FAILS_SECURITY_CHECK =

The check image fails the bank's security check. (Check21 return code V)

Returns:

  • (:image_fails_security_check)
:image_fails_security_check
CANNOT_DETERMINE_AMOUNT =

The bank cannot determine the amount. (Check21 return code W)

Returns:

  • (:cannot_determine_amount)
:cannot_determine_amount
SIGNATURE_IRREGULAR =

The signature is inconsistent with prior signatures. (Check21 return code L)

Returns:

  • (:signature_irregular)
:signature_irregular
NON_CASH_ITEM =

The check is a non-cash item and cannot be drawn against the account. (Check21 return code M)

Returns:

  • (:non_cash_item)
:non_cash_item
UNABLE_TO_PROCESS =

The bank is unable to process this check. (Check21 return code O)

Returns:

  • (:unable_to_process)
:unable_to_process
ITEM_EXCEEDS_DOLLAR_LIMIT =

The check exceeds the bank or customer's limit. (Check21 return code P)

Returns:

  • (:item_exceeds_dollar_limit)
:item_exceeds_dollar_limit
BRANCH_OR_ACCOUNT_SOLD =

The bank sold this account and no longer services this customer. (Check21 return code R)

Returns:

  • (:branch_or_account_sold)
:branch_or_account_sold

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::CheckDeposit::DepositReturn::return_reason]

Returns:

  • (::Array[Increase::Models::CheckDeposit::DepositReturn::return_reason])


486
# File 'sig/increase/models/check_deposit.rbs', line 486

def self?.values: -> ::Array[Increase::Models::CheckDeposit::DepositReturn::return_reason]