Class: Increase::Models::CheckDepositCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/check_deposit_create_params.rb,
sig/increase/models/check_deposit_create_params.rbs

Overview

See Also:

  • Increase::Resources::CheckDeposits#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, amount:, back_image_file_id:, front_image_file_id:, description: nil, request_options: {}) ⇒ Object



# File 'lib/increase/models/check_deposit_create_params.rb', line 40


Instance Attribute Details

#account_idString

The identifier for the Account to deposit the check in.



14
# File 'lib/increase/models/check_deposit_create_params.rb', line 14

required :account_id, String

#amountInteger

The deposit amount in USD cents.



20
# File 'lib/increase/models/check_deposit_create_params.rb', line 20

required :amount, Integer

#back_image_file_idString

The File containing the check's back image.



26
# File 'lib/increase/models/check_deposit_create_params.rb', line 26

required :back_image_file_id, String

#descriptionString?

The description you choose to give the Check Deposit, for display purposes only.



38
# File 'lib/increase/models/check_deposit_create_params.rb', line 38

optional :description, String

#front_image_file_idString

The File containing the check's front image.



32
# File 'lib/increase/models/check_deposit_create_params.rb', line 32

required :front_image_file_id, String

Instance Method Details

#to_hash{



38
# File 'sig/increase/models/check_deposit_create_params.rbs', line 38

def to_hash: -> {