Class: Increase::Models::CheckTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb

Overview

Defined Under Namespace

Modules: BalanceCheck, Currency, FulfillmentMethod, Status, Type Classes: Approval, Cancellation, CreatedBy, Mailing, PhysicalCheck, StopPaymentRequest, Submission, ThirdParty

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(recipient_name:) ⇒ Object

Details relating to the custom fulfillment you will perform. Will be present if and only if ‘fulfillment_method` is equal to `third_party`.

Parameters:

  • recipient_name (String, nil)

    The name that you will print on the check.



# File 'lib/increase/models/check_transfer.rb', line 178

Instance Attribute Details

#account_idString

The identifier of the Account from which funds will be transferred.

Returns:

  • (String)


17
# File 'lib/increase/models/check_transfer.rb', line 17

required :account_id, String

#account_numberString

The account number printed on the check.

Returns:

  • (String)


23
# File 'lib/increase/models/check_transfer.rb', line 23

required :account_number, String

#amountInteger

The transfer amount in USD cents.

Returns:

  • (Integer)


29
# File 'lib/increase/models/check_transfer.rb', line 29

required :amount, Integer

#approvalIncrease::Models::CheckTransfer::Approval?

If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.



36
# File 'lib/increase/models/check_transfer.rb', line 36

required :approval, -> { Increase::CheckTransfer::Approval }, nil?: true

#approved_inbound_check_deposit_idString?

If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. The Inbound Check Deposit object will have information about any associated Transactions for this Check Transfer.

Returns:

  • (String, nil)


45
# File 'lib/increase/models/check_transfer.rb', line 45

required :approved_inbound_check_deposit_id, String, nil?: true

#balance_checkSymbol, ...

How the account’s available balance should be checked.



51
# File 'lib/increase/models/check_transfer.rb', line 51

required :balance_check, enum: -> { Increase::CheckTransfer::BalanceCheck }, nil?: true

#cancellationIncrease::Models::CheckTransfer::Cancellation?

If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.



58
# File 'lib/increase/models/check_transfer.rb', line 58

required :cancellation, -> { Increase::CheckTransfer::Cancellation }, nil?: true

#check_numberString

The check number printed on the check.

Returns:

  • (String)


64
# File 'lib/increase/models/check_transfer.rb', line 64

required :check_number, String

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.

Returns:

  • (Time)


71
# File 'lib/increase/models/check_transfer.rb', line 71

required :created_at, Time

#created_byIncrease::Models::CheckTransfer::CreatedBy?

What object created the transfer, either via the API or the dashboard.



77
# File 'lib/increase/models/check_transfer.rb', line 77

required :created_by, -> { Increase::CheckTransfer::CreatedBy }, nil?: true

#currencySymbol, Increase::Models::CheckTransfer::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.



84
# File 'lib/increase/models/check_transfer.rb', line 84

required :currency, enum: -> { Increase::CheckTransfer::Currency }

#fulfillment_methodSymbol, Increase::Models::CheckTransfer::FulfillmentMethod

Whether Increase will print and mail the check or if you will do it yourself.



90
# File 'lib/increase/models/check_transfer.rb', line 90

required :fulfillment_method, enum: -> { Increase::CheckTransfer::FulfillmentMethod }

#idString

The Check transfer’s identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/check_transfer.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).

Returns:

  • (String, nil)


98
# File 'lib/increase/models/check_transfer.rb', line 98

required :idempotency_key, String, nil?: true

#mailingIncrease::Models::CheckTransfer::Mailing?

If the check has been mailed by Increase, this will contain details of the shipment.



105
# File 'lib/increase/models/check_transfer.rb', line 105

required :mailing, -> { Increase::CheckTransfer::Mailing }, nil?: true

#pending_transaction_idString?

The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer [requires approval](increase.com/documentation/transfer-approvals#transfer-approvals) by someone else in your organization.

Returns:

  • (String, nil)


114
# File 'lib/increase/models/check_transfer.rb', line 114

required :pending_transaction_id, String, nil?: true

#physical_checkIncrease::Models::CheckTransfer::PhysicalCheck?

Details relating to the physical check that Increase will print and mail. Will be present if and only if ‘fulfillment_method` is equal to `physical_check`.



121
# File 'lib/increase/models/check_transfer.rb', line 121

required :physical_check, -> { Increase::CheckTransfer::PhysicalCheck }, nil?: true

#routing_numberString

The routing number printed on the check.

Returns:

  • (String)


127
# File 'lib/increase/models/check_transfer.rb', line 127

required :routing_number, String

#source_account_number_idString?

The identifier of the Account Number from which to send the transfer and print on the check.

Returns:

  • (String, nil)


134
# File 'lib/increase/models/check_transfer.rb', line 134

required :source_account_number_id, String, nil?: true

#statusSymbol, Increase::Models::CheckTransfer::Status

The lifecycle status of the transfer.



140
# File 'lib/increase/models/check_transfer.rb', line 140

required :status, enum: -> { Increase::CheckTransfer::Status }

#stop_payment_requestIncrease::Models::CheckTransfer::StopPaymentRequest?

After a stop-payment is requested on the check, this will contain supplemental details.



147
# File 'lib/increase/models/check_transfer.rb', line 147

required :stop_payment_request, -> { Increase::CheckTransfer::StopPaymentRequest }, nil?: true

#submissionIncrease::Models::CheckTransfer::Submission?

After the transfer is submitted, this will contain supplemental details.



153
# File 'lib/increase/models/check_transfer.rb', line 153

required :submission, -> { Increase::CheckTransfer::Submission }, nil?: true

#third_partyIncrease::Models::CheckTransfer::ThirdParty?

Details relating to the custom fulfillment you will perform. Will be present if and only if ‘fulfillment_method` is equal to `third_party`.



160
# File 'lib/increase/models/check_transfer.rb', line 160

required :third_party, -> { Increase::CheckTransfer::ThirdParty }, nil?: true

#typeSymbol, Increase::Models::CheckTransfer::Type

A constant representing the object’s type. For this resource it will always be ‘check_transfer`.



167
# File 'lib/increase/models/check_transfer.rb', line 167

required :type, enum: -> { Increase::CheckTransfer::Type }

#valid_until_dateDate?

If set, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.

Returns:

  • (Date, nil)


176
# File 'lib/increase/models/check_transfer.rb', line 176

required :valid_until_date, Date, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/check_transfer.rb', line 275