Class: Increase::Models::CheckTransfer::Approval
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::Approval
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#approved_at ⇒ Time
The ISO 8601 date and time at which the transfer was approved.
-
#approved_by ⇒ String?
If the Transfer was approved by a user in the dashboard, the email address of that user.
Instance Method Summary collapse
-
#initialize ⇒ Approval
constructor
A new instance of Approval.
- #to_hash ⇒ { approved_at: Time, approved_by: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Approval
Returns a new instance of Approval.
146 |
# File 'sig/increase/models/check_transfer.rbs', line 146
def initialize: (approved_at: Time, approved_by: String?) -> void
|
Instance Attribute Details
#approved_at ⇒ Time
The ISO 8601 date and time at which the transfer was approved.
242 |
# File 'lib/increase/models/check_transfer.rb', line 242 required :approved_at, Time |
#approved_by ⇒ String?
If the Transfer was approved by a user in the dashboard, the email address of that user.
249 |
# File 'lib/increase/models/check_transfer.rb', line 249 required :approved_by, String, nil?: true |
Instance Method Details
#to_hash ⇒ { approved_at: Time, approved_by: String? }
148 |
# File 'sig/increase/models/check_transfer.rbs', line 148
def to_hash: -> { approved_at: Time, approved_by: String? }
|