Class: Increase::Models::CheckTransfer::Mailing
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::Mailing
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#mailed_at ⇒ Time
The ISO 8601 date and time at which the check was mailed.
Instance Method Summary collapse
-
#initialize ⇒ Mailing
constructor
A new instance of Mailing.
- #to_hash ⇒ { mailed_at: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Mailing
Returns a new instance of Mailing.
286 |
# File 'sig/increase/models/check_transfer.rbs', line 286
def initialize: (mailed_at: Time) -> void
|
Instance Attribute Details
#mailed_at ⇒ Time
The ISO 8601 date and time at which the check was mailed.
443 |
# File 'lib/increase/models/check_transfer.rb', line 443 required :mailed_at, Time |
Instance Method Details
#to_hash ⇒ { mailed_at: Time }
288 |
# File 'sig/increase/models/check_transfer.rbs', line 288
def to_hash: -> { mailed_at: Time }
|