Class: Increase::Models::CheckTransfer::PhysicalCheck

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs

Overview

See Also:

  • Increase::Models::CheckTransfer#physical_check

Defined Under Namespace

Modules: ShippingMethod Classes: MailingAddress, Payer, ReturnAddress, Signature, TrackingUpdate

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(image_file_id:, text:) ⇒ Object

The signature that will appear on the check.

Parameters:

  • image_file_id (String, nil)

    The ID of a File containing a PNG of the signature.

  • text (String, nil)

    The text that will appear as the signature on the check in cursive font.



# File 'lib/increase/models/check_transfer.rb', line 572

Instance Attribute Details

#attachment_file_idString?

The ID of the file for the check attachment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


502
# File 'lib/increase/models/check_transfer.rb', line 502

required :attachment_file_id, String, nil?: true

#check_voucher_image_file_idString?

The ID of the file for the check voucher image.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


508
# File 'lib/increase/models/check_transfer.rb', line 508

required :check_voucher_image_file_id, String, nil?: true

#mailing_addressIncrease::Models::CheckTransfer::PhysicalCheck::MailingAddress

Details for where Increase will mail the check.

Parameters:

  • value (Increase::CheckTransfer::PhysicalCheck::MailingAddress)

Returns:



514
# File 'lib/increase/models/check_transfer.rb', line 514

required :mailing_address, -> { Increase::CheckTransfer::PhysicalCheck::MailingAddress }

#memoString?

The descriptor that will be printed on the memo field on the check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


520
# File 'lib/increase/models/check_transfer.rb', line 520

required :memo, String, nil?: true

#noteString?

The descriptor that will be printed on the letter included with the check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


526
# File 'lib/increase/models/check_transfer.rb', line 526

required :note, String, nil?: true

#payerArray<Increase::Models::CheckTransfer::PhysicalCheck::Payer>

The payer of the check. This will be printed on the top-left portion of the check and defaults to the return address if unspecified.

Parameters:

  • value (::Array[Increase::CheckTransfer::PhysicalCheck::Payer])

Returns:



533
# File 'lib/increase/models/check_transfer.rb', line 533

required :payer, -> { Increase::Internal::Type::ArrayOf[Increase::CheckTransfer::PhysicalCheck::Payer] }

#recipient_nameString

The name that will be printed on the check.

Parameters:

  • value (String)

Returns:

  • (String)


539
# File 'lib/increase/models/check_transfer.rb', line 539

required :recipient_name, String

#return_addressIncrease::Models::CheckTransfer::PhysicalCheck::ReturnAddress?

The return address to be printed on the check.

Parameters:

  • value (Increase::CheckTransfer::PhysicalCheck::ReturnAddress, nil)

Returns:



545
# File 'lib/increase/models/check_transfer.rb', line 545

required :return_address, -> { Increase::CheckTransfer::PhysicalCheck::ReturnAddress }, nil?: true

#return_address_nameString?

A custom name printed above the Increase-managed return address.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


551
# File 'lib/increase/models/check_transfer.rb', line 551

required :return_address_name, String, nil?: true

#shipping_methodSymbol, Increase::Models::CheckTransfer::PhysicalCheck::ShippingMethod

The shipping method for the check.

Parameters:

  • value (Increase::Models::CheckTransfer::PhysicalCheck::shipping_method)

Returns:



557
# File 'lib/increase/models/check_transfer.rb', line 557

required :shipping_method, enum: -> { Increase::CheckTransfer::PhysicalCheck::ShippingMethod }

#signatureIncrease::Models::CheckTransfer::PhysicalCheck::Signature

The signature that will appear on the check.

Parameters:

  • value (Increase::CheckTransfer::PhysicalCheck::Signature)

Returns:



563
# File 'lib/increase/models/check_transfer.rb', line 563

required :signature, -> { Increase::CheckTransfer::PhysicalCheck::Signature }

#tracking_updatesArray<Increase::Models::CheckTransfer::PhysicalCheck::TrackingUpdate>

Tracking updates relating to the physical check's delivery.

Parameters:

  • value (::Array[Increase::CheckTransfer::PhysicalCheck::TrackingUpdate])

Returns:



569
570
# File 'lib/increase/models/check_transfer.rb', line 569

required :tracking_updates,
-> { Increase::Internal::Type::ArrayOf[Increase::CheckTransfer::PhysicalCheck::TrackingUpdate] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/check_transfer.rb', line 760

Instance Method Details

#to_hash{

Returns:

  • ({)


347
# File 'sig/increase/models/check_transfer.rbs', line 347

def to_hash: -> {