Class: Increase::Models::CheckTransfer::PhysicalCheck::MailingAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs

Overview

See Also:

  • Increase::Models::CheckTransfer::PhysicalCheck#mailing_address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



393
# File 'sig/increase/models/check_transfer.rbs', line 393

def initialize: (

Instance Attribute Details

#cityString?

The city of the check's destination.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


624
# File 'lib/increase/models/check_transfer.rb', line 624

required :city, String, nil?: true

#line1String?

The street address of the check's destination.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


630
# File 'lib/increase/models/check_transfer.rb', line 630

required :line1, String, nil?: true

#line2String?

The second line of the address of the check's destination.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


636
# File 'lib/increase/models/check_transfer.rb', line 636

required :line2, String, nil?: true

#nameString?

The name component of the check's mailing address.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


642
# File 'lib/increase/models/check_transfer.rb', line 642

required :name, String, nil?: true

#phoneString?

The phone number to be used in case of delivery issues at the check's mailing address. Only used for FedEx overnight shipping.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


649
# File 'lib/increase/models/check_transfer.rb', line 649

required :phone, String, nil?: true

#postal_codeString?

The postal code of the check's destination.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


655
# File 'lib/increase/models/check_transfer.rb', line 655

required :postal_code, String, nil?: true

#stateString?

The state of the check's destination.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


661
# File 'lib/increase/models/check_transfer.rb', line 661

required :state, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


403
# File 'sig/increase/models/check_transfer.rbs', line 403

def to_hash: -> {