Class: Increase::Models::CheckTransfer::PhysicalCheck::Signature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::PhysicalCheck::Signature
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#image_file_id ⇒ String?
The ID of a File containing a PNG of the signature.
-
#text ⇒ String?
The text that will appear as the signature on the check in cursive font.
Instance Method Summary collapse
-
#initialize ⇒ Signature
constructor
A new instance of Signature.
- #to_hash ⇒ { image_file_id: String?, text: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Signature
Returns a new instance of Signature.
482 |
# File 'sig/increase/models/check_transfer.rbs', line 482
def initialize: (image_file_id: String?, text: String?) -> void
|
Instance Attribute Details
#image_file_id ⇒ String?
The ID of a File containing a PNG of the signature.
721 |
# File 'lib/increase/models/check_transfer.rb', line 721 required :image_file_id, String, nil?: true |
#text ⇒ String?
The text that will appear as the signature on the check in cursive font.
727 |
# File 'lib/increase/models/check_transfer.rb', line 727 required :text, String, nil?: true |
Instance Method Details
#to_hash ⇒ { image_file_id: String?, text: String? }
484 |
# File 'sig/increase/models/check_transfer.rbs', line 484
def to_hash: -> { image_file_id: String?, text: String? }
|