Class: Increase::Models::CheckTransfer::PhysicalCheck::TrackingUpdate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::PhysicalCheck::TrackingUpdate
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, Increase::Models::CheckTransfer::PhysicalCheck::TrackingUpdate::Category
The type of tracking event.
-
#country ⇒ String
The ISO 3166-1 alpha-2 country code for the country where the event took place.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the tracking event took place.
-
#postal_code ⇒ String
The postal code where the event took place.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, country:, created_at:, postal_code:) ⇒ Object
|
|
# File 'lib/increase/models/check_transfer.rb', line 812
|
Instance Attribute Details
#category ⇒ Symbol, Increase::Models::CheckTransfer::PhysicalCheck::TrackingUpdate::Category
The type of tracking event.
791 |
# File 'lib/increase/models/check_transfer.rb', line 791 required :category, enum: -> { Increase::CheckTransfer::PhysicalCheck::TrackingUpdate::Category } |
#country ⇒ String
The ISO 3166-1 alpha-2 country code for the country where the event took place.
797 |
# File 'lib/increase/models/check_transfer.rb', line 797 required :country, String |
#created_at ⇒ Time
The ISO 8601 date and time at which the tracking event took place.
804 |
# File 'lib/increase/models/check_transfer.rb', line 804 required :created_at, Time |
#postal_code ⇒ String
The postal code where the event took place.
810 |
# File 'lib/increase/models/check_transfer.rb', line 810 required :postal_code, String |
Instance Method Details
#to_hash ⇒ {
516 |
# File 'sig/increase/models/check_transfer.rbs', line 516
def to_hash: -> {
|