Class: Increase::Models::CheckTransfer::StopPaymentRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::StopPaymentRequest
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#reason ⇒ Symbol, Increase::Models::CheckTransfer::StopPaymentRequest::Reason
The reason why this transfer was stopped.
-
#requested_at ⇒ Time
The time the stop-payment was requested.
-
#transfer_id ⇒ String
The ID of the check transfer that was stopped.
-
#type ⇒ Symbol, Increase::Models::CheckTransfer::StopPaymentRequest::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(reason:, requested_at:, transfer_id:, type:) ⇒ Object
constructor
After a stop-payment is requested on the check, this will contain supplemental details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reason:, requested_at:, transfer_id:, type:) ⇒ Object
After a stop-payment is requested on the check, this will contain supplemental details.
|
|
# File 'lib/increase/models/check_transfer.rb', line 924
|
Instance Attribute Details
#reason ⇒ Symbol, Increase::Models::CheckTransfer::StopPaymentRequest::Reason
The reason why this transfer was stopped.
903 |
# File 'lib/increase/models/check_transfer.rb', line 903 required :reason, enum: -> { Increase::CheckTransfer::StopPaymentRequest::Reason } |
#requested_at ⇒ Time
The time the stop-payment was requested.
909 |
# File 'lib/increase/models/check_transfer.rb', line 909 required :requested_at, Time |
#transfer_id ⇒ String
The ID of the check transfer that was stopped.
915 |
# File 'lib/increase/models/check_transfer.rb', line 915 required :transfer_id, String |
#type ⇒ Symbol, Increase::Models::CheckTransfer::StopPaymentRequest::Type
A constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
922 |
# File 'lib/increase/models/check_transfer.rb', line 922 required :type, enum: -> { Increase::CheckTransfer::StopPaymentRequest::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_transfer.rb', line 960
|
Instance Method Details
#to_hash ⇒ {
633 |
# File 'sig/increase/models/check_transfer.rbs', line 633
def to_hash: -> {
|