Class: Increase::Models::CheckTransfer::Submission

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs

Overview

See Also:

  • Increase::Models::CheckTransfer#submission

Defined Under Namespace

Classes: SubmittedAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(preview_file_id:, submitted_address:, submitted_at:, tracking_number:) ⇒ Object

After the transfer is submitted, this will contain supplemental details.

Parameters:

  • preview_file_id (String, nil)

    The ID of the file corresponding to an image of the check that was mailed, if available.

  • submitted_address (Increase::Models::CheckTransfer::Submission::SubmittedAddress)

    The address we submitted to the printer. This is what is physically printed on the check.

  • submitted_at (Time)

    When this check was submitted to our check printer.

  • tracking_number (String, nil)

    The tracking number for the check shipment.



# File 'lib/increase/models/check_transfer.rb', line 1006

Instance Attribute Details

#preview_file_idString?

The ID of the file corresponding to an image of the check that was mailed, if available.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


985
# File 'lib/increase/models/check_transfer.rb', line 985

required :preview_file_id, String, nil?: true

#submitted_addressIncrease::Models::CheckTransfer::Submission::SubmittedAddress

The address we submitted to the printer. This is what is physically printed on the check.

Parameters:

  • value (Increase::CheckTransfer::Submission::SubmittedAddress)

Returns:



992
# File 'lib/increase/models/check_transfer.rb', line 992

required :submitted_address, -> { Increase::CheckTransfer::Submission::SubmittedAddress }

#submitted_atTime

When this check was submitted to our check printer.

Parameters:

  • value (Time)

Returns:

  • (Time)


998
# File 'lib/increase/models/check_transfer.rb', line 998

required :submitted_at, Time

#tracking_numberString?

The tracking number for the check shipment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1004
# File 'lib/increase/models/check_transfer.rb', line 1004

required :tracking_number, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


703
# File 'sig/increase/models/check_transfer.rbs', line 703

def to_hash: -> {