Class: Increase::Models::CheckTransfer::ThirdParty
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::ThirdParty
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#recipient_name ⇒ String?
The name that you will print on the check.
Instance Method Summary collapse
-
#initialize ⇒ ThirdParty
constructor
A new instance of ThirdParty.
- #to_hash ⇒ { recipient_name: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ThirdParty
Returns a new instance of ThirdParty.
753 |
# File 'sig/increase/models/check_transfer.rbs', line 753
def initialize: (recipient_name: String?) -> void
|
Instance Attribute Details
#recipient_name ⇒ String?
The name that you will print on the check.
1034 |
# File 'lib/increase/models/check_transfer.rb', line 1034 required :recipient_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ { recipient_name: String? }
755 |
# File 'sig/increase/models/check_transfer.rbs', line 755
def to_hash: -> { recipient_name: String? }
|