Class: Increase::Models::CheckTransferCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransferCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs
Overview
Defined Under Namespace
Modules: BalanceCheck, FulfillmentMethod Classes: PhysicalCheck, ThirdParty
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier for the account that will send the transfer.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#balance_check ⇒ Symbol, ...
How the account's available balance should be checked.
-
#check_number ⇒ String?
The check number Increase should use for the check.
-
#fulfillment_method ⇒ Symbol, Increase::Models::CheckTransferCreateParams::FulfillmentMethod
Whether Increase will print and mail the check or if you will do it yourself.
-
#physical_check ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck?
Details relating to the physical check that Increase will print and mail.
-
#require_approval ⇒ Boolean?
Whether the transfer requires explicit approval via the dashboard or API.
-
#source_account_number_id ⇒ String
The identifier of the Account Number from which to send the transfer and print on the check.
-
#third_party ⇒ Increase::Models::CheckTransferCreateParams::ThirdParty?
Details relating to the custom fulfillment you will perform.
-
#valid_until_date ⇒ Date?
If provided, the check will be valid on or before this date.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(image_file_id: nil, text: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PhysicalCheck::Signature for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(image_file_id: nil, text: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature for more details.
The signature that will appear on the check. If not provided, the check will be
printed with 'No Signature Required'. At most one of text and image_file_id
may be provided.
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 81
|
Instance Attribute Details
#account_id ⇒ String
The identifier for the account that will send the transfer.
14 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 14 required :account_id, String |
#amount ⇒ Integer
The transfer amount in USD cents.
20 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 20 required :amount, Integer |
#balance_check ⇒ Symbol, ...
How the account's available balance should be checked. If omitted, the default
behavior is balance_check: full.
40 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 40 optional :balance_check, enum: -> { Increase::CheckTransferCreateParams::BalanceCheck } |
#check_number ⇒ String?
The check number Increase should use for the check. This should not contain
leading zeroes and must be unique across the source_account_number. If this is
omitted, Increase will generate a check number for you.
48 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 48 optional :check_number, String |
#fulfillment_method ⇒ Symbol, Increase::Models::CheckTransferCreateParams::FulfillmentMethod
Whether Increase will print and mail the check or if you will do it yourself.
26 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 26 required :fulfillment_method, enum: -> { Increase::CheckTransferCreateParams::FulfillmentMethod } |
#physical_check ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck?
Details relating to the physical check that Increase will print and mail. This
is required if fulfillment_method is equal to physical_check. It must not be
included if any other fulfillment_method is provided.
56 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 56 optional :physical_check, -> { Increase::CheckTransferCreateParams::PhysicalCheck } |
#require_approval ⇒ Boolean?
Whether the transfer requires explicit approval via the dashboard or API.
62 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 62 optional :require_approval, Increase::Internal::Type::Boolean |
#source_account_number_id ⇒ String
The identifier of the Account Number from which to send the transfer and print on the check.
33 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 33 required :source_account_number_id, String |
#third_party ⇒ Increase::Models::CheckTransferCreateParams::ThirdParty?
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_method is equal to third_party. It must not be included if any
other fulfillment_method is provided.
70 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 70 optional :third_party, -> { Increase::CheckTransferCreateParams::ThirdParty } |
#valid_until_date ⇒ Date?
If provided, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.
79 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 79 optional :valid_until_date, Date |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 117
|
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/increase/models/check_transfer_create_params.rbs', line 74
def to_hash: -> {
|