Class: Increase::Models::CheckTransferCreateParams::PhysicalCheck::MailingAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer_create_params.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#cityString

The city component of the check’s destination address.

Returns:

  • (String)


243
# File 'lib/increase/models/check_transfer_create_params.rb', line 243

required :city, String

#line1String

The first line of the address component of the check’s destination address.

Returns:

  • (String)


249
# File 'lib/increase/models/check_transfer_create_params.rb', line 249

required :line1, String

#line2String?

The second line of the address component of the check’s destination address.

Returns:

  • (String, nil)


267
# File 'lib/increase/models/check_transfer_create_params.rb', line 267

optional :line2, String

#nameString?

The name component of the check’s destination address. Defaults to the provided ‘recipient_name` parameter if `name` is not provided.

Returns:

  • (String, nil)


274
# File 'lib/increase/models/check_transfer_create_params.rb', line 274

optional :name, String

#phoneString?

The phone number to associate with the check’s destination address. The phone number is only used when ‘shipping_method` is `fedex_overnight` and will be supplied to FedEx to be used in case of delivery issues.

Returns:

  • (String, nil)


282
# File 'lib/increase/models/check_transfer_create_params.rb', line 282

optional :phone, String

#postal_codeString

The postal code component of the check’s destination address.

Returns:

  • (String)


255
# File 'lib/increase/models/check_transfer_create_params.rb', line 255

required :postal_code, String

#stateString

The US state component of the check’s destination address.

Returns:

  • (String)


261
# File 'lib/increase/models/check_transfer_create_params.rb', line 261

required :state, String