Class: Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature
- Defined in:
- lib/increase/models/check_transfer_create_params.rb
Overview
Instance Attribute Summary collapse
-
#image_file_id ⇒ String?
The ID of a File containing a PNG of the signature.
-
#text ⇒ String?
The text that will appear as the signature on the check in cursive font.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#image_file_id ⇒ String?
The ID of a File containing a PNG of the signature. This must have ‘purpose: check_signature` and be a 1320x120 pixel PNG.
411 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 411 optional :image_file_id, String |
#text ⇒ String?
The text that will appear as the signature on the check in cursive font.
417 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 417 optional :text, String |