Class: Increase::Models::DeclinedTransaction::Source::ACHDecline

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/declined_transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Reason, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, inbound_ach_transfer_id:, originator_company_descriptive_date:, originator_company_discretionary_data:, originator_company_id:, originator_company_name:, reason:, receiver_id_number:, receiver_name:, trace_number:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::DeclinedTransaction::Source::ACHDecline for more details.

An ACH Decline object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_decline`.

Parameters:

  • id (String)

    The ACH Decline’s identifier.

  • amount (Integer)

    The declined amount in USD cents.

  • inbound_ach_transfer_id (String)

    The identifier of the Inbound ACH Transfer object associated with this decline.

  • originator_company_descriptive_date (String, nil)

    The descriptive date of the transfer.

  • originator_company_discretionary_data (String, nil)

    The additional information included with the transfer.

  • originator_company_id (String)

    The identifier of the company that initiated the transfer.

  • originator_company_name (String)

    The name of the company that initiated the transfer.

  • reason (Symbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Reason)

    Why the ACH transfer was declined.

  • receiver_id_number (String, nil)

    The id of the receiver of the transfer.

  • receiver_name (String, nil)

    The name of the receiver of the transfer.

  • trace_number (String)

    The trace number of the transfer.

  • type (Symbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Type)

    A constant representing the object’s type. For this resource it will always be ‘



# File 'lib/increase/models/declined_transaction.rb', line 350

Instance Attribute Details

#amountInteger

The declined amount in USD cents.

Returns:

  • (Integer)


287
# File 'lib/increase/models/declined_transaction.rb', line 287

required :amount, Integer

#idString

The ACH Decline’s identifier.

Returns:

  • (String)


281
# File 'lib/increase/models/declined_transaction.rb', line 281

required :id, String

#inbound_ach_transfer_idString

The identifier of the Inbound ACH Transfer object associated with this decline.

Returns:

  • (String)


293
# File 'lib/increase/models/declined_transaction.rb', line 293

required :inbound_ach_transfer_id, String

#originator_company_descriptive_dateString?

The descriptive date of the transfer.

Returns:

  • (String, nil)


299
# File 'lib/increase/models/declined_transaction.rb', line 299

required :originator_company_descriptive_date, String, nil?: true

#originator_company_discretionary_dataString?

The additional information included with the transfer.

Returns:

  • (String, nil)


305
# File 'lib/increase/models/declined_transaction.rb', line 305

required :originator_company_discretionary_data, String, nil?: true

#originator_company_idString

The identifier of the company that initiated the transfer.

Returns:

  • (String)


311
# File 'lib/increase/models/declined_transaction.rb', line 311

required :originator_company_id, String

#originator_company_nameString

The name of the company that initiated the transfer.

Returns:

  • (String)


317
# File 'lib/increase/models/declined_transaction.rb', line 317

required :originator_company_name, String

#reasonSymbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Reason

Why the ACH transfer was declined.



323
# File 'lib/increase/models/declined_transaction.rb', line 323

required :reason, enum: -> { Increase::DeclinedTransaction::Source::ACHDecline::Reason }

#receiver_id_numberString?

The id of the receiver of the transfer.

Returns:

  • (String, nil)


329
# File 'lib/increase/models/declined_transaction.rb', line 329

required :receiver_id_number, String, nil?: true

#receiver_nameString?

The name of the receiver of the transfer.

Returns:

  • (String, nil)


335
# File 'lib/increase/models/declined_transaction.rb', line 335

required :receiver_name, String, nil?: true

#trace_numberString

The trace number of the transfer.

Returns:

  • (String)


341
# File 'lib/increase/models/declined_transaction.rb', line 341

required :trace_number, String

#typeSymbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Type

A constant representing the object’s type. For this resource it will always be ‘ach_decline`.



348
# File 'lib/increase/models/declined_transaction.rb', line 348

required :type, enum: -> { Increase::DeclinedTransaction::Source::ACHDecline::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/declined_transaction.rb', line 440