Module: Increase::Models::DeclinedTransaction::Source::ACHDecline::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs

Overview

Why the ACH transfer was declined.

See Also:

  • Increase::Models::DeclinedTransaction::Source::ACHDecline#reason

Constant Summary collapse

ACH_ROUTE_CANCELED =

The account number is canceled.

Returns:

  • (:ach_route_canceled)
:ach_route_canceled
ACH_ROUTE_DISABLED =

The account number is disabled.

Returns:

  • (:ach_route_disabled)
:ach_route_disabled
BREACHES_LIMIT =

The transaction would cause an Increase limit to be exceeded.

Returns:

  • (:breaches_limit)
:breaches_limit
ENTITY_NOT_ACTIVE =

The account's entity is not active.

Returns:

  • (:entity_not_active)
:entity_not_active
GROUP_LOCKED =

Your account is inactive.

Returns:

  • (:group_locked)
:group_locked
TRANSACTION_NOT_ALLOWED =

The transaction is not allowed per Increase's terms.

Returns:

  • (:transaction_not_allowed)
:transaction_not_allowed
RETURNED_PER_ODFI_REQUEST =

The originating financial institution asked for this transfer to be returned. The receiving bank is complying with the request.

Returns:

  • (:returned_per_odfi_request)
:returned_per_odfi_request
USER_INITIATED =

Your integration declined this transfer via the API.

Returns:

  • (:user_initiated)
:user_initiated
INSUFFICIENT_FUNDS =

Your account contains insufficient funds.

Returns:

  • (:insufficient_funds)
:insufficient_funds
AUTHORIZATION_REVOKED_BY_CUSTOMER =

The customer no longer authorizes this transaction.

Returns:

  • (:authorization_revoked_by_customer)
:authorization_revoked_by_customer
PAYMENT_STOPPED =

The customer asked for the payment to be stopped.

Returns:

  • (:payment_stopped)
:payment_stopped
CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETE =

The customer advises that the debit was unauthorized.

Returns:

  • (:customer_advised_unauthorized_improper_ineligible_or_incomplete)
:customer_advised_unauthorized_improper_ineligible_or_incomplete
REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITY =

The payee is deceased.

Returns:

  • (:representative_payee_deceased_or_unable_to_continue_in_that_capacity)
:representative_payee_deceased_or_unable_to_continue_in_that_capacity
BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASED =

The account holder is deceased.

Returns:

  • (:beneficiary_or_account_holder_deceased)
:beneficiary_or_account_holder_deceased
CREDIT_ENTRY_REFUSED_BY_RECEIVER =

The customer refused a credit entry.

Returns:

  • (:credit_entry_refused_by_receiver)
:credit_entry_refused_by_receiver
DUPLICATE_ENTRY =

The account holder identified this transaction as a duplicate.

Returns:

  • (:duplicate_entry)
:duplicate_entry
CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZED =

The corporate customer no longer authorizes this transaction.

Returns:

  • (:corporate_customer_advised_not_authorized)
:corporate_customer_advised_not_authorized

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::DeclinedTransaction::Source::ACHDecline::reason]

Returns:

  • (::Array[Increase::Models::DeclinedTransaction::Source::ACHDecline::reason])


332
# File 'sig/increase/models/declined_transaction.rbs', line 332

def self?.values: -> ::Array[Increase::Models::DeclinedTransaction::Source::ACHDecline::reason]