Class: Increase::Models::DeclinedTransaction::Source::CardDecline
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransaction::Source::CardDecline
- Defined in:
- lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs
Overview
Defined Under Namespace
Modules: Actioner, Currency, Direction, ProcessingCategory, RealTimeDecisionReason, Reason Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The declined amount in the minor unit of the destination account currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Currency
The ISO 4217 code for the destination account currency.
-
#declined_transaction_id ⇒ String
The identifier of the declined transaction created for this Card Decline.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#id ⇒ String
The Card Decline identifier.
-
#incremented_card_authorization_id ⇒ String?
The identifier of the card authorization this request attempted to incrementally authorize.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::NetworkDetails
Fields specific to the
network. -
#network_identifiers ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The declined amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#processing_category ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#real_time_decision_reason ⇒ Symbol, ...
This is present if a specific decline reason was given in the real-time decision.
-
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Reason
Why the transaction was declined.
-
#scheme_fees ⇒ Array<Increase::Models::DeclinedTransaction::Source::CardDecline::SchemeFee>
The scheme fees associated with this card decline.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#verification ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for a specific request or transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/declined_transaction.rb', line 697
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
504 |
# File 'lib/increase/models/declined_transaction.rb', line 504 required :actioner, enum: -> { Increase::DeclinedTransaction::Source::CardDecline::Actioner } |
#additional_amounts ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM
surcharges fees. These are usually a subset of the amount field and are used
to provide more detailed information about the transaction.
512 |
# File 'lib/increase/models/declined_transaction.rb', line 512 required :additional_amounts, -> { Increase::DeclinedTransaction::Source::CardDecline::AdditionalAmounts } |
#amount ⇒ Integer
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
519 |
# File 'lib/increase/models/declined_transaction.rb', line 519 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
525 |
# File 'lib/increase/models/declined_transaction.rb', line 525 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Currency
The ISO 4217 code for the destination account currency.
532 |
# File 'lib/increase/models/declined_transaction.rb', line 532 required :currency, enum: -> { Increase::DeclinedTransaction::Source::CardDecline::Currency } |
#declined_transaction_id ⇒ String
The identifier of the declined transaction created for this Card Decline.
538 |
# File 'lib/increase/models/declined_transaction.rb', line 538 required :declined_transaction_id, String |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
545 |
# File 'lib/increase/models/declined_transaction.rb', line 545 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
552 |
# File 'lib/increase/models/declined_transaction.rb', line 552 required :direction, enum: -> { Increase::DeclinedTransaction::Source::CardDecline::Direction } |
#id ⇒ String
The Card Decline identifier.
497 |
# File 'lib/increase/models/declined_transaction.rb', line 497 required :id, String |
#incremented_card_authorization_id ⇒ String?
The identifier of the card authorization this request attempted to incrementally authorize.
559 |
# File 'lib/increase/models/declined_transaction.rb', line 559 required :incremented_card_authorization_id, String, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
566 |
# File 'lib/increase/models/declined_transaction.rb', line 566 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
573 |
# File 'lib/increase/models/declined_transaction.rb', line 573 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
579 |
# File 'lib/increase/models/declined_transaction.rb', line 579 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
585 |
# File 'lib/increase/models/declined_transaction.rb', line 585 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
591 |
# File 'lib/increase/models/declined_transaction.rb', line 591 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
598 |
# File 'lib/increase/models/declined_transaction.rb', line 598 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
604 |
# File 'lib/increase/models/declined_transaction.rb', line 604 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::NetworkDetails
Fields specific to the network.
610 |
# File 'lib/increase/models/declined_transaction.rb', line 610 required :network_details, -> { Increase::DeclinedTransaction::Source::CardDecline::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
616 617 |
# File 'lib/increase/models/declined_transaction.rb', line 616 required :network_identifiers, -> { Increase::DeclinedTransaction::Source::CardDecline::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
625 |
# File 'lib/increase/models/declined_transaction.rb', line 625 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
632 |
# File 'lib/increase/models/declined_transaction.rb', line 632 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The declined amount in the minor unit of the transaction's presentment currency.
638 |
# File 'lib/increase/models/declined_transaction.rb', line 638 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
645 |
# File 'lib/increase/models/declined_transaction.rb', line 645 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
652 653 |
# File 'lib/increase/models/declined_transaction.rb', line 652 required :processing_category, enum: -> { Increase::DeclinedTransaction::Source::CardDecline::ProcessingCategory } |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
660 |
# File 'lib/increase/models/declined_transaction.rb', line 660 required :real_time_decision_id, String, nil?: true |
#real_time_decision_reason ⇒ Symbol, ...
This is present if a specific decline reason was given in the real-time decision.
667 668 669 |
# File 'lib/increase/models/declined_transaction.rb', line 667 required :real_time_decision_reason, enum: -> { Increase::DeclinedTransaction::Source::CardDecline::RealTimeDecisionReason }, nil?: true |
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Reason
Why the transaction was declined.
675 |
# File 'lib/increase/models/declined_transaction.rb', line 675 required :reason, enum: -> { Increase::DeclinedTransaction::Source::CardDecline::Reason } |
#scheme_fees ⇒ Array<Increase::Models::DeclinedTransaction::Source::CardDecline::SchemeFee>
The scheme fees associated with this card decline.
681 682 |
# File 'lib/increase/models/declined_transaction.rb', line 681 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::DeclinedTransaction::Source::CardDecline::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
689 |
# File 'lib/increase/models/declined_transaction.rb', line 689 required :terminal_id, String, nil?: true |
#verification ⇒ Increase::Models::DeclinedTransaction::Source::CardDecline::Verification
Fields related to verification of cardholder-provided values.
695 |
# File 'lib/increase/models/declined_transaction.rb', line 695 required :verification, -> { Increase::DeclinedTransaction::Source::CardDecline::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/declined_transaction.rb', line 820
|
Instance Method Details
#to_hash ⇒ {
474 |
# File 'sig/increase/models/declined_transaction.rbs', line 474
def to_hash: -> {
|