Module: Increase::Models::DeclinedTransaction::Source::CardDecline::Direction

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs

Overview

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.

See Also:

  • Increase::Models::DeclinedTransaction::Source::CardDecline#direction

Constant Summary collapse

SETTLEMENT =

A regular card authorization where funds are debited from the cardholder.

Returns:

  • (:settlement)
:settlement
REFUND =

A refund card authorization, sometimes referred to as a credit voucher authorization, where funds are credited to the cardholder.

Returns:

  • (:refund)
:refund

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::DeclinedTransaction::Source::CardDecline::direction]

Returns:

  • (::Array[Increase::Models::DeclinedTransaction::Source::CardDecline::direction])


728
# File 'sig/increase/models/declined_transaction.rbs', line 728

def self?.values: -> ::Array[Increase::Models::DeclinedTransaction::Source::CardDecline::direction]