Class: Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderAddress

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/declined_transaction.rb

Overview

Defined Under Namespace

Modules: Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(actual_line1:, actual_postal_code:, provided_line1:, provided_postal_code:, result:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderAddress for more details.

Cardholder address provided in the authorization request and the address on file we verified it against.

Parameters:

  • actual_line1 (String, nil)

    Line 1 of the address on file for the cardholder.

  • actual_postal_code (String, nil)

    The postal code of the address on file for the cardholder.

  • provided_line1 (String, nil)

    The cardholder address line 1 provided for verification in the authorization req

  • provided_postal_code (String, nil)

    The postal code provided for verification in the authorization request.

  • result (Symbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderAddress::Result)

    The address verification result returned to the card network.



# File 'lib/increase/models/declined_transaction.rb', line 1937

Instance Attribute Details

#actual_line1String?

Line 1 of the address on file for the cardholder.

Returns:

  • (String, nil)


1909
# File 'lib/increase/models/declined_transaction.rb', line 1909

required :actual_line1, String, nil?: true

#actual_postal_codeString?

The postal code of the address on file for the cardholder.

Returns:

  • (String, nil)


1915
# File 'lib/increase/models/declined_transaction.rb', line 1915

required :actual_postal_code, String, nil?: true

#provided_line1String?

The cardholder address line 1 provided for verification in the authorization request.

Returns:

  • (String, nil)


1922
# File 'lib/increase/models/declined_transaction.rb', line 1922

required :provided_line1, String, nil?: true

#provided_postal_codeString?

The postal code provided for verification in the authorization request.

Returns:

  • (String, nil)


1928
# File 'lib/increase/models/declined_transaction.rb', line 1928

required :provided_postal_code, String, nil?: true

#resultSymbol, Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderAddress::Result

The address verification result returned to the card network.



1934
1935
# File 'lib/increase/models/declined_transaction.rb', line 1934

required :result,
enum: -> { Increase::DeclinedTransaction::Source::CardDecline::Verification::CardholderAddress::Result }