Class: Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderName
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderName
- Defined in:
- lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs
Overview
Instance Attribute Summary collapse
-
#provided_first_name ⇒ String?
The first name provided for verification in the authorization request.
-
#provided_last_name ⇒ String?
The last name provided for verification in the authorization request.
-
#provided_middle_name ⇒ String?
The middle name provided for verification in the authorization request.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1508 |
# File 'sig/increase/models/declined_transaction.rbs', line 1508
def initialize: (
|
Instance Attribute Details
#provided_first_name ⇒ String?
The first name provided for verification in the authorization request.
1993 |
# File 'lib/increase/models/declined_transaction.rb', line 1993 required :provided_first_name, String, nil?: true |
#provided_last_name ⇒ String?
The last name provided for verification in the authorization request.
1999 |
# File 'lib/increase/models/declined_transaction.rb', line 1999 required :provided_last_name, String, nil?: true |
#provided_middle_name ⇒ String?
The middle name provided for verification in the authorization request.
2005 |
# File 'lib/increase/models/declined_transaction.rb', line 2005 required :provided_middle_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
1514 |
# File 'sig/increase/models/declined_transaction.rbs', line 1514
def to_hash: -> {
|