Module: Increase::Models::DeclinedTransaction::Source::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs

Overview

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

See Also:

  • Increase::Models::DeclinedTransaction::Source#category

Constant Summary collapse

ACH_DECLINE =

ACH Decline: details will be under the ach_decline object.

Returns:

  • (:ach_decline)
:ach_decline
CARD_DECLINE =

Card Decline: details will be under the card_decline object.

Returns:

  • (:card_decline)
:card_decline
CHECK_DECLINE =

Check Decline: details will be under the check_decline object.

Returns:

  • (:check_decline)
:check_decline
INBOUND_REAL_TIME_PAYMENTS_TRANSFER_DECLINE =

Inbound Real-Time Payments Transfer Decline: details will be under the inbound_real_time_payments_transfer_decline object.

Returns:

  • (:inbound_real_time_payments_transfer_decline)
:inbound_real_time_payments_transfer_decline
INBOUND_FEDNOW_TRANSFER_DECLINE =

Inbound FedNow Transfer Decline: details will be under the inbound_fednow_transfer_decline object.

Returns:

  • (:inbound_fednow_transfer_decline)
:inbound_fednow_transfer_decline
WIRE_DECLINE =

Wire Decline: details will be under the wire_decline object.

Returns:

  • (:wire_decline)
:wire_decline
CHECK_DEPOSIT_REJECTION =

Check Deposit Rejection: details will be under the check_deposit_rejection object.

Returns:

  • (:check_deposit_rejection)
:check_deposit_rejection
OTHER =

The Declined Transaction was made for an undocumented or deprecated reason.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::DeclinedTransaction::Source::category]

Returns:

  • (::Array[Increase::Models::DeclinedTransaction::Source::category])


185
# File 'sig/increase/models/declined_transaction.rbs', line 185

def self?.values: -> ::Array[Increase::Models::DeclinedTransaction::Source::category]