Class: Increase::Models::DeclinedTransaction::Source::CheckDecline

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs

Overview

See Also:

  • Increase::Models::DeclinedTransaction::Source#check_decline

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, auxiliary_on_us:, back_image_file_id:, check_transfer_id:, front_image_file_id:, inbound_check_deposit_id:, reason:) ⇒ Object

A Check Decline object. This field will be present in the JSON response if and only if category is equal to check_decline.

Parameters:

  • amount (Integer)

    The declined amount in USD cents.

  • auxiliary_on_us (String, nil)

    A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.

  • back_image_file_id (String, nil)

    The identifier of the API File object containing an image of the back of the declined check.

  • check_transfer_id (String, nil)

    The identifier of the Check Transfer object associated with this decline.

  • front_image_file_id (String, nil)

    The identifier of the API File object containing an image of the front of the declined check.

  • inbound_check_deposit_id (String, nil)

    The identifier of the Inbound Check Deposit object associated with this decline.

  • reason (Symbol, Increase::Models::DeclinedTransaction::Source::CheckDecline::Reason)

    Why the check was declined.



# File 'lib/increase/models/declined_transaction.rb', line 2182

Instance Attribute Details

#amountInteger

The declined amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


2140
# File 'lib/increase/models/declined_transaction.rb', line 2140

required :amount, Integer

#auxiliary_on_usString?

A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2148
# File 'lib/increase/models/declined_transaction.rb', line 2148

required :auxiliary_on_us, String, nil?: true

#back_image_file_idString?

The identifier of the API File object containing an image of the back of the declined check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2155
# File 'lib/increase/models/declined_transaction.rb', line 2155

required :back_image_file_id, String, nil?: true

#check_transfer_idString?

The identifier of the Check Transfer object associated with this decline.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2161
# File 'lib/increase/models/declined_transaction.rb', line 2161

required :check_transfer_id, String, nil?: true

#front_image_file_idString?

The identifier of the API File object containing an image of the front of the declined check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2168
# File 'lib/increase/models/declined_transaction.rb', line 2168

required :front_image_file_id, String, nil?: true

#inbound_check_deposit_idString?

The identifier of the Inbound Check Deposit object associated with this decline.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2174
# File 'lib/increase/models/declined_transaction.rb', line 2174

required :inbound_check_deposit_id, String, nil?: true

#reasonSymbol, Increase::Models::DeclinedTransaction::Source::CheckDecline::Reason

Why the check was declined.

Parameters:

  • value (Increase::Models::DeclinedTransaction::Source::CheckDecline::reason)

Returns:



2180
# File 'lib/increase/models/declined_transaction.rb', line 2180

required :reason, enum: -> { Increase::DeclinedTransaction::Source::CheckDecline::Reason }

Instance Method Details

#to_hash{

Returns:

  • ({)


1559
# File 'sig/increase/models/declined_transaction.rbs', line 1559

def to_hash: -> {