Module: Increase::Models::DeclinedTransaction::Source::CheckDecline::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs

Overview

Why the check was declined.

See Also:

  • Increase::Models::DeclinedTransaction::Source::CheckDecline#reason

Constant Summary collapse

ACH_ROUTE_DISABLED =

The account number is disabled.

Returns:

  • (:ach_route_disabled)
:ach_route_disabled
ACH_ROUTE_CANCELED =

The account number is canceled.

Returns:

  • (:ach_route_canceled)
:ach_route_canceled
ALTERED_OR_FICTITIOUS =

The deposited check was altered or fictitious.

Returns:

  • (:altered_or_fictitious)
:altered_or_fictitious
BREACHES_LIMIT =

The transaction would cause a limit to be exceeded.

Returns:

  • (:breaches_limit)
:breaches_limit
ENDORSEMENT_IRREGULAR =

The check was not endorsed by the payee.

Returns:

  • (:endorsement_irregular)
:endorsement_irregular
ENTITY_NOT_ACTIVE =

The account's entity is not active.

Returns:

  • (:entity_not_active)
:entity_not_active
GROUP_LOCKED =

Your account is inactive.

Returns:

  • (:group_locked)
:group_locked
INSUFFICIENT_FUNDS =

Your account contains insufficient funds.

Returns:

  • (:insufficient_funds)
:insufficient_funds
STOP_PAYMENT_REQUESTED =

Stop payment requested for this check.

Returns:

  • (:stop_payment_requested)
:stop_payment_requested
DUPLICATE_PRESENTMENT =

The check was a duplicate deposit.

Returns:

  • (:duplicate_presentment)
:duplicate_presentment
NOT_AUTHORIZED =

The check was not authorized.

Returns:

  • (:not_authorized)
:not_authorized
AMOUNT_MISMATCH =

The amount the receiving bank is attempting to deposit does not match the amount on the check.

Returns:

  • (:amount_mismatch)
:amount_mismatch
NOT_OUR_ITEM =

The check attempting to be deposited does not belong to Increase.

Returns:

  • (:not_our_item)
:not_our_item
NO_ACCOUNT_NUMBER_FOUND =

The account number on the check does not exist at Increase.

Returns:

  • (:no_account_number_found)
:no_account_number_found
REFER_TO_IMAGE =

The check is not readable. Please refer to the image.

Returns:

  • (:refer_to_image)
:refer_to_image
UNABLE_TO_PROCESS =

The check cannot be processed. This is rare: please contact support.

Returns:

  • (:unable_to_process)
:unable_to_process
UNUSABLE_IMAGE =

The check image is unusable.

Returns:

  • (:unusable_image)
:unusable_image
USER_INITIATED =

Your integration declined this check via the API.

Returns:

  • (:user_initiated)
:user_initiated

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::DeclinedTransaction::Source::CheckDecline::reason]

Returns:

  • (::Array[Increase::Models::DeclinedTransaction::Source::CheckDecline::reason])


1646
# File 'sig/increase/models/declined_transaction.rbs', line 1646

def self?.values: -> ::Array[Increase::Models::DeclinedTransaction::Source::CheckDecline::reason]