Class: Increase::Models::DeclinedTransaction::Source::CheckDepositRejection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransaction::Source::CheckDepositRejection
- Defined in:
- lib/increase/models/declined_transaction.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The rejected amount in the minor unit of check’s currency.
-
#check_deposit_id ⇒ String
The identifier of the Check Deposit that was rejected.
-
#currency ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CheckDepositRejection::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.
-
#declined_transaction_id ⇒ String
The identifier of the associated declined transaction.
-
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CheckDepositRejection::Reason
Why the check deposit was rejected.
-
#rejected_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the check deposit was rejected.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, check_deposit_id:, currency:, declined_transaction_id:, reason:, rejected_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CheckDepositRejection for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, check_deposit_id:, currency:, declined_transaction_id:, reason:, rejected_at:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::DeclinedTransaction::Source::CheckDepositRejection for more details.
A Check Deposit Rejection object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_rejection`.
|
|
# File 'lib/increase/models/declined_transaction.rb', line 2191
|
Instance Attribute Details
#amount ⇒ Integer
The rejected amount in the minor unit of check’s currency. For dollars, for example, this is cents.
2157 |
# File 'lib/increase/models/declined_transaction.rb', line 2157 required :amount, Integer |
#check_deposit_id ⇒ String
The identifier of the Check Deposit that was rejected.
2163 |
# File 'lib/increase/models/declined_transaction.rb', line 2163 required :check_deposit_id, String |
#currency ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CheckDepositRejection::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.
2170 |
# File 'lib/increase/models/declined_transaction.rb', line 2170 required :currency, enum: -> { Increase::DeclinedTransaction::Source::CheckDepositRejection::Currency } |
#declined_transaction_id ⇒ String
The identifier of the associated declined transaction.
2176 |
# File 'lib/increase/models/declined_transaction.rb', line 2176 required :declined_transaction_id, String |
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::CheckDepositRejection::Reason
Why the check deposit was rejected.
2182 |
# File 'lib/increase/models/declined_transaction.rb', line 2182 required :reason, enum: -> { Increase::DeclinedTransaction::Source::CheckDepositRejection::Reason } |
#rejected_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the check deposit was rejected.
2189 |
# File 'lib/increase/models/declined_transaction.rb', line 2189 required :rejected_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/declined_transaction.rb', line 2221
|