Class: Increase::Models::DigitalCardProfile::TextColor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/digital_card_profile.rb,
sig/increase/models/digital_card_profile.rbs

Overview

See Also:

  • Increase::Models::DigitalCardProfile#text_color

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeTextColor

Returns a new instance of TextColor.

Parameters:

  • blue: (Integer)
  • green: (Integer)
  • red: (Integer)


113
# File 'sig/increase/models/digital_card_profile.rbs', line 113

def initialize: (blue: Integer, green: Integer, red: Integer) -> void

Instance Attribute Details

#blueInteger

The value of the blue channel in the RGB color.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


159
# File 'lib/increase/models/digital_card_profile.rb', line 159

required :blue, Integer

#greenInteger

The value of the green channel in the RGB color.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


165
# File 'lib/increase/models/digital_card_profile.rb', line 165

required :green, Integer

#redInteger

The value of the red channel in the RGB color.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


171
# File 'lib/increase/models/digital_card_profile.rb', line 171

required :red, Integer

Instance Method Details

#to_hash{ blue: Integer, green: Integer, red: Integer }

Returns:

  • ({ blue: Integer, green: Integer, red: Integer })


115
# File 'sig/increase/models/digital_card_profile.rbs', line 115

def to_hash: -> { blue: Integer, green: Integer, red: Integer }