Class: Increase::Models::DigitalCardProfileCloneParams::TextColor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/digital_card_profile_clone_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(blue:, green:, red:) ⇒ Object

The Card’s text color, specified as an RGB triple. The default is white.

Parameters:

  • blue (Integer)

    The value of the blue channel in the RGB color.

  • green (Integer)

    The value of the green channel in the RGB color.

  • red (Integer)

    The value of the red channel in the RGB color.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/increase/models/digital_card_profile_clone_params.rb', line 93

class TextColor < Increase::Internal::Type::BaseModel
  # @!attribute blue
  #   The value of the blue channel in the RGB color.
  #
  #   @return [Integer]
  required :blue, Integer

  # @!attribute green
  #   The value of the green channel in the RGB color.
  #
  #   @return [Integer]
  required :green, Integer

  # @!attribute red
  #   The value of the red channel in the RGB color.
  #
  #   @return [Integer]
  required :red, Integer

  # @!method initialize(blue:, green:, red:)
  #   The Card's text color, specified as an RGB triple. The default is white.
  #
  #   @param blue [Integer] The value of the blue channel in the RGB color.
  #
  #   @param green [Integer] The value of the green channel in the RGB color.
  #
  #   @param red [Integer] The value of the red channel in the RGB color.
end

Instance Attribute Details

#blueInteger

The value of the blue channel in the RGB color.

Returns:

  • (Integer)


98
# File 'lib/increase/models/digital_card_profile_clone_params.rb', line 98

required :blue, Integer

#greenInteger

The value of the green channel in the RGB color.

Returns:

  • (Integer)


104
# File 'lib/increase/models/digital_card_profile_clone_params.rb', line 104

required :green, Integer

#redInteger

The value of the red channel in the RGB color.

Returns:

  • (Integer)


110
# File 'lib/increase/models/digital_card_profile_clone_params.rb', line 110

required :red, Integer