Class: Increase::Models::DigitalWalletToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/digital_wallet_token.rb,
sig/increase/models/digital_wallet_token.rbs

Overview

See Also:

  • Increase::Resources::DigitalWalletTokens#retrieve

Defined Under Namespace

Modules: Status, TokenRequestor, Type Classes: Cardholder, Decline, Device, DynamicPrimaryAccountNumber, Update

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(first6:, last4:) ⇒ Object

The redacted Dynamic Primary Account Number.



# File 'lib/increase/models/digital_wallet_token.rb', line 96


Instance Attribute Details

#account_idString

The identifier for the Account this Digital Wallet Token belongs to.



17
# File 'lib/increase/models/digital_wallet_token.rb', line 17

required :account_id, String

#card_idString

The identifier for the Card this Digital Wallet Token belongs to.



23
# File 'lib/increase/models/digital_wallet_token.rb', line 23

required :card_id, String

#cardholderIncrease::Models::DigitalWalletToken::Cardholder

The cardholder information given when the Digital Wallet Token was created.



29
# File 'lib/increase/models/digital_wallet_token.rb', line 29

required :cardholder, -> { Increase::DigitalWalletToken::Cardholder }

#created_atTime

The ISO 8601 date and time at which the Digital Wallet Token was created.



36
# File 'lib/increase/models/digital_wallet_token.rb', line 36

required :created_at, Time

#declineIncrease::Models::DigitalWalletToken::Decline?

If the Digital Wallet Token was declined during provisioning, details about the decline.



43
# File 'lib/increase/models/digital_wallet_token.rb', line 43

required :decline, -> { Increase::DigitalWalletToken::Decline }, nil?: true

#deviceIncrease::Models::DigitalWalletToken::Device

The device that was used to create the Digital Wallet Token.



49
# File 'lib/increase/models/digital_wallet_token.rb', line 49

required :device, -> { Increase::DigitalWalletToken::Device }

#dynamic_primary_account_numberIncrease::Models::DigitalWalletToken::DynamicPrimaryAccountNumber?

The redacted Dynamic Primary Account Number.



55
56
57
# File 'lib/increase/models/digital_wallet_token.rb', line 55

required :dynamic_primary_account_number,
-> { Increase::DigitalWalletToken::DynamicPrimaryAccountNumber },
nil?: true

#idString

The Digital Wallet Token identifier.



11
# File 'lib/increase/models/digital_wallet_token.rb', line 11

required :id, String

#primary_account_number_reference_identifierString

The reference identifier assigned by the card network to the underlying Card.



63
# File 'lib/increase/models/digital_wallet_token.rb', line 63

required :primary_account_number_reference_identifier, String

#statusSymbol, Increase::Models::DigitalWalletToken::Status

This indicates if payments can be made with the Digital Wallet Token.



69
# File 'lib/increase/models/digital_wallet_token.rb', line 69

required :status, enum: -> { Increase::DigitalWalletToken::Status }

#token_reference_identifierString

The reference identifier assigned by the card network to the token.



75
# File 'lib/increase/models/digital_wallet_token.rb', line 75

required :token_reference_identifier, String

#token_requestorSymbol, Increase::Models::DigitalWalletToken::TokenRequestor

The digital wallet app being used.



81
# File 'lib/increase/models/digital_wallet_token.rb', line 81

required :token_requestor, enum: -> { Increase::DigitalWalletToken::TokenRequestor }

#typeSymbol, Increase::Models::DigitalWalletToken::Type

A constant representing the object's type. For this resource it will always be digital_wallet_token.



88
# File 'lib/increase/models/digital_wallet_token.rb', line 88

required :type, enum: -> { Increase::DigitalWalletToken::Type }

#updatesArray<Increase::Models::DigitalWalletToken::Update>

Updates to the Digital Wallet Token.



94
# File 'lib/increase/models/digital_wallet_token.rb', line 94

required :updates, -> { Increase::Internal::Type::ArrayOf[Increase::DigitalWalletToken::Update] }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/digital_wallet_token.rb', line 195


Instance Method Details

#to_hash{



67
# File 'sig/increase/models/digital_wallet_token.rbs', line 67

def to_hash: -> {