Class: Increase::Models::DigitalWalletToken::Decline
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DigitalWalletToken::Decline
- Defined in:
- lib/increase/models/digital_wallet_token.rb
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#reason ⇒ Symbol, Increase::Models::DigitalWalletToken::Decline::Reason
The reason the token provisioning was declined.
Instance Method Summary collapse
-
#initialize(reason:) ⇒ Object
constructor
If the Digital Wallet Token was declined during provisioning, details about the decline.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reason:) ⇒ Object
If the Digital Wallet Token was declined during provisioning, details about the decline.
|
|
# File 'lib/increase/models/digital_wallet_token.rb', line 130
|
Instance Attribute Details
#reason ⇒ Symbol, Increase::Models::DigitalWalletToken::Decline::Reason
The reason the token provisioning was declined.
128 |
# File 'lib/increase/models/digital_wallet_token.rb', line 128 required :reason, enum: -> { Increase::DigitalWalletToken::Decline::Reason } |