Class: Increase::Models::DigitalWalletToken::Device

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/digital_wallet_token.rb

Overview

See Also:

Defined Under Namespace

Modules: DeviceType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(device_type:, identifier:, ip_address:, name:) ⇒ Object

The device that was used to create the Digital Wallet Token.

Parameters:

  • device_type (Symbol, Increase::Models::DigitalWalletToken::Device::DeviceType, nil)

    Device type.

  • identifier (String, nil)

    ID assigned to the device by the digital wallet provider.

  • ip_address (String, nil)

    IP address of the device.

  • name (String, nil)

    Name of the device, for example “My Work Phone”.



# File 'lib/increase/models/digital_wallet_token.rb', line 139

Instance Attribute Details

#device_typeSymbol, ...

Device type.



119
# File 'lib/increase/models/digital_wallet_token.rb', line 119

required :device_type, enum: -> { Increase::DigitalWalletToken::Device::DeviceType }, nil?: true

#identifierString?

ID assigned to the device by the digital wallet provider.

Returns:

  • (String, nil)


125
# File 'lib/increase/models/digital_wallet_token.rb', line 125

required :identifier, String, nil?: true

#ip_addressString?

IP address of the device.

Returns:

  • (String, nil)


131
# File 'lib/increase/models/digital_wallet_token.rb', line 131

required :ip_address, String, nil?: true

#nameString?

Name of the device, for example “My Work Phone”.

Returns:

  • (String, nil)


137
# File 'lib/increase/models/digital_wallet_token.rb', line 137

required :name, String, nil?: true