Module: Increase::Models::DigitalWalletToken::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/digital_wallet_token.rb,
sig/increase/models/digital_wallet_token.rbs

Overview

This indicates if payments can be made with the Digital Wallet Token.

See Also:

  • Increase::Models::DigitalWalletToken#status

Constant Summary collapse

ACTIVE =

The digital wallet token is active.

Returns:

  • (:active)
:active
INACTIVE =

The digital wallet token has been created but not successfully activated via two-factor authentication yet.

Returns:

  • (:inactive)
:inactive
SUSPENDED =

The digital wallet token has been temporarily paused.

Returns:

  • (:suspended)
:suspended
DEACTIVATED =

The digital wallet token has been permanently canceled.

Returns:

  • (:deactivated)
:deactivated
DECLINED =

The digital wallet token was declined during provisioning.

Returns:

  • (:declined)
:declined

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::DigitalWalletToken::status]

Returns:

  • (::Array[Increase::Models::DigitalWalletToken::status])


235
# File 'sig/increase/models/digital_wallet_token.rbs', line 235

def self?.values: -> ::Array[Increase::Models::DigitalWalletToken::status]