Class: Increase::Models::Entity::Corporation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Corporation
- Defined in:
- lib/increase/models/entity.rb,
sig/increase/models/entity.rbs
Overview
Defined Under Namespace
Modules: BeneficialOwnershipExemptionReason Classes: Address, BeneficialOwner, LegalIdentifier
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::Entity::Corporation::Address
The corporation's address.
-
#beneficial_owners ⇒ Array<Increase::Models::Entity::Corporation::BeneficialOwner>
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
#beneficial_ownership_exemption_reason ⇒ Symbol, ...
If the entity is exempt from the requirement to submit beneficial owners, the justification for the exemption.
-
#email ⇒ String?
An email address for the business.
-
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
#industry_code ⇒ String?
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
-
#legal_identifier ⇒ Increase::Models::Entity::Corporation::LegalIdentifier?
The legal identifier of the corporation, like an Employer Identification Number (EIN).
-
#name ⇒ String
The legal name of the corporation.
-
#website ⇒ String?
The website of the corporation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
constructor
The corporation's address.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
The corporation's address.
|
|
# File 'lib/increase/models/entity.rb', line 287
|
Instance Attribute Details
#address ⇒ Increase::Models::Entity::Corporation::Address
The corporation's address.
229 |
# File 'lib/increase/models/entity.rb', line 229 required :address, -> { Increase::Entity::Corporation::Address } |
#beneficial_owners ⇒ Array<Increase::Models::Entity::Corporation::BeneficialOwner>
The identifying details of anyone controlling or owning 25% or more of the corporation.
236 237 |
# File 'lib/increase/models/entity.rb', line 236 required :beneficial_owners, -> { Increase::Internal::Type::ArrayOf[Increase::Entity::Corporation::BeneficialOwner] } |
#beneficial_ownership_exemption_reason ⇒ Symbol, ...
If the entity is exempt from the requirement to submit beneficial owners, the justification for the exemption.
244 245 246 |
# File 'lib/increase/models/entity.rb', line 244 required :beneficial_ownership_exemption_reason, enum: -> { Increase::Entity::Corporation::BeneficialOwnershipExemptionReason }, nil?: true |
#email ⇒ String?
An email address for the business.
252 |
# File 'lib/increase/models/entity.rb', line 252 required :email, String, nil?: true |
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
259 |
# File 'lib/increase/models/entity.rb', line 259 required :incorporation_state, String, nil?: true |
#industry_code ⇒ String?
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
266 |
# File 'lib/increase/models/entity.rb', line 266 required :industry_code, String, nil?: true |
#legal_identifier ⇒ Increase::Models::Entity::Corporation::LegalIdentifier?
The legal identifier of the corporation, like an Employer Identification Number (EIN).
273 |
# File 'lib/increase/models/entity.rb', line 273 required :legal_identifier, -> { Increase::Entity::Corporation::LegalIdentifier }, nil?: true |
#name ⇒ String
The legal name of the corporation.
279 |
# File 'lib/increase/models/entity.rb', line 279 required :name, String |
#website ⇒ String?
The website of the corporation.
285 |
# File 'lib/increase/models/entity.rb', line 285 required :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity.rb', line 576
|
Instance Method Details
#to_hash ⇒ {
158 |
# File 'sig/increase/models/entity.rbs', line 158
def to_hash: -> {
|