Class: Increase::Models::Entity::Corporation::BeneficialOwner
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Corporation::BeneficialOwner
- Defined in:
- lib/increase/models/entity.rb
Defined Under Namespace
Modules: Prong Classes: Individual
Instance Attribute Summary collapse
-
#company_title ⇒ String?
This person’s role or title within the entity.
-
#id ⇒ String
The identifier of this beneficial owner.
-
#individual ⇒ Increase::Models::Entity::Corporation::BeneficialOwner::Individual
Personal details for the beneficial owner.
-
#prongs ⇒ Array<Symbol, Increase::Models::Entity::Corporation::BeneficialOwner::Prong>
Why this person is considered a beneficial owner of the entity.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, company_title:, individual:, prongs:) ⇒ Object
|
|
# File 'lib/increase/models/entity.rb', line 345
|
Instance Attribute Details
#company_title ⇒ String?
This person’s role or title within the entity.
330 |
# File 'lib/increase/models/entity.rb', line 330 required :company_title, String, nil?: true |
#id ⇒ String
The identifier of this beneficial owner.
324 |
# File 'lib/increase/models/entity.rb', line 324 required :id, String |
#individual ⇒ Increase::Models::Entity::Corporation::BeneficialOwner::Individual
Personal details for the beneficial owner.
336 |
# File 'lib/increase/models/entity.rb', line 336 required :individual, -> { Increase::Entity::Corporation::BeneficialOwner::Individual } |
#prongs ⇒ Array<Symbol, Increase::Models::Entity::Corporation::BeneficialOwner::Prong>
Why this person is considered a beneficial owner of the entity.
342 343 |
# File 'lib/increase/models/entity.rb', line 342 required :prongs, -> { Increase::Internal::Type::ArrayOf[enum: Increase::Entity::Corporation::BeneficialOwner::Prong] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity.rb', line 503
|