Class: Increase::Models::Entity::Corporation::BeneficialOwner::Individual::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Corporation::BeneficialOwner::Individual::Address
- Defined in:
- lib/increase/models/entity.rb,
sig/increase/models/entity.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String?
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
-
#zip ⇒ String?
The ZIP or postal code of the address.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
292 |
# File 'sig/increase/models/entity.rbs', line 292
def initialize: (
|
Instance Attribute Details
#city ⇒ String?
The city, district, town, or village of the address.
411 |
# File 'lib/increase/models/entity.rb', line 411 required :city, String, nil?: true |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
417 |
# File 'lib/increase/models/entity.rb', line 417 required :country, String |
#line1 ⇒ String
The first line of the address.
423 |
# File 'lib/increase/models/entity.rb', line 423 required :line1, String |
#line2 ⇒ String?
The second line of the address.
429 |
# File 'lib/increase/models/entity.rb', line 429 required :line2, String, nil?: true |
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
436 |
# File 'lib/increase/models/entity.rb', line 436 required :state, String, nil?: true |
#zip ⇒ String?
The ZIP or postal code of the address.
442 |
# File 'lib/increase/models/entity.rb', line 442 required :zip, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
301 |
# File 'sig/increase/models/entity.rbs', line 301
def to_hash: -> {
|