Module: Increase::Models::Entity::Corporation::BeneficialOwnershipExemptionReason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Overview

If the entity is exempt from the requirement to submit beneficial owners, the justification for the exemption.

See Also:

  • Increase::Models::Entity::Corporation#beneficial_ownership_exemption_reason

Constant Summary collapse

REGULATED_FINANCIAL_INSTITUTION =

A regulated financial institution.

Returns:

  • (:regulated_financial_institution)
:regulated_financial_institution
PUBLICLY_TRADED_COMPANY =

A publicly traded company.

Returns:

  • (:publicly_traded_company)
:publicly_traded_company
PUBLIC_ENTITY =

A public entity acting on behalf of the federal or a state government.

Returns:

  • (:public_entity)
:public_entity
OTHER =

Any other reason why this entity is exempt from the requirement to submit beneficial owners. You can only use this exemption after approval from your bank partner.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Entity::Corporation::beneficial_ownership_exemption_reason]

Returns:

  • (::Array[Increase::Models::Entity::Corporation::beneficial_ownership_exemption_reason])


398
# File 'sig/increase/models/entity.rbs', line 398

def self?.values: -> ::Array[Increase::Models::Entity::Corporation::beneficial_ownership_exemption_reason]