Class: Increase::Models::Entity::Corporation::LegalIdentifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Corporation::LegalIdentifier
- Defined in:
- lib/increase/models/entity.rb,
sig/increase/models/entity.rbs
Overview
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, Increase::Models::Entity::Corporation::LegalIdentifier::Category
The category of the legal identifier.
-
#value ⇒ String
The legal identifier itself.
Instance Method Summary collapse
-
#initialize(category:, value:) ⇒ Object
constructor
The legal identifier of the corporation, like an Employer Identification Number (EIN).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, value:) ⇒ Object
The legal identifier of the corporation, like an Employer Identification Number (EIN).
|
|
# File 'lib/increase/models/entity.rb', line 572
|
Instance Attribute Details
#category ⇒ Symbol, Increase::Models::Entity::Corporation::LegalIdentifier::Category
The category of the legal identifier.
564 |
# File 'lib/increase/models/entity.rb', line 564 required :category, enum: -> { Increase::Entity::Corporation::LegalIdentifier::Category } |
#value ⇒ String
The legal identifier itself.
570 |
# File 'lib/increase/models/entity.rb', line 570 required :value, String |
Instance Method Details
#to_hash ⇒ {
417 |
# File 'sig/increase/models/entity.rbs', line 417
def to_hash: -> {
|