Class: Increase::Models::Entity::SoleProprietorship

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Overview

See Also:

  • Increase::Models::Entity#sole_proprietorship

Defined Under Namespace

Classes: Address, SoleProprietor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object

The sole proprietorship's address.

Parameters:

  • city (String, nil)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address.

  • line2 (String, nil)

    The second line of the address.

  • state (String, nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.

  • zip (String, nil)

    The ZIP or postal code of the address.



# File 'lib/increase/models/entity.rb', line 1213

Instance Attribute Details

#addressIncrease::Models::Entity::SoleProprietorship::Address

The sole proprietorship's address.

Parameters:

  • value (Increase::Entity::SoleProprietorship::Address)

Returns:



1174
# File 'lib/increase/models/entity.rb', line 1174

required :address, -> { Increase::Entity::SoleProprietorship::Address }

#doing_business_as_nameString?

The name under which the sole proprietorship does business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1180
# File 'lib/increase/models/entity.rb', line 1180

required :doing_business_as_name, String, nil?: true

#emailString?

An email address for the sole proprietorship.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1186
# File 'lib/increase/models/entity.rb', line 1186

required :email, String, nil?: true

#industry_codeString?

The numeric North American Industry Classification System (NAICS) code submitted for the sole proprietorship.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1193
# File 'lib/increase/models/entity.rb', line 1193

required :industry_code, String, nil?: true

#sole_proprietorIncrease::Models::Entity::SoleProprietorship::SoleProprietor

The individual who operates the sole proprietorship.

Parameters:

  • value (Increase::Entity::SoleProprietorship::SoleProprietor)

Returns:



1199
# File 'lib/increase/models/entity.rb', line 1199

required :sole_proprietor, -> { Increase::Entity::SoleProprietorship::SoleProprietor }

#tax_identifierString?

The Employer Identification Number (EIN) for the sole proprietorship.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1205
# File 'lib/increase/models/entity.rb', line 1205

required :tax_identifier, String, nil?: true

#websiteString?

The sole proprietorship's website.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1211
# File 'lib/increase/models/entity.rb', line 1211

required :website, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


902
# File 'sig/increase/models/entity.rbs', line 902

def to_hash: -> {