Class: Increase::Models::Entity::SoleProprietorship::SoleProprietor::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::SoleProprietorship::SoleProprietor::Address
- Defined in:
- lib/increase/models/entity.rb,
sig/increase/models/entity.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String?
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
-
#zip ⇒ String?
The ZIP or postal code of the address.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1008 |
# File 'sig/increase/models/entity.rbs', line 1008
def initialize: (
|
Instance Attribute Details
#city ⇒ String?
The city, district, town, or village of the address.
1338 |
# File 'lib/increase/models/entity.rb', line 1338 required :city, String, nil?: true |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
1344 |
# File 'lib/increase/models/entity.rb', line 1344 required :country, String |
#line1 ⇒ String
The first line of the address.
1350 |
# File 'lib/increase/models/entity.rb', line 1350 required :line1, String |
#line2 ⇒ String?
The second line of the address.
1356 |
# File 'lib/increase/models/entity.rb', line 1356 required :line2, String, nil?: true |
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
1363 |
# File 'lib/increase/models/entity.rb', line 1363 required :state, String, nil?: true |
#zip ⇒ String?
The ZIP or postal code of the address.
1369 |
# File 'lib/increase/models/entity.rb', line 1369 required :zip, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
1017 |
# File 'sig/increase/models/entity.rbs', line 1017
def to_hash: -> {
|