Module: Increase::Models::Entity::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Overview

The status of the entity.

See Also:

  • Increase::Models::Entity#status

Constant Summary collapse

ACTIVE =

The entity is active.

Returns:

  • (:active)
:active
ARCHIVED =

The entity is archived, and can no longer be used to create accounts.

Returns:

  • (:archived)
:archived
DISABLED =

The entity is temporarily disabled and cannot be used for financial activity.

Returns:

  • (:disabled)
:disabled

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Entity::status]

Returns:

  • (::Array[Increase::Models::Entity::status])


875
# File 'sig/increase/models/entity.rbs', line 875

def self?.values: -> ::Array[Increase::Models::Entity::status]