Class: Increase::Models::Entity::TermsAgreement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::TermsAgreement
- Defined in:
- lib/increase/models/entity.rb
Instance Attribute Summary collapse
-
#agreed_at ⇒ Time
The timestamp of when the Entity agreed to the terms.
-
#ip_address ⇒ String
The IP address the Entity accessed reviewed the terms from.
-
#terms_url ⇒ String
The URL of the terms agreement.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#agreed_at ⇒ Time
The timestamp of when the Entity agreed to the terms.
1132 |
# File 'lib/increase/models/entity.rb', line 1132 required :agreed_at, Time |
#ip_address ⇒ String
The IP address the Entity accessed reviewed the terms from.
1138 |
# File 'lib/increase/models/entity.rb', line 1138 required :ip_address, String |
#terms_url ⇒ String
The URL of the terms agreement. This link will be provided by your bank partner.
1144 |
# File 'lib/increase/models/entity.rb', line 1144 required :terms_url, String |