Class: Increase::Models::Entity::Trust
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Trust
- Defined in:
- lib/increase/models/entity.rb,
sig/increase/models/entity.rbs
Overview
Defined Under Namespace
Modules: Category Classes: Address, Grantor, Trustee
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::Entity::Trust::Address
The trust's address.
-
#category ⇒ Symbol, Increase::Models::Entity::Trust::Category
Whether the trust is
revocableorirrevocable. -
#formation_document_file_id ⇒ String?
The ID for the File containing the formation document of the trust.
-
#formation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
#grantor ⇒ Increase::Models::Entity::Trust::Grantor?
The grantor of the trust.
-
#name ⇒ String
The trust's name.
-
#tax_identifier ⇒ String?
The Employer Identification Number (EIN) of the trust itself.
-
#trustees ⇒ Array<Increase::Models::Entity::Trust::Trustee>
The trustees of the trust.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The trust's address.
|
|
# File 'lib/increase/models/entity.rb', line 1293
|
Instance Attribute Details
#address ⇒ Increase::Models::Entity::Trust::Address
The trust's address.
1248 |
# File 'lib/increase/models/entity.rb', line 1248 required :address, -> { Increase::Entity::Trust::Address } |
#category ⇒ Symbol, Increase::Models::Entity::Trust::Category
Whether the trust is revocable or irrevocable.
1254 |
# File 'lib/increase/models/entity.rb', line 1254 required :category, enum: -> { Increase::Entity::Trust::Category } |
#formation_document_file_id ⇒ String?
The ID for the File containing the formation document of the trust.
1260 |
# File 'lib/increase/models/entity.rb', line 1260 required :formation_document_file_id, String, nil?: true |
#formation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
1267 |
# File 'lib/increase/models/entity.rb', line 1267 required :formation_state, String, nil?: true |
#grantor ⇒ Increase::Models::Entity::Trust::Grantor?
The grantor of the trust. Will be present if the category is revocable.
1273 |
# File 'lib/increase/models/entity.rb', line 1273 required :grantor, -> { Increase::Entity::Trust::Grantor }, nil?: true |
#name ⇒ String
The trust's name.
1279 |
# File 'lib/increase/models/entity.rb', line 1279 required :name, String |
#tax_identifier ⇒ String?
The Employer Identification Number (EIN) of the trust itself.
1285 |
# File 'lib/increase/models/entity.rb', line 1285 required :tax_identifier, String, nil?: true |
#trustees ⇒ Array<Increase::Models::Entity::Trust::Trustee>
The trustees of the trust.
1291 |
# File 'lib/increase/models/entity.rb', line 1291 required :trustees, -> { Increase::Internal::Type::ArrayOf[Increase::Entity::Trust::Trustee] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity.rb', line 1385
|
Instance Method Details
#to_hash ⇒ {
1010 |
# File 'sig/increase/models/entity.rbs', line 1010
def to_hash: -> {
|