Class: Increase::Models::Entity::Trust::Trustee::Individual::Identification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Overview

See Also:

  • Increase::Models::Entity::Trust::Trustee::Individual#identification

Defined Under Namespace

Modules: Method

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(method_:, number_last4:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Entity::Trust::Trustee::Individual::Identification for more details.

A means of verifying the person's identity.

Parameters:



# File 'lib/increase/models/entity.rb', line 1678

Instance Attribute Details

#method_Symbol, Increase::Models::Entity::Trust::Trustee::Individual::Identification::Method

A method that can be used to verify the individual's identity.

Parameters:

  • value (Increase::Models::Entity::Trust::Trustee::Individual::Identification::method_)

Returns:



1667
1668
1669
# File 'lib/increase/models/entity.rb', line 1667

required :method_,
enum: -> { Increase::Entity::Trust::Trustee::Individual::Identification::Method },
api_name: :method

#number_last4String

The last 4 digits of the identification number that can be used to verify the individual's identity.

Parameters:

  • value (String)

Returns:

  • (String)


1676
# File 'lib/increase/models/entity.rb', line 1676

required :number_last4, String

Instance Method Details

#to_hash{

Returns:

  • ({)


1311
# File 'sig/increase/models/entity.rbs', line 1311

def to_hash: -> {