Class: Increase::Models::Entity::Validation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Validation
- Defined in:
- lib/increase/models/entity.rb
Overview
Defined Under Namespace
Modules: Status Classes: Issue
Instance Attribute Summary collapse
-
#issues ⇒ Array<Increase::Models::Entity::Validation::Issue>
The list of issues that need to be addressed.
-
#status ⇒ Symbol, Increase::Models::Entity::Validation::Status
The validation status for the entity.
Instance Method Summary collapse
-
#initialize ⇒ Object
constructor
Details when the issue is with the entity’s tax ID.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
Details when the issue is with the entity’s tax ID.
|
|
# File 'lib/increase/models/entity.rb', line 1887
|
Instance Attribute Details
#issues ⇒ Array<Increase::Models::Entity::Validation::Issue>
The list of issues that need to be addressed.
1714 |
# File 'lib/increase/models/entity.rb', line 1714 required :issues, -> { Increase::Internal::Type::ArrayOf[Increase::Entity::Validation::Issue] } |
#status ⇒ Symbol, Increase::Models::Entity::Validation::Status
The validation status for the entity. If the status is ‘invalid`, the `issues` array will be populated.
1721 |
# File 'lib/increase/models/entity.rb', line 1721 required :status, enum: -> { Increase::Entity::Validation::Status } |