Class: Increase::Models::Entity::Validation::Issue

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Defined Under Namespace

Modules: Category Classes: BeneficialOwnerAddress, BeneficialOwnerIdentity, EntityAddress, EntityIdentity, EntityTaxIdentifier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Details when the issue is with the entity's identity verification.



2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
# File 'lib/increase/models/entity.rb', line 2097

class Issue < Increase::Internal::Type::BaseModel
  # @!attribute beneficial_owner_address
  #   Details when the issue is with a beneficial owner's address.
  #
  #   @return [Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress, nil]
  required :beneficial_owner_address,
           -> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress },
           nil?: true

  # @!attribute beneficial_owner_identity
  #   Details when the issue is with a beneficial owner's identity verification.
  #
  #   @return [Increase::Models::Entity::Validation::Issue::BeneficialOwnerIdentity, nil]
  required :beneficial_owner_identity,
           -> { Increase::Entity::Validation::Issue::BeneficialOwnerIdentity },
           nil?: true

  # @!attribute category
  #   The type of issue. We may add additional possible values for this enum over
  #   time; your application should be able to handle such additions gracefully.
  #
  #   @return [Symbol, Increase::Models::Entity::Validation::Issue::Category]
  required :category, enum: -> { Increase::Entity::Validation::Issue::Category }

  # @!attribute entity_address
  #   Details when the issue is with the entity's address.
  #
  #   @return [Increase::Models::Entity::Validation::Issue::EntityAddress, nil]
  required :entity_address, -> { Increase::Entity::Validation::Issue::EntityAddress }, nil?: true

  # @!attribute entity_identity
  #   Details when the issue is with the entity's identity verification.
  #
  #   @return [Increase::Models::Entity::Validation::Issue::EntityIdentity, nil]
  required :entity_identity, -> { Increase::Entity::Validation::Issue::EntityIdentity }, nil?: true

  # @!attribute entity_tax_identifier
  #   Details when the issue is with the entity's tax ID.
  #
  #   @return [Increase::Models::Entity::Validation::Issue::EntityTaxIdentifier, nil]
  required :entity_tax_identifier,
           -> { Increase::Entity::Validation::Issue::EntityTaxIdentifier },
           nil?: true

  # @!method initialize(beneficial_owner_address:, beneficial_owner_identity:, category:, entity_address:, entity_identity:, entity_tax_identifier:)
  #   @param beneficial_owner_address [Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress, nil]
  #     Details when the issue is with a beneficial owner's address.
  #
  #   @param beneficial_owner_identity [Increase::Models::Entity::Validation::Issue::BeneficialOwnerIdentity, nil]
  #     Details when the issue is with a beneficial owner's identity verification.
  #
  #   @param category [Symbol, Increase::Models::Entity::Validation::Issue::Category]
  #     The type of issue. We may add additional possible values for this enum over
  #     time; your application should be able to handle such additions gracefully.
  #
  #   @param entity_address [Increase::Models::Entity::Validation::Issue::EntityAddress, nil]
  #     Details when the issue is with the entity's address.
  #
  #   @param entity_identity [Increase::Models::Entity::Validation::Issue::EntityIdentity, nil]
  #     Details when the issue is with the entity's identity verification.
  #
  #   @param entity_tax_identifier [Increase::Models::Entity::Validation::Issue::EntityTaxIdentifier, nil]
  #     Details when the issue is with the entity's tax ID.

  # @see Increase::Models::Entity::Validation::Issue#beneficial_owner_address
  class BeneficialOwnerAddress < Increase::Internal::Type::BaseModel
    # @!attribute beneficial_owner_id
    #   The ID of the beneficial owner.
    #
    #   @return [String]
    required :beneficial_owner_id, String

    # @!attribute reason
    #   The reason the address is invalid.
    #
    #   @return [Symbol, Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress::Reason]
    required :reason, enum: -> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress::Reason }

    # @!method initialize(beneficial_owner_id:, reason:)
    #   Details when the issue is with a beneficial owner's address.
    #
    #   @param beneficial_owner_id [String] The ID of the beneficial owner.
    #
    #   @param reason [Symbol, Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress::Reason]
    #     The reason the address is invalid.

    # The reason the address is invalid.
    #
    # @see Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress#reason
    module Reason
      extend Increase::Internal::Type::Enum

      # The address is a mailbox or other non-physical address.
      MAILBOX_ADDRESS = :mailbox_address

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @see Increase::Models::Entity::Validation::Issue#beneficial_owner_identity
  class BeneficialOwnerIdentity < Increase::Internal::Type::BaseModel
    # @!attribute beneficial_owner_id
    #   The ID of the beneficial owner.
    #
    #   @return [String]
    required :beneficial_owner_id, String

    # @!method initialize(beneficial_owner_id:)
    #   Details when the issue is with a beneficial owner's identity verification.
    #
    #   @param beneficial_owner_id [String] The ID of the beneficial owner.
  end

  # The type of issue. We may add additional possible values for this enum over
  # time; your application should be able to handle such additions gracefully.
  #
  # @see Increase::Models::Entity::Validation::Issue#category
  module Category
    extend Increase::Internal::Type::Enum

    # The entity's tax identifier could not be verified. Update the tax ID with the [update an entity API](/documentation/api/entities#update-an-entity.corporation.legal_identifier).
    ENTITY_TAX_IDENTIFIER = :entity_tax_identifier

    # The entity's address could not be validated. Update the address with the [update an entity API](/documentation/api/entities#update-an-entity.corporation.address).
    ENTITY_ADDRESS = :entity_address

    # The entity's identity could not be verified. Update the identification with the [update an entity API](/documentation/api/entities#update-an-entity.natural_person.identification).
    ENTITY_IDENTITY = :entity_identity

    # A beneficial owner's identity could not be verified. Update the identification with the [update a beneficial owner API](/documentation/api/beneficial-owners#update-a-beneficial-owner).
    BENEFICIAL_OWNER_IDENTITY = :beneficial_owner_identity

    # A beneficial owner's address could not be validated. Update the address with the [update a beneficial owner API](/documentation/api/beneficial-owners#update-a-beneficial-owner).
    BENEFICIAL_OWNER_ADDRESS = :beneficial_owner_address

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see Increase::Models::Entity::Validation::Issue#entity_address
  class EntityAddress < Increase::Internal::Type::BaseModel
    # @!attribute reason
    #   The reason the address is invalid.
    #
    #   @return [Symbol, Increase::Models::Entity::Validation::Issue::EntityAddress::Reason]
    required :reason, enum: -> { Increase::Entity::Validation::Issue::EntityAddress::Reason }

    # @!method initialize(reason:)
    #   Details when the issue is with the entity's address.
    #
    #   @param reason [Symbol, Increase::Models::Entity::Validation::Issue::EntityAddress::Reason]
    #     The reason the address is invalid.

    # The reason the address is invalid.
    #
    # @see Increase::Models::Entity::Validation::Issue::EntityAddress#reason
    module Reason
      extend Increase::Internal::Type::Enum

      # The address is a mailbox or other non-physical address.
      MAILBOX_ADDRESS = :mailbox_address

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @see Increase::Models::Entity::Validation::Issue#entity_identity
  class EntityIdentity < Increase::Internal::Type::BaseModel
    # @!method initialize
    #   Details when the issue is with the entity's identity verification.
  end

  # @see Increase::Models::Entity::Validation::Issue#entity_tax_identifier
  class EntityTaxIdentifier < Increase::Internal::Type::BaseModel
    # @!method initialize
    #   Details when the issue is with the entity's tax ID.
  end
end

Instance Attribute Details

#beneficial_owner_addressIncrease::Models::Entity::Validation::Issue::BeneficialOwnerAddress?

Details when the issue is with a beneficial owner's address.

Parameters:

  • value (Increase::Entity::Validation::Issue::BeneficialOwnerAddress, nil)

Returns:



2102
2103
2104
# File 'lib/increase/models/entity.rb', line 2102

required :beneficial_owner_address,
-> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress },
nil?: true

#beneficial_owner_identityIncrease::Models::Entity::Validation::Issue::BeneficialOwnerIdentity?

Details when the issue is with a beneficial owner's identity verification.

Parameters:

  • value (Increase::Entity::Validation::Issue::BeneficialOwnerIdentity, nil)

Returns:



2110
2111
2112
# File 'lib/increase/models/entity.rb', line 2110

required :beneficial_owner_identity,
-> { Increase::Entity::Validation::Issue::BeneficialOwnerIdentity },
nil?: true

#categorySymbol, Increase::Models::Entity::Validation::Issue::Category

The type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

Parameters:

  • value (Increase::Models::Entity::Validation::Issue::category)

Returns:



2119
# File 'lib/increase/models/entity.rb', line 2119

required :category, enum: -> { Increase::Entity::Validation::Issue::Category }

#entity_addressIncrease::Models::Entity::Validation::Issue::EntityAddress?

Details when the issue is with the entity's address.

Parameters:

  • value (Increase::Entity::Validation::Issue::EntityAddress, nil)

Returns:



2125
# File 'lib/increase/models/entity.rb', line 2125

required :entity_address, -> { Increase::Entity::Validation::Issue::EntityAddress }, nil?: true

#entity_identityIncrease::Models::Entity::Validation::Issue::EntityIdentity?

Details when the issue is with the entity's identity verification.

Parameters:

  • value (Increase::Entity::Validation::Issue::EntityIdentity, nil)

Returns:



2131
# File 'lib/increase/models/entity.rb', line 2131

required :entity_identity, -> { Increase::Entity::Validation::Issue::EntityIdentity }, nil?: true

#entity_tax_identifierIncrease::Models::Entity::Validation::Issue::EntityTaxIdentifier?

Details when the issue is with the entity's tax ID.

Parameters:

  • value (Increase::Entity::Validation::Issue::EntityTaxIdentifier, nil)

Returns:



2137
2138
2139
# File 'lib/increase/models/entity.rb', line 2137

required :entity_tax_identifier,
-> { Increase::Entity::Validation::Issue::EntityTaxIdentifier },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity.rb', line 2192

Instance Method Details

#to_hash{

Returns:

  • ({)


1648
# File 'sig/increase/models/entity.rbs', line 1648

def to_hash: -> {