Class: Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress
- Defined in:
- lib/increase/models/entity.rb
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#beneficial_owner_id ⇒ String
The ID of the beneficial owner.
-
#reason ⇒ Symbol, Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress::Reason
The reason the address is invalid.
Instance Method Summary collapse
-
#initialize(beneficial_owner_id:, reason:) ⇒ Object
constructor
Details when the issue is with a beneficial owner’s address.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(beneficial_owner_id:, reason:) ⇒ Object
Details when the issue is with a beneficial owner’s address.
|
|
# File 'lib/increase/models/entity.rb', line 1800
|
Instance Attribute Details
#beneficial_owner_id ⇒ String
The ID of the beneficial owner.
1792 |
# File 'lib/increase/models/entity.rb', line 1792 required :beneficial_owner_id, String |
#reason ⇒ Symbol, Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress::Reason
The reason the address is invalid.
1798 |
# File 'lib/increase/models/entity.rb', line 1798 required :reason, enum: -> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress::Reason } |