Module: Increase::Models::Entity::Validation::Issue::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Overview

The type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

See Also:

  • Increase::Models::Entity::Validation::Issue#category

Constant Summary collapse

ENTITY_TAX_IDENTIFIER =

The entity's tax identifier could not be verified. Update the tax ID with the update an entity API.

Returns:

  • (:entity_tax_identifier)
:entity_tax_identifier
ENTITY_ADDRESS =

The entity's address could not be validated. Update the address with the update an entity API.

Returns:

  • (:entity_address)
:entity_address
BENEFICIAL_OWNER_IDENTITY =

A beneficial owner's identity could not be verified. Update the identification with the update a beneficial owner API.

Returns:

  • (:beneficial_owner_identity)
:beneficial_owner_identity
BENEFICIAL_OWNER_ADDRESS =

A beneficial owner's address could not be validated. Update the address with the update a beneficial owner API.

Returns:

  • (:beneficial_owner_address)
:beneficial_owner_address

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Entity::Validation::Issue::category]

Returns:

  • (::Array[Increase::Models::Entity::Validation::Issue::category])


1490
# File 'sig/increase/models/entity.rbs', line 1490

def self?.values: -> ::Array[Increase::Models::Entity::Validation::Issue::category]