Class: Increase::Models::EntityBeneficialOwner

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_beneficial_owner.rb,
sig/increase/models/entity_beneficial_owner.rbs

Overview

See Also:

  • Increase::Resources::BeneficialOwners#create

Defined Under Namespace

Modules: Prong, Type Classes: Individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, company_title:, created_at:, entity_id:, idempotency_key:, individual:, prongs:, type:) ⇒ Object

Beneficial owners are the individuals who control or own 25% or more of a corporation entity. Beneficial owners are always people, and never organizations. Generally, you will need to submit between 1 and 5 beneficial owners for every corporation entity. You should update and archive beneficial owners for a corporation entity as their details change.

Parameters:

  • The identifier of this beneficial owner.

  • This person's role or title within the entity.

  • The ISO 8601 time at which the Beneficial Owner was created.

  • The identifier of the Entity to which this beneficial owner belongs.

  • The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

  • Personal details for the beneficial owner.

  • Why this person is considered a beneficial owner of the entity.

  • A constant representing the object's type. For this resource it will always be entity_beneficial_owner.



# File 'lib/increase/models/entity_beneficial_owner.rb', line 59


Instance Attribute Details

#company_titleString?

This person's role or title within the entity.

Parameters:

Returns:



17
# File 'lib/increase/models/entity_beneficial_owner.rb', line 17

required :company_title, String, nil?: true

#created_atTime

The ISO 8601 time at which the Beneficial Owner was created.

Parameters:

Returns:



24
# File 'lib/increase/models/entity_beneficial_owner.rb', line 24

required :created_at, Time

#entity_idString

The identifier of the Entity to which this beneficial owner belongs.

Parameters:

Returns:



30
# File 'lib/increase/models/entity_beneficial_owner.rb', line 30

required :entity_id, String

#idString

The identifier of this beneficial owner.

Parameters:

Returns:



11
# File 'lib/increase/models/entity_beneficial_owner.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

Parameters:

Returns:



38
# File 'lib/increase/models/entity_beneficial_owner.rb', line 38

required :idempotency_key, String, nil?: true

#individualIncrease::Models::EntityBeneficialOwner::Individual

Personal details for the beneficial owner.

Parameters:

Returns:



44
# File 'lib/increase/models/entity_beneficial_owner.rb', line 44

required :individual, -> { Increase::EntityBeneficialOwner::Individual }

#prongsArray<Symbol, Increase::Models::EntityBeneficialOwner::Prong>

Why this person is considered a beneficial owner of the entity.

Parameters:

Returns:



50
# File 'lib/increase/models/entity_beneficial_owner.rb', line 50

required :prongs, -> { Increase::Internal::Type::ArrayOf[enum: Increase::EntityBeneficialOwner::Prong] }

#typeSymbol, Increase::Models::EntityBeneficialOwner::Type

A constant representing the object's type. For this resource it will always be entity_beneficial_owner.

Parameters:

Returns:



57
# File 'lib/increase/models/entity_beneficial_owner.rb', line 57

required :type, enum: -> { Increase::EntityBeneficialOwner::Type }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/increase/models/entity_beneficial_owner.rb', line 238


Instance Method Details

#to_hash{

Returns:



43
# File 'sig/increase/models/entity_beneficial_owner.rbs', line 43

def to_hash: -> {