Class: Increase::Models::EntityBeneficialOwner::Individual

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_beneficial_owner.rb

Overview

See Also:

Defined Under Namespace

Classes: Address, Identification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The person’s address.

Parameters:

  • city (String, nil)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address.

  • line2 (String, nil)

    The second line of the address.

  • state (String, nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String, nil)

    The ZIP or postal code of the address.



# File 'lib/increase/models/entity_beneficial_owner.rb', line 115

Instance Attribute Details

#addressIncrease::Models::EntityBeneficialOwner::Individual::Address

The person’s address.



91
# File 'lib/increase/models/entity_beneficial_owner.rb', line 91

required :address, -> { Increase::EntityBeneficialOwner::Individual::Address }

#date_of_birthDate

The person’s date of birth in YYYY-MM-DD format.

Returns:

  • (Date)


97
# File 'lib/increase/models/entity_beneficial_owner.rb', line 97

required :date_of_birth, Date

#identificationIncrease::Models::EntityBeneficialOwner::Individual::Identification?

A means of verifying the person’s identity.



103
104
105
106
107
# File 'lib/increase/models/entity_beneficial_owner.rb', line 103

required :identification,
-> {
  Increase::EntityBeneficialOwner::Individual::Identification
},
nil?: true

#nameString

The person’s legal name.

Returns:

  • (String)


113
# File 'lib/increase/models/entity_beneficial_owner.rb', line 113

required :name, String