Class: Increase::Models::EntityBeneficialOwner::Individual::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityBeneficialOwner::Individual::Identification
- Defined in:
- lib/increase/models/entity_beneficial_owner.rb,
sig/increase/models/entity_beneficial_owner.rbs
Overview
Defined Under Namespace
Modules: Method
Instance Attribute Summary collapse
-
#method_ ⇒ Symbol, Increase::Models::EntityBeneficialOwner::Individual::Identification::Method
A method that can be used to verify the individual's identity.
-
#number_last4 ⇒ String
The last 4 digits of the identification number that can be used to verify the individual's identity.
Instance Method Summary collapse
-
#initialize(method_:, number_last4:) ⇒ Object
constructor
A means of verifying the person's identity.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(method_:, number_last4:) ⇒ Object
A means of verifying the person's identity.
|
|
# File 'lib/increase/models/entity_beneficial_owner.rb', line 207
|
Instance Attribute Details
#method_ ⇒ Symbol, Increase::Models::EntityBeneficialOwner::Individual::Identification::Method
A method that can be used to verify the individual's identity.
196 197 198 |
# File 'lib/increase/models/entity_beneficial_owner.rb', line 196 required :method_, enum: -> { Increase::EntityBeneficialOwner::Individual::Identification::Method }, api_name: :method |
#number_last4 ⇒ String
The last 4 digits of the identification number that can be used to verify the individual's identity.
205 |
# File 'lib/increase/models/entity_beneficial_owner.rb', line 205 required :number_last4, String |
Instance Method Details
#to_hash ⇒ {
143 |
# File 'sig/increase/models/entity_beneficial_owner.rbs', line 143
def to_hash: -> {
|