Module: Increase::Models::EntityBeneficialOwner::Prong

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/entity_beneficial_owner.rb,
sig/increase/models/entity_beneficial_owner.rbs

Constant Summary collapse

OWNERSHIP =

A person with 25% or greater direct or indirect ownership of the entity.

Returns:

  • (:ownership)
:ownership
CONTROL =

A person who manages, directs, or has significant control of the entity.

Returns:

  • (:control)
:control

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::EntityBeneficialOwner::prong]

Returns:

  • (::Array[Increase::Models::EntityBeneficialOwner::prong])


189
# File 'sig/increase/models/entity_beneficial_owner.rbs', line 189

def self?.values: -> ::Array[Increase::Models::EntityBeneficialOwner::prong]