Class: Increase::Models::EntityCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Overview

See Also:

  • Increase::Resources::Entities#create

Defined Under Namespace

Modules: Structure Classes: Corporation, GovernmentAuthority, Joint, NaturalPerson, RiskRating, SoleProprietorship, SupplementalDocument, TermsAgreement, ThirdPartyVerification, Trust

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agreed_at:, ip_address:, terms_url:) ⇒ Object



# File 'lib/increase/models/entity_create_params.rb', line 96


Instance Attribute Details

#corporationIncrease::Models::EntityCreateParams::Corporation?

Details of the corporation entity to create. Required if structure is equal to corporation.



21
# File 'lib/increase/models/entity_create_params.rb', line 21

optional :corporation, -> { Increase::EntityCreateParams::Corporation }

#descriptionString?

The description you choose to give the entity.



27
# File 'lib/increase/models/entity_create_params.rb', line 27

optional :description, String

#government_authorityIncrease::Models::EntityCreateParams::GovernmentAuthority?

Details of the Government Authority entity to create. Required if structure is equal to government_authority.



34
# File 'lib/increase/models/entity_create_params.rb', line 34

optional :government_authority, -> { Increase::EntityCreateParams::GovernmentAuthority }

#jointIncrease::Models::EntityCreateParams::Joint?

Details of the joint entity to create. Required if structure is equal to joint.



41
# File 'lib/increase/models/entity_create_params.rb', line 41

optional :joint, -> { Increase::EntityCreateParams::Joint }

#natural_personIncrease::Models::EntityCreateParams::NaturalPerson?

Details of the natural person entity to create. Required if structure is equal to natural_person. Natural people entities should be submitted with social_security_number or individual_taxpayer_identification_number identification methods.



50
# File 'lib/increase/models/entity_create_params.rb', line 50

optional :natural_person, -> { Increase::EntityCreateParams::NaturalPerson }

#risk_ratingIncrease::Models::EntityCreateParams::RiskRating?

An assessment of the entity's potential risk of involvement in financial crimes, such as money laundering.



57
# File 'lib/increase/models/entity_create_params.rb', line 57

optional :risk_rating, -> { Increase::EntityCreateParams::RiskRating }

#sole_proprietorshipIncrease::Models::EntityCreateParams::SoleProprietorship?

Details of the sole proprietorship entity to create. Required if structure is equal to sole_proprietorship.



64
# File 'lib/increase/models/entity_create_params.rb', line 64

optional :sole_proprietorship, -> { Increase::EntityCreateParams::SoleProprietorship }

#structureSymbol, Increase::Models::EntityCreateParams::Structure

The type of Entity to create.



14
# File 'lib/increase/models/entity_create_params.rb', line 14

required :structure, enum: -> { Increase::EntityCreateParams::Structure }

#supplemental_documentsArray<Increase::Models::EntityCreateParams::SupplementalDocument>?

Additional documentation associated with the entity.



70
71
# File 'lib/increase/models/entity_create_params.rb', line 70

optional :supplemental_documents,
-> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::SupplementalDocument] }

#terms_agreementsArray<Increase::Models::EntityCreateParams::TermsAgreement>?

The terms that the Entity agreed to. Not all programs are required to submit this data.



78
79
# File 'lib/increase/models/entity_create_params.rb', line 78

optional :terms_agreements,
-> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::TermsAgreement] }

#third_party_verificationIncrease::Models::EntityCreateParams::ThirdPartyVerification?

If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.



87
# File 'lib/increase/models/entity_create_params.rb', line 87

optional :third_party_verification, -> { Increase::EntityCreateParams::ThirdPartyVerification }

#trustIncrease::Models::EntityCreateParams::Trust?

Details of the trust entity to create. Required if structure is equal to trust.



94
# File 'lib/increase/models/entity_create_params.rb', line 94

optional :trust, -> { Increase::EntityCreateParams::Trust }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/entity_create_params.rb', line 167


Instance Method Details

#to_hash{



106
# File 'sig/increase/models/entity_create_params.rbs', line 106

def to_hash: -> {