Class: Increase::Models::EntityCreateParams::Corporation::BeneficialOwner

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Defined Under Namespace

Modules: Prong Classes: Individual

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, expiration_date:, file_id:) ⇒ Object

Information about the passport used for identification. Required if method is equal to passport.

Parameters:

  • The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).

  • The passport's expiration date in YYYY-MM-DD format.

  • The identifier of the File containing the passport.



# File 'lib/increase/models/entity_create_params.rb', line 375


Instance Attribute Details

#company_titleString?

This person's role or title within the entity.

Parameters:

Returns:



373
# File 'lib/increase/models/entity_create_params.rb', line 373

optional :company_title, String

#individualIncrease::Models::EntityCreateParams::Corporation::BeneficialOwner::Individual

Personal details for the beneficial owner.

Parameters:

Returns:



358
# File 'lib/increase/models/entity_create_params.rb', line 358

required :individual, -> { Increase::EntityCreateParams::Corporation::BeneficialOwner::Individual }

#prongsArray<Symbol, Increase::Models::EntityCreateParams::Corporation::BeneficialOwner::Prong>

Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both.

Parameters:

Returns:



366
367
# File 'lib/increase/models/entity_create_params.rb', line 366

required :prongs,
-> { Increase::Internal::Type::ArrayOf[enum: Increase::EntityCreateParams::Corporation::BeneficialOwner::Prong] }

Instance Method Details

#to_hash{

Returns:



292
# File 'sig/increase/models/entity_create_params.rbs', line 292

def to_hash: -> {