Class: Increase::Models::EntityCreateParams::Corporation::BeneficialOwner::Individual::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Corporation::BeneficialOwner::Individual::Address
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
-
#zip ⇒ String?
The ZIP or postal code of the address.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
348 |
# File 'sig/increase/models/entity_create_params.rbs', line 348
def initialize: (
|
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
390 |
# File 'lib/increase/models/entity_create_params.rb', line 390 required :city, String |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
396 |
# File 'lib/increase/models/entity_create_params.rb', line 396 required :country, String |
#line1 ⇒ String
The first line of the address. This is usually the street number and street.
402 |
# File 'lib/increase/models/entity_create_params.rb', line 402 required :line1, String |
#line2 ⇒ String?
The second line of the address. This might be the floor or room number.
408 |
# File 'lib/increase/models/entity_create_params.rb', line 408 optional :line2, String |
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. Required in certain countries.
415 |
# File 'lib/increase/models/entity_create_params.rb', line 415 optional :state, String |
#zip ⇒ String?
The ZIP or postal code of the address. Required in certain countries.
421 |
# File 'lib/increase/models/entity_create_params.rb', line 421 optional :zip, String |
Instance Method Details
#to_hash ⇒ {
357 |
# File 'sig/increase/models/entity_create_params.rbs', line 357
def to_hash: -> {
|