Class: Increase::Models::EntityCreateParams::Corporation::LegalIdentifier
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Corporation::LegalIdentifier
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Overview
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, ...
The category of the legal identifier.
-
#value ⇒ String
The legal identifier itself.
Instance Method Summary collapse
-
#initialize(value:, category: nil) ⇒ Object
constructor
The legal identifier of the corporation.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(value:, category: nil) ⇒ Object
The legal identifier of the corporation. This is usually the Employer
Identification Number (EIN). This replaces the deprecated tax_identifier
field.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 738
|
Instance Attribute Details
#category ⇒ Symbol, ...
The category of the legal identifier. If not provided, the default is
us_employer_identification_number.
736 |
# File 'lib/increase/models/entity_create_params.rb', line 736 optional :category, enum: -> { Increase::EntityCreateParams::Corporation::LegalIdentifier::Category } |
#value ⇒ String
The legal identifier itself. For US Employer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.
729 |
# File 'lib/increase/models/entity_create_params.rb', line 729 required :value, String |
Instance Method Details
#to_hash ⇒ {
578 |
# File 'sig/increase/models/entity_create_params.rbs', line 578
def to_hash: -> {
|