Class: Increase::Models::EntityCreateParams::GovernmentAuthority

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Defined Under Namespace

Modules: Category Classes: Address, AuthorizedPerson

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:) ⇒ Object

Parameters:

  • name (String)

    The person's legal name.



# File 'lib/increase/models/entity_create_params.rb', line 843

Instance Attribute Details

#addressIncrease::Models::EntityCreateParams::GovernmentAuthority::Address

The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.

Parameters:

  • value (Increase::EntityCreateParams::GovernmentAuthority::Address)

Returns:



808
# File 'lib/increase/models/entity_create_params.rb', line 808

required :address, -> { Increase::EntityCreateParams::GovernmentAuthority::Address }

#authorized_personsArray<Increase::Models::EntityCreateParams::GovernmentAuthority::AuthorizedPerson>

The identifying details of authorized officials acting on the entity's behalf.

Parameters:

  • value (::Array[Increase::EntityCreateParams::GovernmentAuthority::AuthorizedPerson])

Returns:



814
815
# File 'lib/increase/models/entity_create_params.rb', line 814

required :authorized_persons,
-> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::GovernmentAuthority::AuthorizedPerson] }

#categorySymbol, Increase::Models::EntityCreateParams::GovernmentAuthority::Category

The category of the government authority.

Parameters:

  • value (Increase::Models::EntityCreateParams::GovernmentAuthority::category)

Returns:



821
# File 'lib/increase/models/entity_create_params.rb', line 821

required :category, enum: -> { Increase::EntityCreateParams::GovernmentAuthority::Category }

#nameString

The legal name of the government authority.

Parameters:

  • value (String)

Returns:

  • (String)


827
# File 'lib/increase/models/entity_create_params.rb', line 827

required :name, String

#tax_identifierString

The Employer Identification Number (EIN) for the government authority. Submit nine digits with no dashes or other separators.

Parameters:

  • value (String)

Returns:

  • (String)


834
# File 'lib/increase/models/entity_create_params.rb', line 834

required :tax_identifier, String

#websiteString?

A website for the government authority. Not every program requires a website for submitted Entities.

Parameters:

  • (String)

Returns:

  • (String, nil)


841
# File 'lib/increase/models/entity_create_params.rb', line 841

optional :website, String

Instance Method Details

#to_hash{

Returns:

  • ({)


661
# File 'sig/increase/models/entity_create_params.rbs', line 661

def to_hash: -> {