Class: Increase::Models::EntityCreateParams::Joint
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Joint
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Defined Under Namespace
Classes: Individual
Instance Attribute Summary collapse
-
#individuals ⇒ Array<Increase::Models::EntityCreateParams::Joint::Individual>
The two individuals that share control of the entity.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
745 |
# File 'sig/increase/models/entity_create_params.rbs', line 745
def initialize: (
|
Instance Attribute Details
#individuals ⇒ Array<Increase::Models::EntityCreateParams::Joint::Individual>
The two individuals that share control of the entity.
901 902 |
# File 'lib/increase/models/entity_create_params.rb', line 901 required :individuals, -> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::Joint::Individual] } |
Instance Method Details
#to_hash ⇒ {
749 |
# File 'sig/increase/models/entity_create_params.rbs', line 749
def to_hash: -> {
|