Class: Increase::Models::EntityCreateParams::Joint::Individual

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb

Defined Under Namespace

Classes: Address, Identification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The individual’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.

Parameters:

  • city (String)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address. This is usually the street number and street.

  • line2 (String) (defaults to: nil)

    The second line of the address. This might be the floor or room number.

  • state (String) (defaults to: nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String) (defaults to: nil)

    The ZIP or postal code of the address. Required in certain countries.



896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
# File 'lib/increase/models/entity_create_params.rb', line 896

class Individual < Increase::Internal::Type::BaseModel
  # @!attribute address
  #   The individual's physical address. Mail receiving locations like PO Boxes and
  #   PMB's are disallowed.
  #
  #   @return [Increase::Models::EntityCreateParams::Joint::Individual::Address]
  required :address, -> { Increase::EntityCreateParams::Joint::Individual::Address }

  # @!attribute date_of_birth
  #   The person's date of birth in YYYY-MM-DD format.
  #
  #   @return [Date]
  required :date_of_birth, Date

  # @!attribute identification
  #   A means of verifying the person's identity.
  #
  #   @return [Increase::Models::EntityCreateParams::Joint::Individual::Identification]
  required :identification, -> { Increase::EntityCreateParams::Joint::Individual::Identification }

  # @!attribute name
  #   The person's legal name.
  #
  #   @return [String]
  required :name, String

  # @!attribute confirmed_no_us_tax_id
  #   The identification method for an individual can only be a passport, driver's
  #   license, or other document if you've confirmed the individual does not have a US
  #   tax id (either a Social Security Number or Individual Taxpayer Identification
  #   Number).
  #
  #   @return [Boolean, nil]
  optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean

  # @!method initialize(address:, date_of_birth:, identification:, name:, confirmed_no_us_tax_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {Increase::Models::EntityCreateParams::Joint::Individual} for more details.
  #
  #   @param address [Increase::Models::EntityCreateParams::Joint::Individual::Address] The individual's physical address. Mail receiving locations like PO Boxes and PM
  #
  #   @param date_of_birth [Date] The person's date of birth in YYYY-MM-DD format.
  #
  #   @param identification [Increase::Models::EntityCreateParams::Joint::Individual::Identification] A means of verifying the person's identity.
  #
  #   @param name [String] The person's legal name.
  #
  #   @param confirmed_no_us_tax_id [Boolean] The identification method for an individual can only be a passport, driver's lic

  # @see Increase::Models::EntityCreateParams::Joint::Individual#address
  class Address < Increase::Internal::Type::BaseModel
    # @!attribute city
    #   The city, district, town, or village of the address.
    #
    #   @return [String]
    required :city, String

    # @!attribute country
    #   The two-letter ISO 3166-1 alpha-2 code for the country of the address.
    #
    #   @return [String]
    required :country, String

    # @!attribute line1
    #   The first line of the address. This is usually the street number and street.
    #
    #   @return [String]
    required :line1, String

    # @!attribute line2
    #   The second line of the address. This might be the floor or room number.
    #
    #   @return [String, nil]
    optional :line2, String

    # @!attribute state
    #   The two-letter United States Postal Service (USPS) abbreviation for the US
    #   state, province, or region of the address. Required in certain countries.
    #
    #   @return [String, nil]
    optional :state, String

    # @!attribute zip
    #   The ZIP or postal code of the address. Required in certain countries.
    #
    #   @return [String, nil]
    optional :zip, String

    # @!method initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil)
    #   Some parameter documentations has been truncated, see
    #   {Increase::Models::EntityCreateParams::Joint::Individual::Address} for more
    #   details.
    #
    #   The individual's physical address. Mail receiving locations like PO Boxes and
    #   PMB's are disallowed.
    #
    #   @param city [String] The city, district, town, or village of the address.
    #
    #   @param country [String] The two-letter ISO 3166-1 alpha-2 code for the country of the address.
    #
    #   @param line1 [String] The first line of the address. This is usually the street number and street.
    #
    #   @param line2 [String] The second line of the address. This might be the floor or room number.
    #
    #   @param state [String] The two-letter United States Postal Service (USPS) abbreviation for the US state
    #
    #   @param zip [String] The ZIP or postal code of the address. Required in certain countries.
  end

  # @see Increase::Models::EntityCreateParams::Joint::Individual#identification
  class Identification < Increase::Internal::Type::BaseModel
    # @!attribute method_
    #   A method that can be used to verify the individual's identity.
    #
    #   @return [Symbol, Increase::Models::EntityCreateParams::Joint::Individual::Identification::Method]
    required :method_,
             enum: -> { Increase::EntityCreateParams::Joint::Individual::Identification::Method },
             api_name: :method

    # @!attribute number
    #   An identification number that can be used to verify the individual's identity,
    #   such as a social security number.
    #
    #   @return [String]
    required :number, String

    # @!attribute drivers_license
    #   Information about the United States driver's license used for identification.
    #   Required if `method` is equal to `drivers_license`.
    #
    #   @return [Increase::Models::EntityCreateParams::Joint::Individual::Identification::DriversLicense, nil]
    optional :drivers_license,
             -> { Increase::EntityCreateParams::Joint::Individual::Identification::DriversLicense }

    # @!attribute other
    #   Information about the identification document provided. Required if `method` is
    #   equal to `other`.
    #
    #   @return [Increase::Models::EntityCreateParams::Joint::Individual::Identification::Other, nil]
    optional :other, -> { Increase::EntityCreateParams::Joint::Individual::Identification::Other }

    # @!attribute passport
    #   Information about the passport used for identification. Required if `method` is
    #   equal to `passport`.
    #
    #   @return [Increase::Models::EntityCreateParams::Joint::Individual::Identification::Passport, nil]
    optional :passport, -> { Increase::EntityCreateParams::Joint::Individual::Identification::Passport }

    # @!method initialize(method_:, number:, drivers_license: nil, other: nil, passport: nil)
    #   Some parameter documentations has been truncated, see
    #   {Increase::Models::EntityCreateParams::Joint::Individual::Identification} for
    #   more details.
    #
    #   A means of verifying the person's identity.
    #
    #   @param method_ [Symbol, Increase::Models::EntityCreateParams::Joint::Individual::Identification::Method] A method that can be used to verify the individual's identity.
    #
    #   @param number [String] An identification number that can be used to verify the individual's identity, s
    #
    #   @param drivers_license [Increase::Models::EntityCreateParams::Joint::Individual::Identification::DriversLicense] Information about the United States driver's license used for identification. Re
    #
    #   @param other [Increase::Models::EntityCreateParams::Joint::Individual::Identification::Other] Information about the identification document provided. Required if `method` is
    #
    #   @param passport [Increase::Models::EntityCreateParams::Joint::Individual::Identification::Passport] Information about the passport used for identification. Required if `method` is

    # A method that can be used to verify the individual's identity.
    #
    # @see Increase::Models::EntityCreateParams::Joint::Individual::Identification#method_
    module Method
      extend Increase::Internal::Type::Enum

      # A social security number.
      SOCIAL_SECURITY_NUMBER = :social_security_number

      # An individual taxpayer identification number (ITIN).
      INDIVIDUAL_TAXPAYER_IDENTIFICATION_NUMBER = :individual_taxpayer_identification_number

      # A passport number.
      PASSPORT = :passport

      # A driver's license number.
      DRIVERS_LICENSE = :drivers_license

      # Another identifying document.
      OTHER = :other

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Increase::Models::EntityCreateParams::Joint::Individual::Identification#drivers_license
    class DriversLicense < Increase::Internal::Type::BaseModel
      # @!attribute expiration_date
      #   The driver's license's expiration date in YYYY-MM-DD format.
      #
      #   @return [Date]
      required :expiration_date, Date

      # @!attribute file_id
      #   The identifier of the File containing the front of the driver's license.
      #
      #   @return [String]
      required :file_id, String

      # @!attribute state
      #   The state that issued the provided driver's license.
      #
      #   @return [String]
      required :state, String

      # @!attribute back_file_id
      #   The identifier of the File containing the back of the driver's license.
      #
      #   @return [String, nil]
      optional :back_file_id, String

      # @!method initialize(expiration_date:, file_id:, state:, back_file_id: nil)
      #   Information about the United States driver's license used for identification.
      #   Required if `method` is equal to `drivers_license`.
      #
      #   @param expiration_date [Date] The driver's license's expiration date in YYYY-MM-DD format.
      #
      #   @param file_id [String] The identifier of the File containing the front of the driver's license.
      #
      #   @param state [String] The state that issued the provided driver's license.
      #
      #   @param back_file_id [String] The identifier of the File containing the back of the driver's license.
    end

    # @see Increase::Models::EntityCreateParams::Joint::Individual::Identification#other
    class Other < Increase::Internal::Type::BaseModel
      # @!attribute country
      #   The two-character ISO 3166-1 code representing the country that issued the
      #   document (e.g., `US`).
      #
      #   @return [String]
      required :country, String

      # @!attribute description
      #   A description of the document submitted.
      #
      #   @return [String]
      required :description, String

      # @!attribute file_id
      #   The identifier of the File containing the front of the document.
      #
      #   @return [String]
      required :file_id, String

      # @!attribute back_file_id
      #   The identifier of the File containing the back of the document. Not every
      #   document has a reverse side.
      #
      #   @return [String, nil]
      optional :back_file_id, String

      # @!attribute expiration_date
      #   The document's expiration date in YYYY-MM-DD format.
      #
      #   @return [Date, nil]
      optional :expiration_date, Date

      # @!method initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil)
      #   Some parameter documentations has been truncated, see
      #   {Increase::Models::EntityCreateParams::Joint::Individual::Identification::Other}
      #   for more details.
      #
      #   Information about the identification document provided. Required if `method` is
      #   equal to `other`.
      #
      #   @param country [String] The two-character ISO 3166-1 code representing the country that issued the docum
      #
      #   @param description [String] A description of the document submitted.
      #
      #   @param file_id [String] The identifier of the File containing the front of the document.
      #
      #   @param back_file_id [String] The identifier of the File containing the back of the document. Not every docume
      #
      #   @param expiration_date [Date] The document's expiration date in YYYY-MM-DD format.
    end

    # @see Increase::Models::EntityCreateParams::Joint::Individual::Identification#passport
    class Passport < Increase::Internal::Type::BaseModel
      # @!attribute country
      #   The two-character ISO 3166-1 code representing the country that issued the
      #   document (e.g., `US`).
      #
      #   @return [String]
      required :country, String

      # @!attribute expiration_date
      #   The passport's expiration date in YYYY-MM-DD format.
      #
      #   @return [Date]
      required :expiration_date, Date

      # @!attribute file_id
      #   The identifier of the File containing the passport.
      #
      #   @return [String]
      required :file_id, String

      # @!method initialize(country:, expiration_date:, file_id:)
      #   Some parameter documentations has been truncated, see
      #   {Increase::Models::EntityCreateParams::Joint::Individual::Identification::Passport}
      #   for more details.
      #
      #   Information about the passport used for identification. Required if `method` is
      #   equal to `passport`.
      #
      #   @param country [String] The two-character ISO 3166-1 code representing the country that issued the docum
      #
      #   @param expiration_date [Date] The passport's expiration date in YYYY-MM-DD format.
      #
      #   @param file_id [String] The identifier of the File containing the passport.
    end
  end
end

Instance Attribute Details

#addressIncrease::Models::EntityCreateParams::Joint::Individual::Address

The individual’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.



902
# File 'lib/increase/models/entity_create_params.rb', line 902

required :address, -> { Increase::EntityCreateParams::Joint::Individual::Address }

#confirmed_no_us_tax_idBoolean?

The identification method for an individual can only be a passport, driver’s license, or other document if you’ve confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).

Returns:

  • (Boolean, nil)


929
# File 'lib/increase/models/entity_create_params.rb', line 929

optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean

#date_of_birthDate

The person’s date of birth in YYYY-MM-DD format.

Returns:

  • (Date)


908
# File 'lib/increase/models/entity_create_params.rb', line 908

required :date_of_birth, Date

#identificationIncrease::Models::EntityCreateParams::Joint::Individual::Identification

A means of verifying the person’s identity.



914
# File 'lib/increase/models/entity_create_params.rb', line 914

required :identification, -> { Increase::EntityCreateParams::Joint::Individual::Identification }

#nameString

The person’s legal name.

Returns:

  • (String)


920
# File 'lib/increase/models/entity_create_params.rb', line 920

required :name, String