Class: Increase::Models::EntityCreateParams::Joint::Individual::Identification::Other

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#back_file_idString?

The identifier of the File containing the back of the document. Not every document has a reverse side.

Returns:

  • (String, nil)


1151
# File 'lib/increase/models/entity_create_params.rb', line 1151

optional :back_file_id, String

#countryString

The two-character ISO 3166-1 code representing the country that issued the document (e.g., ‘US`).

Returns:

  • (String)


1132
# File 'lib/increase/models/entity_create_params.rb', line 1132

required :country, String

#descriptionString

A description of the document submitted.

Returns:

  • (String)


1138
# File 'lib/increase/models/entity_create_params.rb', line 1138

required :description, String

#expiration_dateDate?

The document’s expiration date in YYYY-MM-DD format.

Returns:

  • (Date, nil)


1157
# File 'lib/increase/models/entity_create_params.rb', line 1157

optional :expiration_date, Date

#file_idString

The identifier of the File containing the front of the document.

Returns:

  • (String)


1144
# File 'lib/increase/models/entity_create_params.rb', line 1144

required :file_id, String