Class: Increase::Models::EntityCreateParams::NaturalPerson::Identification::DriversLicense
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::NaturalPerson::Identification::DriversLicense
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#back_file_id ⇒ String?
The identifier of the File containing the back of the driver's license.
-
#expiration_date ⇒ Date
The driver's license's expiration date in YYYY-MM-DD format.
-
#file_id ⇒ String
The identifier of the File containing the front of the driver's license.
-
#state ⇒ String
The state that issued the provided driver's license.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1197 |
# File 'sig/increase/models/entity_create_params.rbs', line 1197
def initialize: (
|
Instance Attribute Details
#back_file_id ⇒ String?
The identifier of the File containing the back of the driver's license.
1455 |
# File 'lib/increase/models/entity_create_params.rb', line 1455 optional :back_file_id, String |
#expiration_date ⇒ Date
The driver's license's expiration date in YYYY-MM-DD format.
1437 |
# File 'lib/increase/models/entity_create_params.rb', line 1437 required :expiration_date, Date |
#file_id ⇒ String
The identifier of the File containing the front of the driver's license.
1443 |
# File 'lib/increase/models/entity_create_params.rb', line 1443 required :file_id, String |
#state ⇒ String
The state that issued the provided driver's license.
1449 |
# File 'lib/increase/models/entity_create_params.rb', line 1449 required :state, String |
Instance Method Details
#to_hash ⇒ {
1204 |
# File 'sig/increase/models/entity_create_params.rbs', line 1204
def to_hash: -> {
|