Class: Increase::Models::EntityCreateParams::NaturalPerson::Identification::Other

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Overview

See Also:

  • Increase::Models::EntityCreateParams::NaturalPerson::Identification#other

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1253
# File 'sig/increase/models/entity_create_params.rbs', line 1253

def initialize: (

Instance Attribute Details

#back_file_idString?

The identifier of the File containing the back of the document. Not every document has a reverse side.



1610
# File 'lib/increase/models/entity_create_params.rb', line 1610

optional :back_file_id, String

#countryString

The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).



1591
# File 'lib/increase/models/entity_create_params.rb', line 1591

required :country, String

#descriptionString

A description of the document submitted.



1597
# File 'lib/increase/models/entity_create_params.rb', line 1597

required :description, String

#expiration_dateDate?

The document's expiration date in YYYY-MM-DD format.



1616
# File 'lib/increase/models/entity_create_params.rb', line 1616

optional :expiration_date, Date

#file_idString

The identifier of the File containing the front of the document.



1603
# File 'lib/increase/models/entity_create_params.rb', line 1603

required :file_id, String

Instance Method Details

#to_hash{



1261
# File 'sig/increase/models/entity_create_params.rbs', line 1261

def to_hash: -> {