Class: Increase::Models::EntityCreateParams::ThirdPartyVerification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Defined Under Namespace

Modules: Vendor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(reference:, vendor:) ⇒ Object

If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.

Parameters:



# File 'lib/increase/models/entity_create_params.rb', line 1660

Instance Attribute Details

#referenceString

The reference identifier for the third party verification.

Parameters:

  • value (String)

Returns:

  • (String)


1652
# File 'lib/increase/models/entity_create_params.rb', line 1652

required :reference, String

#vendorSymbol, Increase::Models::EntityCreateParams::ThirdPartyVerification::Vendor

The vendor that was used to perform the verification.

Parameters:

  • value (Increase::Models::EntityCreateParams::ThirdPartyVerification::vendor)

Returns:



1658
# File 'lib/increase/models/entity_create_params.rb', line 1658

required :vendor, enum: -> { Increase::EntityCreateParams::ThirdPartyVerification::Vendor }

Instance Method Details

#to_hash{

Returns:

  • ({)


1366
# File 'sig/increase/models/entity_create_params.rbs', line 1366

def to_hash: -> {