Class: Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::DriversLicense

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Overview

See Also:

  • Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification#drivers_license

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1726
# File 'sig/increase/models/entity_create_params.rbs', line 1726

def initialize: (

Instance Attribute Details

#back_file_idString?

The identifier of the File containing the back of the driver's license.

Parameters:

  • (String)

Returns:

  • (String, nil)


2101
# File 'lib/increase/models/entity_create_params.rb', line 2101

optional :back_file_id, String

#expiration_dateDate

The driver's license's expiration date in YYYY-MM-DD format.

Parameters:

  • value (Date)

Returns:

  • (Date)


2083
# File 'lib/increase/models/entity_create_params.rb', line 2083

required :expiration_date, Date

#file_idString

The identifier of the File containing the front of the driver's license.

Parameters:

  • value (String)

Returns:

  • (String)


2089
# File 'lib/increase/models/entity_create_params.rb', line 2089

required :file_id, String

#stateString

The state that issued the provided driver's license.

Parameters:

  • value (String)

Returns:

  • (String)


2095
# File 'lib/increase/models/entity_create_params.rb', line 2095

required :state, String

Instance Method Details

#to_hash{

Returns:

  • ({)


1733
# File 'sig/increase/models/entity_create_params.rbs', line 1733

def to_hash: -> {