Module: Increase::Models::EntityListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/entity_list_params.rb,
sig/increase/models/entity_list_params.rbs

Constant Summary collapse

ACTIVE =

The entity is active.

:active
ARCHIVED =

The entity is archived, and can no longer be used to create accounts.

:archived
DISABLED =

The entity is temporarily disabled and cannot be used for financial activity.

:disabled

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(in_: nil) ⇒ Object



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/increase/models/entity_list_params.rb', line 136

module In
  extend Increase::Internal::Type::Enum

  # The entity is active.
  ACTIVE = :active

  # The entity is archived, and can no longer be used to create accounts.
  ARCHIVED = :archived

  # The entity is temporarily disabled and cannot be used for financial activity.
  DISABLED = :disabled

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::EntityListParams::Status::in_]



135
# File 'sig/increase/models/entity_list_params.rbs', line 135

def self?.values: -> ::Array[Increase::Models::EntityListParams::Status::in_]