Class: Increase::Models::EntityOnboardingSessionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityOnboardingSessionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/entity_onboarding_session_create_params.rb,
sig/increase/models/entity_onboarding_session_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#entity_id ⇒ String?
The identifier of an existing Entity to associate with the onboarding session.
-
#program_id ⇒ String
The identifier of the Program the Entity will be onboarded to.
-
#redirect_url ⇒ String
The URL to redirect the customer to after they complete the onboarding form.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(program_id:, redirect_url:, entity_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EntityOnboardingSessionCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(program_id:, redirect_url:, entity_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::EntityOnboardingSessionCreateParams for more details.
|
|
# File 'lib/increase/models/entity_onboarding_session_create_params.rb', line 32
|
Instance Attribute Details
#entity_id ⇒ String?
The identifier of an existing Entity to associate with the onboarding session. If provided, the onboarding form will display any outstanding tasks required to complete the Entity's onboarding.
30 |
# File 'lib/increase/models/entity_onboarding_session_create_params.rb', line 30 optional :entity_id, String |
#program_id ⇒ String
The identifier of the Program the Entity will be onboarded to.
14 |
# File 'lib/increase/models/entity_onboarding_session_create_params.rb', line 14 required :program_id, String |
#redirect_url ⇒ String
The URL to redirect the customer to after they complete the onboarding form. The
redirect will include entity_onboarding_session_id and entity_id query
parameters.
22 |
# File 'lib/increase/models/entity_onboarding_session_create_params.rb', line 22 required :redirect_url, String |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/increase/models/entity_onboarding_session_create_params.rbs', line 26
def to_hash: -> {
|