Class: Increase::Models::EntityUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/entity_update_params.rb
Overview
Defined Under Namespace
Classes: Corporation, GovernmentAuthority, NaturalPerson, RiskRating, TermsAgreement, ThirdPartyVerification, Trust
Instance Attribute Summary collapse
-
#corporation ⇒ Increase::Models::EntityUpdateParams::Corporation?
Details of the corporation entity to update.
-
#details_confirmed_at ⇒ Time?
When your user last confirmed the Entity’s details.
-
#entity_id ⇒ String
The entity identifier.
-
#government_authority ⇒ Increase::Models::EntityUpdateParams::GovernmentAuthority?
Details of the government authority entity to update.
-
#natural_person ⇒ Increase::Models::EntityUpdateParams::NaturalPerson?
Details of the natural person entity to update.
-
#risk_rating ⇒ Increase::Models::EntityUpdateParams::RiskRating?
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
#terms_agreements ⇒ Array<Increase::Models::EntityUpdateParams::TermsAgreement>?
New terms that the Entity agreed to.
-
#third_party_verification ⇒ Increase::Models::EntityUpdateParams::ThirdPartyVerification?
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
#trust ⇒ Increase::Models::EntityUpdateParams::Trust?
Details of the trust entity to update.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agreed_at:, ip_address:, terms_url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see TermsAgreement for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agreed_at:, ip_address:, terms_url:) ⇒ Object
Some parameter documentations has been truncated, see TermsAgreement for more details.
|
|
# File 'lib/increase/models/entity_update_params.rb', line 319
|
Instance Attribute Details
#corporation ⇒ Increase::Models::EntityUpdateParams::Corporation?
Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
21 |
# File 'lib/increase/models/entity_update_params.rb', line 21 optional :corporation, -> { Increase::EntityUpdateParams::Corporation } |
#details_confirmed_at ⇒ Time?
When your user last confirmed the Entity’s details. Depending on your program, you may be required to affirmatively confirm details with your users on an annual basis.
29 |
# File 'lib/increase/models/entity_update_params.rb', line 29 optional :details_confirmed_at, Time |
#entity_id ⇒ String
The entity identifier.
14 |
# File 'lib/increase/models/entity_update_params.rb', line 14 required :entity_id, String |
#government_authority ⇒ Increase::Models::EntityUpdateParams::GovernmentAuthority?
Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
36 |
# File 'lib/increase/models/entity_update_params.rb', line 36 optional :government_authority, -> { Increase::EntityUpdateParams::GovernmentAuthority } |
#natural_person ⇒ Increase::Models::EntityUpdateParams::NaturalPerson?
Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
43 |
# File 'lib/increase/models/entity_update_params.rb', line 43 optional :natural_person, -> { Increase::EntityUpdateParams::NaturalPerson } |
#risk_rating ⇒ Increase::Models::EntityUpdateParams::RiskRating?
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
50 |
# File 'lib/increase/models/entity_update_params.rb', line 50 optional :risk_rating, -> { Increase::EntityUpdateParams::RiskRating } |
#terms_agreements ⇒ Array<Increase::Models::EntityUpdateParams::TermsAgreement>?
New terms that the Entity agreed to. Not all programs are required to submit this data. This will not archive previously submitted terms.
57 58 |
# File 'lib/increase/models/entity_update_params.rb', line 57 optional :terms_agreements, -> { Increase::Internal::Type::ArrayOf[Increase::EntityUpdateParams::TermsAgreement] } |
#third_party_verification ⇒ Increase::Models::EntityUpdateParams::ThirdPartyVerification?
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
66 |
# File 'lib/increase/models/entity_update_params.rb', line 66 optional :third_party_verification, -> { Increase::EntityUpdateParams::ThirdPartyVerification } |
#trust ⇒ Increase::Models::EntityUpdateParams::Trust?
Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
73 |
# File 'lib/increase/models/entity_update_params.rb', line 73 optional :trust, -> { Increase::EntityUpdateParams::Trust } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity_update_params.rb', line 255
|