Class: Increase::Models::EntityUpdateParams::NaturalPerson

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Defined Under Namespace

Classes: Address, Identification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object

The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.



# File 'lib/increase/models/entity_update_params.rb', line 425


Instance Attribute Details

#addressIncrease::Models::EntityUpdateParams::NaturalPerson::Address?

The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.



402
# File 'lib/increase/models/entity_update_params.rb', line 402

optional :address, -> { Increase::EntityUpdateParams::NaturalPerson::Address }

#confirmed_no_us_tax_idBoolean?

The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).



411
# File 'lib/increase/models/entity_update_params.rb', line 411

optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean

#identificationIncrease::Models::EntityUpdateParams::NaturalPerson::Identification?

A means of verifying the person's identity.



417
# File 'lib/increase/models/entity_update_params.rb', line 417

optional :identification, -> { Increase::EntityUpdateParams::NaturalPerson::Identification }

#nameString?

The legal name of the natural person.



423
# File 'lib/increase/models/entity_update_params.rb', line 423

optional :name, String

Instance Method Details

#to_hash{



360
# File 'sig/increase/models/entity_update_params.rbs', line 360

def to_hash: -> {