Class: Increase::Models::EntityUpdateParams::NaturalPerson::Identification::DriversLicense

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Overview

See Also:

  • Increase::Models::EntityUpdateParams::NaturalPerson::Identification#drivers_license

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



501
# File 'sig/increase/models/entity_update_params.rbs', line 501

def initialize: (

Instance Attribute Details

#back_file_idString?

The identifier of the File containing the back of the driver's license.

Parameters:

  • (String)

Returns:

  • (String, nil)


564
# File 'lib/increase/models/entity_update_params.rb', line 564

optional :back_file_id, String

#expiration_dateDate

The driver's license's expiration date in YYYY-MM-DD format.

Parameters:

  • value (Date)

Returns:

  • (Date)


546
# File 'lib/increase/models/entity_update_params.rb', line 546

required :expiration_date, Date

#file_idString

The identifier of the File containing the front of the driver's license.

Parameters:

  • value (String)

Returns:

  • (String)


552
# File 'lib/increase/models/entity_update_params.rb', line 552

required :file_id, String

#stateString

The state that issued the provided driver's license.

Parameters:

  • value (String)

Returns:

  • (String)


558
# File 'lib/increase/models/entity_update_params.rb', line 558

required :state, String

Instance Method Details

#to_hash{

Returns:

  • ({)


508
# File 'sig/increase/models/entity_update_params.rbs', line 508

def to_hash: -> {