Class: Increase::Models::EntityUpdateParams::SoleProprietorship

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Defined Under Namespace

Classes: Address, SoleProprietor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, line1:, state:, zip:, line2: nil) ⇒ Object

The sole proprietorship's business address. Mail receiving locations like PO Boxes and PMB's are disallowed.



# File 'lib/increase/models/entity_update_params.rb', line 820


Instance Attribute Details

#addressIncrease::Models::EntityUpdateParams::SoleProprietorship::Address?

The sole proprietorship's business address. Mail receiving locations like PO Boxes and PMB's are disallowed.



782
# File 'lib/increase/models/entity_update_params.rb', line 782

optional :address, -> { Increase::EntityUpdateParams::SoleProprietorship::Address }

#emailString?

An email address for the sole proprietorship. Not every program requires an email for submitted Entities.



789
# File 'lib/increase/models/entity_update_params.rb', line 789

optional :email, String

#industry_codeString?

The North American Industry Classification System (NAICS) code for the sole proprietorship's primary line of business. This is a number, like 5132 for Software Publishers. A full list of classification codes is available here.



798
# File 'lib/increase/models/entity_update_params.rb', line 798

optional :industry_code, String

#sole_proprietorIncrease::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor?

Details of the individual who operates the sole proprietorship.



804
# File 'lib/increase/models/entity_update_params.rb', line 804

optional :sole_proprietor, -> { Increase::EntityUpdateParams::SoleProprietorship::SoleProprietor }

#tax_identifierString?

The United States Employer Identification Number (EIN) for the sole proprietorship. Submit nine digits with no dashes or other separators.



811
# File 'lib/increase/models/entity_update_params.rb', line 811

optional :tax_identifier, String

#websiteString?

A website for the sole proprietorship. Not every program requires a website for submitted Entities.



818
# File 'lib/increase/models/entity_update_params.rb', line 818

optional :website, String

Instance Method Details

#to_hash{



678
# File 'sig/increase/models/entity_update_params.rbs', line 678

def to_hash: -> {