Class: Increase::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Overview

See Also:

  • Increase::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor#identification

Defined Under Namespace

Modules: Method Classes: DriversLicense, Other, Passport

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object

Information about the identification document provided. Required if method is equal to other.



# File 'lib/increase/models/entity_update_params.rb', line 1045


Instance Attribute Details

#drivers_licenseIncrease::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::DriversLicense?

Information about the United States driver's license used for identification. Required if method is equal to drivers_license.



1026
1027
# File 'lib/increase/models/entity_update_params.rb', line 1026

optional :drivers_license,
-> { Increase::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::DriversLicense }

#method_Symbol, Increase::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::Method

A method that can be used to verify the individual's identity.

Defaults to social_security_number.



1006
1007
1008
1009
1010
# File 'lib/increase/models/entity_update_params.rb', line 1006

required :method_,
enum: -> {
  Increase::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::Method
},
api_name: :method

#numberString

An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators.



1019
# File 'lib/increase/models/entity_update_params.rb', line 1019

required :number, String

#otherIncrease::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::Other?

Information about the identification document provided. Required if method is equal to other.



1034
1035
# File 'lib/increase/models/entity_update_params.rb', line 1034

optional :other,
-> { Increase::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::Other }

#passportIncrease::Models::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::Passport?

Information about the passport used for identification. Required if method is equal to passport.



1042
1043
# File 'lib/increase/models/entity_update_params.rb', line 1042

optional :passport,
-> { Increase::EntityUpdateParams::SoleProprietorship::SoleProprietor::Identification::Passport }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/entity_update_params.rb', line 1095


Instance Method Details

#to_hash{



850
# File 'sig/increase/models/entity_update_params.rbs', line 850

def to_hash: -> {