Class: Increase::Models::EntityUpdateParams::Trust

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Defined Under Namespace

Classes: Address, Grantor, Trustee

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, expiration_date:, file_id:) ⇒ Object

Information about the passport used for identification. Required if method is equal to passport.

Parameters:

  • country (String)

    The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).

  • expiration_date (Date)

    The passport's expiration date in YYYY-MM-DD format.

  • file_id (String)

    The identifier of the File containing the passport.



# File 'lib/increase/models/entity_update_params.rb', line 871

Instance Attribute Details

#addressIncrease::Models::EntityUpdateParams::Trust::Address?

The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.



849
# File 'lib/increase/models/entity_update_params.rb', line 849

optional :address, -> { Increase::EntityUpdateParams::Trust::Address }

#grantorIncrease::Models::EntityUpdateParams::Trust::Grantor?

The grantor of the trust. If you specify this parameter, the trust's existing grantor will be archived and replaced with the grantor you provide.



856
# File 'lib/increase/models/entity_update_params.rb', line 856

optional :grantor, -> { Increase::EntityUpdateParams::Trust::Grantor }

#nameString?

The legal name of the trust.

Parameters:

  • (String)

Returns:

  • (String, nil)


862
# File 'lib/increase/models/entity_update_params.rb', line 862

optional :name, String

#trusteesArray<Increase::Models::EntityUpdateParams::Trust::Trustee>?

The trustees of the trust. If you specify this parameter, the trust's existing trustees will be archived and replaced with the trustees you provide.



869
# File 'lib/increase/models/entity_update_params.rb', line 869

optional :trustees, -> { Increase::Internal::Type::ArrayOf[Increase::EntityUpdateParams::Trust::Trustee] }

Instance Method Details

#to_hash{

Returns:

  • ({)


727
# File 'sig/increase/models/entity_update_params.rbs', line 727

def to_hash: -> {