Class: Increase::Models::EntityUpdateParams::Trust::Grantor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Overview

See Also:

  • Increase::Models::EntityUpdateParams::Trust#grantor

Defined Under Namespace

Classes: Address, Identification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object

The grantor's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.



# File 'lib/increase/models/entity_update_params.rb', line 1449


Instance Attribute Details

#addressIncrease::Models::EntityUpdateParams::Trust::Grantor::Address

The grantor's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.



1420
# File 'lib/increase/models/entity_update_params.rb', line 1420

required :address, -> { Increase::EntityUpdateParams::Trust::Grantor::Address }

#confirmed_no_us_tax_idBoolean?

The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).



1447
# File 'lib/increase/models/entity_update_params.rb', line 1447

optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean

#date_of_birthDate

The grantor's date of birth in YYYY-MM-DD format.



1426
# File 'lib/increase/models/entity_update_params.rb', line 1426

required :date_of_birth, Date

#identificationIncrease::Models::EntityUpdateParams::Trust::Grantor::Identification

A means of verifying the person's identity.



1432
# File 'lib/increase/models/entity_update_params.rb', line 1432

required :identification, -> { Increase::EntityUpdateParams::Trust::Grantor::Identification }

#nameString

The grantor's legal name.



1438
# File 'lib/increase/models/entity_update_params.rb', line 1438

required :name, String

Instance Method Details

#to_hash{



1178
# File 'sig/increase/models/entity_update_params.rbs', line 1178

def to_hash: -> {