Class: Increase::Models::EntityUpdateParams::Trust::Trustee::Individual::Identification::Passport

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Overview

See Also:

  • Increase::Models::EntityUpdateParams::Trust::Trustee::Individual::Identification#passport

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, expiration_date:, file_id:) ⇒ Object

Information about the passport used for identification. Required if method is equal to passport.

Parameters:

  • The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).

  • The passport's expiration date in YYYY-MM-DD format.

  • The identifier of the File containing the passport.



# File 'lib/increase/models/entity_update_params.rb', line 2124


Instance Attribute Details

#countryString

The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).

Parameters:

Returns:



2110
# File 'lib/increase/models/entity_update_params.rb', line 2110

required :country, String

#expiration_dateDate

The passport's expiration date in YYYY-MM-DD format.

Parameters:

Returns:



2116
# File 'lib/increase/models/entity_update_params.rb', line 2116

required :expiration_date, Date

#file_idString

The identifier of the File containing the passport.

Parameters:

Returns:



2122
# File 'lib/increase/models/entity_update_params.rb', line 2122

required :file_id, String

Instance Method Details

#to_hash{

Returns:



1699
# File 'sig/increase/models/entity_update_params.rbs', line 1699

def to_hash: -> {