Class: Increase::Models::Event

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/event.rb

Overview

Defined Under Namespace

Modules: Category, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, associated_object_id:, associated_object_type:, category:, created_at:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Event for more details.

Events are records of things that happened to objects at Increase. Events are accessible via the List Events endpoint and can be delivered to your application via webhooks. For more information, see our [webhooks guide](increase.com/documentation/webhooks).

Parameters:

  • id (String)

    The Event identifier.

  • associated_object_id (String)

    The identifier of the object that generated this Event.

  • associated_object_type (String)

    The type of the object that generated this Event.

  • category (Symbol, Increase::Models::Event::Category)

    The category of the Event. We may add additional possible values for this enum o

  • created_at (Time)

    The time the Event was created.

  • type (Symbol, Increase::Models::Event::Type)

    A constant representing the object’s type. For this resource it will always be ‘



# File 'lib/increase/models/event.rb', line 45

Instance Attribute Details

#associated_object_idString

The identifier of the object that generated this Event.

Returns:

  • (String)


17
# File 'lib/increase/models/event.rb', line 17

required :associated_object_id, String

#associated_object_typeString

The type of the object that generated this Event.

Returns:

  • (String)


23
# File 'lib/increase/models/event.rb', line 23

required :associated_object_type, String

#categorySymbol, Increase::Models::Event::Category

The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.



30
# File 'lib/increase/models/event.rb', line 30

required :category, enum: -> { Increase::Event::Category }

#created_atTime

The time the Event was created.

Returns:

  • (Time)


36
# File 'lib/increase/models/event.rb', line 36

required :created_at, Time

#idString

The Event identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/event.rb', line 11

required :id, String

#typeSymbol, Increase::Models::Event::Type

A constant representing the object’s type. For this resource it will always be ‘event`.

Returns:



43
# File 'lib/increase/models/event.rb', line 43

required :type, enum: -> { Increase::Event::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/event.rb', line 405