Module: Increase::Models::EventSubscription::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/event_subscription.rb,
sig/increase/models/event_subscription.rbs
Overview
This indicates if we'll send notifications to this subscription.
Constant Summary collapse
- ACTIVE =
The subscription is active and Events will be delivered normally.
:active- DISABLED =
The subscription is temporarily disabled and Events will not be delivered.
:disabled- DELETED =
The subscription is permanently disabled and Events will not be delivered.
:deleted
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::EventSubscription::status]
545 |
# File 'sig/increase/models/event_subscription.rbs', line 545
def self?.values: -> ::Array[Increase::Models::EventSubscription::status]
|