Class: Increase::Models::Export

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/export.rb

Overview

Defined Under Namespace

Modules: Category, Status, Type Classes: AccountStatementBai2, AccountStatementOfx, AccountVerificationLetter, BalanceCsv, BookkeepingAccountBalanceCsv, DailyAccountBalanceCsv, DashboardTableCsv, EntityCsv, FeeCsv, Form1099Int, Form1099Misc, FundingInstructions, Result, TransactionCsv, VendorCsv, VoidedCheck

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Details of the vendor CSV export. This field will be present when the ‘category` is equal to `vendor_csv`.



# File 'lib/increase/models/export.rb', line 161

Instance Attribute Details

#account_statement_bai2Increase::Models::Export::AccountStatementBai2?

Details of the account statement BAI2 export. This field will be present when the ‘category` is equal to `account_statement_bai2`.



18
# File 'lib/increase/models/export.rb', line 18

required :account_statement_bai2, -> { Increase::Export::AccountStatementBai2 }, nil?: true

#account_statement_ofxIncrease::Models::Export::AccountStatementOfx?

Details of the account statement OFX export. This field will be present when the ‘category` is equal to `account_statement_ofx`.



25
# File 'lib/increase/models/export.rb', line 25

required :account_statement_ofx, -> { Increase::Export::AccountStatementOfx }, nil?: true

#account_verification_letterIncrease::Models::Export::AccountVerificationLetter?

Details of the account verification letter export. This field will be present when the ‘category` is equal to `account_verification_letter`.



32
# File 'lib/increase/models/export.rb', line 32

required :account_verification_letter, -> { Increase::Export::AccountVerificationLetter }, nil?: true

#balance_csvIncrease::Models::Export::BalanceCsv?

Details of the balance CSV export. This field will be present when the ‘category` is equal to `balance_csv`.



39
# File 'lib/increase/models/export.rb', line 39

required :balance_csv, -> { Increase::Export::BalanceCsv }, nil?: true

#bookkeeping_account_balance_csvIncrease::Models::Export::BookkeepingAccountBalanceCsv?

Details of the bookkeeping account balance CSV export. This field will be present when the ‘category` is equal to `bookkeeping_account_balance_csv`.



46
47
48
# File 'lib/increase/models/export.rb', line 46

required :bookkeeping_account_balance_csv,
-> { Increase::Export::BookkeepingAccountBalanceCsv },
nil?: true

#categorySymbol, Increase::Models::Export::Category

The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.



55
# File 'lib/increase/models/export.rb', line 55

required :category, enum: -> { Increase::Export::Category }

#created_atTime

The time the Export was created.

Returns:

  • (Time)


61
# File 'lib/increase/models/export.rb', line 61

required :created_at, Time

#daily_account_balance_csvIncrease::Models::Export::DailyAccountBalanceCsv?

Details of the daily account balance CSV export. This field will be present when the ‘category` is equal to `daily_account_balance_csv`.



68
# File 'lib/increase/models/export.rb', line 68

required :daily_account_balance_csv, -> { Increase::Export::DailyAccountBalanceCsv }, nil?: true

#dashboard_table_csvIncrease::Models::Export::DashboardTableCsv?

Details of the dashboard table CSV export. This field will be present when the ‘category` is equal to `dashboard_table_csv`.



75
# File 'lib/increase/models/export.rb', line 75

required :dashboard_table_csv, -> { Increase::Export::DashboardTableCsv }, nil?: true

#entity_csvIncrease::Models::Export::EntityCsv?

Details of the entity CSV export. This field will be present when the ‘category` is equal to `entity_csv`.



82
# File 'lib/increase/models/export.rb', line 82

required :entity_csv, -> { Increase::Export::EntityCsv }, nil?: true

#fee_csvIncrease::Models::Export::FeeCsv?

Details of the fee CSV export. This field will be present when the ‘category` is equal to `fee_csv`.



89
# File 'lib/increase/models/export.rb', line 89

required :fee_csv, -> { Increase::Export::FeeCsv }, nil?: true

#form_1099_intIncrease::Models::Export::Form1099Int?

Details of the Form 1099-INT export. This field will be present when the ‘category` is equal to `form_1099_int`.



96
# File 'lib/increase/models/export.rb', line 96

required :form_1099_int, -> { Increase::Export::Form1099Int }, nil?: true

#form_1099_miscIncrease::Models::Export::Form1099Misc?

Details of the Form 1099-MISC export. This field will be present when the ‘category` is equal to `form_1099_misc`.



103
# File 'lib/increase/models/export.rb', line 103

required :form_1099_misc, -> { Increase::Export::Form1099Misc }, nil?: true

#funding_instructionsIncrease::Models::Export::FundingInstructions?

Details of the funding instructions export. This field will be present when the ‘category` is equal to `funding_instructions`.



110
# File 'lib/increase/models/export.rb', line 110

required :funding_instructions, -> { Increase::Export::FundingInstructions }, nil?: true

#idString

The Export identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/export.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).

Returns:

  • (String, nil)


118
# File 'lib/increase/models/export.rb', line 118

required :idempotency_key, String, nil?: true

#resultIncrease::Models::Export::Result?

The result of the Export. This will be present when the Export’s status transitions to ‘complete`.



125
# File 'lib/increase/models/export.rb', line 125

required :result, -> { Increase::Export::Result }, nil?: true

#statusSymbol, Increase::Models::Export::Status

The status of the Export.



131
# File 'lib/increase/models/export.rb', line 131

required :status, enum: -> { Increase::Export::Status }

#transaction_csvIncrease::Models::Export::TransactionCsv?

Details of the transaction CSV export. This field will be present when the ‘category` is equal to `transaction_csv`.



138
# File 'lib/increase/models/export.rb', line 138

required :transaction_csv, -> { Increase::Export::TransactionCsv }, nil?: true

#typeSymbol, Increase::Models::Export::Type

A constant representing the object’s type. For this resource it will always be ‘export`.

Returns:



145
# File 'lib/increase/models/export.rb', line 145

required :type, enum: -> { Increase::Export::Type }

#vendor_csvIncrease::Models::Export::VendorCsv?

Details of the vendor CSV export. This field will be present when the ‘category` is equal to `vendor_csv`.



152
# File 'lib/increase/models/export.rb', line 152

required :vendor_csv, -> { Increase::Export::VendorCsv }, nil?: true

#voided_checkIncrease::Models::Export::VoidedCheck?

Details of the voided check export. This field will be present when the ‘category` is equal to `voided_check`.



159
# File 'lib/increase/models/export.rb', line 159

required :voided_check, -> { Increase::Export::VoidedCheck }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/export.rb', line 442