Class: Increase::Models::Export::AccountStatementOfx::CreatedAt
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Export::AccountStatementOfx::CreatedAt
- Defined in:
- lib/increase/models/export.rb,
sig/increase/models/export.rbs
Overview
Instance Attribute Summary collapse
-
#before ⇒ Time?
Filter results to transactions created before this time.
-
#on_or_after ⇒ Time?
Filter results to transactions created on or after this time.
Instance Method Summary collapse
-
#initialize ⇒ CreatedAt
constructor
A new instance of CreatedAt.
- #to_hash ⇒ { before: Time?, on_or_after: Time? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ CreatedAt
Returns a new instance of CreatedAt.
175 |
# File 'sig/increase/models/export.rbs', line 175
def initialize: (before: Time?, on_or_after: Time?) -> void
|
Instance Attribute Details
#before ⇒ Time?
Filter results to transactions created before this time.
274 |
# File 'lib/increase/models/export.rb', line 274 required :before, Time, nil?: true |
#on_or_after ⇒ Time?
Filter results to transactions created on or after this time.
280 |
# File 'lib/increase/models/export.rb', line 280 required :on_or_after, Time, nil?: true |
Instance Method Details
#to_hash ⇒ { before: Time?, on_or_after: Time? }
177 |
# File 'sig/increase/models/export.rbs', line 177
def to_hash: -> { before: Time?, on_or_after: Time? }
|