Class: Increase::Models::Export::BookkeepingAccountBalanceCsv
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Export::BookkeepingAccountBalanceCsv
- Defined in:
- lib/increase/models/export.rb,
sig/increase/models/export.rbs
Overview
Instance Attribute Summary collapse
-
#bookkeeping_account_id ⇒ String?
Filter results by Bookkeeping Account.
-
#on_or_after_date ⇒ Date?
Filter balances to those on or after this date.
-
#on_or_before_date ⇒ Date?
Filter balances to those on or before this date.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
242 |
# File 'sig/increase/models/export.rbs', line 242
def initialize: (
|
Instance Attribute Details
#bookkeeping_account_id ⇒ String?
Filter results by Bookkeeping Account.
365 |
# File 'lib/increase/models/export.rb', line 365 required :bookkeeping_account_id, String, nil?: true |
#on_or_after_date ⇒ Date?
Filter balances to those on or after this date.
371 |
# File 'lib/increase/models/export.rb', line 371 required :on_or_after_date, Date, nil?: true |
#on_or_before_date ⇒ Date?
Filter balances to those on or before this date.
377 |
# File 'lib/increase/models/export.rb', line 377 required :on_or_before_date, Date, nil?: true |
Instance Method Details
#to_hash ⇒ {
248 |
# File 'sig/increase/models/export.rbs', line 248
def to_hash: -> {
|