Module: Increase::Models::Export::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/export.rb,
sig/increase/models/export.rbs

Overview

The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.

See Also:

  • Increase::Models::Export#category

Constant Summary collapse

ACCOUNT_STATEMENT_OFX =

Export an Open Financial Exchange (OFX) file of transactions and balances for a given time range and Account.

Returns:

  • (:account_statement_ofx)
:account_statement_ofx
ACCOUNT_STATEMENT_BAI2 =

Export a BAI2 file of transactions and balances for a given date and optional Account.

Returns:

  • (:account_statement_bai2)
:account_statement_bai2
TRANSACTION_CSV =

Export a CSV of all transactions for a given time range.

Returns:

  • (:transaction_csv)
:transaction_csv
BALANCE_CSV =

Export a CSV of account balances for the dates in a given range. (deprecated, use daily_account_balance_csv instead)

Returns:

  • (:balance_csv)
:balance_csv
BOOKKEEPING_ACCOUNT_BALANCE_CSV =

Export a CSV of bookkeeping account balances for the dates in a given range.

Returns:

  • (:bookkeeping_account_balance_csv)
:bookkeeping_account_balance_csv
ENTITY_CSV =

Export a CSV of entities with a given status.

Returns:

  • (:entity_csv)
:entity_csv
VENDOR_CSV =

Export a CSV of vendors added to the third-party risk management dashboard.

Returns:

  • (:vendor_csv)
:vendor_csv
DASHBOARD_TABLE_CSV =

Certain dashboard tables are available as CSV exports. This export cannot be created via the API.

Returns:

  • (:dashboard_table_csv)
:dashboard_table_csv
ACCOUNT_VERIFICATION_LETTER =

A PDF of an account verification letter.

Returns:

  • (:account_verification_letter)
:account_verification_letter
FUNDING_INSTRUCTIONS =

A PDF of funding instructions.

Returns:

  • (:funding_instructions)
:funding_instructions
FORM_1099_INT =

A PDF of an Internal Revenue Service Form 1099-INT.

Returns:

  • (:form_1099_int)
:form_1099_int
FORM_1099_MISC =

A PDF of an Internal Revenue Service Form 1099-MISC.

Returns:

  • (:form_1099_misc)
:form_1099_misc
FEE_CSV =

Export a CSV of fees. The time range must not include any fees that are part of an open fee statement.

Returns:

  • (:fee_csv)
:fee_csv
VOIDED_CHECK =

A PDF of a voided check.

Returns:

  • (:voided_check)
:voided_check
DAILY_ACCOUNT_BALANCE_CSV =

Export a CSV of daily account balances with starting and ending balances for a given date range.

Returns:

  • (:daily_account_balance_csv)
:daily_account_balance_csv

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Export::category]

Returns:

  • (::Array[Increase::Models::Export::category])


320
# File 'sig/increase/models/export.rbs', line 320

def self?.values: -> ::Array[Increase::Models::Export::category]