Class: Increase::Models::ExportCreateParams::AccountStatementBai2

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/export_create_params.rb,
sig/increase/models/export_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



196
# File 'sig/increase/models/export_create_params.rbs', line 196

def initialize: (

Instance Attribute Details

#account_idString?

The Account to create a BAI2 report for. If not provided, all open accounts will be included.

Parameters:

  • (String)

Returns:

  • (String, nil)


173
# File 'lib/increase/models/export_create_params.rb', line 173

optional :account_id, String

#effective_dateDate?

The date to create a BAI2 report for. If not provided, the current date will be used. The timezone is UTC. If the current date is used, the report will include intraday balances, otherwise it will include end-of-day balances for the provided date.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


182
# File 'lib/increase/models/export_create_params.rb', line 182

optional :effective_date, Date

#program_idString?

The Program to create a BAI2 report for. If not provided, all open accounts will be included.

Parameters:

  • (String)

Returns:

  • (String, nil)


189
# File 'lib/increase/models/export_create_params.rb', line 189

optional :program_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


202
# File 'sig/increase/models/export_create_params.rbs', line 202

def to_hash: -> {