Class: Increase::Models::ExportCreateParams::AccountStatementOfx::CreatedAt
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExportCreateParams::AccountStatementOfx::CreatedAt
- Defined in:
- lib/increase/models/export_create_params.rb,
sig/increase/models/export_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#before ⇒ Time?
Filter results to transactions created before this time.
-
#on_or_after ⇒ Time?
Filter results to transactions created on or after this time.
Instance Method Summary collapse
-
#initialize ⇒ CreatedAt
constructor
A new instance of CreatedAt.
- #to_hash ⇒ { before: Time, on_or_after: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ CreatedAt
Returns a new instance of CreatedAt.
245 |
# File 'sig/increase/models/export_create_params.rbs', line 245
def initialize: (?before: Time, ?on_or_after: Time) -> void
|
Instance Attribute Details
#before ⇒ Time?
Filter results to transactions created before this time.
232 |
# File 'lib/increase/models/export_create_params.rb', line 232 optional :before, Time |
#on_or_after ⇒ Time?
Filter results to transactions created on or after this time.
238 |
# File 'lib/increase/models/export_create_params.rb', line 238 optional :on_or_after, Time |
Instance Method Details
#to_hash ⇒ { before: Time, on_or_after: Time }
247 |
# File 'sig/increase/models/export_create_params.rbs', line 247
def to_hash: -> { before: Time, on_or_after: Time }
|