Class: Increase::Models::ExportCreateParams::AccountVerificationLetter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExportCreateParams::AccountVerificationLetter
- Defined in:
- lib/increase/models/export_create_params.rb,
sig/increase/models/export_create_params.rbs
Instance Attribute Summary collapse
-
#account_number_id ⇒ String
The Account Number to create a letter for.
-
#balance_date ⇒ Date?
The date of the balance to include in the letter.
Instance Method Summary collapse
-
#initialize ⇒ AccountVerificationLetter
constructor
A new instance of AccountVerificationLetter.
- #to_hash ⇒ { account_number_id: String, balance_date: Date }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ AccountVerificationLetter
Returns a new instance of AccountVerificationLetter.
261 |
# File 'sig/increase/models/export_create_params.rbs', line 261
def initialize: (account_number_id: String, ?balance_date: Date) -> void
|
Instance Attribute Details
#account_number_id ⇒ String
The Account Number to create a letter for.
254 |
# File 'lib/increase/models/export_create_params.rb', line 254 required :account_number_id, String |
#balance_date ⇒ Date?
The date of the balance to include in the letter. Defaults to the current date.
260 |
# File 'lib/increase/models/export_create_params.rb', line 260 optional :balance_date, Date |
Instance Method Details
#to_hash ⇒ { account_number_id: String, balance_date: Date }
263 |
# File 'sig/increase/models/export_create_params.rbs', line 263
def to_hash: -> { account_number_id: String, balance_date: Date }
|