Class: Increase::Models::ExportCreateParams::BookkeepingAccountBalanceCsv
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExportCreateParams::BookkeepingAccountBalanceCsv
- Defined in:
- lib/increase/models/export_create_params.rb
Instance Attribute Summary collapse
-
#bookkeeping_account_id ⇒ String?
Filter exported Bookkeeping Account Balances to the specified Bookkeeping Account.
-
#on_or_after_date ⇒ Date?
Filter exported Balances to those on or after this date.
-
#on_or_before_date ⇒ Date?
Filter exported Balances to those on or before this date.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#bookkeeping_account_id ⇒ String?
Filter exported Bookkeeping Account Balances to the specified Bookkeeping Account.
266 |
# File 'lib/increase/models/export_create_params.rb', line 266 optional :bookkeeping_account_id, String |
#on_or_after_date ⇒ Date?
Filter exported Balances to those on or after this date.
272 |
# File 'lib/increase/models/export_create_params.rb', line 272 optional :on_or_after_date, Date |
#on_or_before_date ⇒ Date?
Filter exported Balances to those on or before this date.
278 |
# File 'lib/increase/models/export_create_params.rb', line 278 optional :on_or_before_date, Date |