Class: Increase::Models::ExportCreateParams::DailyAccountBalanceCsv

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/export_create_params.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#account_idString?

Filter exported Balances to the specified Account.

Returns:

  • (String, nil)


300
# File 'lib/increase/models/export_create_params.rb', line 300

optional :account_id, String

#on_or_after_dateDate?

Filter exported Balances to those on or after this date.

Returns:

  • (Date, nil)


306
# File 'lib/increase/models/export_create_params.rb', line 306

optional :on_or_after_date, Date

#on_or_before_dateDate?

Filter exported Balances to those on or before this date.

Returns:

  • (Date, nil)


312
# File 'lib/increase/models/export_create_params.rb', line 312

optional :on_or_before_date, Date