Class: Increase::Models::ExportCreateParams::VoidedCheck
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExportCreateParams::VoidedCheck
- Defined in:
- lib/increase/models/export_create_params.rb,
sig/increase/models/export_create_params.rbs
Defined Under Namespace
Classes: Payer
Instance Attribute Summary collapse
-
#account_number_id ⇒ String
The Account Number for the voided check.
-
#payer ⇒ Array<Increase::Models::ExportCreateParams::VoidedCheck::Payer>?
The payer information to be printed on the check.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
495 |
# File 'sig/increase/models/export_create_params.rbs', line 495
def initialize: (
|
Instance Attribute Details
#account_number_id ⇒ String
The Account Number for the voided check.
499 |
# File 'lib/increase/models/export_create_params.rb', line 499 required :account_number_id, String |
#payer ⇒ Array<Increase::Models::ExportCreateParams::VoidedCheck::Payer>?
The payer information to be printed on the check.
505 506 |
# File 'lib/increase/models/export_create_params.rb', line 505 optional :payer, -> { Increase::Internal::Type::ArrayOf[Increase::ExportCreateParams::VoidedCheck::Payer] } |
Instance Method Details
#to_hash ⇒ {
500 |
# File 'sig/increase/models/export_create_params.rbs', line 500
def to_hash: -> {
|