Class: Increase::Models::ExportListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExportListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/export_list_params.rb
Overview
Defined Under Namespace
Modules: Category Classes: CreatedAt, Form1099Int, Form1099Misc, Status
Instance Attribute Summary collapse
-
#category ⇒ Symbol, ...
Filter Exports for those with the specified category.
- #created_at ⇒ Increase::Models::ExportListParams::CreatedAt?
-
#cursor ⇒ String?
Return the page of entries after this one.
- #form_1099_int ⇒ Increase::Models::ExportListParams::Form1099Int?
- #form_1099_misc ⇒ Increase::Models::ExportListParams::Form1099Misc?
-
#idempotency_key ⇒ String?
Filter records to the one with the specified ‘idempotency_key` you chose for that object.
-
#limit ⇒ Integer?
Limit the size of the list that is returned.
- #status ⇒ Increase::Models::ExportListParams::Status?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(account_id: nil) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id: nil) ⇒ Object
|
|
# File 'lib/increase/models/export_list_params.rb', line 58
|
Instance Attribute Details
#category ⇒ Symbol, ...
Filter Exports for those with the specified category.
14 |
# File 'lib/increase/models/export_list_params.rb', line 14 optional :category, enum: -> { Increase::ExportListParams::Category } |
#created_at ⇒ Increase::Models::ExportListParams::CreatedAt?
19 |
# File 'lib/increase/models/export_list_params.rb', line 19 optional :created_at, -> { Increase::ExportListParams::CreatedAt } |
#cursor ⇒ String?
Return the page of entries after this one.
25 |
# File 'lib/increase/models/export_list_params.rb', line 25 optional :cursor, String |
#form_1099_int ⇒ Increase::Models::ExportListParams::Form1099Int?
30 |
# File 'lib/increase/models/export_list_params.rb', line 30 optional :form_1099_int, -> { Increase::ExportListParams::Form1099Int } |
#form_1099_misc ⇒ Increase::Models::ExportListParams::Form1099Misc?
35 |
# File 'lib/increase/models/export_list_params.rb', line 35 optional :form_1099_misc, -> { Increase::ExportListParams::Form1099Misc } |
#idempotency_key ⇒ String?
Filter records to the one with the specified ‘idempotency_key` you chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
44 |
# File 'lib/increase/models/export_list_params.rb', line 44 optional :idempotency_key, String |
#limit ⇒ Integer?
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
51 |
# File 'lib/increase/models/export_list_params.rb', line 51 optional :limit, Integer |
#status ⇒ Increase::Models::ExportListParams::Status?
56 |
# File 'lib/increase/models/export_list_params.rb', line 56 optional :status, -> { Increase::ExportListParams::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/export_list_params.rb', line 129
|