Class: Increase::Models::ExportListParams::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExportListParams::Status
- Defined in:
- lib/increase/models/export_list_params.rb,
sig/increase/models/export_list_params.rbs
Defined Under Namespace
Modules: In
Instance Attribute Summary collapse
-
#in_ ⇒ Array<Symbol, Increase::Models::ExportListParams::Status::In>?
Filter Exports for those with the specified status or statuses.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
223 |
# File 'sig/increase/models/export_list_params.rbs', line 223
def initialize: (
|
Instance Attribute Details
#in_ ⇒ Array<Symbol, Increase::Models::ExportListParams::Status::In>?
Filter Exports for those with the specified status or statuses. For GET
requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
204 205 206 |
# File 'lib/increase/models/export_list_params.rb', line 204 optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::ExportListParams::Status::In] }, api_name: :in |
Instance Method Details
#to_hash ⇒ {
227 |
# File 'sig/increase/models/export_list_params.rbs', line 227
def to_hash: -> {
|