Module: Increase::Models::ExportListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/export_list_params.rb,
sig/increase/models/export_list_params.rbs

Constant Summary collapse

PENDING =

Increase is generating the export.

:pending
COMPLETE =

The export has been successfully generated.

:complete
FAILED =

The export failed to generate. Increase will reach out to you to resolve the issue.

:failed

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/export_list_params.rb', line 239


Instance Method Details

#initialize(in_: nil) ⇒ Object



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/increase/models/export_list_params.rb', line 227

module In
  extend Increase::Internal::Type::Enum

  # Increase is generating the export.
  PENDING = :pending

  # The export has been successfully generated.
  COMPLETE = :complete

  # The export failed to generate. Increase will reach out to you to resolve the issue.
  FAILED = :failed

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::ExportListParams::Status::in_]



245
# File 'sig/increase/models/export_list_params.rbs', line 245

def self?.values: -> ::Array[Increase::Models::ExportListParams::Status::in_]