Module: Increase::Models::ExternalAccountCreateParams::AccountHolder

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/external_account_create_params.rb,
sig/increase/models/external_account_create_params.rbs

Overview

The type of entity that owns the External Account.

Constant Summary collapse

BUSINESS =

The External Account is owned by a business.

Returns:

  • (:business)
:business
INDIVIDUAL =

The External Account is owned by an individual.

Returns:

  • (:individual)
:individual
UNKNOWN =

It's unknown what kind of entity owns the External Account.

Returns:

  • (:unknown)
:unknown

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::ExternalAccountCreateParams::account_holder]

Returns:

  • (::Array[Increase::Models::ExternalAccountCreateParams::account_holder])


67
# File 'sig/increase/models/external_account_create_params.rbs', line 67

def self?.values: -> ::Array[Increase::Models::ExternalAccountCreateParams::account_holder]