Class: Increase::Models::FednowTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/fednow_transfer.rb,
sig/increase/models/fednow_transfer.rbs

Overview

See Also:

  • Increase::Resources::FednowTransfers#create

Defined Under Namespace

Modules: Currency, Status, Type Classes: Acknowledgement, CreatedBy, CreditorAddress, DebtorAddress, Rejection, Return, Submission

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message_identification:, submitted_at:) ⇒ Object

After the transfer is submitted to FedNow, this will contain supplemental details.



# File 'lib/increase/models/fednow_transfer.rb', line 172


Instance Attribute Details

#account_idString

The Account from which the transfer was sent.



17
# File 'lib/increase/models/fednow_transfer.rb', line 17

required :account_id, String

#account_numberString

The destination account number.



23
# File 'lib/increase/models/fednow_transfer.rb', line 23

required :account_number, String

#acknowledgementIncrease::Models::FednowTransfer::Acknowledgement?

If the transfer is acknowledged by the recipient bank, this will contain supplemental details.



30
# File 'lib/increase/models/fednow_transfer.rb', line 30

required :acknowledgement, -> { Increase::FednowTransfer::Acknowledgement }, nil?: true

#amountInteger

The transfer amount in USD cents.



36
# File 'lib/increase/models/fednow_transfer.rb', line 36

required :amount, Integer

#created_atTime

The ISO 8601 date and time at which the transfer was created.



43
# File 'lib/increase/models/fednow_transfer.rb', line 43

required :created_at, Time

#created_byIncrease::Models::FednowTransfer::CreatedBy?

What object created the transfer, either via the API or the dashboard.



49
# File 'lib/increase/models/fednow_transfer.rb', line 49

required :created_by, -> { Increase::FednowTransfer::CreatedBy }, nil?: true

#creditor_addressIncrease::Models::FednowTransfer::CreditorAddress?

The creditor's address.



55
# File 'lib/increase/models/fednow_transfer.rb', line 55

required :creditor_address, -> { Increase::FednowTransfer::CreditorAddress }, nil?: true

#creditor_nameString

The name of the transfer's recipient. This is set by the sender when creating the transfer.



62
# File 'lib/increase/models/fednow_transfer.rb', line 62

required :creditor_name, String

#currencySymbol, Increase::Models::FednowTransfer::Currency

The ISO 4217 code for the transfer's currency. For FedNow transfers this is always equal to USD.



69
# File 'lib/increase/models/fednow_transfer.rb', line 69

required :currency, enum: -> { Increase::FednowTransfer::Currency }

#debtor_addressIncrease::Models::FednowTransfer::DebtorAddress?

The debtor's address.



75
# File 'lib/increase/models/fednow_transfer.rb', line 75

required :debtor_address, -> { Increase::FednowTransfer::DebtorAddress }, nil?: true

#debtor_nameString

The name of the transfer's sender. If not provided, defaults to the name of the account's entity.



82
# File 'lib/increase/models/fednow_transfer.rb', line 82

required :debtor_name, String

#external_account_idString?

The identifier of the External Account the transfer was made to, if any.



88
# File 'lib/increase/models/fednow_transfer.rb', line 88

required :external_account_id, String, nil?: true

#idString

The FedNow Transfer's identifier.



11
# File 'lib/increase/models/fednow_transfer.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.



96
# File 'lib/increase/models/fednow_transfer.rb', line 96

required :idempotency_key, String, nil?: true

#pending_transaction_idString?

The ID for the pending transaction representing the transfer.



102
# File 'lib/increase/models/fednow_transfer.rb', line 102

required :pending_transaction_id, String, nil?: true

#rejectionIncrease::Models::FednowTransfer::Rejection?

If the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details.



109
# File 'lib/increase/models/fednow_transfer.rb', line 109

required :rejection, -> { Increase::FednowTransfer::Rejection }, nil?: true

#returnsArray<Increase::Models::FednowTransfer::Return>

If the transfer is returned by the recipient's bank, this will contain details of each return. FedNow allows returning part of a transfer, so a transfer can be returned more than once.



117
# File 'lib/increase/models/fednow_transfer.rb', line 117

required :returns, -> { Increase::Internal::Type::ArrayOf[Increase::FednowTransfer::Return] }

#routing_numberString

The destination American Bankers' Association (ABA) Routing Transit Number (RTN).



124
# File 'lib/increase/models/fednow_transfer.rb', line 124

required :routing_number, String

#source_account_number_idString

The Account Number the recipient will see as having sent the transfer.



130
# File 'lib/increase/models/fednow_transfer.rb', line 130

required :source_account_number_id, String

#statusSymbol, Increase::Models::FednowTransfer::Status

The lifecycle status of the transfer.



136
# File 'lib/increase/models/fednow_transfer.rb', line 136

required :status, enum: -> { Increase::FednowTransfer::Status }

#submissionIncrease::Models::FednowTransfer::Submission?

After the transfer is submitted to FedNow, this will contain supplemental details.



143
# File 'lib/increase/models/fednow_transfer.rb', line 143

required :submission, -> { Increase::FednowTransfer::Submission }, nil?: true

#transaction_idString?

The Transaction funding the transfer once it is complete.



149
# File 'lib/increase/models/fednow_transfer.rb', line 149

required :transaction_id, String, nil?: true

#typeSymbol, Increase::Models::FednowTransfer::Type

A constant representing the object's type. For this resource it will always be fednow_transfer.



156
# File 'lib/increase/models/fednow_transfer.rb', line 156

required :type, enum: -> { Increase::FednowTransfer::Type }

#unique_end_to_end_transaction_referenceString

The Unique End-to-end Transaction Reference (UETR) of the transfer.



164
# File 'lib/increase/models/fednow_transfer.rb', line 164

required :unique_end_to_end_transaction_reference, String

#unstructured_remittance_informationString

Unstructured information that will show on the recipient's bank statement.



170
# File 'lib/increase/models/fednow_transfer.rb', line 170

required :unstructured_remittance_information, String

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/fednow_transfer.rb', line 423


Instance Method Details

#to_hash{



111
# File 'sig/increase/models/fednow_transfer.rbs', line 111

def to_hash: -> {