Class: Increase::Models::FednowTransfer::CreditorAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::FednowTransfer::CreditorAddress
- Defined in:
- lib/increase/models/fednow_transfer.rb
Overview
Instance Attribute Summary collapse
-
#city ⇒ String?
The city, district, town, or village of the address.
-
#line1 ⇒ String?
The first line of the address.
-
#postal_code ⇒ String?
The ZIP code of the address.
-
#state ⇒ String?
The address state.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#city ⇒ String?
The city, district, town, or village of the address.
331 |
# File 'lib/increase/models/fednow_transfer.rb', line 331 required :city, String, nil?: true |
#line1 ⇒ String?
The first line of the address.
337 |
# File 'lib/increase/models/fednow_transfer.rb', line 337 required :line1, String, nil?: true |
#postal_code ⇒ String?
The ZIP code of the address.
343 |
# File 'lib/increase/models/fednow_transfer.rb', line 343 required :postal_code, String, nil?: true |
#state ⇒ String?
The address state.
349 |
# File 'lib/increase/models/fednow_transfer.rb', line 349 required :state, String, nil?: true |