Class: Increase::Models::FednowTransfer::Rejection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/fednow_transfer.rb,
sig/increase/models/fednow_transfer.rbs

Overview

See Also:

  • Increase::Models::FednowTransfer#rejection

Defined Under Namespace

Modules: RejectReasonCode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(reject_reason_additional_information:, reject_reason_code:, rejected_at:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::FednowTransfer::Rejection for more details.

If the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details.

Parameters:

  • reject_reason_additional_information (String, nil)

    Additional information about the rejection provided by the recipient bank.

  • reject_reason_code (Symbol, Increase::Models::FednowTransfer::Rejection::RejectReasonCode)

    The reason the transfer was rejected as provided by the recipient bank or the Fe

  • rejected_at (Time, nil)

    The ISO 8601 date and time at which th



# File 'lib/increase/models/fednow_transfer.rb', line 445

Instance Attribute Details

#reject_reason_additional_informationString?

Additional information about the rejection provided by the recipient bank.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


429
# File 'lib/increase/models/fednow_transfer.rb', line 429

required :reject_reason_additional_information, String, nil?: true

#reject_reason_codeSymbol, Increase::Models::FednowTransfer::Rejection::RejectReasonCode

The reason the transfer was rejected as provided by the recipient bank or the FedNow network.

Parameters:

  • value (Increase::Models::FednowTransfer::Rejection::reject_reason_code)

Returns:



436
# File 'lib/increase/models/fednow_transfer.rb', line 436

required :reject_reason_code, enum: -> { Increase::FednowTransfer::Rejection::RejectReasonCode }

#rejected_atTime?

The ISO 8601 date and time at which the transfer was rejected.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


443
# File 'lib/increase/models/fednow_transfer.rb', line 443

required :rejected_at, Time, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


318
# File 'sig/increase/models/fednow_transfer.rbs', line 318

def to_hash: -> {