Module: Increase::Models::FednowTransfer::Return::ReturnReasonCode

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/fednow_transfer.rb,
sig/increase/models/fednow_transfer.rbs

Overview

The reason the transfer was returned as provided by the recipient's bank.

See Also:

  • Increase::Models::FednowTransfer::Return#return_reason_code

Constant Summary collapse

ACCOUNT_CLOSED =

The destination account is closed. Corresponds to the FedNow reason codes AC04 and AC07.

Returns:

  • (:account_closed)
:account_closed
ACCOUNT_BLOCKED =

The destination account is currently blocked from receiving transactions. Corresponds to the FedNow reason code AC06.

Returns:

  • (:account_blocked)
:account_blocked
INVALID_AGENT =

The recipient's bank was not a valid agent for this transfer. Corresponds to the FedNow reason codes AC14 and AGNT.

Returns:

  • (:invalid_agent)
:invalid_agent
INVALID_CREDITOR_ACCOUNT_NUMBER =

The destination account does not exist. Corresponds to the FedNow reason code AC03.

Returns:

  • (:invalid_creditor_account_number)
:invalid_creditor_account_number
INCORRECT_ACCOUNT_NUMBER =

The destination account number was incorrect. Corresponds to the FedNow reason code AC01.

Returns:

  • (:incorrect_account_number)
:incorrect_account_number
END_CUSTOMER_DECEASED =

The destination account holder is deceased. Corresponds to the FedNow reason code MD07.

Returns:

  • (:end_customer_deceased)
:end_customer_deceased
TRANSACTION_FORBIDDEN =

The transfer was not permitted by the recipient's bank. Corresponds to the FedNow reason code AG01.

Returns:

  • (:transaction_forbidden)
:transaction_forbidden
REGULATORY_REASON =

The transfer was returned for a regulatory reason at the recipient's bank. Corresponds to the FedNow reason code RR04.

Returns:

  • (:regulatory_reason)
:regulatory_reason
FRAUD =

The transfer was reported as fraudulent. Corresponds to the FedNow reason code FR01.

Returns:

  • (:fraud)
:fraud
DUPLICATION =

The transfer duplicated another transfer. Corresponds to the FedNow reason codes AM05 and DUPL.

Returns:

  • (:duplication)
:duplication
WRONG_AMOUNT =

The transfer amount was incorrect. Corresponds to the FedNow reason code AM09.

Returns:

  • (:wrong_amount)
:wrong_amount
REQUESTED_BY_CUSTOMER =

The transfer was returned at the request of the recipient's customer. Corresponds to the FedNow reason code CUST.

Returns:

  • (:requested_by_customer)
:requested_by_customer
UNABLE_TO_APPLY =

The recipient's bank could not apply the funds. Corresponds to the FedNow reason code RUTA.

Returns:

  • (:unable_to_apply)
:unable_to_apply
NOT_SPECIFIED =

The recipient's bank did not specify a reason. Corresponds to the FedNow reason codes MS02 and MS03.

Returns:

  • (:not_specified)
:not_specified
NARRATIVE =

The reason is provided as narrative information in the additional information field. Corresponds to the FedNow reason code NARR.

Returns:

  • (:narrative)
:narrative
OTHER =

The transfer was returned for some other reason.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::FednowTransfer::Return::return_reason_code]

Returns:

  • (::Array[Increase::Models::FednowTransfer::Return::return_reason_code])


498
# File 'sig/increase/models/fednow_transfer.rbs', line 498

def self?.values: -> ::Array[Increase::Models::FednowTransfer::Return::return_reason_code]