Class: Increase::Models::FednowTransfer::Submission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::FednowTransfer::Submission
- Defined in:
- lib/increase/models/fednow_transfer.rb,
sig/increase/models/fednow_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#message_identification ⇒ String
The FedNow network identification of the message submitted.
-
#submitted_at ⇒ Time?
The ISO 8601 date and time at which the transfer was submitted to FedNow.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
444 |
# File 'sig/increase/models/fednow_transfer.rbs', line 444
def initialize: (
|
Instance Attribute Details
#message_identification ⇒ String
The FedNow network identification of the message submitted.
558 |
# File 'lib/increase/models/fednow_transfer.rb', line 558 required :message_identification, String |
#submitted_at ⇒ Time?
The ISO 8601 date and time at which the transfer was submitted to FedNow.
565 |
# File 'lib/increase/models/fednow_transfer.rb', line 565 required :submitted_at, Time, nil?: true |
Instance Method Details
#to_hash ⇒ { message_identification: String, submitted_at: Time? }
449 |
# File 'sig/increase/models/fednow_transfer.rbs', line 449
def to_hash: -> { message_identification: String, submitted_at: Time? }
|