Class: Increase::Models::FednowTransferCreateParams::CreditorAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/fednow_transfer_create_params.rb,
sig/increase/models/fednow_transfer_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, creditor_name:, debtor_name:, source_account_number_id:, unstructured_remittance_information:, account_number: nil, creditor_address: nil, debtor_address: nil, external_account_id: nil, require_approval: nil, routing_number: nil, request_options: {}) ⇒ Object

Parameters:

  • amount (Integer)

    The amount, in minor units, to send to the creditor.

  • creditor_name (String)

    The creditor's name.

  • debtor_name (String)

    The debtor's name.

  • source_account_number_id (String)

    The Account Number to include in the transfer as the debtor's account number.

  • unstructured_remittance_information (String)

    Unstructured remittance information to include in the transfer.

  • account_number (String) (defaults to: nil)

    The creditor's account number.

  • creditor_address (Increase::Models::FednowTransferCreateParams::CreditorAddress) (defaults to: nil)

    The creditor's address.

  • debtor_address (Increase::Models::FednowTransferCreateParams::DebtorAddress) (defaults to: nil)

    The debtor's address.

  • external_account_id (String) (defaults to: nil)

    The ID of an External Account to initiate a transfer to. If this parameter is provided, account_number and routing_number must be absent.

  • require_approval (Boolean) (defaults to: nil)

    Whether the transfer requires explicit approval via the dashboard or API.

  • routing_number (String) (defaults to: nil)

    The creditor's bank account routing number.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 108

class CreditorAddress < Increase::Internal::Type::BaseModel
  # @!attribute city
  #   The city, district, town, or village of the address.
  #
  #   @return [String]
  required :city, String

  # @!attribute postal_code
  #   The postal code component of the address.
  #
  #   @return [String]
  required :postal_code, String

  # @!attribute state
  #   The US state component of the address.
  #
  #   @return [String]
  required :state, String

  # @!attribute line1
  #   The first line of the address. This is usually the street number and street.
  #
  #   @return [String, nil]
  optional :line1, String

  # @!method initialize(city:, postal_code:, state:, line1: nil)
  #   The creditor's address.
  #
  #   @param city [String] The city, district, town, or village of the address.
  #
  #   @param postal_code [String] The postal code component of the address.
  #
  #   @param state [String] The US state component of the address.
  #
  #   @param line1 [String] The first line of the address. This is usually the street number and street.
end

Instance Attribute Details

#cityString

The city, district, town, or village of the address.

Parameters:

  • value (String)

Returns:

  • (String)


113
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 113

required :city, String

#line1String?

The first line of the address. This is usually the street number and street.

Parameters:

  • (String)

Returns:

  • (String, nil)


131
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 131

optional :line1, String

#postal_codeString

The postal code component of the address.

Parameters:

  • value (String)

Returns:

  • (String)


119
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 119

required :postal_code, String

#stateString

The US state component of the address.

Parameters:

  • value (String)

Returns:

  • (String)


125
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 125

required :state, String

Instance Method Details

#to_hash{

Returns:

  • ({)


112
# File 'sig/increase/models/fednow_transfer_create_params.rbs', line 112

def to_hash: -> {