Module: Increase::Models::FileCreateParams::Purpose

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/file_create_params.rb,
sig/increase/models/file_create_params.rbs

Overview

What the File will be used for in Increase's systems.

Constant Summary collapse

CARD_DISPUTE_ATTACHMENT =

A file to be attached to a Card Dispute.

Returns:

  • (:card_dispute_attachment)
:card_dispute_attachment
CHECK_IMAGE_FRONT =

An image of the front of a check, used for check deposits.

Returns:

  • (:check_image_front)
:check_image_front
CHECK_IMAGE_BACK =

An image of the back of a check, used for check deposits.

Returns:

  • (:check_image_back)
:check_image_back
MAILED_CHECK_IMAGE =

An image of a check that was mailed to a recipient.

Returns:

  • (:mailed_check_image)
:mailed_check_image
CHECK_ATTACHMENT =

A document to be printed on an additional page and mailed with a check that you've requested Increase print. This must be a PDF whose pages are all US letter size and all have the same orientation.

Returns:

  • (:check_attachment)
:check_attachment
CHECK_VOUCHER_IMAGE =

An image to be used as the check voucher image, which is printed in the middle of the trifold area of a check. This must be a 2550x1100 pixel PNG.

Returns:

  • (:check_voucher_image)
:check_voucher_image
CHECK_SIGNATURE =

A signature image to be printed on a check. This must be a 1320x120 pixel PNG.

Returns:

  • (:check_signature)
:check_signature
FORM_SS_4 =

IRS Form SS-4.

Returns:

  • (:form_ss_4)
:form_ss_4
IDENTITY_DOCUMENT =

An image of a government-issued ID.

Returns:

  • (:identity_document)
:identity_document
LOAN_APPLICATION_SUPPLEMENTAL_DOCUMENT =

A supplemental document for a Loan Application.

Returns:

  • (:loan_application_supplemental_document)
:loan_application_supplemental_document
OTHER =

A file purpose not covered by any of the other cases.

Returns:

  • (:other)
:other
TRUST_FORMATION_DOCUMENT =

A legal document forming a trust.

Returns:

  • (:trust_formation_document)
:trust_formation_document
DIGITAL_WALLET_ARTWORK =

A card image to be rendered inside digital wallet apps. This must be a 1536x969 pixel PNG.

Returns:

  • (:digital_wallet_artwork)
:digital_wallet_artwork
DIGITAL_WALLET_APP_ICON =

An icon for you app to be rendered inside digital wallet apps. This must be a 100x100 pixel PNG.

Returns:

  • (:digital_wallet_app_icon)
:digital_wallet_app_icon
PHYSICAL_CARD_FRONT =

A card image to be printed on the front of a physical card. This must be a 2100x1344 pixel PNG with no other color but black.

Returns:

  • (:physical_card_front)
:physical_card_front
PHYSICAL_CARD_CARRIER =

An image representing the entirety of the carrier used for a physical card. This must be a 2550x3300 pixel PNG with no other color but black.

Returns:

  • (:physical_card_carrier)
:physical_card_carrier
DOCUMENT_REQUEST =

A document requested by Increase.

Returns:

  • (:document_request)
:document_request
ENTITY_SUPPLEMENTAL_DOCUMENT =

A supplemental document associated an an Entity.

Returns:

  • (:entity_supplemental_document)
:entity_supplemental_document
UNUSUAL_ACTIVITY_REPORT_ATTACHMENT =

An attachment to an Unusual Activity Report.

Returns:

  • (:unusual_activity_report_attachment)
:unusual_activity_report_attachment
PROOF_OF_AUTHORIZATION_REQUEST_SUBMISSION =

A file containing additional evidence for a Proof of Authorization Request Submission.

Returns:

  • (:proof_of_authorization_request_submission)
:proof_of_authorization_request_submission

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/file_create_params.rb', line 106

Instance Method Details

#self?.values::Array[Increase::Models::FileCreateParams::purpose]

Returns:

  • (::Array[Increase::Models::FileCreateParams::purpose])


122
# File 'sig/increase/models/file_create_params.rbs', line 122

def self?.values: -> ::Array[Increase::Models::FileCreateParams::purpose]