Class: Increase::Models::InboundACHTransfer::Acceptance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundACHTransfer::Acceptance
- Defined in:
- lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#accepted_at ⇒ Time
The time at which the transfer was accepted.
-
#transaction_id ⇒ String
The id of the transaction for the accepted transfer.
Instance Method Summary collapse
-
#initialize ⇒ Acceptance
constructor
A new instance of Acceptance.
- #to_hash ⇒ { accepted_at: Time, transaction_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Acceptance
Returns a new instance of Acceptance.
156 |
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 156
def initialize: (accepted_at: Time, transaction_id: String) -> void
|
Instance Attribute Details
#accepted_at ⇒ Time
The time at which the transfer was accepted.
246 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 246 required :accepted_at, Time |
#transaction_id ⇒ String
The id of the transaction for the accepted transfer.
252 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 252 required :transaction_id, String |
Instance Method Details
#to_hash ⇒ { accepted_at: Time, transaction_id: String }
158 |
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 158
def to_hash: -> { accepted_at: Time, transaction_id: String }
|