Module: Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs

Overview

A description of how the foreign exchange rate was calculated.

See Also:

  • Increase::Models::InboundACHTransfer::InternationalAddenda#foreign_exchange_indicator

Constant Summary collapse

FIXED_TO_VARIABLE =

The originator chose an amount in their own currency. The settled amount in USD was converted using the exchange rate.

Returns:

  • (:fixed_to_variable)
:fixed_to_variable
VARIABLE_TO_FIXED =

The originator chose an amount to settle in USD. The originator's amount was variable; known only after the foreign exchange conversion.

Returns:

  • (:variable_to_fixed)
:variable_to_fixed
FIXED_TO_FIXED =

The amount was originated and settled as a fixed amount in USD. There is no foreign exchange conversion.

Returns:

  • (:fixed_to_fixed)
:fixed_to_fixed

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::InboundACHTransfer::InternationalAddenda::foreign_exchange_indicator]

Returns:

  • (::Array[Increase::Models::InboundACHTransfer::InternationalAddenda::foreign_exchange_indicator])


529
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 529

def self?.values: -> ::Array[Increase::Models::InboundACHTransfer::InternationalAddenda::foreign_exchange_indicator]