Class: Increase::Models::InboundACHTransfer::NotificationOfChange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs

Overview

See Also:

  • Increase::Models::InboundACHTransfer#notification_of_change

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



683
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 683

def initialize: (

Instance Attribute Details

#updated_account_numberString?

The new account number provided in the notification of change.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


886
# File 'lib/increase/models/inbound_ach_transfer.rb', line 886

required :updated_account_number, String, nil?: true

#updated_routing_numberString?

The new routing number provided in the notification of change.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


892
# File 'lib/increase/models/inbound_ach_transfer.rb', line 892

required :updated_routing_number, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


688
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 688

def to_hash: -> {