Class: Increase::Models::InboundACHTransfer::TransferReturn

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs

Overview

See Also:

  • Increase::Models::InboundACHTransfer#transfer_return

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(raw_reason_code:, reason:, returned_at:, transaction_id:) ⇒ Object

If your transfer is returned, this will contain details of the return.



# File 'lib/increase/models/inbound_ach_transfer.rb', line 1115


Instance Attribute Details

#raw_reason_codeString

The three character ACH return code, in the range R01 to R85.



1095
# File 'lib/increase/models/inbound_ach_transfer.rb', line 1095

required :raw_reason_code, String

#reasonSymbol, Increase::Models::InboundACHTransfer::TransferReturn::Reason

The reason for the transfer return.



1101
# File 'lib/increase/models/inbound_ach_transfer.rb', line 1101

required :reason, enum: -> { Increase::InboundACHTransfer::TransferReturn::Reason }

#returned_atTime

The time at which the transfer was returned.



1107
# File 'lib/increase/models/inbound_ach_transfer.rb', line 1107

required :returned_at, Time

#transaction_idString

The id of the transaction for the returned transfer.



1113
# File 'lib/increase/models/inbound_ach_transfer.rb', line 1113

required :transaction_id, String

Instance Method Details

#to_hash{



846
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 846

def to_hash: -> {