Module: Increase::Models::InboundACHTransfer::TransferReturn::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs

Overview

The reason for the transfer return.

See Also:

  • Increase::Models::InboundACHTransfer::TransferReturn#reason

Constant Summary collapse

INSUFFICIENT_FUNDS =

The customer's account has insufficient funds. This reason is only allowed for debits. The Nacha return code is R01.

Returns:

  • (:insufficient_funds)
:insufficient_funds
RETURNED_PER_ODFI_REQUEST =

The originating financial institution asked for this transfer to be returned. The receiving bank is complying with the request. The Nacha return code is R06.

Returns:

  • (:returned_per_odfi_request)
:returned_per_odfi_request
AUTHORIZATION_REVOKED_BY_CUSTOMER =

The customer no longer authorizes this transaction. The Nacha return code is R07.

Returns:

  • (:authorization_revoked_by_customer)
:authorization_revoked_by_customer
PAYMENT_STOPPED =

The customer asked for the payment to be stopped. This reason is only allowed for debits. The Nacha return code is R08.

Returns:

  • (:payment_stopped)
:payment_stopped
CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETE =

The customer advises that the debit was unauthorized. The Nacha return code is R10.

Returns:

  • (:customer_advised_unauthorized_improper_ineligible_or_incomplete)
:customer_advised_unauthorized_improper_ineligible_or_incomplete
REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITY =

The payee is deceased. The Nacha return code is R14.

Returns:

  • (:representative_payee_deceased_or_unable_to_continue_in_that_capacity)
:representative_payee_deceased_or_unable_to_continue_in_that_capacity
BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASED =

The account holder is deceased. The Nacha return code is R15.

Returns:

  • (:beneficiary_or_account_holder_deceased)
:beneficiary_or_account_holder_deceased
CREDIT_ENTRY_REFUSED_BY_RECEIVER =

The customer refused a credit entry. This reason is only allowed for credits. The Nacha return code is R23.

Returns:

  • (:credit_entry_refused_by_receiver)
:credit_entry_refused_by_receiver
DUPLICATE_ENTRY =

The account holder identified this transaction as a duplicate. The Nacha return code is R24.

Returns:

  • (:duplicate_entry)
:duplicate_entry
CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZED =

The corporate customer no longer authorizes this transaction. The Nacha return code is R29.

Returns:

  • (:corporate_customer_advised_not_authorized)
:corporate_customer_advised_not_authorized

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::InboundACHTransfer::TransferReturn::reason]

Returns:

  • (::Array[Increase::Models::InboundACHTransfer::TransferReturn::reason])


893
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 893

def self?.values: -> ::Array[Increase::Models::InboundACHTransfer::TransferReturn::reason]