Module: Increase::Models::InboundACHTransferTransferReturnParams::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/inbound_ach_transfer_transfer_return_params.rb,
sig/increase/models/inbound_ach_transfer_transfer_return_params.rbs

Overview

The reason why this transfer will be returned. The most usual return codes are payment_stopped for debits and credit_entry_refused_by_receiver for credits.

Constant Summary collapse

INSUFFICIENT_FUNDS =

The customer's account has insufficient funds. This reason is only allowed for debits. The Nacha return code is R01.

Returns:

  • (:insufficient_funds)
:insufficient_funds
AUTHORIZATION_REVOKED_BY_CUSTOMER =

The customer no longer authorizes this transaction. The Nacha return code is R07.

Returns:

  • (:authorization_revoked_by_customer)
:authorization_revoked_by_customer
PAYMENT_STOPPED =

The customer asked for the payment to be stopped. This reason is only allowed for debits. The Nacha return code is R08.

Returns:

  • (:payment_stopped)
:payment_stopped
CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETE =

The customer advises that the debit was unauthorized. The Nacha return code is R10.

Returns:

  • (:customer_advised_unauthorized_improper_ineligible_or_incomplete)
:customer_advised_unauthorized_improper_ineligible_or_incomplete
REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITY =

The payee is deceased. The Nacha return code is R14.

Returns:

  • (:representative_payee_deceased_or_unable_to_continue_in_that_capacity)
:representative_payee_deceased_or_unable_to_continue_in_that_capacity
BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASED =

The account holder is deceased. The Nacha return code is R15.

Returns:

  • (:beneficiary_or_account_holder_deceased)
:beneficiary_or_account_holder_deceased
CREDIT_ENTRY_REFUSED_BY_RECEIVER =

The customer refused a credit entry. This reason is only allowed for credits. The Nacha return code is R23.

Returns:

  • (:credit_entry_refused_by_receiver)
:credit_entry_refused_by_receiver
DUPLICATE_ENTRY =

The account holder identified this transaction as a duplicate. The Nacha return code is R24.

Returns:

  • (:duplicate_entry)
:duplicate_entry
CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZED =

The corporate customer no longer authorizes this transaction. The Nacha return code is R29.

Returns:

  • (:corporate_customer_advised_not_authorized)
:corporate_customer_advised_not_authorized

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/inbound_ach_transfer_transfer_return_params.rb', line 68

Instance Method Details

#self?.values::Array[Increase::Models::InboundACHTransferTransferReturnParams::reason]

Returns:

  • (::Array[Increase::Models::InboundACHTransferTransferReturnParams::reason])


71
# File 'sig/increase/models/inbound_ach_transfer_transfer_return_params.rbs', line 71

def self?.values: -> ::Array[Increase::Models::InboundACHTransferTransferReturnParams::reason]