Class: Increase::Models::InboundCheckDeposit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_check_deposit.rb,
sig/increase/models/inbound_check_deposit.rbs

Overview

See Also:

  • Increase::Resources::InboundCheckDeposits#retrieve

Defined Under Namespace

Modules: Currency, PayeeNameAnalysis, Status, Type Classes: Adjustment, DepositReturn

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



71
# File 'sig/increase/models/inbound_check_deposit.rbs', line 71

def initialize: (

Instance Attribute Details

#accepted_atTime?

If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


19
# File 'lib/increase/models/inbound_check_deposit.rb', line 19

required :accepted_at, Time, nil?: true

#account_idString

The Account the check is being deposited against.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/increase/models/inbound_check_deposit.rb', line 25

required :account_id, String

#account_number_idString?

The Account Number the check is being deposited against.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


31
# File 'lib/increase/models/inbound_check_deposit.rb', line 31

required :account_number_id, String, nil?: true

#adjustmentsArray<Increase::Models::InboundCheckDeposit::Adjustment>

If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.

Parameters:

  • value (::Array[Increase::InboundCheckDeposit::Adjustment])

Returns:



38
# File 'lib/increase/models/inbound_check_deposit.rb', line 38

required :adjustments, -> { Increase::Internal::Type::ArrayOf[Increase::InboundCheckDeposit::Adjustment] }

#amountInteger

The deposited amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


44
# File 'lib/increase/models/inbound_check_deposit.rb', line 44

required :amount, Integer

#automatically_resolves_atTime

The ISO 8601 date and time at which the Inbound Check Deposit will be automatically resolved if it has not been actioned by then.

Parameters:

  • value (Time)

Returns:

  • (Time)


52
# File 'lib/increase/models/inbound_check_deposit.rb', line 52

required :automatically_resolves_at, Time

#back_image_file_idString?

The ID for the File containing the image of the back of the check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


58
# File 'lib/increase/models/inbound_check_deposit.rb', line 58

required :back_image_file_id, String, nil?: true

#bank_of_first_deposit_routing_numberString?

The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


66
# File 'lib/increase/models/inbound_check_deposit.rb', line 66

required :bank_of_first_deposit_routing_number, String, nil?: true

#check_numberString?

The check number printed on the check being deposited.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


72
# File 'lib/increase/models/inbound_check_deposit.rb', line 72

required :check_number, String, nil?: true

#check_transfer_idString?

If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


79
# File 'lib/increase/models/inbound_check_deposit.rb', line 79

required :check_transfer_id, String, nil?: true

#created_atTime

The ISO 8601 date and time at which the deposit was attempted.

Parameters:

  • value (Time)

Returns:

  • (Time)


86
# File 'lib/increase/models/inbound_check_deposit.rb', line 86

required :created_at, Time

#currencySymbol, Increase::Models::InboundCheckDeposit::Currency

The ISO 4217 code for the deposit.

Parameters:

  • value (Increase::Models::InboundCheckDeposit::currency)

Returns:



92
# File 'lib/increase/models/inbound_check_deposit.rb', line 92

required :currency, enum: -> { Increase::InboundCheckDeposit::Currency }

#declined_atTime?

If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


100
# File 'lib/increase/models/inbound_check_deposit.rb', line 100

required :declined_at, Time, nil?: true

#declined_transaction_idString?

If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


107
# File 'lib/increase/models/inbound_check_deposit.rb', line 107

required :declined_transaction_id, String, nil?: true

#deposit_returnIncrease::Models::InboundCheckDeposit::DepositReturn?

If you requested a return of this deposit, this will contain details of the return.

Parameters:

  • value (Increase::InboundCheckDeposit::DepositReturn, nil)

Returns:



114
# File 'lib/increase/models/inbound_check_deposit.rb', line 114

required :deposit_return, -> { Increase::InboundCheckDeposit::DepositReturn }, nil?: true

#front_image_file_idString?

The ID for the File containing the image of the front of the check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


120
# File 'lib/increase/models/inbound_check_deposit.rb', line 120

required :front_image_file_id, String, nil?: true

#idString

The deposit's identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/inbound_check_deposit.rb', line 11

required :id, String

#payee_name_analysisSymbol, Increase::Models::InboundCheckDeposit::PayeeNameAnalysis

Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.

Parameters:

  • value (Increase::Models::InboundCheckDeposit::payee_name_analysis)

Returns:



127
# File 'lib/increase/models/inbound_check_deposit.rb', line 127

required :payee_name_analysis, enum: -> { Increase::InboundCheckDeposit::PayeeNameAnalysis }

#statusSymbol, Increase::Models::InboundCheckDeposit::Status

The status of the Inbound Check Deposit.

Parameters:

  • value (Increase::Models::InboundCheckDeposit::status)

Returns:



133
# File 'lib/increase/models/inbound_check_deposit.rb', line 133

required :status, enum: -> { Increase::InboundCheckDeposit::Status }

#transaction_idString?

If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


140
# File 'lib/increase/models/inbound_check_deposit.rb', line 140

required :transaction_id, String, nil?: true

#typeSymbol, Increase::Models::InboundCheckDeposit::Type

A constant representing the object's type. For this resource it will always be inbound_check_deposit.

Parameters:

  • value (Increase::Models::InboundCheckDeposit::type_)

Returns:



147
# File 'lib/increase/models/inbound_check_deposit.rb', line 147

required :type, enum: -> { Increase::InboundCheckDeposit::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/inbound_check_deposit.rb', line 273

Instance Method Details

#to_hash{

Returns:

  • ({)


95
# File 'sig/increase/models/inbound_check_deposit.rbs', line 95

def to_hash: -> {