Class: Increase::Models::InboundCheckDeposit::Adjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundCheckDeposit::Adjustment
- Defined in:
- lib/increase/models/inbound_check_deposit.rb,
sig/increase/models/inbound_check_deposit.rbs
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#adjusted_at ⇒ Time
The time at which the return adjustment was received.
-
#amount ⇒ Integer
The amount of the adjustment.
-
#reason ⇒ Symbol, Increase::Models::InboundCheckDeposit::Adjustment::Reason
The reason for the adjustment.
-
#transaction_id ⇒ String
The id of the transaction for the adjustment.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(adjusted_at:, amount:, reason:, transaction_id:) ⇒ Object
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/increase/models/inbound_check_deposit.rb', line 226 class Adjustment < Increase::Internal::Type::BaseModel # @!attribute adjusted_at # The time at which the return adjustment was received. # # @return [Time] required :adjusted_at, Time # @!attribute amount # The amount of the adjustment. # # @return [Integer] required :amount, Integer # @!attribute reason # The reason for the adjustment. # # @return [Symbol, Increase::Models::InboundCheckDeposit::Adjustment::Reason] required :reason, enum: -> { Increase::InboundCheckDeposit::Adjustment::Reason } # @!attribute transaction_id # The id of the transaction for the adjustment. # # @return [String] required :transaction_id, String # @!method initialize(adjusted_at:, amount:, reason:, transaction_id:) # @param adjusted_at [Time] The time at which the return adjustment was received. # # @param amount [Integer] The amount of the adjustment. # # @param reason [Symbol, Increase::Models::InboundCheckDeposit::Adjustment::Reason] # The reason for the adjustment. # # @param transaction_id [String] The id of the transaction for the adjustment. # The reason for the adjustment. # # @see Increase::Models::InboundCheckDeposit::Adjustment#reason module Reason extend Increase::Internal::Type::Enum # The return was initiated too late and the receiving institution has responded with a Late Return Claim. LATE_RETURN = :late_return # The check was deposited to the wrong payee and the depositing institution has reimbursed the funds with a Wrong Payee Credit. WRONG_PAYEE_CREDIT = :wrong_payee_credit # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#adjusted_at ⇒ Time
The time at which the return adjustment was received.
231 |
# File 'lib/increase/models/inbound_check_deposit.rb', line 231 required :adjusted_at, Time |
#amount ⇒ Integer
The amount of the adjustment.
237 |
# File 'lib/increase/models/inbound_check_deposit.rb', line 237 required :amount, Integer |
#reason ⇒ Symbol, Increase::Models::InboundCheckDeposit::Adjustment::Reason
The reason for the adjustment.
243 |
# File 'lib/increase/models/inbound_check_deposit.rb', line 243 required :reason, enum: -> { Increase::InboundCheckDeposit::Adjustment::Reason } |
#transaction_id ⇒ String
The id of the transaction for the adjustment.
249 |
# File 'lib/increase/models/inbound_check_deposit.rb', line 249 required :transaction_id, String |
Instance Method Details
#to_hash ⇒ {
143 |
# File 'sig/increase/models/inbound_check_deposit.rbs', line 143
def to_hash: -> {
|