Module: Increase::Models::InboundCheckDeposit::PayeeNameAnalysis

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/inbound_check_deposit.rb,
sig/increase/models/inbound_check_deposit.rbs

Overview

Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.

See Also:

  • Increase::Models::InboundCheckDeposit#payee_name_analysis

Constant Summary collapse

NAME_MATCHES =

The details on the check match the recipient name of the check transfer.

Returns:

  • (:name_matches)
:name_matches
DOES_NOT_MATCH =

The details on the check do not match the recipient name of the check transfer.

Returns:

  • (:does_not_match)
:does_not_match
NOT_EVALUATED =

The payee name analysis was not evaluated.

Returns:

  • (:not_evaluated)
:not_evaluated

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::InboundCheckDeposit::payee_name_analysis]

Returns:

  • (::Array[Increase::Models::InboundCheckDeposit::payee_name_analysis])


245
# File 'sig/increase/models/inbound_check_deposit.rbs', line 245

def self?.values: -> ::Array[Increase::Models::InboundCheckDeposit::payee_name_analysis]