Class: Increase::Models::InboundMailItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_mail_item.rb,
sig/increase/models/inbound_mail_item.rbs

Overview

See Also:

  • Increase::Resources::InboundMailItems#retrieve

Defined Under Namespace

Modules: RejectionReason, Status, Type Classes: Check

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



41
# File 'sig/increase/models/inbound_mail_item.rbs', line 41

def initialize: (

Instance Attribute Details

#account_idString?

The identifier for the Account that checks in this mail item are deposited into. For mail items that could not be routed to a Lockbox Recipient, this will be null.



19
# File 'lib/increase/models/inbound_mail_item.rb', line 19

required :account_id, String, nil?: true

#checksArray<Increase::Models::InboundMailItem::Check>

The checks in the mail item.



25
# File 'lib/increase/models/inbound_mail_item.rb', line 25

required :checks, -> { Increase::Internal::Type::ArrayOf[Increase::InboundMailItem::Check] }

#created_atTime

The ISO 8601 time at which the Inbound Mail Item was created.



32
# File 'lib/increase/models/inbound_mail_item.rb', line 32

required :created_at, Time

#file_idString

The identifier for the File containing the scanned contents of the mail item.



38
# File 'lib/increase/models/inbound_mail_item.rb', line 38

required :file_id, String

#idString

The Inbound Mail Item identifier.



11
# File 'lib/increase/models/inbound_mail_item.rb', line 11

required :id, String

#lockbox_address_idString

The identifier for the Lockbox Address that received this mail item.



44
# File 'lib/increase/models/inbound_mail_item.rb', line 44

required :lockbox_address_id, String

#lockbox_recipient_idString?

The identifier for the Lockbox Recipient that received this mail item. For mail items that could not be routed to a Lockbox Recipient, this will be null.



51
# File 'lib/increase/models/inbound_mail_item.rb', line 51

required :lockbox_recipient_id, String, nil?: true

#recipient_nameString?

The recipient name as written on the mail item.



57
# File 'lib/increase/models/inbound_mail_item.rb', line 57

required :recipient_name, String, nil?: true

#rejection_reasonSymbol, ...

If the mail item has been rejected, why it was rejected.



63
# File 'lib/increase/models/inbound_mail_item.rb', line 63

required :rejection_reason, enum: -> { Increase::InboundMailItem::RejectionReason }, nil?: true

#statusSymbol, Increase::Models::InboundMailItem::Status

If the mail item has been processed.



69
# File 'lib/increase/models/inbound_mail_item.rb', line 69

required :status, enum: -> { Increase::InboundMailItem::Status }

#typeSymbol, Increase::Models::InboundMailItem::Type

A constant representing the object's type. For this resource it will always be inbound_mail_item.



76
# File 'lib/increase/models/inbound_mail_item.rb', line 76

required :type, enum: -> { Increase::InboundMailItem::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/inbound_mail_item.rb', line 176


Instance Method Details

#to_hash{



55
# File 'sig/increase/models/inbound_mail_item.rbs', line 55

def to_hash: -> {