Module: Increase::Models::InboundMailItem::RejectionReason
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/inbound_mail_item.rb,
sig/increase/models/inbound_mail_item.rbs
Overview
If the mail item has been rejected, why it was rejected.
Constant Summary collapse
- NO_MATCHING_LOCKBOX =
The mail item does not match any lockbox.
:no_matching_lockbox- NO_CHECK =
The mail item does not contain a check.
:no_check- LOCKBOX_NOT_ACTIVE =
The Lockbox or its associated Account is not active.
:lockbox_not_active- LOCKBOX_ADDRESS_NOT_ACTIVE =
The Lockbox Address is not active.
:lockbox_address_not_active- LOCKBOX_RECIPIENT_NOT_ACTIVE =
The Lockbox Recipient or its associated Account is not active.
:lockbox_recipient_not_active
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::InboundMailItem::rejection_reason]
143 |
# File 'sig/increase/models/inbound_mail_item.rbs', line 143
def self?.values: -> ::Array[Increase::Models::InboundMailItem::rejection_reason]
|