Class: Increase::Models::InboundMailItemActionParams::Check
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundMailItemActionParams::Check
- Defined in:
- lib/increase/models/inbound_mail_item_action_params.rb
Defined Under Namespace
Modules: Action
Instance Attribute Summary collapse
-
#account_id ⇒ String?
The identifier of the Account to deposit the check into.
-
#action ⇒ Symbol, Increase::Models::InboundMailItemActionParams::Check::Action
The action to perform on the Inbound Mail Item.
Instance Method Summary collapse
- #initialize(action:, account_id: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action:, account_id: nil) ⇒ Object
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/increase/models/inbound_mail_item_action_params.rb', line 29 class Check < Increase::Internal::Type::BaseModel # @!attribute action # The action to perform on the Inbound Mail Item. # # @return [Symbol, Increase::Models::InboundMailItemActionParams::Check::Action] required :action, enum: -> { Increase::InboundMailItemActionParams::Check::Action } # @!attribute account_id # The identifier of the Account to deposit the check into. # # @return [String, nil] optional :account_id, String # @!method initialize(action:, account_id: nil) # @param action [Symbol, Increase::Models::InboundMailItemActionParams::Check::Action] The action to perform on the Inbound Mail Item. # # @param account_id [String] The identifier of the Account to deposit the check into. # The action to perform on the Inbound Mail Item. # # @see Increase::Models::InboundMailItemActionParams::Check#action module Action extend Increase::Internal::Type::Enum # The check will be deposited. DEPOSIT = :deposit # The check will be ignored. IGNORE = :ignore # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#account_id ⇒ String?
The identifier of the Account to deposit the check into.
40 |
# File 'lib/increase/models/inbound_mail_item_action_params.rb', line 40 optional :account_id, String |
#action ⇒ Symbol, Increase::Models::InboundMailItemActionParams::Check::Action
The action to perform on the Inbound Mail Item.
34 |
# File 'lib/increase/models/inbound_mail_item_action_params.rb', line 34 required :action, enum: -> { Increase::InboundMailItemActionParams::Check::Action } |