Class: Increase::Models::InboundRealTimePaymentsTransfer::Confirmation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundRealTimePaymentsTransfer::Confirmation
- Defined in:
- lib/increase/models/inbound_real_time_payments_transfer.rb,
sig/increase/models/inbound_real_time_payments_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#confirmed_at ⇒ Time
The time at which the transfer was confirmed.
-
#transaction_id ⇒ String
The id of the transaction for the confirmed transfer.
Instance Method Summary collapse
-
#initialize ⇒ Confirmation
constructor
A new instance of Confirmation.
- #to_hash ⇒ { confirmed_at: Time, transaction_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Confirmation
Returns a new instance of Confirmation.
101 |
# File 'sig/increase/models/inbound_real_time_payments_transfer.rbs', line 101
def initialize: (confirmed_at: Time, transaction_id: String) -> void
|
Instance Attribute Details
#confirmed_at ⇒ Time
The time at which the transfer was confirmed.
151 |
# File 'lib/increase/models/inbound_real_time_payments_transfer.rb', line 151 required :confirmed_at, Time |
#transaction_id ⇒ String
The id of the transaction for the confirmed transfer.
157 |
# File 'lib/increase/models/inbound_real_time_payments_transfer.rb', line 157 required :transaction_id, String |
Instance Method Details
#to_hash ⇒ { confirmed_at: Time, transaction_id: String }
103 |
# File 'sig/increase/models/inbound_real_time_payments_transfer.rbs', line 103
def to_hash: -> { confirmed_at: Time, transaction_id: String }
|