Class: Increase::Models::InboundRealTimePaymentsTransfer::Decline

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_real_time_payments_transfer.rb

Overview

See Also:

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(declined_at:, declined_transaction_id:, reason:) ⇒ Object

If your transfer is declined, this will contain details of the decline.

Parameters:



# File 'lib/increase/models/inbound_real_time_payments_transfer.rb', line 201

Instance Attribute Details

#declined_atTime

The time at which the transfer was declined.

Returns:

  • (Time)


187
# File 'lib/increase/models/inbound_real_time_payments_transfer.rb', line 187

required :declined_at, Time

#declined_transaction_idString

The id of the transaction for the declined transfer.

Returns:

  • (String)


193
# File 'lib/increase/models/inbound_real_time_payments_transfer.rb', line 193

required :declined_transaction_id, String

#reasonSymbol, Increase::Models::InboundRealTimePaymentsTransfer::Decline::Reason

The reason for the transfer decline.



199
# File 'lib/increase/models/inbound_real_time_payments_transfer.rb', line 199

required :reason, enum: -> { Increase::InboundRealTimePaymentsTransfer::Decline::Reason }