Module: Increase::Models::InboundRealTimePaymentsTransfer::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/inbound_real_time_payments_transfer.rb,
sig/increase/models/inbound_real_time_payments_transfer.rbs

Overview

The lifecycle status of the transfer.

See Also:

  • Increase::Models::InboundRealTimePaymentsTransfer#status

Constant Summary collapse

PENDING_CONFIRMING =

The transfer is pending confirmation.

Returns:

  • (:pending_confirming)
:pending_confirming
TIMED_OUT =

The transfer was not responded to in time. This is rare and represents an error at Increase.

Returns:

  • (:timed_out)
:timed_out
CONFIRMED =

The transfer has been received successfully and is confirmed.

Returns:

  • (:confirmed)
:confirmed
DECLINED =

The transfer has been declined.

Returns:

  • (:declined)
:declined

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::InboundRealTimePaymentsTransfer::status]

Returns:

  • (::Array[Increase::Models::InboundRealTimePaymentsTransfer::status])


193
# File 'sig/increase/models/inbound_real_time_payments_transfer.rbs', line 193

def self?.values: -> ::Array[Increase::Models::InboundRealTimePaymentsTransfer::status]