Class: Increase::Models::InboundWireDrawdownRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_wire_drawdown_request.rb,
sig/increase/models/inbound_wire_drawdown_request.rbs

Overview

See Also:

  • Increase::Resources::InboundWireDrawdownRequests#retrieve

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, account_id:, amount:, created_at:, creditor_account_number:, creditor_address_line1:, creditor_address_line2:, creditor_address_line3:, creditor_name:, creditor_routing_number:, currency:, debtor_address_line1:, debtor_address_line2:, debtor_address_line3:, debtor_name:, end_to_end_identification:, input_message_accountability_data:, instruction_identification:, recipient_account_number_id:, type:, unique_end_to_end_transaction_reference:, unstructured_remittance_information:) ⇒ Object

Inbound wire drawdown requests are requests from someone else to send them a wire. For more information, see our Wire Drawdown Requests documentation.



# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 149


Instance Attribute Details

#account_idString

The Account from which the recipient of this request is being requested to send funds.



18
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 18

required :account_id, String

#amountInteger

The amount being requested in cents.



24
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 24

required :amount, Integer

#created_atTime

The ISO 8601 date and time at which the inbound wire drawdown request was created.



31
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 31

required :created_at, Time

#creditor_account_numberString

The creditor's account number.



37
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 37

required :creditor_account_number, String

#creditor_address_line1String?

A free-form address field set by the sender.



43
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 43

required :creditor_address_line1, String, nil?: true

#creditor_address_line2String?

A free-form address field set by the sender.



49
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 49

required :creditor_address_line2, String, nil?: true

#creditor_address_line3String?

A free-form address field set by the sender.



55
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 55

required :creditor_address_line3, String, nil?: true

#creditor_nameString?

A name set by the sender.



61
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 61

required :creditor_name, String, nil?: true

#creditor_routing_numberString

The creditor's routing number.



67
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 67

required :creditor_routing_number, String

#currencyString

The ISO 4217 code for the amount being requested. Will always be "USD".



74
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 74

required :currency, String

#debtor_address_line1String?

A free-form address field set by the sender.



80
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 80

required :debtor_address_line1, String, nil?: true

#debtor_address_line2String?

A free-form address field set by the sender.



86
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 86

required :debtor_address_line2, String, nil?: true

#debtor_address_line3String?

A free-form address field set by the sender.



92
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 92

required :debtor_address_line3, String, nil?: true

#debtor_nameString?

A name set by the sender.



98
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 98

required :debtor_name, String, nil?: true

#end_to_end_identificationString?

A free-form reference string set by the sender, to help identify the drawdown request.



105
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 105

required :end_to_end_identification, String, nil?: true

#idString

The Wire drawdown request identifier.



11
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 11

required :id, String

#input_message_accountability_dataString?

A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.



113
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 113

required :input_message_accountability_data, String, nil?: true

#instruction_identificationString?

The sending bank's identifier for the drawdown request.



119
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 119

required :instruction_identification, String, nil?: true

#recipient_account_number_idString

The Account Number from which the recipient of this request is being requested to send funds.



126
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 126

required :recipient_account_number_id, String

#typeSymbol, Increase::Models::InboundWireDrawdownRequest::Type

A constant representing the object's type. For this resource it will always be inbound_wire_drawdown_request.



133
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 133

required :type, enum: -> { Increase::InboundWireDrawdownRequest::Type }

#unique_end_to_end_transaction_referenceString?

The Unique End-to-end Transaction Reference (UETR) of the drawdown request.



141
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 141

required :unique_end_to_end_transaction_reference, String, nil?: true

#unstructured_remittance_informationString?

A free-form message set by the sender.



147
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 147

required :unstructured_remittance_information, String, nil?: true

Instance Method Details

#to_hash{



99
# File 'sig/increase/models/inbound_wire_drawdown_request.rbs', line 99

def to_hash: -> {