Class: Increase::Models::InboundWireTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundWireTransfer
- Defined in:
- lib/increase/models/inbound_wire_transfer.rb
Overview
Defined Under Namespace
Modules: Status, Type Classes: Acceptance, Reversal
Instance Attribute Summary collapse
-
#acceptance ⇒ Increase::Models::InboundWireTransfer::Acceptance?
If the transfer is accepted, this will contain details of the acceptance.
-
#account_id ⇒ String
The Account to which the transfer belongs.
-
#account_number_id ⇒ String
The identifier of the Account Number to which this transfer was sent.
-
#amount ⇒ Integer
The amount in USD cents.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the inbound wire transfer was created.
-
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#creditor_name ⇒ String?
A name set by the sender.
-
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#debtor_name ⇒ String?
A name set by the sender.
-
#description ⇒ String
An Increase-constructed description of the transfer.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
-
#id ⇒ String
The inbound wire transfer’s identifier.
-
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD.
-
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
#instruction_identification ⇒ String?
The sending bank’s identifier for the wire transfer.
-
#reversal ⇒ Increase::Models::InboundWireTransfer::Reversal?
If the transfer is reversed, this will contain details of the reversal.
-
#status ⇒ Symbol, Increase::Models::InboundWireTransfer::Status
The status of the transfer.
-
#type ⇒ Symbol, Increase::Models::InboundWireTransfer::Type
A constant representing the object’s type.
-
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
-
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
-
#wire_drawdown_request_id ⇒ String?
The wire drawdown request the inbound wire transfer is fulfilling.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(accepted_at:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Acceptance for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accepted_at:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see Acceptance for more details.
If the transfer is accepted, this will contain details of the acceptance.
|
|
# File 'lib/increase/models/inbound_wire_transfer.rb', line 164
|
Instance Attribute Details
#acceptance ⇒ Increase::Models::InboundWireTransfer::Acceptance?
If the transfer is accepted, this will contain details of the acceptance.
17 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 17 required :acceptance, -> { Increase::InboundWireTransfer::Acceptance }, nil?: true |
#account_id ⇒ String
The Account to which the transfer belongs.
23 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 23 required :account_id, String |
#account_number_id ⇒ String
The identifier of the Account Number to which this transfer was sent.
29 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 29 required :account_number_id, String |
#amount ⇒ Integer
The amount in USD cents.
35 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 35 required :amount, Integer |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the inbound wire transfer was created.
42 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 42 required :created_at, Time |
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
48 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 48 required :creditor_address_line1, String, nil?: true |
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
54 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 54 required :creditor_address_line2, String, nil?: true |
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
60 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 60 required :creditor_address_line3, String, nil?: true |
#creditor_name ⇒ String?
A name set by the sender.
66 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 66 required :creditor_name, String, nil?: true |
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
72 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 72 required :debtor_address_line1, String, nil?: true |
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
78 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 78 required :debtor_address_line2, String, nil?: true |
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
84 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 84 required :debtor_address_line3, String, nil?: true |
#debtor_name ⇒ String?
A name set by the sender.
90 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 90 required :debtor_name, String, nil?: true |
#description ⇒ String
An Increase-constructed description of the transfer.
96 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 96 required :description, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
102 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 102 required :end_to_end_identification, String, nil?: true |
#id ⇒ String
The inbound wire transfer’s identifier.
11 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 11 required :id, String |
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
110 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 110 required :input_message_accountability_data, String, nil?: true |
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
117 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 117 required :instructing_agent_routing_number, String, nil?: true |
#instruction_identification ⇒ String?
The sending bank’s identifier for the wire transfer.
123 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 123 required :instruction_identification, String, nil?: true |
#reversal ⇒ Increase::Models::InboundWireTransfer::Reversal?
If the transfer is reversed, this will contain details of the reversal.
129 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 129 required :reversal, -> { Increase::InboundWireTransfer::Reversal }, nil?: true |
#status ⇒ Symbol, Increase::Models::InboundWireTransfer::Status
The status of the transfer.
135 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 135 required :status, enum: -> { Increase::InboundWireTransfer::Status } |
#type ⇒ Symbol, Increase::Models::InboundWireTransfer::Type
A constant representing the object’s type. For this resource it will always be ‘inbound_wire_transfer`.
142 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 142 required :type, enum: -> { Increase::InboundWireTransfer::Type } |
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
150 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 150 required :unique_end_to_end_transaction_reference, String, nil?: true |
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
156 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 156 required :unstructured_remittance_information, String, nil?: true |
#wire_drawdown_request_id ⇒ String?
The wire drawdown request the inbound wire transfer is fulfilling.
162 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 162 required :wire_drawdown_request_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/inbound_wire_transfer.rb', line 287
|