Class: Increase::Models::InboundWireTransfer::Acceptance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_wire_transfer.rb,
sig/increase/models/inbound_wire_transfer.rbs

Overview

See Also:

  • Increase::Models::InboundWireTransfer#acceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeAcceptance

Returns a new instance of Acceptance.

Parameters:

  • accepted_at: (Time)
  • transaction_id: (String)


151
# File 'sig/increase/models/inbound_wire_transfer.rbs', line 151

def initialize: (accepted_at: Time, transaction_id: String) -> void

Instance Attribute Details

#accepted_atTime

The ISO 8601 date and time at which the transfer was accepted.

Parameters:

  • value (Time)

Returns:

  • (Time)


236
# File 'lib/increase/models/inbound_wire_transfer.rb', line 236

required :accepted_at, Time

#transaction_idString

The identifier of the transaction for the accepted transfer.

Parameters:

  • value (String)

Returns:

  • (String)


242
# File 'lib/increase/models/inbound_wire_transfer.rb', line 242

required :transaction_id, String

Instance Method Details

#to_hash{ accepted_at: Time, transaction_id: String }

Returns:

  • ({ accepted_at: Time, transaction_id: String })


153
# File 'sig/increase/models/inbound_wire_transfer.rbs', line 153

def to_hash: -> { accepted_at: Time, transaction_id: String }