Class: Increase::Models::InboundWireTransfer::Reversal

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_wire_transfer.rb,
sig/increase/models/inbound_wire_transfer.rbs

Overview

See Also:

  • Increase::Models::InboundWireTransfer#reversal

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(reason:, reversed_at:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::InboundWireTransfer::Reversal for more details.

If the transfer is reversed, this will contain details of the reversal.

Parameters:



# File 'lib/increase/models/inbound_wire_transfer.rb', line 270

Instance Attribute Details

#reasonSymbol, Increase::Models::InboundWireTransfer::Reversal::Reason

The reason for the reversal.

Parameters:

  • value (Increase::Models::InboundWireTransfer::Reversal::reason)

Returns:



261
# File 'lib/increase/models/inbound_wire_transfer.rb', line 261

required :reason, enum: -> { Increase::InboundWireTransfer::Reversal::Reason }

#reversed_atTime

The ISO 8601 date and time at which the transfer was reversed.

Parameters:

  • value (Time)

Returns:

  • (Time)


268
# File 'lib/increase/models/inbound_wire_transfer.rb', line 268

required :reversed_at, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


172
# File 'sig/increase/models/inbound_wire_transfer.rbs', line 172

def to_hash: -> {