Module: Increase::Models::InboundWireTransferListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/inbound_wire_transfer_list_params.rb,
sig/increase/models/inbound_wire_transfer_list_params.rbs

Constant Summary collapse

PENDING =

The Inbound Wire Transfer is awaiting action, will transition automatically if no action is taken.

:pending
ACCEPTED =

The Inbound Wire Transfer is accepted.

:accepted
DECLINED =

The Inbound Wire Transfer was declined.

:declined
REVERSED =

The Inbound Wire Transfer was reversed.

:reversed

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/inbound_wire_transfer_list_params.rb', line 159


Instance Method Details

#initialize(in_: nil) ⇒ Object



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/increase/models/inbound_wire_transfer_list_params.rb', line 144

module In
  extend Increase::Internal::Type::Enum

  # The Inbound Wire Transfer is awaiting action, will transition automatically if no action is taken.
  PENDING = :pending

  # The Inbound Wire Transfer is accepted.
  ACCEPTED = :accepted

  # The Inbound Wire Transfer was declined.
  DECLINED = :declined

  # The Inbound Wire Transfer was reversed.
  REVERSED = :reversed

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::InboundWireTransferListParams::Status::in_]



145
# File 'sig/increase/models/inbound_wire_transfer_list_params.rbs', line 145

def self?.values: -> ::Array[Increase::Models::InboundWireTransferListParams::Status::in_]