Class: Increase::Models::IntrafiAccountEnrollmentListParams::Status

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/intrafi_account_enrollment_list_params.rb,
sig/increase/models/intrafi_account_enrollment_list_params.rbs

Defined Under Namespace

Modules: In

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: nil, cursor: nil, idempotency_key: nil, limit: nil, status: nil, request_options: {}) ⇒ Object



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/increase/models/intrafi_account_enrollment_list_params.rb', line 66

class Status < Increase::Internal::Type::BaseModel
  # @!attribute in_
  #   Filter IntraFi Account Enrollments for those with the specified status or
  #   statuses. For GET requests, this should be encoded as a comma-delimited string,
  #   such as `?in=one,two,three`.
  #
  #   @return [Array<Symbol, Increase::Models::IntrafiAccountEnrollmentListParams::Status::In>, nil]
  optional :in_,
           -> {
             Increase::Internal::Type::ArrayOf[enum: Increase::IntrafiAccountEnrollmentListParams::Status::In]
           },
           api_name: :in

  # @!method initialize(in_: nil)
  #   @param in_ [Array<Symbol, Increase::Models::IntrafiAccountEnrollmentListParams::Status::In>]
  #     Filter IntraFi Account Enrollments for those with the specified status or
  #     statuses. For GET requests, this should be encoded as a comma-delimited string,
  #     such as `?in=one,two,three`.

  module In
    extend Increase::Internal::Type::Enum

    # The account is being added to the IntraFi network.
    PENDING_ENROLLING = :pending_enrolling

    # The account has been enrolled with IntraFi.
    ENROLLED = :enrolled

    # The account is being unenrolled from IntraFi's deposit sweep.
    PENDING_UNENROLLING = :pending_unenrolling

    # The account was once enrolled, but is no longer enrolled at IntraFi.
    UNENROLLED = :unenrolled

    # Something unexpected happened with this account. Contact Increase support.
    REQUIRES_ATTENTION = :requires_attention

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#in_Array<Symbol, Increase::Models::IntrafiAccountEnrollmentListParams::Status::In>?

Filter IntraFi Account Enrollments for those with the specified status or statuses. For GET requests, this should be encoded as a comma-delimited string, such as ?in=one,two,three.



73
74
75
76
77
# File 'lib/increase/models/intrafi_account_enrollment_list_params.rb', line 73

optional :in_,
-> {
  Increase::Internal::Type::ArrayOf[enum: Increase::IntrafiAccountEnrollmentListParams::Status::In]
},
api_name: :in

Instance Method Details

#to_hash{



73
# File 'sig/increase/models/intrafi_account_enrollment_list_params.rbs', line 73

def to_hash: -> {