Class: Increase::Models::IntrafiBalance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/intrafi_balance.rb,
sig/increase/models/intrafi_balance.rbs

Overview

See Also:

  • Increase::Resources::IntrafiBalances#intrafi_balance

Defined Under Namespace

Modules: Currency, Type Classes: Balance

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, state:) ⇒ Object

The primary location of the bank.



# File 'lib/increase/models/intrafi_balance.rb', line 118


Instance Attribute Details

#balancesArray<Increase::Models::IntrafiBalance::Balance>

Each entry represents a balance held at a different bank. IntraFi separates the total balance across many participating banks in the network.



12
# File 'lib/increase/models/intrafi_balance.rb', line 12

required :balances, -> { Increase::Internal::Type::ArrayOf[Increase::IntrafiBalance::Balance] }

#currencySymbol, Increase::Models::IntrafiBalance::Currency

The ISO 4217 code for the account currency.



19
# File 'lib/increase/models/intrafi_balance.rb', line 19

required :currency, enum: -> { Increase::IntrafiBalance::Currency }

#effective_dateDate

The date this balance reflects.



25
# File 'lib/increase/models/intrafi_balance.rb', line 25

required :effective_date, Date

#total_balanceInteger

The total balance, in minor units of currency. Increase reports this balance to IntraFi daily.



32
# File 'lib/increase/models/intrafi_balance.rb', line 32

required :total_balance, Integer

#typeSymbol, Increase::Models::IntrafiBalance::Type

A constant representing the object's type. For this resource it will always be intrafi_balance.



39
# File 'lib/increase/models/intrafi_balance.rb', line 39

required :type, enum: -> { Increase::IntrafiBalance::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/intrafi_balance.rb', line 137


Instance Method Details

#to_hash{



31
# File 'sig/increase/models/intrafi_balance.rbs', line 31

def to_hash: -> {