Class: Increase::Models::IntrafiExclusion

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/intrafi_exclusion.rb,
sig/increase/models/intrafi_exclusion.rbs

Overview

See Also:

  • Increase::Resources::IntrafiExclusions#create

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, bank_name:, created_at:, entity_id:, excluded_at:, fdic_certificate_number:, idempotency_key:, status:, submitted_at:, type:) ⇒ Object

Certain institutions may be excluded per Entity when sweeping funds into the IntraFi network. This is useful when an Entity already has deposits at a particular bank, and does not want to sweep additional funds to it. It may take 5 business days for an exclusion to be processed.



# File 'lib/increase/models/intrafi_exclusion.rb', line 72


Instance Attribute Details

#bank_nameString?

The name of the excluded institution.



17
# File 'lib/increase/models/intrafi_exclusion.rb', line 17

required :bank_name, String, nil?: true

#created_atTime

The ISO 8601 date and time at which the exclusion was created.



24
# File 'lib/increase/models/intrafi_exclusion.rb', line 24

required :created_at, Time

#entity_idString

The entity for which this institution is excluded.



30
# File 'lib/increase/models/intrafi_exclusion.rb', line 30

required :entity_id, String

#excluded_atTime?

When this exclusion was confirmed by IntraFi.



36
# File 'lib/increase/models/intrafi_exclusion.rb', line 36

required :excluded_at, Time, nil?: true

#fdic_certificate_numberString?

The Federal Deposit Insurance Corporation's certificate number for the institution.



43
# File 'lib/increase/models/intrafi_exclusion.rb', line 43

required :fdic_certificate_number, String, nil?: true

#idString

The identifier of this exclusion request.



11
# File 'lib/increase/models/intrafi_exclusion.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.



51
# File 'lib/increase/models/intrafi_exclusion.rb', line 51

required :idempotency_key, String, nil?: true

#statusSymbol, Increase::Models::IntrafiExclusion::Status

The status of the exclusion request.



57
# File 'lib/increase/models/intrafi_exclusion.rb', line 57

required :status, enum: -> { Increase::IntrafiExclusion::Status }

#submitted_atTime?

When this exclusion was submitted to IntraFi by Increase.



63
# File 'lib/increase/models/intrafi_exclusion.rb', line 63

required :submitted_at, Time, nil?: true

#typeSymbol, Increase::Models::IntrafiExclusion::Type

A constant representing the object's type. For this resource it will always be intrafi_exclusion.



70
# File 'lib/increase/models/intrafi_exclusion.rb', line 70

required :type, enum: -> { Increase::IntrafiExclusion::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/intrafi_exclusion.rb', line 125


Instance Method Details

#to_hash{



51
# File 'sig/increase/models/intrafi_exclusion.rbs', line 51

def to_hash: -> {