Class: Increase::Models::IntrafiExclusionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/intrafi_exclusion_create_params.rb,
sig/increase/models/intrafi_exclusion_create_params.rbs

Overview

See Also:

  • Increase::Resources::IntrafiExclusions#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(entity_id:, fdic_certificate_number:, request_options: {}) ⇒ Object



# File 'lib/increase/models/intrafi_exclusion_create_params.rb', line 25


Instance Attribute Details

#entity_idString

The identifier of the Entity whose deposits will be excluded.



14
# File 'lib/increase/models/intrafi_exclusion_create_params.rb', line 14

required :entity_id, String

#fdic_certificate_numberString

The FDIC certificate number of the financial institution to be excluded. An FDIC certificate number uniquely identifies a financial institution, and is different than a routing number. To find one, we recommend searching by Bank Name using the FDIC's bankfind tool.



23
# File 'lib/increase/models/intrafi_exclusion_create_params.rb', line 23

required :fdic_certificate_number, String

Instance Method Details

#to_hash{



21
# File 'sig/increase/models/intrafi_exclusion_create_params.rbs', line 21

def to_hash: -> {