Class: Increase::Models::LockboxAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/lockbox_address.rb

Overview

Defined Under Namespace

Modules: Status, Type Classes: Address

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, line1:, line2:, postal_code:, state:) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The mailing address for the Lockbox Address. It will be present after Increase generates it.

Parameters:

  • city (String)

    The city of the address.

  • line1 (String)

    The first line of the address.

  • line2 (String)

    The second line of the address.

  • postal_code (String)

    The postal code of the address.

  • state (String)

    The two-letter United States Postal Service (USPS) abbreviation for the state of



# File 'lib/increase/models/lockbox_address.rb', line 54

Instance Attribute Details

#addressIncrease::Models::LockboxAddress::Address?

The mailing address for the Lockbox Address. It will be present after Increase generates it.



18
# File 'lib/increase/models/lockbox_address.rb', line 18

required :address, -> { Increase::LockboxAddress::Address }, nil?: true

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Lockbox Address was created.

Returns:

  • (Time)


25
# File 'lib/increase/models/lockbox_address.rb', line 25

required :created_at, Time

#descriptionString?

The description you choose for the Lockbox Address.

Returns:

  • (String, nil)


31
# File 'lib/increase/models/lockbox_address.rb', line 31

required :description, String, nil?: true

#idString

The Lockbox Address identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/lockbox_address.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).

Returns:

  • (String, nil)


39
# File 'lib/increase/models/lockbox_address.rb', line 39

required :idempotency_key, String, nil?: true

#statusSymbol, Increase::Models::LockboxAddress::Status

The status of the Lockbox Address.



45
# File 'lib/increase/models/lockbox_address.rb', line 45

required :status, enum: -> { Increase::LockboxAddress::Status }

#typeSymbol, Increase::Models::LockboxAddress::Type

A constant representing the object’s type. For this resource it will always be ‘lockbox_address`.



52
# File 'lib/increase/models/lockbox_address.rb', line 52

required :type, enum: -> { Increase::LockboxAddress::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/lockbox_address.rb', line 144