Module: Increase::Models::LockboxRecipient::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/lockbox_recipient.rb

Overview

The status of the Lockbox Recipient.

See Also:

Constant Summary collapse

ACTIVE =

This Lockbox Recipient is active.

:active
DISABLED =

This Lockbox Recipient is disabled. Checks mailed to this Lockbox Recipient will be rejected.

:disabled
CANCELED =

This Lockbox Recipient is canceled and cannot be modified. Checks mailed to this Lockbox Recipient will be rejected.

:canceled

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info