Class: Increase::Models::LockboxRecipientCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::LockboxRecipientCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/lockbox_recipient_create_params.rb
Overview
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account that checks sent to this Lockbox Recipient should be deposited into.
-
#description ⇒ String?
The description you choose for the Lockbox Recipient.
-
#lockbox_address_id ⇒ String
The Lockbox Address where this Lockbox Recipient may receive mail.
-
#recipient_name ⇒ String?
The name of the Lockbox Recipient.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_id:, lockbox_address_id:, description: nil, recipient_name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LockboxRecipientCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, lockbox_address_id:, description: nil, recipient_name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::LockboxRecipientCreateParams for more details.
|
|
# File 'lib/increase/models/lockbox_recipient_create_params.rb', line 34
|
Instance Attribute Details
#account_id ⇒ String
The Account that checks sent to this Lockbox Recipient should be deposited into.
14 |
# File 'lib/increase/models/lockbox_recipient_create_params.rb', line 14 required :account_id, String |
#description ⇒ String?
The description you choose for the Lockbox Recipient.
26 |
# File 'lib/increase/models/lockbox_recipient_create_params.rb', line 26 optional :description, String |
#lockbox_address_id ⇒ String
The Lockbox Address where this Lockbox Recipient may receive mail.
20 |
# File 'lib/increase/models/lockbox_recipient_create_params.rb', line 20 required :lockbox_address_id, String |
#recipient_name ⇒ String?
The name of the Lockbox Recipient
32 |
# File 'lib/increase/models/lockbox_recipient_create_params.rb', line 32 optional :recipient_name, String |