Module: Increase::Models::LockboxRecipientUpdateParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/lockbox_recipient_update_params.rb,
sig/increase/models/lockbox_recipient_update_params.rbs

Overview

The status of the Lockbox Recipient.

Constant Summary collapse

ACTIVE =

This Lockbox Recipient is active.

Returns:

  • (:active)
:active
DISABLED =

This Lockbox Recipient is disabled. Checks mailed to this Lockbox Recipient will be rejected.

Returns:

  • (:disabled)
:disabled
CANCELED =

This Lockbox Recipient is canceled and cannot be modified. Checks mailed to this Lockbox Recipient will be rejected.

Returns:

  • (:canceled)
:canceled

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/lockbox_recipient_update_params.rb', line 58

Instance Method Details

#self?.values::Array[Increase::Models::LockboxRecipientUpdateParams::status]

Returns:

  • (::Array[Increase::Models::LockboxRecipientUpdateParams::status])


62
# File 'sig/increase/models/lockbox_recipient_update_params.rbs', line 62

def self?.values: -> ::Array[Increase::Models::LockboxRecipientUpdateParams::status]