Class: Increase::Models::OAuthApplication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/oauth_application.rb,
sig/increase/models/oauth_application.rbs

Overview

See Also:

  • Increase::Resources::OAuthApplications#retrieve

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, client_id:, created_at:, deleted_at:, name:, status:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::OAuthApplication for more details.

An OAuth Application lets you build an application for others to use with their Increase data. You can create an OAuth Application via the Dashboard and read information about it with the API. Learn more about OAuth here.

Parameters:

  • id (String)

    The OAuth Application's identifier.

  • client_id (String)

    The OAuth Application's client_id. Use this to authenticate with the OAuth Appli

  • created_at (Time)

    The ISO 8601 timestamp when the OAuth

  • deleted_at (Time, nil)

    The ISO 8601 timestamp when the OAuth

  • name (String, nil)

    The name you chose for this OAuth Application.

  • status (Symbol, Increase::Models::OAuthApplication::Status)

    Whether the application is active.

  • type (Symbol, Increase::Models::OAuthApplication::Type)

    A constant representing the object's type. For this resource it will always be `



# File 'lib/increase/models/oauth_application.rb', line 53

Instance Attribute Details

#client_idString

The OAuth Application's client_id. Use this to authenticate with the OAuth Application.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/increase/models/oauth_application.rb', line 18

required :client_id, String

#created_atTime

The ISO 8601 timestamp when the OAuth Application was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


25
# File 'lib/increase/models/oauth_application.rb', line 25

required :created_at, Time

#deleted_atTime?

The ISO 8601 timestamp when the OAuth Application was deleted.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


32
# File 'lib/increase/models/oauth_application.rb', line 32

required :deleted_at, Time, nil?: true

#idString

The OAuth Application's identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/oauth_application.rb', line 11

required :id, String

#nameString?

The name you chose for this OAuth Application.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/increase/models/oauth_application.rb', line 38

required :name, String, nil?: true

#statusSymbol, Increase::Models::OAuthApplication::Status

Whether the application is active.

Parameters:

  • value (Increase::Models::OAuthApplication::status)

Returns:



44
# File 'lib/increase/models/oauth_application.rb', line 44

required :status, enum: -> { Increase::OAuthApplication::Status }

#typeSymbol, Increase::Models::OAuthApplication::Type

A constant representing the object's type. For this resource it will always be oauth_application.

Parameters:

  • value (Increase::Models::OAuthApplication::type_)

Returns:



51
# File 'lib/increase/models/oauth_application.rb', line 51

required :type, enum: -> { Increase::OAuthApplication::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/oauth_application.rb', line 88

Instance Method Details

#to_hash{

Returns:

  • ({)


39
# File 'sig/increase/models/oauth_application.rbs', line 39

def to_hash: -> {