Module: Increase::Models::OAuthApplicationListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/oauth_application_list_params.rb,
sig/increase/models/oauth_application_list_params.rbs

Constant Summary collapse

ACTIVE =

The application is active and can be used by your users.

Returns:

  • (:active)
:active
DELETED =

The application is deleted.

Returns:

  • (:deleted)
:deleted

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/oauth_application_list_params.rb', line 119

Instance Method Details

#initialize(in_: nil) ⇒ Object

Parameters:



110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/increase/models/oauth_application_list_params.rb', line 110

module In
  extend Increase::Internal::Type::Enum

  # The application is active and can be used by your users.
  ACTIVE = :active

  # The application is deleted.
  DELETED = :deleted

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::OAuthApplicationListParams::Status::in_]

Returns:

  • (::Array[Increase::Models::OAuthApplicationListParams::Status::in_])


118
# File 'sig/increase/models/oauth_application_list_params.rbs', line 118

def self?.values: -> ::Array[Increase::Models::OAuthApplicationListParams::Status::in_]