Class: Increase::Models::OAuthConnection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/oauth_connection.rb,
sig/increase/models/oauth_connection.rbs

Overview

See Also:

  • Increase::Resources::OAuthConnections#retrieve

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, deleted_at:, group_id:, oauth_application_id:, status:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::OAuthConnection for more details.

When a user authorizes your OAuth application, an OAuth Connection object is created. Learn more about OAuth here.

Parameters:

  • id (String)

    The OAuth Connection's identifier.

  • created_at (Time)

    The ISO 8601 timestamp when the OAuth

  • deleted_at (Time, nil)

    The ISO 8601 timestamp when the OAuth

  • group_id (String)

    The identifier of the Group that has authorized your OAuth application.

  • oauth_application_id (String)

    The identifier of the OAuth application this connection is for.

  • status (Symbol, Increase::Models::OAuthConnection::Status)

    Whether the connection is active.

  • type (Symbol, Increase::Models::OAuthConnection::Type)

    A constant representing the object's type. For this resource it will always be `



# File 'lib/increase/models/oauth_connection.rb', line 52

Instance Attribute Details

#created_atTime

The ISO 8601 timestamp when the OAuth Connection was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


18
# File 'lib/increase/models/oauth_connection.rb', line 18

required :created_at, Time

#deleted_atTime?

The ISO 8601 timestamp when the OAuth Connection was deleted.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


25
# File 'lib/increase/models/oauth_connection.rb', line 25

required :deleted_at, Time, nil?: true

#group_idString

The identifier of the Group that has authorized your OAuth application.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/increase/models/oauth_connection.rb', line 31

required :group_id, String

#idString

The OAuth Connection's identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/oauth_connection.rb', line 11

required :id, String

#oauth_application_idString

The identifier of the OAuth application this connection is for.

Parameters:

  • value (String)

Returns:

  • (String)


37
# File 'lib/increase/models/oauth_connection.rb', line 37

required :oauth_application_id, String

#statusSymbol, Increase::Models::OAuthConnection::Status

Whether the connection is active.

Parameters:

  • value (Increase::Models::OAuthConnection::status)

Returns:



43
# File 'lib/increase/models/oauth_connection.rb', line 43

required :status, enum: -> { Increase::OAuthConnection::Status }

#typeSymbol, Increase::Models::OAuthConnection::Type

A constant representing the object's type. For this resource it will always be oauth_connection.

Parameters:

  • value (Increase::Models::OAuthConnection::type_)

Returns:



50
# File 'lib/increase/models/oauth_connection.rb', line 50

required :type, enum: -> { Increase::OAuthConnection::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/oauth_connection.rb', line 86

Instance Method Details

#to_hash{

Returns:

  • ({)


39
# File 'sig/increase/models/oauth_connection.rbs', line 39

def to_hash: -> {