Class: Increase::Models::PendingTransaction::Source

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Overview

See Also:

  • Increase::Models::PendingTransaction#source

Defined Under Namespace

Modules: Category Classes: ACHTransferInstruction, AccountTransferInstruction, BlockchainOfframpTransfer, BlockchainOnrampTransferInstruction, CardAuthorization, CardPushTransferInstruction, CheckDepositInstruction, CheckTransferInstruction, FednowTransferInstruction, InboundFundsHold, InboundWireTransferReversal, Other, RealTimePaymentsTransferInstruction, SwiftTransferInstruction, WireTransferInstruction

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transfer_id:) ⇒ Object

A Swift Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to swift_transfer_instruction.

Parameters:

  • transfer_id (String)

    The identifier of the Swift Transfer that led to this Pending Transaction.



# File 'lib/increase/models/pending_transaction.rb', line 362

Instance Attribute Details

#account_transfer_instructionIncrease::Models::PendingTransaction::Source::AccountTransferInstruction?

An Account Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to account_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::AccountTransferInstruction, nil)

Returns:



210
211
212
# File 'lib/increase/models/pending_transaction.rb', line 210

optional :account_transfer_instruction,
-> { Increase::PendingTransaction::Source::AccountTransferInstruction },
nil?: true

#ach_transfer_instructionIncrease::Models::PendingTransaction::Source::ACHTransferInstruction?

An ACH Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to ach_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::ACHTransferInstruction, nil)

Returns:



219
220
221
# File 'lib/increase/models/pending_transaction.rb', line 219

optional :ach_transfer_instruction,
-> { Increase::PendingTransaction::Source::ACHTransferInstruction },
nil?: true

#blockchain_offramp_transferIncrease::Models::PendingTransaction::Source::BlockchainOfframpTransfer?

A Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if category is equal to blockchain_offramp_transfer. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They're automatically created when funds land in a Blockchain Address.

Parameters:

  • value (Increase::PendingTransaction::Source::BlockchainOfframpTransfer, nil)

Returns:



230
231
232
# File 'lib/increase/models/pending_transaction.rb', line 230

optional :blockchain_offramp_transfer,
-> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer },
nil?: true

#blockchain_onramp_transfer_instructionIncrease::Models::PendingTransaction::Source::BlockchainOnrampTransferInstruction?

A Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to blockchain_onramp_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::BlockchainOnrampTransferInstruction, nil)

Returns:



240
241
242
# File 'lib/increase/models/pending_transaction.rb', line 240

optional :blockchain_onramp_transfer_instruction,
-> { Increase::PendingTransaction::Source::BlockchainOnrampTransferInstruction },
nil?: true

#card_authorizationIncrease::Models::PendingTransaction::Source::CardAuthorization?

A Card Authorization object. This field will be present in the JSON response if and only if category is equal to card_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.

Parameters:

  • value (Increase::PendingTransaction::Source::CardAuthorization, nil)

Returns:



251
252
253
254
255
# File 'lib/increase/models/pending_transaction.rb', line 251

optional :card_authorization,
-> {
  Increase::PendingTransaction::Source::CardAuthorization
},
nil?: true

#card_push_transfer_instructionIncrease::Models::PendingTransaction::Source::CardPushTransferInstruction?

A Card Push Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to card_push_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::CardPushTransferInstruction, nil)

Returns:



262
263
264
# File 'lib/increase/models/pending_transaction.rb', line 262

optional :card_push_transfer_instruction,
-> { Increase::PendingTransaction::Source::CardPushTransferInstruction },
nil?: true

#categorySymbol, Increase::Models::PendingTransaction::Source::Category

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

Parameters:

  • value (Increase::Models::PendingTransaction::Source::category)

Returns:



203
# File 'lib/increase/models/pending_transaction.rb', line 203

required :category, enum: -> { Increase::PendingTransaction::Source::Category }

#check_deposit_instructionIncrease::Models::PendingTransaction::Source::CheckDepositInstruction?

A Check Deposit Instruction object. This field will be present in the JSON response if and only if category is equal to check_deposit_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::CheckDepositInstruction, nil)

Returns:



271
272
273
# File 'lib/increase/models/pending_transaction.rb', line 271

optional :check_deposit_instruction,
-> { Increase::PendingTransaction::Source::CheckDepositInstruction },
nil?: true

#check_transfer_instructionIncrease::Models::PendingTransaction::Source::CheckTransferInstruction?

A Check Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to check_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::CheckTransferInstruction, nil)

Returns:



280
281
282
# File 'lib/increase/models/pending_transaction.rb', line 280

optional :check_transfer_instruction,
-> { Increase::PendingTransaction::Source::CheckTransferInstruction },
nil?: true

#fednow_transfer_instructionIncrease::Models::PendingTransaction::Source::FednowTransferInstruction?

A FedNow Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to fednow_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::FednowTransferInstruction, nil)

Returns:



289
290
291
# File 'lib/increase/models/pending_transaction.rb', line 289

optional :fednow_transfer_instruction,
-> { Increase::PendingTransaction::Source::FednowTransferInstruction },
nil?: true

#inbound_funds_holdIncrease::Models::PendingTransaction::Source::InboundFundsHold?

An Inbound Funds Hold object. This field will be present in the JSON response if and only if category is equal to inbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.

Parameters:

  • value (Increase::PendingTransaction::Source::InboundFundsHold, nil)

Returns:



300
301
302
303
304
# File 'lib/increase/models/pending_transaction.rb', line 300

optional :inbound_funds_hold,
-> {
  Increase::PendingTransaction::Source::InboundFundsHold
},
nil?: true

#inbound_wire_transfer_reversalIncrease::Models::PendingTransaction::Source::InboundWireTransferReversal?

An Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if category is equal to inbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.

Parameters:

  • value (Increase::PendingTransaction::Source::InboundWireTransferReversal, nil)

Returns:



313
314
315
# File 'lib/increase/models/pending_transaction.rb', line 313

optional :inbound_wire_transfer_reversal,
-> { Increase::PendingTransaction::Source::InboundWireTransferReversal },
nil?: true

#otherIncrease::Models::PendingTransaction::Source::Other?

If the category of this Transaction source is equal to other, this field will contain an empty object, otherwise it will contain null.

Parameters:

  • value (Increase::PendingTransaction::Source::Other, nil)

Returns:



322
# File 'lib/increase/models/pending_transaction.rb', line 322

optional :other, -> { Increase::PendingTransaction::Source::Other }, nil?: true

#real_time_payments_transfer_instructionIncrease::Models::PendingTransaction::Source::RealTimePaymentsTransferInstruction?

A Real-Time Payments Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to real_time_payments_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::RealTimePaymentsTransferInstruction, nil)

Returns:



330
331
332
# File 'lib/increase/models/pending_transaction.rb', line 330

optional :real_time_payments_transfer_instruction,
-> { Increase::PendingTransaction::Source::RealTimePaymentsTransferInstruction },
nil?: true

#swift_transfer_instructionIncrease::Models::PendingTransaction::Source::SwiftTransferInstruction?

A Swift Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to swift_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::SwiftTransferInstruction, nil)

Returns:



339
340
341
# File 'lib/increase/models/pending_transaction.rb', line 339

optional :swift_transfer_instruction,
-> { Increase::PendingTransaction::Source::SwiftTransferInstruction },
nil?: true

#user_initiated_holdHash{Symbol=>Object}?

An User Initiated Hold object. This field will be present in the JSON response if and only if category is equal to user_initiated_hold. Created when a user initiates a hold on funds in their account.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


349
350
351
# File 'lib/increase/models/pending_transaction.rb', line 349

optional :user_initiated_hold,
Increase::Internal::Type::HashOf[Increase::Internal::Type::Unknown],
nil?: true

#wire_transfer_instructionIncrease::Models::PendingTransaction::Source::WireTransferInstruction?

A Wire Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to wire_transfer_instruction.

Parameters:

  • value (Increase::PendingTransaction::Source::WireTransferInstruction, nil)

Returns:



358
359
360
# File 'lib/increase/models/pending_transaction.rb', line 358

optional :wire_transfer_instruction,
-> { Increase::PendingTransaction::Source::WireTransferInstruction },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/pending_transaction.rb', line 501

Instance Method Details

#to_hash{

Returns:

  • ({)


183
# File 'sig/increase/models/pending_transaction.rbs', line 183

def to_hash: -> {