Class: Increase::Models::PendingTransaction::Source::AccountTransferInstruction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Overview

See Also:

  • Increase::Models::PendingTransaction::Source#account_transfer_instruction

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, transfer_id:) ⇒ Object

An Account Transfer Instruction object. This field will be present in the JSON response if and only if category is equal to account_transfer_instruction.

Parameters:

  • The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

  • The ISO 4217 code for the destination account currency.

  • The identifier of the Account Transfer that led to this Pending Transaction.



# File 'lib/increase/models/pending_transaction.rb', line 564


Instance Attribute Details

#amountInteger

The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

Returns:



548
# File 'lib/increase/models/pending_transaction.rb', line 548

required :amount, Integer

#currencySymbol, Increase::Models::PendingTransaction::Source::AccountTransferInstruction::Currency

The ISO 4217 code for the destination account currency.

Parameters:

Returns:



555
556
# File 'lib/increase/models/pending_transaction.rb', line 555

required :currency,
enum: -> { Increase::PendingTransaction::Source::AccountTransferInstruction::Currency }

#transfer_idString

The identifier of the Account Transfer that led to this Pending Transaction.

Parameters:

Returns:



562
# File 'lib/increase/models/pending_transaction.rb', line 562

required :transfer_id, String

Instance Method Details

#to_hash{

Returns:



313
# File 'sig/increase/models/pending_transaction.rbs', line 313

def to_hash: -> {