Class: Increase::Models::PendingTransaction::Source::CardAuthorization::AdditionalAmounts::Surcharge

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Overview

See Also:

  • Increase::Models::PendingTransaction::Source::CardAuthorization::AdditionalAmounts#surcharge

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeSurcharge



766
# File 'sig/increase/models/pending_transaction.rbs', line 766

def initialize: (amount: Integer, currency: String) -> void

Instance Attribute Details

#amountInteger

The amount in minor units of the currency field. The amount is positive if it is added to the amount (such as an ATM surcharge fee) and negative if it is subtracted from the amount (such as a discount).



1411
# File 'lib/increase/models/pending_transaction.rb', line 1411

required :amount, Integer

#currencyString

The ISO 4217 code for the additional amount's currency.



1418
# File 'lib/increase/models/pending_transaction.rb', line 1418

required :currency, String

Instance Method Details

#to_hash{ amount: Integer, currency: String }



768
# File 'sig/increase/models/pending_transaction.rbs', line 768

def to_hash: -> { amount: Integer, currency: String }