Class: Increase::Models::PendingTransaction::Source::CardAuthorization::Healthcare

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: MerchantNinetyPercentEligibility

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(merchant_ninety_percent_eligibility:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::CardAuthorization::Healthcare for more details.

The healthcare-related fields for this authorization. Only present for specific programs.

Parameters:



# File 'lib/increase/models/pending_transaction.rb', line 1447

Instance Attribute Details

#merchant_ninety_percent_eligibilitySymbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Healthcare::MerchantNinetyPercentEligibility

The merchant’s eligibility under the Internal Revenue Service’s 90% Rule for Flexible Spending Account (FSA) and Health Savings Account (HSA) eligible products. The eligibility is determined based on the list of merchants maintained by the Special Interest Group for IIAS Standards (SIGIS).



1444
1445
# File 'lib/increase/models/pending_transaction.rb', line 1444

required :merchant_ninety_percent_eligibility,
enum: -> { Increase::PendingTransaction::Source::CardAuthorization::Healthcare::MerchantNinetyPercentEligibility }