Class: Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Defined Under Namespace

Modules: Currency, FeeType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, created_at:, currency:, fee_type:, fixed_component:, variable_rate:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee for more details.

Parameters:



# File 'lib/increase/models/pending_transaction.rb', line 1890

Instance Attribute Details

#amountString

The fee amount given as a string containing a decimal number.

Parameters:

  • value (String)

Returns:

  • (String)


1852
# File 'lib/increase/models/pending_transaction.rb', line 1852

required :amount, String

#created_atTime

The ISO 8601 time at which the fee was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


1859
# File 'lib/increase/models/pending_transaction.rb', line 1859

required :created_at, Time

#currencySymbol, Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::Currency

The ISO 4217 code for the fee reimbursement.

Parameters:

  • value (Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::currency)

Returns:



1866
1867
# File 'lib/increase/models/pending_transaction.rb', line 1866

required :currency,
enum: -> { Increase::PendingTransaction::Source::CardAuthorization::SchemeFee::Currency }

#fee_typeSymbol, Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::FeeType

The type of fee being assessed.

Parameters:

  • value (Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::fee_type)

Returns:



1873
1874
# File 'lib/increase/models/pending_transaction.rb', line 1873

required :fee_type,
enum: -> { Increase::PendingTransaction::Source::CardAuthorization::SchemeFee::FeeType }

#fixed_componentString?

The fixed component of the fee, if applicable, given in major units of the fee amount.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1881
# File 'lib/increase/models/pending_transaction.rb', line 1881

required :fixed_component, String, nil?: true

#variable_rateString?

The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1888
# File 'lib/increase/models/pending_transaction.rb', line 1888

required :variable_rate, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/pending_transaction.rb', line 1917

Instance Method Details

#to_hash{

Returns:

  • ({)


1230
# File 'sig/increase/models/pending_transaction.rbs', line 1230

def to_hash: -> {