Module: Increase::Models::PendingTransaction::Source::CardAuthorization::Verification::CardVerificationCode::Result
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs
Overview
The result of verifying the Card Verification Code.
Constant Summary collapse
- NOT_CHECKED =
No card verification code was provided in the authorization request.
:not_checked- MATCH =
The card verification code matched the one on file.
:match- NO_MATCH =
The card verification code did not match the one on file.
:no_match
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::PendingTransaction::Source::CardAuthorization::Verification::CardVerificationCode::result]
1441 |
# File 'sig/increase/models/pending_transaction.rbs', line 1441
def self?.values: -> ::Array[Increase::Models::PendingTransaction::Source::CardAuthorization::Verification::CardVerificationCode::result]
|