Class: Increase::Models::PendingTransaction::Source::CheckDepositInstruction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Overview

See Also:

  • Increase::Models::PendingTransaction::Source#check_deposit_instruction

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, back_image_file_id:, check_deposit_id:, currency:, front_image_file_id:) ⇒ Object

A Check Deposit Instruction object. This field will be present in the JSON response if and only if category is equal to check_deposit_instruction.



# File 'lib/increase/models/pending_transaction.rb', line 2485


Instance Attribute Details

#amountInteger

The pending amount in USD cents.



2456
# File 'lib/increase/models/pending_transaction.rb', line 2456

required :amount, Integer

#back_image_file_idString?

The identifier of the File containing the image of the back of the check that was deposited.



2463
# File 'lib/increase/models/pending_transaction.rb', line 2463

required :back_image_file_id, String, nil?: true

#check_deposit_idString?

The identifier of the Check Deposit.



2469
# File 'lib/increase/models/pending_transaction.rb', line 2469

required :check_deposit_id, String, nil?: true

#currencySymbol, Increase::Models::PendingTransaction::Source::CheckDepositInstruction::Currency

The ISO 4217 code for the transaction's currency.



2476
# File 'lib/increase/models/pending_transaction.rb', line 2476

required :currency, enum: -> { Increase::PendingTransaction::Source::CheckDepositInstruction::Currency }

#front_image_file_idString

The identifier of the File containing the image of the front of the check that was deposited.



2483
# File 'lib/increase/models/pending_transaction.rb', line 2483

required :front_image_file_id, String

Instance Method Details

#to_hash{



1607
# File 'sig/increase/models/pending_transaction.rbs', line 1607

def to_hash: -> {