Class: Increase::Models::PendingTransaction::Source::InboundFundsHold

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Overview

See Also:

  • Increase::Models::PendingTransaction::Source#inbound_funds_hold

Defined Under Namespace

Modules: Currency, Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object

An Inbound Funds Hold object. This field will be present in the JSON response if and only if category is equal to inbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.



# File 'lib/increase/models/pending_transaction.rb', line 2644


Instance Attribute Details

#amountInteger

The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.



2590
# File 'lib/increase/models/pending_transaction.rb', line 2590

required :amount, Integer

#automatically_releases_atTime

When the hold will be released automatically. Certain conditions may cause it to be released before this time.



2597
# File 'lib/increase/models/pending_transaction.rb', line 2597

required :automatically_releases_at, Time

#created_atTime

The ISO 8601 time at which the hold was created.



2604
# File 'lib/increase/models/pending_transaction.rb', line 2604

required :created_at, Time

#currencySymbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Currency

The ISO 4217 code for the hold's currency.



2611
# File 'lib/increase/models/pending_transaction.rb', line 2611

required :currency, enum: -> { Increase::PendingTransaction::Source::InboundFundsHold::Currency }

#held_transaction_idString?

The ID of the Transaction for which funds were held.



2617
# File 'lib/increase/models/pending_transaction.rb', line 2617

required :held_transaction_id, String, nil?: true

#pending_transaction_idString?

The ID of the Pending Transaction representing the held funds.



2623
# File 'lib/increase/models/pending_transaction.rb', line 2623

required :pending_transaction_id, String, nil?: true

#released_atTime?

When the hold was released (if it has been released).



2629
# File 'lib/increase/models/pending_transaction.rb', line 2629

required :released_at, Time, nil?: true

#statusSymbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Status

The status of the hold.



2635
# File 'lib/increase/models/pending_transaction.rb', line 2635

required :status, enum: -> { Increase::PendingTransaction::Source::InboundFundsHold::Status }

#typeSymbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Type

A constant representing the object's type. For this resource it will always be inbound_funds_hold.



2642
# File 'lib/increase/models/pending_transaction.rb', line 2642

required :type, enum: -> { Increase::PendingTransaction::Source::InboundFundsHold::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/pending_transaction.rb', line 2689


Instance Method Details

#to_hash{



1719
# File 'sig/increase/models/pending_transaction.rbs', line 1719

def to_hash: -> {