Class: Increase::Models::PendingTransaction::Source::RealTimePaymentsTransferInstruction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::RealTimePaymentsTransferInstruction
- Defined in:
- lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#transfer_id ⇒ String
The identifier of the Real-Time Payments Transfer that led to this Pending Transaction.
Instance Method Summary collapse
-
#initialize ⇒ RealTimePaymentsTransferInstruction
constructor
A new instance of RealTimePaymentsTransferInstruction.
- #to_hash ⇒ { amount: Integer, transfer_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ RealTimePaymentsTransferInstruction
Returns a new instance of RealTimePaymentsTransferInstruction.
1771 |
# File 'sig/increase/models/pending_transaction.rbs', line 1771
def initialize: (amount: Integer, transfer_id: String) -> void
|
Instance Attribute Details
#amount ⇒ Integer
The transfer amount in USD cents.
2543 |
# File 'lib/increase/models/pending_transaction.rb', line 2543 required :amount, Integer |
#transfer_id ⇒ String
The identifier of the Real-Time Payments Transfer that led to this Pending Transaction.
2550 |
# File 'lib/increase/models/pending_transaction.rb', line 2550 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ { amount: Integer, transfer_id: String }
1773 |
# File 'sig/increase/models/pending_transaction.rbs', line 1773
def to_hash: -> { amount: Integer, transfer_id: String }
|