Class: Increase::Models::PendingTransaction::Source::WireTransferInstruction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::WireTransferInstruction
- Defined in:
- lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs
Overview
Instance Attribute Summary collapse
-
#account_number ⇒ String
The account number for the destination account.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#message_to_recipient ⇒ String
The message that will show on the recipient's bank statement.
-
#routing_number ⇒ String
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
#transfer_id ⇒ String
The identifier of the Wire Transfer that led to this Pending Transaction.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1806 |
# File 'sig/increase/models/pending_transaction.rbs', line 1806
def initialize: (
|
Instance Attribute Details
#account_number ⇒ String
The account number for the destination account.
2587 |
# File 'lib/increase/models/pending_transaction.rb', line 2587 required :account_number, String |
#amount ⇒ Integer
The transfer amount in USD cents.
2593 |
# File 'lib/increase/models/pending_transaction.rb', line 2593 required :amount, Integer |
#message_to_recipient ⇒ String
The message that will show on the recipient's bank statement.
2599 |
# File 'lib/increase/models/pending_transaction.rb', line 2599 required :message_to_recipient, String |
#routing_number ⇒ String
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
2606 |
# File 'lib/increase/models/pending_transaction.rb', line 2606 required :routing_number, String |
#transfer_id ⇒ String
The identifier of the Wire Transfer that led to this Pending Transaction.
2612 |
# File 'lib/increase/models/pending_transaction.rb', line 2612 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
1814 |
# File 'sig/increase/models/pending_transaction.rbs', line 1814
def to_hash: -> {
|