Class: Increase::Models::PendingTransactionListParams::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransactionListParams::Status
- Defined in:
- lib/increase/models/pending_transaction_list_params.rb,
sig/increase/models/pending_transaction_list_params.rbs
Defined Under Namespace
Modules: In
Instance Attribute Summary collapse
-
#in_ ⇒ Array<Symbol, Increase::Models::PendingTransactionListParams::Status::In>?
Filter Pending Transactions for those with the specified status.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
215 |
# File 'sig/increase/models/pending_transaction_list_params.rbs', line 215
def initialize: (
|
Instance Attribute Details
#in_ ⇒ Array<Symbol, Increase::Models::PendingTransactionListParams::Status::In>?
Filter Pending Transactions for those with the specified status. By default only
Pending Transactions in with status pending will be returned. For GET
requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
194 195 196 197 198 |
# File 'lib/increase/models/pending_transaction_list_params.rb', line 194 optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::PendingTransactionListParams::Status::In] }, api_name: :in |
Instance Method Details
#to_hash ⇒ {
219 |
# File 'sig/increase/models/pending_transaction_list_params.rbs', line 219
def to_hash: -> {
|