Module: Increase::Models::PendingTransactionListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/pending_transaction_list_params.rb,
sig/increase/models/pending_transaction_list_params.rbs

Constant Summary collapse

PENDING =

The Pending Transaction is still awaiting confirmation.

:pending
COMPLETE =

The Pending Transaction is confirmed. An associated Transaction exists for this object. The Pending Transaction will no longer count against your balance and can generally be hidden from UIs, etc. The Pending Transaction's amount is the amount that was still held when it completed, which can differ from the amount of the associated Transaction.

:complete

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/pending_transaction_list_params.rb', line 227


Instance Method Details

#initialize(in_: nil) ⇒ Object



218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/increase/models/pending_transaction_list_params.rb', line 218

module In
  extend Increase::Internal::Type::Enum

  # The Pending Transaction is still awaiting confirmation.
  PENDING = :pending

  # The Pending Transaction is confirmed. An associated Transaction exists for this object. The Pending Transaction will no longer count against your balance and can generally be hidden from UIs, etc. The Pending Transaction's `amount` is the amount that was still held when it completed, which can differ from the amount of the associated Transaction.
  COMPLETE = :complete

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::PendingTransactionListParams::Status::in_]



242
# File 'sig/increase/models/pending_transaction_list_params.rbs', line 242

def self?.values: -> ::Array[Increase::Models::PendingTransactionListParams::Status::in_]