Class: Increase::Models::PhysicalCard

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs

Overview

See Also:

  • Increase::Resources::PhysicalCards#create

Defined Under Namespace

Modules: Status, Type Classes: Cardholder, Shipment

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(first_name:, last_name:) ⇒ Object

Details about the cardholder, as it appears on the printed card.



# File 'lib/increase/models/physical_card.rb', line 71


Instance Attribute Details

#account_idString

The identifier for the Account this Physical Card belongs to.



17
# File 'lib/increase/models/physical_card.rb', line 17

required :account_id, String

#card_idString

The identifier for the Card this Physical Card represents.



23
# File 'lib/increase/models/physical_card.rb', line 23

required :card_id, String

#cardholderIncrease::Models::PhysicalCard::Cardholder

Details about the cardholder, as it appears on the printed card.



29
# File 'lib/increase/models/physical_card.rb', line 29

required :cardholder, -> { Increase::PhysicalCard::Cardholder }

#created_atTime

The ISO 8601 date and time at which the Physical Card was created.



36
# File 'lib/increase/models/physical_card.rb', line 36

required :created_at, Time

#idString

The physical card identifier.



11
# File 'lib/increase/models/physical_card.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.



44
# File 'lib/increase/models/physical_card.rb', line 44

required :idempotency_key, String, nil?: true

#physical_card_profile_idString?

The Physical Card Profile used for this Physical Card.



50
# File 'lib/increase/models/physical_card.rb', line 50

required :physical_card_profile_id, String, nil?: true

#shipmentIncrease::Models::PhysicalCard::Shipment

The details used to ship this physical card.



56
# File 'lib/increase/models/physical_card.rb', line 56

required :shipment, -> { Increase::PhysicalCard::Shipment }

#statusSymbol, Increase::Models::PhysicalCard::Status

The status of the Physical Card.



62
# File 'lib/increase/models/physical_card.rb', line 62

required :status, enum: -> { Increase::PhysicalCard::Status }

#typeSymbol, Increase::Models::PhysicalCard::Type

A constant representing the object's type. For this resource it will always be physical_card.



69
# File 'lib/increase/models/physical_card.rb', line 69

required :type, enum: -> { Increase::PhysicalCard::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/physical_card.rb', line 463


Instance Method Details

#to_hash{



51
# File 'sig/increase/models/physical_card.rbs', line 51

def to_hash: -> {