Class: Increase::Models::PhysicalCard::Shipment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs

Overview

See Also:

  • Increase::Models::PhysicalCard#shipment

Defined Under Namespace

Modules: Method, Schedule, Status Classes: Address, Tracking

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2:, line3:, name:, postal_code:, state:) ⇒ Object

The location to where the card's packing label is addressed.



# File 'lib/increase/models/physical_card.rb', line 164


Instance Attribute Details

#addressIncrease::Models::PhysicalCard::Shipment::Address

The location to where the card's packing label is addressed.



134
# File 'lib/increase/models/physical_card.rb', line 134

required :address, -> { Increase::PhysicalCard::Shipment::Address }

#method_Symbol, Increase::Models::PhysicalCard::Shipment::Method

The shipping method.



140
# File 'lib/increase/models/physical_card.rb', line 140

required :method_, enum: -> { Increase::PhysicalCard::Shipment::Method }, api_name: :method

#scheduleSymbol, Increase::Models::PhysicalCard::Shipment::Schedule

When this physical card should be produced by the card printer. The default timeline is the day after the card printer receives the order, except for FEDEX_PRIORITY_OVERNIGHT cards, which default to SAME_DAY. To use faster production methods, please reach out to [email protected].



150
# File 'lib/increase/models/physical_card.rb', line 150

required :schedule, enum: -> { Increase::PhysicalCard::Shipment::Schedule }

#statusSymbol, Increase::Models::PhysicalCard::Shipment::Status

The status of this shipment.



156
# File 'lib/increase/models/physical_card.rb', line 156

required :status, enum: -> { Increase::PhysicalCard::Shipment::Status }

#trackingIncrease::Models::PhysicalCard::Shipment::Tracking?

Tracking details for the shipment.



162
# File 'lib/increase/models/physical_card.rb', line 162

required :tracking, -> { Increase::PhysicalCard::Shipment::Tracking }, nil?: true

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/physical_card.rb', line 272


Instance Method Details

#to_hash{



104
# File 'sig/increase/models/physical_card.rbs', line 104

def to_hash: -> {