Module: Increase::Models::PhysicalCard::Shipment::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs

Overview

The status of this shipment.

See Also:

  • Increase::Models::PhysicalCard::Shipment#status

Constant Summary collapse

PENDING =

The physical card has not yet been shipped.

Returns:

  • (:pending)
:pending
CANCELED =

The physical card shipment was canceled prior to submission.

Returns:

  • (:canceled)
:canceled
SUBMITTED =

The physical card shipment has been submitted to the card fulfillment provider.

Returns:

  • (:submitted)
:submitted
ACKNOWLEDGED =

The physical card shipment has been acknowledged by the card fulfillment provider and will be processed in their next batch.

Returns:

  • (:acknowledged)
:acknowledged
REJECTED =

The physical card shipment was rejected by the card printer due to an error.

Returns:

  • (:rejected)
:rejected
SHIPPED =

The physical card has been shipped.

Returns:

  • (:shipped)
:shipped
RETURNED =

The physical card shipment was returned to the sender and destroyed by the production facility.

Returns:

  • (:returned)
:returned
REQUIRES_ATTENTION =

The physical card shipment requires attention from Increase before progressing.

Returns:

  • (:requires_attention)
:requires_attention

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::PhysicalCard::Shipment::status]

Returns:

  • (::Array[Increase::Models::PhysicalCard::Shipment::status])


234
# File 'sig/increase/models/physical_card.rbs', line 234

def self?.values: -> ::Array[Increase::Models::PhysicalCard::Shipment::status]