Class: Increase::Models::PhysicalCard::Shipment::Tracking

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs

Overview

See Also:

  • Increase::Models::PhysicalCard::Shipment#tracking

Defined Under Namespace

Classes: Update

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



262
# File 'sig/increase/models/physical_card.rbs', line 262

def initialize: (

Instance Attribute Details

#numberString?

The tracking number. Not available for USPS shipments.



336
# File 'lib/increase/models/physical_card.rb', line 336

required :number, String, nil?: true

#return_numberString?

For returned shipments, the tracking number of the return shipment.



342
# File 'lib/increase/models/physical_card.rb', line 342

required :return_number, String, nil?: true

#return_reasonString?

For returned shipments, this describes why the package was returned.



348
# File 'lib/increase/models/physical_card.rb', line 348

required :return_reason, String, nil?: true

#shipped_atTime

The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier.



356
# File 'lib/increase/models/physical_card.rb', line 356

required :shipped_at, Time

#updatesArray<Increase::Models::PhysicalCard::Shipment::Tracking::Update>

Tracking updates relating to the physical card's delivery.



362
363
# File 'lib/increase/models/physical_card.rb', line 362

required :updates,
-> { Increase::Internal::Type::ArrayOf[Increase::PhysicalCard::Shipment::Tracking::Update] }

Instance Method Details

#to_hash{



270
# File 'sig/increase/models/physical_card.rbs', line 270

def to_hash: -> {