Class: Increase::Models::PhysicalCard::Shipment::Tracking::Update
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PhysicalCard::Shipment::Tracking::Update
- Defined in:
- lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#carrier_estimated_delivery_at ⇒ Time?
The ISO 8601 date and time when the carrier expects the card to be delivered.
-
#category ⇒ Symbol, Increase::Models::PhysicalCard::Shipment::Tracking::Update::Category
The type of tracking event.
-
#city ⇒ String?
The city where the event took place.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the tracking event took place.
-
#postal_code ⇒ String?
The postal code where the event took place.
-
#state ⇒ String?
The state where the event took place.
Instance Method Summary collapse
- #initialize(carrier_estimated_delivery_at:, category:, city:, created_at:, postal_code:, state:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(carrier_estimated_delivery_at:, category:, city:, created_at:, postal_code:, state:) ⇒ Object
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/increase/models/physical_card.rb', line 374 class Update < Increase::Internal::Type::BaseModel # @!attribute carrier_estimated_delivery_at # The [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) date and time when the # carrier expects the card to be delivered. # # @return [Time, nil] required :carrier_estimated_delivery_at, Time, nil?: true # @!attribute category # The type of tracking event. # # @return [Symbol, Increase::Models::PhysicalCard::Shipment::Tracking::Update::Category] required :category, enum: -> { Increase::PhysicalCard::Shipment::Tracking::Update::Category } # @!attribute city # The city where the event took place. # # @return [String, nil] required :city, String, nil?: true # @!attribute created_at # The [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) date and time at which # the tracking event took place. # # @return [Time] required :created_at, Time # @!attribute postal_code # The postal code where the event took place. # # @return [String, nil] required :postal_code, String, nil?: true # @!attribute state # The state where the event took place. # # @return [String, nil] required :state, String, nil?: true # @!method initialize(carrier_estimated_delivery_at:, category:, city:, created_at:, postal_code:, state:) # @param carrier_estimated_delivery_at [Time, nil] # The [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) date and time when the # carrier expects the card to be delivered. # # @param category [Symbol, Increase::Models::PhysicalCard::Shipment::Tracking::Update::Category] # The type of tracking event. # # @param city [String, nil] The city where the event took place. # # @param created_at [Time] # The [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) date and time at which # the tracking event took place. # # @param postal_code [String, nil] The postal code where the event took place. # # @param state [String, nil] The state where the event took place. # The type of tracking event. # # @see Increase::Models::PhysicalCard::Shipment::Tracking::Update#category module Category extend Increase::Internal::Type::Enum # The physical card is in transit. IN_TRANSIT = :in_transit # The physical card has been processed for delivery. PROCESSED_FOR_DELIVERY = :processed_for_delivery # The physical card has been delivered. Note that some couriers track delivery status based on driver location data rather than an explicit scan. While uncommon, a single physical card may have more than one delivered event. DELIVERED = :delivered # There is an issue preventing delivery. The delivery will be attempted again if possible. If the issue cannot be resolved, the physical card will be rerouted to the return address. DELIVERY_ISSUE = :delivery_issue # The physical card has been rerouted to the return address. RETURNING_TO_SENDER = :returning_to_sender # The physical card has been delivered to the return address. RETURNED_TO_SENDER = :returned_to_sender # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#carrier_estimated_delivery_at ⇒ Time?
The ISO 8601 date and time when the carrier expects the card to be delivered.
380 |
# File 'lib/increase/models/physical_card.rb', line 380 required :carrier_estimated_delivery_at, Time, nil?: true |
#category ⇒ Symbol, Increase::Models::PhysicalCard::Shipment::Tracking::Update::Category
The type of tracking event.
386 |
# File 'lib/increase/models/physical_card.rb', line 386 required :category, enum: -> { Increase::PhysicalCard::Shipment::Tracking::Update::Category } |
#city ⇒ String?
The city where the event took place.
392 |
# File 'lib/increase/models/physical_card.rb', line 392 required :city, String, nil?: true |
#created_at ⇒ Time
The ISO 8601 date and time at which the tracking event took place.
399 |
# File 'lib/increase/models/physical_card.rb', line 399 required :created_at, Time |
#postal_code ⇒ String?
The postal code where the event took place.
405 |
# File 'lib/increase/models/physical_card.rb', line 405 required :postal_code, String, nil?: true |
#state ⇒ String?
The state where the event took place.
411 |
# File 'lib/increase/models/physical_card.rb', line 411 required :state, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
305 |
# File 'sig/increase/models/physical_card.rbs', line 305
def to_hash: -> {
|