Module: Increase::Models::PhysicalCard::Shipment::Tracking::Update::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs

Overview

The type of tracking event.

See Also:

  • Increase::Models::PhysicalCard::Shipment::Tracking::Update#category

Constant Summary collapse

IN_TRANSIT =

The physical card is in transit.

Returns:

  • (:in_transit)
:in_transit
PROCESSED_FOR_DELIVERY =

The physical card has been processed for delivery.

Returns:

  • (:processed_for_delivery)
:processed_for_delivery
DELIVERED =

The physical card has been delivered. Note that some couriers track delivery status based on driver location data rather than an explicit scan. While uncommon, a single physical card may have more than one delivered event.

Returns:

  • (:delivered)
:delivered
DELIVERY_ISSUE =

There is an issue preventing delivery. The delivery will be attempted again if possible. If the issue cannot be resolved, the physical card will be rerouted to the return address.

Returns:

  • (:delivery_issue)
:delivery_issue
RETURNING_TO_SENDER =

The physical card has been rerouted to the return address.

Returns:

  • (:returning_to_sender)
:returning_to_sender
RETURNED_TO_SENDER =

The physical card has been delivered to the return address.

Returns:

  • (:returned_to_sender)
:returned_to_sender

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::PhysicalCard::Shipment::Tracking::Update::category]

Returns:

  • (::Array[Increase::Models::PhysicalCard::Shipment::Tracking::Update::category])


343
# File 'sig/increase/models/physical_card.rbs', line 343

def self?.values: -> ::Array[Increase::Models::PhysicalCard::Shipment::Tracking::Update::category]