Class: Increase::Models::PhysicalCardCreateParams::Shipment::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PhysicalCardCreateParams::Shipment::Address
- Defined in:
- lib/increase/models/physical_card_create_params.rb,
sig/increase/models/physical_card_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String
The city of the shipping address.
-
#country ⇒ String?
The two-character ISO 3166-1 code of the country where the card should be shipped (e.g.,
US). -
#line1 ⇒ String
The first line of the shipping address.
-
#line2 ⇒ String?
The second line of the shipping address.
-
#line3 ⇒ String?
The third line of the shipping address.
-
#name ⇒ String
The name of the recipient.
-
#phone_number ⇒ String?
The phone number of the recipient.
-
#postal_code ⇒ String
The postal code of the shipping address.
-
#state ⇒ String
The state of the shipping address.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
124 |
# File 'sig/increase/models/physical_card_create_params.rbs', line 124
def initialize: (
|
Instance Attribute Details
#city ⇒ String
The city of the shipping address.
120 |
# File 'lib/increase/models/physical_card_create_params.rb', line 120 required :city, String |
#country ⇒ String?
The two-character ISO 3166-1 code of the country where the card should be
shipped (e.g., US). Please reach out to
support@increase.com to ship cards
internationally.
153 |
# File 'lib/increase/models/physical_card_create_params.rb', line 153 optional :country, String |
#line1 ⇒ String
The first line of the shipping address.
126 |
# File 'lib/increase/models/physical_card_create_params.rb', line 126 required :line1, String |
#line2 ⇒ String?
The second line of the shipping address.
159 |
# File 'lib/increase/models/physical_card_create_params.rb', line 159 optional :line2, String |
#line3 ⇒ String?
The third line of the shipping address.
165 |
# File 'lib/increase/models/physical_card_create_params.rb', line 165 optional :line3, String |
#name ⇒ String
The name of the recipient.
132 |
# File 'lib/increase/models/physical_card_create_params.rb', line 132 required :name, String |
#phone_number ⇒ String?
The phone number of the recipient.
171 |
# File 'lib/increase/models/physical_card_create_params.rb', line 171 optional :phone_number, String |
#postal_code ⇒ String
The postal code of the shipping address.
138 |
# File 'lib/increase/models/physical_card_create_params.rb', line 138 required :postal_code, String |
#state ⇒ String
The state of the shipping address.
144 |
# File 'lib/increase/models/physical_card_create_params.rb', line 144 required :state, String |
Instance Method Details
#to_hash ⇒ {
136 |
# File 'sig/increase/models/physical_card_create_params.rbs', line 136
def to_hash: -> {
|