Module: Increase::Models::PhysicalCardCreateParams::Shipment::Schedule
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/physical_card_create_params.rb,
sig/increase/models/physical_card_create_params.rbs
Overview
When this physical card should be produced by the card printer. The default
timeline is the day after the card printer receives the order, except for
FEDEX_PRIORITY_OVERNIGHT cards, which default to SAME_DAY. To use faster
production methods, please reach out to
support@increase.com.
Constant Summary collapse
- NEXT_DAY =
The physical card will be shipped one business day after the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Wednesday.
:next_day- SAME_DAY =
The physical card will be shipped on the same business day that the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Tuesday.
:same_day
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/physical_card_create_params.rb', line 232
|
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::PhysicalCardCreateParams::Shipment::schedule]
184 |
# File 'sig/increase/models/physical_card_create_params.rbs', line 184
def self?.values: -> ::Array[Increase::Models::PhysicalCardCreateParams::Shipment::schedule]
|