Class: Increase::Models::PhysicalCardProfile::FrontText

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/physical_card_profile.rb,
sig/increase/models/physical_card_profile.rbs

Overview

See Also:

  • Increase::Models::PhysicalCardProfile#front_text

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeFrontText

Returns a new instance of FrontText.

Parameters:

  • line1: (String)
  • line2: (String, nil)


105
# File 'sig/increase/models/physical_card_profile.rbs', line 105

def initialize: (line1: String, line2: String?) -> void

Instance Attribute Details

#line1String

The first line of text on the front of the card.

Parameters:

  • value (String)

Returns:

  • (String)


158
# File 'lib/increase/models/physical_card_profile.rb', line 158

required :line1, String

#line2String?

The second line of text on the front of the card. Providing a second line moves the first line slightly higher and prints the second line in the spot where the first line would have otherwise been printed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


166
# File 'lib/increase/models/physical_card_profile.rb', line 166

required :line2, String, nil?: true

Instance Method Details

#to_hash{ :line1 => String, :line2 => String? }

Returns:

  • ({ :line1 => String, :line2 => String? })


107
# File 'sig/increase/models/physical_card_profile.rbs', line 107

def to_hash: -> { :line1 => String, :line2 => String? }