Module: Increase::Models::PhysicalCardProfile::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/physical_card_profile.rb,
sig/increase/models/physical_card_profile.rbs

Overview

The status of the Physical Card Profile.

See Also:

  • Increase::Models::PhysicalCardProfile#status

Constant Summary collapse

PENDING_CREATING =

The Card Profile has not yet been processed by Increase.

Returns:

  • (:pending_creating)
:pending_creating
PENDING_REVIEWING =

The card profile is awaiting review by Increase.

Returns:

  • (:pending_reviewing)
:pending_reviewing
REJECTED =

There is an issue with the Physical Card Profile preventing it from use.

Returns:

  • (:rejected)
:rejected
PENDING_SUBMITTING =

The card profile is awaiting submission to the fulfillment provider.

Returns:

  • (:pending_submitting)
:pending_submitting
ACTIVE =

The Physical Card Profile has been submitted to the fulfillment provider and is ready to use.

Returns:

  • (:active)
:active
ARCHIVED =

The Physical Card Profile has been archived.

Returns:

  • (:archived)
:archived

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::PhysicalCardProfile::status]

Returns:

  • (::Array[Increase::Models::PhysicalCardProfile::status])


139
# File 'sig/increase/models/physical_card_profile.rbs', line 139

def self?.values: -> ::Array[Increase::Models::PhysicalCardProfile::status]