Class: Increase::Models::Program

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/program.rb

Overview

Defined Under Namespace

Modules: Bank, Type Classes: Lending

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(maximum_extendable_credit:) ⇒ Object

The lending details for the program.

Parameters:

  • maximum_extendable_credit (Integer)

    The maximum extendable credit of the program.



# File 'lib/increase/models/program.rb', line 72


Instance Attribute Details

#bankSymbol, Increase::Models::Program::Bank

The Bank the Program is with.

Returns:



17
# File 'lib/increase/models/program.rb', line 17

required :bank, enum: -> { Increase::Program::Bank }

#billing_account_idString?

The Program billing account.

Returns:

  • (String, nil)


23
# File 'lib/increase/models/program.rb', line 23

required :billing_account_id, String, nil?: true

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Program was created.

Returns:

  • (Time)


30
# File 'lib/increase/models/program.rb', line 30

required :created_at, Time

#default_digital_card_profile_idString?

The default configuration for digital cards attached to this Program.

Returns:

  • (String, nil)


36
# File 'lib/increase/models/program.rb', line 36

required :default_digital_card_profile_id, String, nil?: true

#idString

The Program identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/program.rb', line 11

required :id, String

#interest_rateString

The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as “0.01”.

Returns:

  • (String)


44
# File 'lib/increase/models/program.rb', line 44

required :interest_rate, String

#lendingIncrease::Models::Program::Lending?

The lending details for the program.



50
# File 'lib/increase/models/program.rb', line 50

required :lending, -> { Increase::Program::Lending }, nil?: true

#nameString

The name of the Program.

Returns:

  • (String)


56
# File 'lib/increase/models/program.rb', line 56

required :name, String

#typeSymbol, Increase::Models::Program::Type

A constant representing the object’s type. For this resource it will always be program.

Returns:



63
# File 'lib/increase/models/program.rb', line 63

required :type, enum: -> { Increase::Program::Type }

#updated_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Program was last updated.

Returns:

  • (Time)


70
# File 'lib/increase/models/program.rb', line 70

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/program.rb', line 116