Class: Increase::Models::RealTimeDecision
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision
- Defined in:
- lib/increase/models/real_time_decision.rb
Overview
Defined Under Namespace
Modules: Category, Status, Type Classes: CardAuthentication, CardAuthenticationChallenge, CardAuthorization, CardBalanceInquiry, DigitalWalletAuthentication, DigitalWalletToken
Instance Attribute Summary collapse
-
#card_authentication ⇒ Increase::Models::RealTimeDecision::CardAuthentication?
Fields related to a 3DS authentication attempt.
-
#card_authentication_challenge ⇒ Increase::Models::RealTimeDecision::CardAuthenticationChallenge?
Fields related to a 3DS authentication attempt.
-
#card_authorization ⇒ Increase::Models::RealTimeDecision::CardAuthorization?
Fields related to a card authorization.
-
#card_balance_inquiry ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry?
Fields related to a card balance inquiry.
-
#category ⇒ Symbol, Increase::Models::RealTimeDecision::Category
The category of the Real-Time Decision.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Real-Time Decision was created.
-
#digital_wallet_authentication ⇒ Increase::Models::RealTimeDecision::DigitalWalletAuthentication?
Fields related to a digital wallet authentication attempt.
-
#digital_wallet_token ⇒ Increase::Models::RealTimeDecision::DigitalWalletToken?
Fields related to a digital wallet token provisioning attempt.
-
#id ⇒ String
The Real-Time Decision identifier.
-
#status ⇒ Symbol, Increase::Models::RealTimeDecision::Status
The status of the Real-Time Decision.
-
#timeout_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which your application can no longer respond to the Real-Time Decision.
-
#type ⇒ Symbol, Increase::Models::RealTimeDecision::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(provided_first_name:, provided_last_name:, provided_middle_name:) ⇒ Object
constructor
Cardholder name provided in the authorization request.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(provided_first_name:, provided_last_name:, provided_middle_name:) ⇒ Object
Cardholder name provided in the authorization request.
|
|
# File 'lib/increase/models/real_time_decision.rb', line 86
|
Instance Attribute Details
#card_authentication ⇒ Increase::Models::RealTimeDecision::CardAuthentication?
Fields related to a 3DS authentication attempt.
17 |
# File 'lib/increase/models/real_time_decision.rb', line 17 required :card_authentication, -> { Increase::RealTimeDecision::CardAuthentication }, nil?: true |
#card_authentication_challenge ⇒ Increase::Models::RealTimeDecision::CardAuthenticationChallenge?
Fields related to a 3DS authentication attempt.
23 24 25 |
# File 'lib/increase/models/real_time_decision.rb', line 23 required :card_authentication_challenge, -> { Increase::RealTimeDecision::CardAuthenticationChallenge }, nil?: true |
#card_authorization ⇒ Increase::Models::RealTimeDecision::CardAuthorization?
Fields related to a card authorization.
31 |
# File 'lib/increase/models/real_time_decision.rb', line 31 required :card_authorization, -> { Increase::RealTimeDecision::CardAuthorization }, nil?: true |
#card_balance_inquiry ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry?
Fields related to a card balance inquiry.
37 |
# File 'lib/increase/models/real_time_decision.rb', line 37 required :card_balance_inquiry, -> { Increase::RealTimeDecision::CardBalanceInquiry }, nil?: true |
#category ⇒ Symbol, Increase::Models::RealTimeDecision::Category
The category of the Real-Time Decision.
43 |
# File 'lib/increase/models/real_time_decision.rb', line 43 required :category, enum: -> { Increase::RealTimeDecision::Category } |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Real-Time Decision was created.
50 |
# File 'lib/increase/models/real_time_decision.rb', line 50 required :created_at, Time |
#digital_wallet_authentication ⇒ Increase::Models::RealTimeDecision::DigitalWalletAuthentication?
Fields related to a digital wallet authentication attempt.
56 57 58 |
# File 'lib/increase/models/real_time_decision.rb', line 56 required :digital_wallet_authentication, -> { Increase::RealTimeDecision::DigitalWalletAuthentication }, nil?: true |
#digital_wallet_token ⇒ Increase::Models::RealTimeDecision::DigitalWalletToken?
Fields related to a digital wallet token provisioning attempt.
64 |
# File 'lib/increase/models/real_time_decision.rb', line 64 required :digital_wallet_token, -> { Increase::RealTimeDecision::DigitalWalletToken }, nil?: true |
#id ⇒ String
The Real-Time Decision identifier.
11 |
# File 'lib/increase/models/real_time_decision.rb', line 11 required :id, String |
#status ⇒ Symbol, Increase::Models::RealTimeDecision::Status
The status of the Real-Time Decision.
70 |
# File 'lib/increase/models/real_time_decision.rb', line 70 required :status, enum: -> { Increase::RealTimeDecision::Status } |
#timeout_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which your application can no longer respond to the Real-Time Decision.
77 |
# File 'lib/increase/models/real_time_decision.rb', line 77 required :timeout_at, Time |
#type ⇒ Symbol, Increase::Models::RealTimeDecision::Type
A constant representing the object’s type. For this resource it will always be ‘real_time_decision`.
84 |
# File 'lib/increase/models/real_time_decision.rb', line 84 required :type, enum: -> { Increase::RealTimeDecision::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_decision.rb', line 838
|