Class: Increase::Models::RealTimeDecision::CardAuthentication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb

Overview

Defined Under Namespace

Modules: Decision, RequestorAuthenticationIndicator, RequestorChallengeIndicator Classes: DeviceChannel, MessageCategory

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_control_server_transaction_identifier:, account_id:, billing_address_city:, billing_address_country:, billing_address_line1:, billing_address_line2:, billing_address_line3:, billing_address_postal_code:, billing_address_state:, card_id:, cardholder_email:, cardholder_name:, decision:, device_channel:, directory_server_transaction_identifier:, merchant_acceptor_id:, merchant_category_code:, merchant_country:, merchant_name:, message_category:, prior_authenticated_card_payment_id:, requestor_authentication_indicator:, requestor_challenge_indicator:, requestor_name:, requestor_url:, shipping_address_city:, shipping_address_country:, shipping_address_line1:, shipping_address_line2:, shipping_address_line3:, shipping_address_postal_code:, shipping_address_state:, three_d_secure_server_transaction_identifier:, upcoming_card_payment_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::RealTimeDecision::CardAuthentication for more details.

Fields related to a 3DS authentication attempt.

Parameters:

  • access_control_server_transaction_identifier (String)

    A unique identifier assigned by the Access Control Server (us) for this transact

  • account_id (String)

    The identifier of the Account the card belongs to.

  • billing_address_city (String, nil)

    The city of the cardholder billing address associated with the card used for thi

  • billing_address_country (String, nil)

    The country of the cardholder billing address associated with the card used for

  • billing_address_line1 (String, nil)

    The first line of the cardholder billing address associated with the card used f

  • billing_address_line2 (String, nil)

    The second line of the cardholder billing address associated with the card used

  • billing_address_line3 (String, nil)

    The third line of the cardholder billing address associated with the card used f

  • billing_address_postal_code (String, nil)

    The postal code of the cardholder billing address associated with the card used

  • billing_address_state (String, nil)

    The US state of the cardholder billing address associated with the card used for

  • card_id (String)

    The identifier of the Card.

  • cardholder_email (String, nil)

    The email address of the cardholder.

  • cardholder_name (String, nil)

    The name of the cardholder.

  • decision (Symbol, Increase::Models::RealTimeDecision::CardAuthentication::Decision, nil)

    Whether or not the authentication attempt was approved.

  • device_channel (Increase::Models::RealTimeDecision::CardAuthentication::DeviceChannel)

    The device channel of the card authentication attempt.

  • directory_server_transaction_identifier (String)

    A unique identifier assigned by the Directory Server (the card network) for this

  • merchant_acceptor_id (String, nil)

    The merchant identifier (commonly abbreviated as MID) of the merchant the card i

  • merchant_category_code (String, nil)

    The Merchant Category Code (commonly abbreviated as MCC) of the merchant the car

  • merchant_country (String, nil)

    The country the merchant resides in.

  • merchant_name (String, nil)

    The name of the merchant.

  • message_category (Increase::Models::RealTimeDecision::CardAuthentication::MessageCategory)

    The message category of the card authentication attempt.

  • prior_authenticated_card_payment_id (String, nil)

    The ID of a prior Card Authentication that the requestor used to authenticate th

  • requestor_authentication_indicator (Symbol, Increase::Models::RealTimeDecision::CardAuthentication::RequestorAuthenticationIndicator, nil)

    The 3DS requestor authentication indicator describes why the authentication atte

  • requestor_challenge_indicator (Symbol, Increase::Models::RealTimeDecision::CardAuthentication::RequestorChallengeIndicator, nil)

    Indicates whether a challenge is requested for this transaction.

  • requestor_name (String)

    The name of the 3DS requestor.

  • requestor_url (String)

    The URL of the 3DS requestor.

  • shipping_address_city (String, nil)

    The city of the shipping address associated with this purchase.

  • shipping_address_country (String, nil)

    The country of the shipping address associated with this purchase.

  • shipping_address_line1 (String, nil)

    The first line of the shipping address associated with this purchase.

  • shipping_address_line2 (String, nil)

    The second line of the shipping address associated with this purchase.

  • shipping_address_line3 (String, nil)

    The third line of the shipping address associated with this purchase.

  • shipping_address_postal_code (String, nil)

    The postal code of the shipping address associated with this purchase.

  • shipping_address_state (String, nil)

    The US state of the shipping address associated with this purchase.

  • three_d_secure_server_transaction_identifier (String)

    A unique identifier assigned by the 3DS Server initiating the authentication att

  • upcoming_card_payment_id (String)

    The identifier of the Card Payment this authentication attempt will belong to. A



# File 'lib/increase/models/real_time_decision.rb', line 346

Instance Attribute Details

#access_control_server_transaction_identifierString

A unique identifier assigned by the Access Control Server (us) for this transaction.

Returns:

  • (String)


126
# File 'lib/increase/models/real_time_decision.rb', line 126

required :access_control_server_transaction_identifier, String

#account_idString

The identifier of the Account the card belongs to.

Returns:

  • (String)


132
# File 'lib/increase/models/real_time_decision.rb', line 132

required :account_id, String

#billing_address_cityString?

The city of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


139
# File 'lib/increase/models/real_time_decision.rb', line 139

required :billing_address_city, String, nil?: true

#billing_address_countryString?

The country of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


146
# File 'lib/increase/models/real_time_decision.rb', line 146

required :billing_address_country, String, nil?: true

#billing_address_line1String?

The first line of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


153
# File 'lib/increase/models/real_time_decision.rb', line 153

required :billing_address_line1, String, nil?: true

#billing_address_line2String?

The second line of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


160
# File 'lib/increase/models/real_time_decision.rb', line 160

required :billing_address_line2, String, nil?: true

#billing_address_line3String?

The third line of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


167
# File 'lib/increase/models/real_time_decision.rb', line 167

required :billing_address_line3, String, nil?: true

#billing_address_postal_codeString?

The postal code of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


174
# File 'lib/increase/models/real_time_decision.rb', line 174

required :billing_address_postal_code, String, nil?: true

#billing_address_stateString?

The US state of the cardholder billing address associated with the card used for this purchase.

Returns:

  • (String, nil)


181
# File 'lib/increase/models/real_time_decision.rb', line 181

required :billing_address_state, String, nil?: true

#card_idString

The identifier of the Card.

Returns:

  • (String)


187
# File 'lib/increase/models/real_time_decision.rb', line 187

required :card_id, String

#cardholder_emailString?

The email address of the cardholder.

Returns:

  • (String, nil)


193
# File 'lib/increase/models/real_time_decision.rb', line 193

required :cardholder_email, String, nil?: true

#cardholder_nameString?

The name of the cardholder.

Returns:

  • (String, nil)


199
# File 'lib/increase/models/real_time_decision.rb', line 199

required :cardholder_name, String, nil?: true

#decisionSymbol, ...

Whether or not the authentication attempt was approved.



205
# File 'lib/increase/models/real_time_decision.rb', line 205

required :decision, enum: -> { Increase::RealTimeDecision::CardAuthentication::Decision }, nil?: true

#device_channelIncrease::Models::RealTimeDecision::CardAuthentication::DeviceChannel

The device channel of the card authentication attempt.



211
# File 'lib/increase/models/real_time_decision.rb', line 211

required :device_channel, -> { Increase::RealTimeDecision::CardAuthentication::DeviceChannel }

#directory_server_transaction_identifierString

A unique identifier assigned by the Directory Server (the card network) for this transaction.

Returns:

  • (String)


218
# File 'lib/increase/models/real_time_decision.rb', line 218

required :directory_server_transaction_identifier, String

#merchant_acceptor_idString?

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String, nil)


225
# File 'lib/increase/models/real_time_decision.rb', line 225

required :merchant_acceptor_id, String, nil?: true

#merchant_category_codeString?

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Returns:

  • (String, nil)


232
# File 'lib/increase/models/real_time_decision.rb', line 232

required :merchant_category_code, String, nil?: true

#merchant_countryString?

The country the merchant resides in.

Returns:

  • (String, nil)


238
# File 'lib/increase/models/real_time_decision.rb', line 238

required :merchant_country, String, nil?: true

#merchant_nameString?

The name of the merchant.

Returns:

  • (String, nil)


244
# File 'lib/increase/models/real_time_decision.rb', line 244

required :merchant_name, String, nil?: true

#message_categoryIncrease::Models::RealTimeDecision::CardAuthentication::MessageCategory

The message category of the card authentication attempt.



250
# File 'lib/increase/models/real_time_decision.rb', line 250

required :message_category, -> { Increase::RealTimeDecision::CardAuthentication::MessageCategory }

#prior_authenticated_card_payment_idString?

The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction.

Returns:

  • (String, nil)


257
# File 'lib/increase/models/real_time_decision.rb', line 257

required :prior_authenticated_card_payment_id, String, nil?: true

#requestor_authentication_indicatorSymbol, ...

The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.



264
265
266
267
268
# File 'lib/increase/models/real_time_decision.rb', line 264

required :requestor_authentication_indicator,
enum: -> {
  Increase::RealTimeDecision::CardAuthentication::RequestorAuthenticationIndicator
},
nil?: true

#requestor_challenge_indicatorSymbol, ...

Indicates whether a challenge is requested for this transaction.



274
275
276
# File 'lib/increase/models/real_time_decision.rb', line 274

required :requestor_challenge_indicator,
enum: -> { Increase::RealTimeDecision::CardAuthentication::RequestorChallengeIndicator },
nil?: true

#requestor_nameString

The name of the 3DS requestor.

Returns:

  • (String)


282
# File 'lib/increase/models/real_time_decision.rb', line 282

required :requestor_name, String

#requestor_urlString

The URL of the 3DS requestor.

Returns:

  • (String)


288
# File 'lib/increase/models/real_time_decision.rb', line 288

required :requestor_url, String

#shipping_address_cityString?

The city of the shipping address associated with this purchase.

Returns:

  • (String, nil)


294
# File 'lib/increase/models/real_time_decision.rb', line 294

required :shipping_address_city, String, nil?: true

#shipping_address_countryString?

The country of the shipping address associated with this purchase.

Returns:

  • (String, nil)


300
# File 'lib/increase/models/real_time_decision.rb', line 300

required :shipping_address_country, String, nil?: true

#shipping_address_line1String?

The first line of the shipping address associated with this purchase.

Returns:

  • (String, nil)


306
# File 'lib/increase/models/real_time_decision.rb', line 306

required :shipping_address_line1, String, nil?: true

#shipping_address_line2String?

The second line of the shipping address associated with this purchase.

Returns:

  • (String, nil)


312
# File 'lib/increase/models/real_time_decision.rb', line 312

required :shipping_address_line2, String, nil?: true

#shipping_address_line3String?

The third line of the shipping address associated with this purchase.

Returns:

  • (String, nil)


318
# File 'lib/increase/models/real_time_decision.rb', line 318

required :shipping_address_line3, String, nil?: true

#shipping_address_postal_codeString?

The postal code of the shipping address associated with this purchase.

Returns:

  • (String, nil)


324
# File 'lib/increase/models/real_time_decision.rb', line 324

required :shipping_address_postal_code, String, nil?: true

#shipping_address_stateString?

The US state of the shipping address associated with this purchase.

Returns:

  • (String, nil)


330
# File 'lib/increase/models/real_time_decision.rb', line 330

required :shipping_address_state, String, nil?: true

#three_d_secure_server_transaction_identifierString

A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction.

Returns:

  • (String)


337
# File 'lib/increase/models/real_time_decision.rb', line 337

required :three_d_secure_server_transaction_identifier, String

#upcoming_card_payment_idString

The identifier of the Card Payment this authentication attempt will belong to. Available in the API once the card authentication has completed.

Returns:

  • (String)


344
# File 'lib/increase/models/real_time_decision.rb', line 344

required :upcoming_card_payment_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 435