Class: Increase::Models::RealTimeDecision::CardAuthentication::MessageCategory::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecision::CardAuthentication::MessageCategory#payment

Defined Under Namespace

Modules: TransactionType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(purchase_amount:, purchase_amount_cardholder_estimated:, purchase_currency:, transaction_type:) ⇒ Object

Fields specific to payment authentication attempts.

Parameters:

  • purchase_amount (Integer)

    The purchase amount in minor units.

  • purchase_amount_cardholder_estimated (Integer, nil)

    The purchase amount in the cardholder's currency (i.e., USD) estimated using daily conversion rates from the card network.

  • purchase_currency (String)

    The ISO 4217 code for the authentication attempt's purchase currency.

  • transaction_type (Symbol, Increase::Models::RealTimeDecision::CardAuthentication::MessageCategory::Payment::TransactionType, nil)

    The type of transaction being authenticated.



# File 'lib/increase/models/real_time_decision.rb', line 782

Instance Attribute Details

#purchase_amountInteger

The purchase amount in minor units.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


756
# File 'lib/increase/models/real_time_decision.rb', line 756

required :purchase_amount, Integer

#purchase_amount_cardholder_estimatedInteger?

The purchase amount in the cardholder's currency (i.e., USD) estimated using daily conversion rates from the card network.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


763
# File 'lib/increase/models/real_time_decision.rb', line 763

required :purchase_amount_cardholder_estimated, Integer, nil?: true

#purchase_currencyString

The ISO 4217 code for the authentication attempt's purchase currency.

Parameters:

  • value (String)

Returns:

  • (String)


770
# File 'lib/increase/models/real_time_decision.rb', line 770

required :purchase_currency, String

#transaction_typeSymbol, ...

The type of transaction being authenticated.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardAuthentication::MessageCategory::Payment::transaction_type, nil)

Returns:



776
777
778
779
780
# File 'lib/increase/models/real_time_decision.rb', line 776

required :transaction_type,
enum: -> {
  Increase::RealTimeDecision::CardAuthentication::MessageCategory::Payment::TransactionType
},
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


540
# File 'sig/increase/models/real_time_decision.rbs', line 540

def to_hash: -> {