Module: Increase::Models::RealTimeDecision::CardAuthentication::RequestorAuthenticationIndicator

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/real_time_decision.rb

Overview

The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.

Constant Summary collapse

PAYMENT_TRANSACTION =

The authentication is for a payment transaction.

:payment_transaction
RECURRING_TRANSACTION =

The authentication is for a recurring transaction.

:recurring_transaction
INSTALLMENT_TRANSACTION =

The authentication is for an installment transaction.

:installment_transaction
ADD_CARD =

The authentication is for adding a card.

:add_card
MAINTAIN_CARD =

The authentication is for maintaining a card.

:maintain_card
EMV_TOKEN_CARDHOLDER_VERIFICATION =

The authentication is for EMV token cardholder verification.

:emv_token_cardholder_verification
BILLING_AGREEMENT =

The authentication is for a billing agreement.

:billing_agreement

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info