Class: Increase::Models::RealTimeDecision::CardAuthorization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecision#card_authorization

Defined Under Namespace

Modules: Decision, Direction, PartialApprovalCapability, ProcessingCategory Classes: AdditionalAmounts, Approval, Decline, Healthcare, NetworkDetails, NetworkIdentifiers, RequestDetails, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Fields specific to the category initial_authorization.



# File 'lib/increase/models/real_time_decision.rb', line 1184

Instance Attribute Details

#account_idString

The identifier of the Account the authorization will debit.

Parameters:

  • value (String)

Returns:

  • (String)


975
# File 'lib/increase/models/real_time_decision.rb', line 975

required :account_id, String

#additional_amountsIncrease::Models::RealTimeDecision::CardAuthorization::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::AdditionalAmounts)

Returns:



983
# File 'lib/increase/models/real_time_decision.rb', line 983

required :additional_amounts, -> { Increase::RealTimeDecision::CardAuthorization::AdditionalAmounts }

#approvalIncrease::Models::RealTimeDecision::CardAuthorization::Approval?

Present if and only if decision is approve. Contains information related to the approval of the authorization.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::Approval, nil)

Returns:



990
# File 'lib/increase/models/real_time_decision.rb', line 990

required :approval, -> { Increase::RealTimeDecision::CardAuthorization::Approval }, nil?: true

#card_idString

The identifier of the Card that is being authorized.

Parameters:

  • value (String)

Returns:

  • (String)


996
# File 'lib/increase/models/real_time_decision.rb', line 996

required :card_id, String

#decisionSymbol, ...

Whether or not the authorization was approved.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardAuthorization::decision, nil)

Returns:



1002
# File 'lib/increase/models/real_time_decision.rb', line 1002

required :decision, enum: -> { Increase::RealTimeDecision::CardAuthorization::Decision }, nil?: true

#declineIncrease::Models::RealTimeDecision::CardAuthorization::Decline?

Present if and only if decision is decline. Contains information related to the reason the authorization was declined.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::Decline, nil)

Returns:



1009
# File 'lib/increase/models/real_time_decision.rb', line 1009

required :decline, -> { Increase::RealTimeDecision::CardAuthorization::Decline }, nil?: true

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1016
# File 'lib/increase/models/real_time_decision.rb', line 1016

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::RealTimeDecision::CardAuthorization::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardAuthorization::direction)

Returns:



1023
# File 'lib/increase/models/real_time_decision.rb', line 1023

required :direction, enum: -> { Increase::RealTimeDecision::CardAuthorization::Direction }

#healthcareIncrease::Models::RealTimeDecision::CardAuthorization::Healthcare?

The healthcare-related fields for this authorization. Only present for specific programs.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::Healthcare, nil)

Returns:



1030
# File 'lib/increase/models/real_time_decision.rb', line 1030

required :healthcare, -> { Increase::RealTimeDecision::CardAuthorization::Healthcare }, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1037
# File 'lib/increase/models/real_time_decision.rb', line 1037

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1044
# File 'lib/increase/models/real_time_decision.rb', line 1044

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1050
# File 'lib/increase/models/real_time_decision.rb', line 1050

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


1056
# File 'lib/increase/models/real_time_decision.rb', line 1056

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1062
# File 'lib/increase/models/real_time_decision.rb', line 1062

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1069
# File 'lib/increase/models/real_time_decision.rb', line 1069

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1075
# File 'lib/increase/models/real_time_decision.rb', line 1075

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::RealTimeDecision::CardAuthorization::NetworkDetails

Fields specific to the network.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::NetworkDetails)

Returns:



1081
# File 'lib/increase/models/real_time_decision.rb', line 1081

required :network_details, -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails }

#network_identifiersIncrease::Models::RealTimeDecision::CardAuthorization::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::NetworkIdentifiers)

Returns:



1087
# File 'lib/increase/models/real_time_decision.rb', line 1087

required :network_identifiers, -> { Increase::RealTimeDecision::CardAuthorization::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


1095
# File 'lib/increase/models/real_time_decision.rb', line 1095

required :network_risk_score, Integer, nil?: true

#original_card_payment_idString?

The identifier of the Card Payment containing the original authorization or card validation this transaction references. For a merchant-initiated transaction, this is the Card Payment from when the card was first stored, which is typically where the CVV2 was verified. The reference this is derived from is supplied by the merchant or their acquirer, so it is not guaranteed to be present.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1105
# File 'lib/increase/models/real_time_decision.rb', line 1105

required :original_card_payment_id, String, nil?: true

#partial_approval_capabilitySymbol, Increase::Models::RealTimeDecision::CardAuthorization::PartialApprovalCapability

Whether or not the authorization supports partial approvals.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardAuthorization::partial_approval_capability)

Returns:



1111
1112
# File 'lib/increase/models/real_time_decision.rb', line 1111

required :partial_approval_capability,
enum: -> { Increase::RealTimeDecision::CardAuthorization::PartialApprovalCapability }

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1119
# File 'lib/increase/models/real_time_decision.rb', line 1119

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1127
# File 'lib/increase/models/real_time_decision.rb', line 1127

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the currency the user sees at the time of purchase.

Parameters:

  • value (String)

Returns:

  • (String)


1134
# File 'lib/increase/models/real_time_decision.rb', line 1134

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::RealTimeDecision::CardAuthorization::ProcessingCategory

The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardAuthorization::processing_category)

Returns:



1141
1142
# File 'lib/increase/models/real_time_decision.rb', line 1141

required :processing_category,
enum: -> { Increase::RealTimeDecision::CardAuthorization::ProcessingCategory }

#request_detailsIncrease::Models::RealTimeDecision::CardAuthorization::RequestDetails

Fields specific to the type of request, such as an incremental authorization.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::RequestDetails)

Returns:



1148
# File 'lib/increase/models/real_time_decision.rb', line 1148

required :request_details, -> { Increase::RealTimeDecision::CardAuthorization::RequestDetails }

#settlement_amountInteger

The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1155
# File 'lib/increase/models/real_time_decision.rb', line 1155

required :settlement_amount, Integer

#settlement_currencyString

The ISO 4217 code for the currency the transaction will be settled in.

Parameters:

  • value (String)

Returns:

  • (String)


1162
# File 'lib/increase/models/real_time_decision.rb', line 1162

required :settlement_currency, String

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1169
# File 'lib/increase/models/real_time_decision.rb', line 1169

required :terminal_id, String, nil?: true

#upcoming_card_payment_idString

The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.

Parameters:

  • value (String)

Returns:

  • (String)


1176
# File 'lib/increase/models/real_time_decision.rb', line 1176

required :upcoming_card_payment_id, String

#verificationIncrease::Models::RealTimeDecision::CardAuthorization::Verification

Fields related to verification of cardholder-provided values.

Parameters:

  • value (Increase::RealTimeDecision::CardAuthorization::Verification)

Returns:



1182
# File 'lib/increase/models/real_time_decision.rb', line 1182

required :verification, -> { Increase::RealTimeDecision::CardAuthorization::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 1747

Instance Method Details

#to_hash{

Returns:

  • ({)


841
# File 'sig/increase/models/real_time_decision.rbs', line 841

def to_hash: -> {