Class: Increase::Models::RealTimeDecision::CardAuthorization::AdditionalAmounts::Original

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecision::CardAuthorization::AdditionalAmounts#original

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeOriginal

Returns a new instance of Original.

Parameters:

  • amount: (Integer)
  • currency: (String)


962
# File 'sig/increase/models/real_time_decision.rbs', line 962

def initialize: (amount: Integer, currency: String) -> void

Instance Attribute Details

#amountInteger

The amount in minor units of the currency field. The amount is positive if it is added to the amount (such as an ATM surcharge fee) and negative if it is subtracted from the amount (such as a discount).

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1362
# File 'lib/increase/models/real_time_decision.rb', line 1362

required :amount, Integer

#currencyString

The ISO 4217 code for the additional amount's currency.

Parameters:

  • value (String)

Returns:

  • (String)


1369
# File 'lib/increase/models/real_time_decision.rb', line 1369

required :currency, String

Instance Method Details

#to_hash{ amount: Integer, currency: String }

Returns:

  • ({ amount: Integer, currency: String })


964
# File 'sig/increase/models/real_time_decision.rbs', line 964

def to_hash: -> { amount: Integer, currency: String }