Class: Increase::Models::RealTimeDecision::CardAuthorization::NetworkDetails::Visa
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::CardAuthorization::NetworkDetails::Visa
- Defined in:
- lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs
Overview
Defined Under Namespace
Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability
Instance Attribute Summary collapse
-
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential.
-
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder's primary account number and card expiration date.
-
#stand_in_processing_reason ⇒ Symbol, ...
Only present when
actioner: network. -
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
constructor
Fields specific to the
visanetwork. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
Fields specific to the visa network.
|
|
# File 'lib/increase/models/real_time_decision.rb', line 1966
|
Instance Attribute Details
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
1924 1925 1926 1927 1928 |
# File 'lib/increase/models/real_time_decision.rb', line 1924 required :electronic_commerce_indicator, enum: -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::ElectronicCommerceIndicator }, nil?: true |
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder's primary account number and card expiration date.
1935 1936 1937 1938 1939 |
# File 'lib/increase/models/real_time_decision.rb', line 1935 required :point_of_service_entry_mode, enum: -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::PointOfServiceEntryMode }, nil?: true |
#stand_in_processing_reason ⇒ Symbol, ...
Only present when actioner: network. Describes why a card authorization was
approved or declined by Visa through stand-in processing.
1946 1947 1948 1949 1950 |
# File 'lib/increase/models/real_time_decision.rb', line 1946 required :stand_in_processing_reason, enum: -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::StandInProcessingReason }, nil?: true |
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
1960 1961 1962 1963 1964 |
# File 'lib/increase/models/real_time_decision.rb', line 1960 required :terminal_entry_capability, enum: -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::TerminalEntryCapability }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_decision.rb', line 2022
|
Instance Method Details
#to_hash ⇒ {
1247 |
# File 'sig/increase/models/real_time_decision.rbs', line 1247
def to_hash: -> {
|