Class: Increase::Models::RealTimeDecision::CardAuthorization::RequestDetails::IncrementalAuthorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::CardAuthorization::RequestDetails::IncrementalAuthorization
- Defined in:
- lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs
Overview
Instance Attribute Summary collapse
-
#card_payment_id ⇒ String
The card payment for this authorization and increment.
-
#original_card_authorization_id ⇒ String
The identifier of the card authorization this request is attempting to increment.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1565 |
# File 'sig/increase/models/real_time_decision.rbs', line 1565
def initialize: (
|
Instance Attribute Details
#card_payment_id ⇒ String
The card payment for this authorization and increment.
2174 |
# File 'lib/increase/models/real_time_decision.rb', line 2174 required :card_payment_id, String |
#original_card_authorization_id ⇒ String
The identifier of the card authorization this request is attempting to increment.
2181 |
# File 'lib/increase/models/real_time_decision.rb', line 2181 required :original_card_authorization_id, String |
Instance Method Details
#to_hash ⇒ {
1570 |
# File 'sig/increase/models/real_time_decision.rbs', line 1570
def to_hash: -> {
|