Class: Increase::Models::RealTimeDecision::CardAuthorization::Verification::CardholderName
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::CardAuthorization::Verification::CardholderName
- Defined in:
- lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs
Overview
Instance Attribute Summary collapse
-
#provided_first_name ⇒ String?
The first name provided for verification in the authorization request.
-
#provided_last_name ⇒ String?
The last name provided for verification in the authorization request.
-
#provided_middle_name ⇒ String?
The middle name provided for verification in the authorization request.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1728 |
# File 'sig/increase/models/real_time_decision.rbs', line 1728
def initialize: (
|
Instance Attribute Details
#provided_first_name ⇒ String?
The first name provided for verification in the authorization request.
2363 |
# File 'lib/increase/models/real_time_decision.rb', line 2363 required :provided_first_name, String, nil?: true |
#provided_last_name ⇒ String?
The last name provided for verification in the authorization request.
2369 |
# File 'lib/increase/models/real_time_decision.rb', line 2369 required :provided_last_name, String, nil?: true |
#provided_middle_name ⇒ String?
The middle name provided for verification in the authorization request.
2375 |
# File 'lib/increase/models/real_time_decision.rb', line 2375 required :provided_middle_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
1734 |
# File 'sig/increase/models/real_time_decision.rbs', line 1734
def to_hash: -> {
|