Class: Increase::Models::RealTimeDecision::CardBalanceInquiry::Approval

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecision::CardBalanceInquiry#approval

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeApproval

Returns a new instance of Approval.

Parameters:

  • balance: (Integer)


2041
# File 'sig/increase/models/real_time_decision.rbs', line 2041

def initialize: (balance: Integer) -> void

Instance Attribute Details

#balanceInteger

If the balance inquiry was approved, this field contains the balance in the minor unit of the settlement currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


2978
# File 'lib/increase/models/real_time_decision.rb', line 2978

required :balance, Integer

Instance Method Details

#to_hash{ balance: Integer }

Returns:

  • ({ balance: Integer })


2043
# File 'sig/increase/models/real_time_decision.rbs', line 2043

def to_hash: -> { balance: Integer }