Class: Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails#visa

Defined Under Namespace

Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object

Fields specific to the visa network.

Parameters:



# File 'lib/increase/models/real_time_decision.rb', line 3304

Instance Attribute Details

#electronic_commerce_indicatorSymbol, ...

For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::electronic_commerce_indicator, nil)

Returns:



3262
3263
3264
3265
3266
# File 'lib/increase/models/real_time_decision.rb', line 3262

required :electronic_commerce_indicator,
enum: -> {
  Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::ElectronicCommerceIndicator
},
nil?: true

#point_of_service_entry_modeSymbol, ...

The method used to enter the cardholder's primary account number and card expiration date.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::point_of_service_entry_mode, nil)

Returns:



3273
3274
3275
3276
3277
# File 'lib/increase/models/real_time_decision.rb', line 3273

required :point_of_service_entry_mode,
enum: -> {
  Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::PointOfServiceEntryMode
},
nil?: true

#stand_in_processing_reasonSymbol, ...

Only present when actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::stand_in_processing_reason, nil)

Returns:



3284
3285
3286
3287
3288
# File 'lib/increase/models/real_time_decision.rb', line 3284

required :stand_in_processing_reason,
enum: -> {
  Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::StandInProcessingReason
},
nil?: true

#terminal_entry_capabilitySymbol, ...

The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::terminal_entry_capability, nil)

Returns:



3298
3299
3300
3301
3302
# File 'lib/increase/models/real_time_decision.rb', line 3298

required :terminal_entry_capability,
enum: -> {
  Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails::Visa::TerminalEntryCapability
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 3360

Instance Method Details

#to_hash{

Returns:

  • ({)


2137
# File 'sig/increase/models/real_time_decision.rbs', line 2137

def to_hash: -> {