Class: Increase::Models::RealTimeDecision::DigitalWalletAuthentication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb

Overview

Defined Under Namespace

Modules: Channel, DigitalWallet, Result

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_id:, channel:, digital_wallet:, email:, one_time_passcode:, phone:, result:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::RealTimeDecision::DigitalWalletAuthentication for more details.

Fields related to a digital wallet authentication attempt.

Parameters:



# File 'lib/increase/models/real_time_decision.rb', line 3544

Instance Attribute Details

#card_idString

The identifier of the Card that is being tokenized.

Returns:

  • (String)


3500
# File 'lib/increase/models/real_time_decision.rb', line 3500

required :card_id, String

#channelSymbol, Increase::Models::RealTimeDecision::DigitalWalletAuthentication::Channel

The channel to send the card user their one-time passcode.



3506
# File 'lib/increase/models/real_time_decision.rb', line 3506

required :channel, enum: -> { Increase::RealTimeDecision::DigitalWalletAuthentication::Channel }

#digital_walletSymbol, Increase::Models::RealTimeDecision::DigitalWalletAuthentication::DigitalWallet

The digital wallet app being used.



3512
3513
# File 'lib/increase/models/real_time_decision.rb', line 3512

required :digital_wallet,
enum: -> { Increase::RealTimeDecision::DigitalWalletAuthentication::DigitalWallet }

#emailString?

The email to send the one-time passcode to if ‘channel` is equal to `email`.

Returns:

  • (String, nil)


3519
# File 'lib/increase/models/real_time_decision.rb', line 3519

required :email, String, nil?: true

#one_time_passcodeString

The one-time passcode to send the card user.

Returns:

  • (String)


3525
# File 'lib/increase/models/real_time_decision.rb', line 3525

required :one_time_passcode, String

#phoneString?

The phone number to send the one-time passcode to if ‘channel` is equal to `sms`.

Returns:

  • (String, nil)


3532
# File 'lib/increase/models/real_time_decision.rb', line 3532

required :phone, String, nil?: true

#resultSymbol, ...

Whether your application successfully delivered the one-time passcode.



3538
3539
3540
3541
3542
# File 'lib/increase/models/real_time_decision.rb', line 3538

required :result,
enum: -> {
  Increase::RealTimeDecision::DigitalWalletAuthentication::Result
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 3577