Class: Increase::Models::RealTimeDecision::DigitalWalletToken::Device
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::DigitalWalletToken::Device
- Defined in:
- lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs
Overview
Instance Attribute Summary collapse
-
#identifier ⇒ String?
ID assigned to the device by the digital wallet provider.
Instance Method Summary collapse
-
#initialize ⇒ Device
constructor
A new instance of Device.
- #to_hash ⇒ { identifier: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Device
Returns a new instance of Device.
2676 |
# File 'sig/increase/models/real_time_decision.rbs', line 2676
def initialize: (identifier: String?) -> void
|
Instance Attribute Details
#identifier ⇒ String?
ID assigned to the device by the digital wallet provider.
3738 |
# File 'lib/increase/models/real_time_decision.rb', line 3738 required :identifier, String, nil?: true |
Instance Method Details
#to_hash ⇒ { identifier: String? }
2678 |
# File 'sig/increase/models/real_time_decision.rbs', line 2678
def to_hash: -> { identifier: String? }
|