Class: Increase::Models::RealTimeDecisionActionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecisionActionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/real_time_decision_action_params.rb
Overview
Defined Under Namespace
Classes: CardAuthentication, CardAuthenticationChallenge, CardAuthorization, CardBalanceInquiry, DigitalWalletAuthentication, DigitalWalletToken
Instance Attribute Summary collapse
-
#card_authentication ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthentication?
If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication.
-
#card_authentication_challenge ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge?
If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response.
-
#card_authorization ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthorization?
If the Real-Time Decision relates to a card authorization attempt, this object contains your response to the authorization.
-
#card_balance_inquiry ⇒ Increase::Models::RealTimeDecisionActionParams::CardBalanceInquiry?
If the Real-Time Decision relates to a card balance inquiry attempt, this object contains your response to the inquiry.
-
#digital_wallet_authentication ⇒ Increase::Models::RealTimeDecisionActionParams::DigitalWalletAuthentication?
If the Real-Time Decision relates to a digital wallet authentication attempt, this object contains your response to the authentication.
-
#digital_wallet_token ⇒ Increase::Models::RealTimeDecisionActionParams::DigitalWalletToken?
If the Real-Time Decision relates to a digital wallet token provisioning attempt, this object contains your response to the attempt.
-
#real_time_decision_id ⇒ String
The identifier of the Real-Time Decision.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(email: nil, phone: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DigitalWalletAuthentication::Success for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email: nil, phone: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::RealTimeDecisionActionParams::DigitalWalletAuthentication::Success for more details.
If your application was able to deliver the one-time passcode, this contains metadata about the delivery. Exactly one of ‘phone` or `email` must be provided.
|
|
# File 'lib/increase/models/real_time_decision_action_params.rb', line 172
|
Instance Attribute Details
#card_authentication ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthentication?
If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication.
21 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 21 optional :card_authentication, -> { Increase::RealTimeDecisionActionParams::CardAuthentication } |
#card_authentication_challenge ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge?
If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response.
28 29 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 28 optional :card_authentication_challenge, -> { Increase::RealTimeDecisionActionParams::CardAuthenticationChallenge } |
#card_authorization ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthorization?
If the Real-Time Decision relates to a card authorization attempt, this object contains your response to the authorization.
36 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 36 optional :card_authorization, -> { Increase::RealTimeDecisionActionParams::CardAuthorization } |
#card_balance_inquiry ⇒ Increase::Models::RealTimeDecisionActionParams::CardBalanceInquiry?
If the Real-Time Decision relates to a card balance inquiry attempt, this object contains your response to the inquiry.
43 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 43 optional :card_balance_inquiry, -> { Increase::RealTimeDecisionActionParams::CardBalanceInquiry } |
#digital_wallet_authentication ⇒ Increase::Models::RealTimeDecisionActionParams::DigitalWalletAuthentication?
If the Real-Time Decision relates to a digital wallet authentication attempt, this object contains your response to the authentication.
50 51 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 50 optional :digital_wallet_authentication, -> { Increase::RealTimeDecisionActionParams::DigitalWalletAuthentication } |
#digital_wallet_token ⇒ Increase::Models::RealTimeDecisionActionParams::DigitalWalletToken?
If the Real-Time Decision relates to a digital wallet token provisioning attempt, this object contains your response to the attempt.
58 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 58 optional :digital_wallet_token, -> { Increase::RealTimeDecisionActionParams::DigitalWalletToken } |
#real_time_decision_id ⇒ String
The identifier of the Real-Time Decision.
14 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 14 required :real_time_decision_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_decision_action_params.rb', line 108
|