Class: Increase::Models::RealTimeDecisionActionParams::CardAuthentication

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision_action_params.rb,
sig/increase/models/real_time_decision_action_params.rbs

Defined Under Namespace

Modules: Decision

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(decision:) ⇒ Object

If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication.

Parameters:

  • Whether the card authentication attempt should be approved or declined.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/increase/models/real_time_decision_action_params.rb', line 89

class CardAuthentication < Increase::Internal::Type::BaseModel
  # @!attribute decision
  #   Whether the card authentication attempt should be approved or declined.
  #
  #   @return [Symbol, Increase::Models::RealTimeDecisionActionParams::CardAuthentication::Decision]
  required :decision, enum: -> { Increase::RealTimeDecisionActionParams::CardAuthentication::Decision }

  # @!method initialize(decision:)
  #   If the Real-Time Decision relates to a 3DS card authentication attempt, this
  #   object contains your response to the authentication.
  #
  #   @param decision [Symbol, Increase::Models::RealTimeDecisionActionParams::CardAuthentication::Decision]
  #     Whether the card authentication attempt should be approved or declined.

  # Whether the card authentication attempt should be approved or declined.
  #
  # @see Increase::Models::RealTimeDecisionActionParams::CardAuthentication#decision
  module Decision
    extend Increase::Internal::Type::Enum

    # Approve the authentication attempt without triggering a challenge.
    APPROVE = :approve

    # Request further validation before approving the authentication attempt.
    CHALLENGE = :challenge

    # Deny the authentication attempt.
    DENY = :deny

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#decisionSymbol, Increase::Models::RealTimeDecisionActionParams::CardAuthentication::Decision

Whether the card authentication attempt should be approved or declined.

Parameters:

Returns:



94
# File 'lib/increase/models/real_time_decision_action_params.rb', line 94

required :decision, enum: -> { Increase::RealTimeDecisionActionParams::CardAuthentication::Decision }

Instance Method Details

#to_hash{

Returns:



91
# File 'sig/increase/models/real_time_decision_action_params.rbs', line 91

def to_hash: -> {