Class: Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge
- Defined in:
- lib/increase/models/real_time_decision_action_params.rb
Defined Under Namespace
Modules: Result Classes: Success
Instance Attribute Summary collapse
-
#result ⇒ Symbol, Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge::Result
Whether the card authentication challenge was successfully delivered to the cardholder.
-
#success ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge::Success?
If your application was able to deliver the one-time code, this contains metadata about the delivery.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(result:, success: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardAuthenticationChallenge for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(result:, success: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge for more details.
If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response.
|
|
# File 'lib/increase/models/real_time_decision_action_params.rb', line 128
|
Instance Attribute Details
#result ⇒ Symbol, Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge::Result
Whether the card authentication challenge was successfully delivered to the cardholder.
119 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 119 required :result, enum: -> { Increase::RealTimeDecisionActionParams::CardAuthenticationChallenge::Result } |
#success ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthenticationChallenge::Success?
If your application was able to deliver the one-time code, this contains metadata about the delivery.
126 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 126 optional :success, -> { Increase::RealTimeDecisionActionParams::CardAuthenticationChallenge::Success } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_decision_action_params.rb', line 153
|