Module: Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Decline::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/real_time_decision_action_params.rb,
sig/increase/models/real_time_decision_action_params.rbs

Overview

The reason the card authorization was declined. This translates to a specific decline code that is sent to the card network.

See Also:

  • Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Decline#reason

Constant Summary collapse

INSUFFICIENT_FUNDS =

The cardholder does not have sufficient funds to cover the transaction. The merchant may attempt to process the transaction again.

Returns:

  • (:insufficient_funds)
:insufficient_funds
TRANSACTION_NEVER_ALLOWED =

This type of transaction is not allowed for this card. This transaction should not be retried.

Returns:

  • (:transaction_never_allowed)
:transaction_never_allowed
EXCEEDS_APPROVAL_LIMIT =

The transaction amount exceeds the cardholder's approval limit. The merchant may attempt to process the transaction again.

Returns:

  • (:exceeds_approval_limit)
:exceeds_approval_limit
CARD_TEMPORARILY_DISABLED =

The card has been temporarily disabled or not yet activated. The merchant may attempt to process the transaction again.

Returns:

  • (:card_temporarily_disabled)
:card_temporarily_disabled
SUSPECTED_FRAUD =

The transaction is suspected to be fraudulent. The merchant may attempt to process the transaction again.

Returns:

  • (:suspected_fraud)
:suspected_fraud
OTHER =

The transaction was declined for another reason. The merchant may attempt to process the transaction again. This should be used sparingly.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Decline::reason]

Returns:

  • (::Array[Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Decline::reason])


340
# File 'sig/increase/models/real_time_decision_action_params.rbs', line 340

def self?.values: -> ::Array[Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Decline::reason]