Class: Increase::Models::RealTimeDecisionActionParams::CardBalanceInquiry::Approval
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecisionActionParams::CardBalanceInquiry::Approval
- Defined in:
- lib/increase/models/real_time_decision_action_params.rb,
sig/increase/models/real_time_decision_action_params.rbs
Overview
Instance Attribute Summary collapse
-
#balance ⇒ Integer
The balance on the card in the settlement currency of the transaction.
Instance Method Summary collapse
-
#initialize ⇒ Approval
constructor
A new instance of Approval.
- #to_hash ⇒ { balance: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Approval
Returns a new instance of Approval.
389 |
# File 'sig/increase/models/real_time_decision_action_params.rbs', line 389
def initialize: (balance: Integer) -> void
|
Instance Attribute Details
#balance ⇒ Integer
The balance on the card in the settlement currency of the transaction.
436 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 436 required :balance, Integer |
Instance Method Details
#to_hash ⇒ { balance: Integer }
391 |
# File 'sig/increase/models/real_time_decision_action_params.rbs', line 391
def to_hash: -> { balance: Integer }
|