Class: Increase::Models::RealTimeDecisionActionParams::DigitalWalletToken::Approval

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision_action_params.rb,
sig/increase/models/real_time_decision_action_params.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecisionActionParams::DigitalWalletToken#approval

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeApproval

Returns a new instance of Approval.

Parameters:

  • email: (String)
  • phone: (String)


491
# File 'sig/increase/models/real_time_decision_action_params.rbs', line 491

def initialize: (?email: String, ?phone: String) -> void

Instance Attribute Details

#emailString?

An email address that can be used to verify the cardholder via one-time passcode.

Parameters:

  • (String)

Returns:

  • (String, nil)


551
# File 'lib/increase/models/real_time_decision_action_params.rb', line 551

optional :email, String

#phoneString?

A phone number that can be used to verify the cardholder via one-time passcode over SMS.

Parameters:

  • (String)

Returns:

  • (String, nil)


558
# File 'lib/increase/models/real_time_decision_action_params.rb', line 558

optional :phone, String

Instance Method Details

#to_hash{ email: String, phone: String }

Returns:

  • ({ email: String, phone: String })


493
# File 'sig/increase/models/real_time_decision_action_params.rbs', line 493

def to_hash: -> { email: String, phone: String }