Class: Increase::Models::RealTimePaymentsTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_payments_transfer.rb

Overview

Defined Under Namespace

Modules: Currency, Status, Type Classes: Acknowledgement, Approval, Cancellation, CreatedBy, Rejection, Submission

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(submitted_at:, transaction_identification:) ⇒ Object

Some parameter documentations has been truncated, see Submission for more details.

After the transfer is submitted to Real-Time Payments, this will contain supplemental details.

Parameters:

  • submitted_at (Time, nil)

    The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which th

  • transaction_identification (String)

    The Real-Time Payments network identification of the transfer.



# File 'lib/increase/models/real_time_payments_transfer.rb', line 175

Instance Attribute Details

#account_idString

The Account from which the transfer was sent.

Returns:

  • (String)


17
# File 'lib/increase/models/real_time_payments_transfer.rb', line 17

required :account_id, String

#account_numberString

The destination account number.

Returns:

  • (String)


23
# File 'lib/increase/models/real_time_payments_transfer.rb', line 23

required :account_number, String

#acknowledgementIncrease::Models::RealTimePaymentsTransfer::Acknowledgement?

If the transfer is acknowledged by the recipient bank, this will contain supplemental details.



30
# File 'lib/increase/models/real_time_payments_transfer.rb', line 30

required :acknowledgement, -> { Increase::RealTimePaymentsTransfer::Acknowledgement }, nil?: true

#amountInteger

The transfer amount in USD cents.

Returns:

  • (Integer)


36
# File 'lib/increase/models/real_time_payments_transfer.rb', line 36

required :amount, Integer

#approvalIncrease::Models::RealTimePaymentsTransfer::Approval?

If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.



43
# File 'lib/increase/models/real_time_payments_transfer.rb', line 43

required :approval, -> { Increase::RealTimePaymentsTransfer::Approval }, nil?: true

#cancellationIncrease::Models::RealTimePaymentsTransfer::Cancellation?

If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.



50
# File 'lib/increase/models/real_time_payments_transfer.rb', line 50

required :cancellation, -> { Increase::RealTimePaymentsTransfer::Cancellation }, nil?: true

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.

Returns:

  • (Time)


57
# File 'lib/increase/models/real_time_payments_transfer.rb', line 57

required :created_at, Time

#created_byIncrease::Models::RealTimePaymentsTransfer::CreatedBy?

What object created the transfer, either via the API or the dashboard.



63
# File 'lib/increase/models/real_time_payments_transfer.rb', line 63

required :created_by, -> { Increase::RealTimePaymentsTransfer::CreatedBy }, nil?: true

#creditor_nameString

The name of the transfer’s recipient. This is set by the sender when creating the transfer.

Returns:

  • (String)


70
# File 'lib/increase/models/real_time_payments_transfer.rb', line 70

required :creditor_name, String

#currencySymbol, Increase::Models::RealTimePaymentsTransfer::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transfer’s currency. For real-time payments transfers this is always equal to ‘USD`.



77
# File 'lib/increase/models/real_time_payments_transfer.rb', line 77

required :currency, enum: -> { Increase::RealTimePaymentsTransfer::Currency }

#debtor_nameString?

The name of the transfer’s sender. If not provided, defaults to the name of the account’s entity.

Returns:

  • (String, nil)


84
# File 'lib/increase/models/real_time_payments_transfer.rb', line 84

required :debtor_name, String, nil?: true

#external_account_idString?

The identifier of the External Account the transfer was made to, if any.

Returns:

  • (String, nil)


90
# File 'lib/increase/models/real_time_payments_transfer.rb', line 90

required :external_account_id, String, nil?: true

#idString

The Real-Time Payments Transfer’s identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/real_time_payments_transfer.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).

Returns:

  • (String, nil)


98
# File 'lib/increase/models/real_time_payments_transfer.rb', line 98

required :idempotency_key, String, nil?: true

#pending_transaction_idString?

The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer [requires approval](increase.com/documentation/transfer-approvals#transfer-approvals) by someone else in your organization.

Returns:

  • (String, nil)


107
# File 'lib/increase/models/real_time_payments_transfer.rb', line 107

required :pending_transaction_id, String, nil?: true

#rejectionIncrease::Models::RealTimePaymentsTransfer::Rejection?

If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.



114
# File 'lib/increase/models/real_time_payments_transfer.rb', line 114

required :rejection, -> { Increase::RealTimePaymentsTransfer::Rejection }, nil?: true

#routing_numberString

The destination American Bankers’ Association (ABA) Routing Transit Number (RTN).

Returns:

  • (String)


121
# File 'lib/increase/models/real_time_payments_transfer.rb', line 121

required :routing_number, String

#source_account_number_idString

The Account Number the recipient will see as having sent the transfer.

Returns:

  • (String)


127
# File 'lib/increase/models/real_time_payments_transfer.rb', line 127

required :source_account_number_id, String

#statusSymbol, Increase::Models::RealTimePaymentsTransfer::Status

The lifecycle status of the transfer.



133
# File 'lib/increase/models/real_time_payments_transfer.rb', line 133

required :status, enum: -> { Increase::RealTimePaymentsTransfer::Status }

#submissionIncrease::Models::RealTimePaymentsTransfer::Submission?

After the transfer is submitted to Real-Time Payments, this will contain supplemental details.



140
# File 'lib/increase/models/real_time_payments_transfer.rb', line 140

required :submission, -> { Increase::RealTimePaymentsTransfer::Submission }, nil?: true

#transaction_idString?

The Transaction funding the transfer once it is complete.

Returns:

  • (String, nil)


146
# File 'lib/increase/models/real_time_payments_transfer.rb', line 146

required :transaction_id, String, nil?: true

#typeSymbol, Increase::Models::RealTimePaymentsTransfer::Type

A constant representing the object’s type. For this resource it will always be ‘real_time_payments_transfer`.



153
# File 'lib/increase/models/real_time_payments_transfer.rb', line 153

required :type, enum: -> { Increase::RealTimePaymentsTransfer::Type }

#ultimate_creditor_nameString?

The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.

Returns:

  • (String, nil)


160
# File 'lib/increase/models/real_time_payments_transfer.rb', line 160

required :ultimate_creditor_name, String, nil?: true

#ultimate_debtor_nameString?

The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.

Returns:

  • (String, nil)


167
# File 'lib/increase/models/real_time_payments_transfer.rb', line 167

required :ultimate_debtor_name, String, nil?: true

#unstructured_remittance_informationString

Unstructured information that will show on the recipient’s bank statement.

Returns:

  • (String)


173
# File 'lib/increase/models/real_time_payments_transfer.rb', line 173

required :unstructured_remittance_information, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_payments_transfer.rb', line 414