Module: Increase::Models::RealTimePaymentsTransfer::Rejection::RejectReasonCode

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/real_time_payments_transfer.rb,
sig/increase/models/real_time_payments_transfer.rbs

Overview

The reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network.

See Also:

  • Increase::Models::RealTimePaymentsTransfer::Rejection#reject_reason_code

Constant Summary collapse

ACCOUNT_CLOSED =

The destination account is closed. Corresponds to the Real-Time Payments reason code "AC04".

:account_closed
ACCOUNT_BLOCKED =

The destination account is currently blocked from receiving transactions. Corresponds to the Real-Time Payments reason code "AC06".

:account_blocked
INVALID_CREDITOR_ACCOUNT_TYPE =

The destination account is ineligible to receive Real-Time Payments transfers. Corresponds to the Real-Time Payments reason code "AC14".

:invalid_creditor_account_type
INVALID_CREDITOR_ACCOUNT_NUMBER =

The destination account does not exist. Corresponds to the Real-Time Payments reason code "AC03".

:invalid_creditor_account_number
INVALID_CREDITOR_FINANCIAL_INSTITUTION_IDENTIFIER =

The destination routing number is invalid. Corresponds to the Real-Time Payments reason code "RC04".

:invalid_creditor_financial_institution_identifier
END_CUSTOMER_DECEASED =

The destination account holder is deceased. Corresponds to the Real-Time Payments reason code "MD07".

:end_customer_deceased
NARRATIVE =

The reason is provided as narrative information in the additional information field.

:narrative
TRANSACTION_FORBIDDEN =

Real-Time Payments transfers are not allowed to the destination account. Corresponds to the Real-Time Payments reason code "AG01".

:transaction_forbidden
TRANSACTION_TYPE_NOT_SUPPORTED =

Real-Time Payments transfers are not enabled for the destination account. Corresponds to the Real-Time Payments reason code "AG03".

:transaction_type_not_supported
UNEXPECTED_AMOUNT =

The amount of the transfer is different than expected by the recipient. Corresponds to the Real-Time Payments reason code "AM09".

:unexpected_amount
AMOUNT_EXCEEDS_BANK_LIMITS =

The amount is higher than the recipient is authorized to send or receive. Corresponds to the Real-Time Payments reason code "AM14".

:amount_exceeds_bank_limits
INVALID_CREDITOR_ADDRESS =

The creditor's address is required, but missing or invalid. Corresponds to the Real-Time Payments reason code "BE04".

:invalid_creditor_address
UNKNOWN_END_CUSTOMER =

The specified creditor is unknown. Corresponds to the Real-Time Payments reason code "BE06".

:unknown_end_customer
INVALID_DEBTOR_ADDRESS =

The debtor's address is required, but missing or invalid. Corresponds to the Real-Time Payments reason code "BE07".

:invalid_debtor_address
TIMEOUT =

There was a timeout processing the transfer. Corresponds to the Real-Time Payments reason code "DS24".

:timeout
UNSUPPORTED_MESSAGE_FOR_RECIPIENT =

Real-Time Payments transfers are not enabled for the destination account. Corresponds to the Real-Time Payments reason code "NOAT".

:unsupported_message_for_recipient
RECIPIENT_CONNECTION_NOT_AVAILABLE =

The destination financial institution is currently not connected to Real-Time Payments. Corresponds to the Real-Time Payments reason code "9912".

:recipient_connection_not_available
REAL_TIME_PAYMENTS_SUSPENDED =

Real-Time Payments is currently unavailable. Corresponds to the Real-Time Payments reason code "9948".

:real_time_payments_suspended
INSTRUCTED_AGENT_SIGNED_OFF =

The destination financial institution is currently signed off of Real-Time Payments. Corresponds to the Real-Time Payments reason code "9910".

:instructed_agent_signed_off
PROCESSING_ERROR =

The transfer was rejected due to an internal Increase issue. We have been notified.

:processing_error
OTHER =

Some other error or issue has occurred.

:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::RealTimePaymentsTransfer::Rejection::reject_reason_code]



383
# File 'sig/increase/models/real_time_payments_transfer.rbs', line 383

def self?.values: -> ::Array[Increase::Models::RealTimePaymentsTransfer::Rejection::reject_reason_code]