Class: Increase::Models::RealTimePaymentsTransfer::Submission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimePaymentsTransfer::Submission
- Defined in:
- lib/increase/models/real_time_payments_transfer.rb,
sig/increase/models/real_time_payments_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#submitted_at ⇒ Time?
The ISO 8601 date and time at which the transfer was submitted to The Clearing House.
-
#transaction_identification ⇒ String
The Real-Time Payments network identification of the transfer.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
430 |
# File 'sig/increase/models/real_time_payments_transfer.rbs', line 430
def initialize: (
|
Instance Attribute Details
#submitted_at ⇒ Time?
The ISO 8601 date and time at which the transfer was submitted to The Clearing House.
570 |
# File 'lib/increase/models/real_time_payments_transfer.rb', line 570 required :submitted_at, Time, nil?: true |
#transaction_identification ⇒ String
The Real-Time Payments network identification of the transfer.
576 |
# File 'lib/increase/models/real_time_payments_transfer.rb', line 576 required :transaction_identification, String |
Instance Method Details
#to_hash ⇒ {
435 |
# File 'sig/increase/models/real_time_payments_transfer.rbs', line 435
def to_hash: -> {
|