Class: Increase::Models::RealTimePaymentsTransferCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/real_time_payments_transfer_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, creditor_name:, source_account_number_id:, unstructured_remittance_information:, account_number: nil, debtor_name: nil, external_account_id: nil, require_approval: nil, routing_number: nil, ultimate_creditor_name: nil, ultimate_debtor_name: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::RealTimePaymentsTransferCreateParams for more details.

Parameters:

  • amount (Integer)

    The transfer amount in USD cents. For Real-Time Payments transfers, must be posi

  • creditor_name (String)

    The name of the transfer’s recipient.

  • source_account_number_id (String)

    The identifier of the Account Number from which to send the transfer.

  • unstructured_remittance_information (String)

    Unstructured information that will show on the recipient’s bank statement.

  • account_number (String) (defaults to: nil)

    The destination account number.

  • debtor_name (String) (defaults to: nil)

    The name of the transfer’s sender. If not provided, defaults to the name of the

  • external_account_id (String) (defaults to: nil)

    The ID of an External Account to initiate a transfer to. If this parameter is pr

  • require_approval (Boolean) (defaults to: nil)

    Whether the transfer requires explicit approval via the dashboard or API.

  • routing_number (String) (defaults to: nil)

    The destination American Bankers’ Association (ABA) Routing Transit Number (RTN)

  • ultimate_creditor_name (String) (defaults to: nil)

    The name of the ultimate recipient of the transfer. Set this if the creditor is

  • ultimate_debtor_name (String) (defaults to: nil)

    The name of the ultimate sender of the transfer. Set this if the funds are being

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 82

Instance Attribute Details

#account_numberString?

The destination account number.

Returns:

  • (String, nil)


39
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 39

optional :account_number, String

#amountInteger

The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.

Returns:

  • (Integer)


15
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 15

required :amount, Integer

#creditor_nameString

The name of the transfer’s recipient.

Returns:

  • (String)


21
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 21

required :creditor_name, String

#debtor_nameString?

The name of the transfer’s sender. If not provided, defaults to the name of the account’s entity.

Returns:

  • (String, nil)


46
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 46

optional :debtor_name, String

#external_account_idString?

The ID of an External Account to initiate a transfer to. If this parameter is provided, ‘account_number` and `routing_number` must be absent.

Returns:

  • (String, nil)


53
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 53

optional :external_account_id, String

#require_approvalBoolean?

Whether the transfer requires explicit approval via the dashboard or API.

Returns:

  • (Boolean, nil)


59
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 59

optional :require_approval, Increase::Internal::Type::Boolean

#routing_numberString?

The destination American Bankers’ Association (ABA) Routing Transit Number (RTN).

Returns:

  • (String, nil)


66
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 66

optional :routing_number, String

#source_account_number_idString

The identifier of the Account Number from which to send the transfer.

Returns:

  • (String)


27
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 27

required :source_account_number_id, String

#ultimate_creditor_nameString?

The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.

Returns:

  • (String, nil)


73
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 73

optional :ultimate_creditor_name, String

#ultimate_debtor_nameString?

The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.

Returns:

  • (String, nil)


80
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 80

optional :ultimate_debtor_name, String

#unstructured_remittance_informationString

Unstructured information that will show on the recipient’s bank statement.

Returns:

  • (String)


33
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 33

required :unstructured_remittance_information, String