Class: Increase::Models::RealTimePaymentsTransferListParams::CreatedAt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_payments_transfer_list_params.rb,
sig/increase/models/real_time_payments_transfer_list_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: nil, created_at: nil, cursor: nil, external_account_id: nil, idempotency_key: nil, limit: nil, status: nil, request_options: {}) ⇒ Object

Parameters:

  • account_id (String) (defaults to: nil)

    Filter Real-Time Payments Transfers to those belonging to the specified Account.

  • created_at (Increase::Models::RealTimePaymentsTransferListParams::CreatedAt) (defaults to: nil)
  • cursor (String) (defaults to: nil)

    Return the page of entries after this one.

  • external_account_id (String) (defaults to: nil)

    Filter Real-Time Payments Transfers to those made to the specified External Account.

  • idempotency_key (String) (defaults to: nil)

    Filter records to the one with the specified idempotency_key you chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

  • limit (Integer) (defaults to: nil)

    Limit the size of the list that is returned. The default (and maximum) is 100 objects.

    Defaults to 100.

  • status (Increase::Models::RealTimePaymentsTransferListParams::Status) (defaults to: nil)
  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 85

class CreatedAt < Increase::Internal::Type::BaseModel
  # @!attribute after
  #   Return results after this [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)
  #   timestamp.
  #
  #   @return [Time, nil]
  optional :after, Time

  # @!attribute before
  #   Return results before this [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)
  #   timestamp.
  #
  #   @return [Time, nil]
  optional :before, Time

  # @!attribute on_or_after
  #   Return results on or after this
  #   [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) timestamp.
  #
  #   @return [Time, nil]
  optional :on_or_after, Time

  # @!attribute on_or_before
  #   Return results on or before this
  #   [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) timestamp.
  #
  #   @return [Time, nil]
  optional :on_or_before, Time

  # @!method initialize(after: nil, before: nil, on_or_after: nil, on_or_before: nil)
  #   @param after [Time]
  #     Return results after this [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)
  #     timestamp.
  #
  #   @param before [Time]
  #     Return results before this [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)
  #     timestamp.
  #
  #   @param on_or_after [Time]
  #     Return results on or after this
  #     [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) timestamp.
  #
  #   @param on_or_before [Time]
  #     Return results on or before this
  #     [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) timestamp.
end

Instance Attribute Details

#afterTime?

Return results after this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


91
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 91

optional :after, Time

#beforeTime?

Return results before this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


98
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 98

optional :before, Time

#on_or_afterTime?

Return results on or after this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


105
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 105

optional :on_or_after, Time

#on_or_beforeTime?

Return results on or before this ISO 8601 timestamp.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


112
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 112

optional :on_or_before, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


100
# File 'sig/increase/models/real_time_payments_transfer_list_params.rbs', line 100

def to_hash: -> {