Class: Increase::Models::Simulations::ACHTransferReturnParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::ACHTransferReturnParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/ach_transfer_return_params.rb,
sig/increase/models/simulations/ach_transfer_return_params.rbs
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#ach_transfer_id ⇒ String
The identifier of the ACH Transfer you wish to return.
-
#addenda_information ⇒ String?
Free-form information the returning bank includes in the return addenda.
-
#reason ⇒ Symbol, ...
The reason why the Federal Reserve or destination bank returned this transfer.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(ach_transfer_id:, addenda_information: nil, reason: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ach_transfer_id:, addenda_information: nil, reason: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/increase/models/simulations/ach_transfer_return_params.rb', line 32
|
Instance Attribute Details
#ach_transfer_id ⇒ String
The identifier of the ACH Transfer you wish to return.
15 |
# File 'lib/increase/models/simulations/ach_transfer_return_params.rb', line 15 required :ach_transfer_id, String |
#addenda_information ⇒ String?
Free-form information the returning bank includes in the return addenda. For a
file_record_edit_criteria (R17) return, set this to QUESTIONABLE to simulate
a return the bank believes was initiated under questionable circumstances.
23 |
# File 'lib/increase/models/simulations/ach_transfer_return_params.rb', line 23 optional :addenda_information, String |
#reason ⇒ Symbol, ...
The reason why the Federal Reserve or destination bank returned this transfer.
Defaults to no_account.
30 |
# File 'lib/increase/models/simulations/ach_transfer_return_params.rb', line 30 optional :reason, enum: -> { Increase::Simulations::ACHTransferReturnParams::Reason } |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/increase/models/simulations/ach_transfer_return_params.rbs', line 35
def to_hash: -> {
|