Module: Increase::Models::Simulations::ACHTransferReturnParams::Reason
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/simulations/ach_transfer_return_params.rb
Overview
The reason why the Federal Reserve or destination bank returned this transfer. Defaults to ‘no_account`.
Constant Summary collapse
- INSUFFICIENT_FUND =
Code R01. Insufficient funds in the receiving account. Sometimes abbreviated to “NSF.”
:insufficient_fund- NO_ACCOUNT =
Code R03. The account does not exist or the receiving bank was unable to locate it.
:no_account- ACCOUNT_CLOSED =
Code R02. The account is closed at the receiving bank.
:account_closed- INVALID_ACCOUNT_NUMBER_STRUCTURE =
Code R04. The account number is invalid at the receiving bank.
:invalid_account_number_structure- ACCOUNT_FROZEN_ENTRY_RETURNED_PER_OFAC_INSTRUCTION =
Code R16. This return code has two separate meanings. (1) The receiving bank froze the account or (2) the Office of Foreign Assets Control (OFAC) instructed the receiving bank to return the entry.
:account_frozen_entry_returned_per_ofac_instruction- CREDIT_ENTRY_REFUSED_BY_RECEIVER =
Code R23. The receiving bank refused the credit transfer.
:credit_entry_refused_by_receiver- UNAUTHORIZED_DEBIT_TO_CONSUMER_ACCOUNT_USING_CORPORATE_SEC_CODE =
Code R05. The receiving bank rejected because of an incorrect Standard Entry Class code. Consumer accounts cannot be debited as ‘corporate_credit_or_debit` or `corporate_trade_exchange`.
:unauthorized_debit_to_consumer_account_using_corporate_sec_code- CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZED =
Code R29. The corporate customer at the receiving bank reversed the transfer.
:corporate_customer_advised_not_authorized- PAYMENT_STOPPED =
Code R08. The receiving bank stopped payment on this transfer.
:payment_stopped- NON_TRANSACTION_ACCOUNT =
Code R20. The account is not eligible for ACH, such as a savings account with transaction limits.
:non_transaction_account- UNCOLLECTED_FUNDS =
Code R09. The receiving bank account does not have enough available balance for the transfer.
:uncollected_funds- ROUTING_NUMBER_CHECK_DIGIT_ERROR =
Code R28. The routing number is incorrect.
:routing_number_check_digit_error- CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETE =
Code R10. The customer at the receiving bank reversed the transfer.
:customer_advised_unauthorized_improper_ineligible_or_incomplete- AMOUNT_FIELD_ERROR =
Code R19. The amount field is incorrect or too large.
:amount_field_error- AUTHORIZATION_REVOKED_BY_CUSTOMER =
Code R07. The customer revoked their authorization for a previously authorized transfer.
:authorization_revoked_by_customer- INVALID_ACH_ROUTING_NUMBER =
Code R13. The routing number is invalid.
:invalid_ach_routing_number- FILE_RECORD_EDIT_CRITERIA =
Code R17. The receiving bank is unable to process a field in the transfer.
:file_record_edit_criteria- ENR_INVALID_INDIVIDUAL_NAME =
Code R45. A rare return reason. The individual name field was invalid.
:enr_invalid_individual_name- RETURNED_PER_ODFI_REQUEST =
Code R06. The originating financial institution asked for this transfer to be returned. The receiving bank is complying with the request.
:returned_per_odfi_request- LIMITED_PARTICIPATION_DFI =
Code R34. The receiving bank’s regulatory supervisor has limited their participation in the ACH network.
:limited_participation_dfi- INCORRECTLY_CODED_OUTBOUND_INTERNATIONAL_PAYMENT =
Code R85. The outbound international ACH transfer was incorrect.
:incorrectly_coded_outbound_international_payment- ACCOUNT_SOLD_TO_ANOTHER_DFI =
Code R12. A rare return reason. The account was sold to another bank.
:account_sold_to_another_dfi- ADDENDA_ERROR =
Code R25. The addenda record is incorrect or missing.
:addenda_error- BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASED =
Code R15. A rare return reason. The account holder is deceased.
:beneficiary_or_account_holder_deceased- CUSTOMER_ADVISED_NOT_WITHIN_AUTHORIZATION_TERMS =
Code R11. A rare return reason. The customer authorized some payment to the sender, but this payment was not in error.
:customer_advised_not_within_authorization_terms- CORRECTED_RETURN =
Code R74. A rare return reason. Sent in response to a return that was returned with code ‘field_error`. The latest return should include the corrected field(s).
:corrected_return- DUPLICATE_ENTRY =
Code R24. A rare return reason. The receiving bank received an exact duplicate entry with the same trace number and amount.
:duplicate_entry- DUPLICATE_RETURN =
Code R67. A rare return reason. The return this message refers to was a duplicate.
:duplicate_return- ENR_DUPLICATE_ENROLLMENT =
Code R47. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_duplicate_enrollment- ENR_INVALID_DFI_ACCOUNT_NUMBER =
Code R43. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_invalid_dfi_account_number- ENR_INVALID_INDIVIDUAL_ID_NUMBER =
Code R44. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_invalid_individual_id_number- ENR_INVALID_REPRESENTATIVE_PAYEE_INDICATOR =
Code R46. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_invalid_representative_payee_indicator- ENR_INVALID_TRANSACTION_CODE =
Code R41. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_invalid_transaction_code- ENR_RETURN_OF_ENR_ENTRY =
Code R40. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_return_of_enr_entry- ENR_ROUTING_NUMBER_CHECK_DIGIT_ERROR =
Code R42. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
:enr_routing_number_check_digit_error- ENTRY_NOT_PROCESSED_BY_GATEWAY =
Code R84. A rare return reason. The International ACH Transfer cannot be processed by the gateway.
:entry_not_processed_by_gateway- FIELD_ERROR =
Code R69. A rare return reason. One or more of the fields in the ACH were malformed.
:field_error- FOREIGN_RECEIVING_DFI_UNABLE_TO_SETTLE =
Code R83. A rare return reason. The Foreign receiving bank was unable to settle this ACH transfer.
:foreign_receiving_dfi_unable_to_settle- IAT_ENTRY_CODING_ERROR =
Code R80. A rare return reason. The International ACH Transfer is malformed.
:iat_entry_coding_error- IMPROPER_EFFECTIVE_ENTRY_DATE =
Code R18. A rare return reason. The ACH has an improper effective entry date field.
:improper_effective_entry_date- IMPROPER_SOURCE_DOCUMENT_SOURCE_DOCUMENT_PRESENTED =
Code R39. A rare return reason. The source document related to this ACH, usually an ACH check conversion, was presented to the bank.
:improper_source_document_source_document_presented- INVALID_COMPANY_ID =
Code R21. A rare return reason. The Company ID field of the ACH was invalid.
:invalid_company_id- INVALID_FOREIGN_RECEIVING_DFI_IDENTIFICATION =
Code R82. A rare return reason. The foreign receiving bank identifier for an International ACH Transfer was invalid.
:invalid_foreign_receiving_dfi_identification- INVALID_INDIVIDUAL_ID_NUMBER =
Code R22. A rare return reason. The Individual ID number field of the ACH was invalid.
:invalid_individual_id_number- ITEM_AND_RCK_ENTRY_PRESENTED_FOR_PAYMENT =
Code R53. A rare return reason. Both the Represented Check (“RCK”) entry and the original check were presented to the bank.
:item_and_rck_entry_presented_for_payment- ITEM_RELATED_TO_RCK_ENTRY_IS_INELIGIBLE =
Code R51. A rare return reason. The Represented Check (“RCK”) entry is ineligible.
:item_related_to_rck_entry_is_ineligible- MANDATORY_FIELD_ERROR =
Code R26. A rare return reason. The ACH is missing a required field.
:mandatory_field_error- MISROUTED_DISHONORED_RETURN =
Code R71. A rare return reason. The receiving bank does not recognize the routing number in a dishonored return entry.
:misrouted_dishonored_return- MISROUTED_RETURN =
Code R61. A rare return reason. The receiving bank does not recognize the routing number in a return entry.
:misrouted_return- NO_ERRORS_FOUND =
Code R76. A rare return reason. Sent in response to a return, the bank does not find the errors alleged by the returning bank.
:no_errors_found- NON_ACCEPTANCE_OF_R62_DISHONORED_RETURN =
Code R77. A rare return reason. The receiving bank does not accept the return of the erroneous debit. The funds are not available at the receiving bank.
:non_acceptance_of_r62_dishonored_return- NON_PARTICIPANT_IN_IAT_PROGRAM =
Code R81. A rare return reason. The receiving bank does not accept International ACH Transfers.
:non_participant_in_iat_program- PERMISSIBLE_RETURN_ENTRY =
Code R31. A rare return reason. A return that has been agreed to be accepted by the receiving bank, despite falling outside of the usual return timeframe.
:permissible_return_entry- PERMISSIBLE_RETURN_ENTRY_NOT_ACCEPTED =
Code R70. A rare return reason. The receiving bank had not approved this return.
:permissible_return_entry_not_accepted- RDFI_NON_SETTLEMENT =
Code R32. A rare return reason. The receiving bank could not settle this transaction.
:rdfi_non_settlement- RDFI_PARTICIPANT_IN_CHECK_TRUNCATION_PROGRAM =
Code R30. A rare return reason. The receiving bank does not accept Check Truncation ACH transfers.
:rdfi_participant_in_check_truncation_program- REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITY =
Code R14. A rare return reason. The payee is deceased.
:representative_payee_deceased_or_unable_to_continue_in_that_capacity- RETURN_NOT_A_DUPLICATE =
Code R75. A rare return reason. The originating bank disputes that an earlier ‘duplicate_entry` return was actually a duplicate.
:return_not_a_duplicate- RETURN_OF_ERRONEOUS_OR_REVERSING_DEBIT =
Code R62. A rare return reason. The originating financial institution made a mistake and this return corrects it.
:return_of_erroneous_or_reversing_debit- RETURN_OF_IMPROPER_CREDIT_ENTRY =
Code R36. A rare return reason. Return of a malformed credit entry.
:return_of_improper_credit_entry- RETURN_OF_IMPROPER_DEBIT_ENTRY =
Code R35. A rare return reason. Return of a malformed debit entry.
:return_of_improper_debit_entry- RETURN_OF_XCK_ENTRY =
Code R33. A rare return reason. Return of a destroyed check (“XCK”) entry.
:return_of_xck_entry- SOURCE_DOCUMENT_PRESENTED_FOR_PAYMENT =
Code R37. A rare return reason. The source document related to this ACH, usually an ACH check conversion, was presented to the bank.
:source_document_presented_for_payment- STATE_LAW_AFFECTING_RCK_ACCEPTANCE =
Code R50. A rare return reason. State law prevents the bank from accepting the Represented Check (“RCK”) entry.
:state_law_affecting_rck_acceptance- STOP_PAYMENT_ON_ITEM_RELATED_TO_RCK_ENTRY =
Code R52. A rare return reason. A stop payment was issued on a Represented Check (“RCK”) entry.
:stop_payment_on_item_related_to_rck_entry- STOP_PAYMENT_ON_SOURCE_DOCUMENT =
Code R38. A rare return reason. The source attached to the ACH, usually an ACH check conversion, includes a stop payment.
:stop_payment_on_source_document- TIMELY_ORIGINAL_RETURN =
Code R73. A rare return reason. The bank receiving an ‘untimely_return` believes it was on time.
:timely_original_return- TRACE_NUMBER_ERROR =
Code R27. A rare return reason. An ACH return’s trace number does not match an originated ACH.
:trace_number_error- UNTIMELY_DISHONORED_RETURN =
Code R72. A rare return reason. The dishonored return was sent too late.
:untimely_dishonored_return- UNTIMELY_RETURN =
Code R68. A rare return reason. The return was sent too late.
:untimely_return
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/simulations/ach_transfer_return_params.rb', line 252
|