Class: Increase::Models::Simulations::ACHTransferSettleParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::ACHTransferSettleParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/ach_transfer_settle_params.rb
Overview
Defined Under Namespace
Modules: InboundFundsHoldBehavior
Instance Attribute Summary collapse
-
#ach_transfer_id ⇒ String
The identifier of the ACH Transfer you wish to become settled.
-
#inbound_funds_hold_behavior ⇒ Symbol, ...
The behavior of the inbound funds hold that is created when the ACH Transfer is settled.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(ach_transfer_id:, inbound_funds_hold_behavior: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ACHTransferSettleParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ach_transfer_id:, inbound_funds_hold_behavior: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Simulations::ACHTransferSettleParams for more details.
|
|
# File 'lib/increase/models/simulations/ach_transfer_settle_params.rb', line 26
|
Instance Attribute Details
#ach_transfer_id ⇒ String
The identifier of the ACH Transfer you wish to become settled.
15 |
# File 'lib/increase/models/simulations/ach_transfer_settle_params.rb', line 15 required :ach_transfer_id, String |
#inbound_funds_hold_behavior ⇒ Symbol, ...
The behavior of the inbound funds hold that is created when the ACH Transfer is settled. If no behavior is specified, the inbound funds hold will be released immediately in order for the funds to be available for use.
23 24 |
# File 'lib/increase/models/simulations/ach_transfer_settle_params.rb', line 23 optional :inbound_funds_hold_behavior, enum: -> { Increase::Simulations::ACHTransferSettleParams::InboundFundsHoldBehavior } |