Module: Increase::Models::Simulations::CardAuthorizationCreateParams::DeclineReason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/card_authorization_create_params.rb,
sig/increase/models/simulations/card_authorization_create_params.rbs

Overview

Forces a card decline with a specific reason. No real time decision will be sent.

Constant Summary collapse

ACCOUNT_CLOSED =

The account has been closed.

Returns:

  • (:account_closed)
:account_closed
CARD_NOT_ACTIVE =

The Card was not active.

Returns:

  • (:card_not_active)
:card_not_active
CARD_CANCELED =

The Card has been canceled.

Returns:

  • (:card_canceled)
:card_canceled
PHYSICAL_CARD_NOT_ACTIVE =

The Physical Card was not active.

Returns:

  • (:physical_card_not_active)
:physical_card_not_active
ENTITY_NOT_ACTIVE =

The account's entity was not active.

Returns:

  • (:entity_not_active)
:entity_not_active
GROUP_LOCKED =

The account was inactive.

Returns:

  • (:group_locked)
:group_locked
INSUFFICIENT_FUNDS =

The Card's Account did not have a sufficient available balance.

Returns:

  • (:insufficient_funds)
:insufficient_funds
CVV2_MISMATCH =

The given CVV2 did not match the card's value.

Returns:

  • (:cvv2_mismatch)
:cvv2_mismatch
PIN_MISMATCH =

The given PIN did not match the card's value.

Returns:

  • (:pin_mismatch)
:pin_mismatch
CARD_EXPIRATION_MISMATCH =

The given expiration date did not match the card's value. Only applies when a CVV2 is present.

Returns:

  • (:card_expiration_mismatch)
:card_expiration_mismatch
TRANSACTION_NOT_ALLOWED =

The attempted card transaction is not allowed per Increase's terms.

Returns:

  • (:transaction_not_allowed)
:transaction_not_allowed
BREACHES_LIMIT =

The transaction was blocked by a limit or an authorization control.

Returns:

  • (:breaches_limit)
:breaches_limit
WEBHOOK_DECLINED =

Your application declined the transaction via webhook.

Returns:

  • (:webhook_declined)
:webhook_declined
WEBHOOK_TIMED_OUT =

Your application webhook did not respond without the required timeout.

Returns:

  • (:webhook_timed_out)
:webhook_timed_out
DECLINED_BY_STAND_IN_PROCESSING =

Declined by stand-in processing.

Returns:

  • (:declined_by_stand_in_processing)
:declined_by_stand_in_processing
INVALID_PHYSICAL_CARD =

The card read had an invalid CVV or dCVV.

Returns:

  • (:invalid_physical_card)
:invalid_physical_card
MISSING_ORIGINAL_AUTHORIZATION =

The original card authorization for this incremental authorization does not exist.

Returns:

  • (:missing_original_authorization)
:missing_original_authorization
INVALID_CRYPTOGRAM =

The card's authorization request cryptogram was invalid. The cryptogram can be from a physical card or a Digital Wallet Token purchase.

Returns:

  • (:invalid_cryptogram)
:invalid_cryptogram
FAILED_3DS_AUTHENTICATION =

The transaction was declined because the 3DS authentication failed.

Returns:

  • (:failed_3ds_authentication)
:failed_3ds_authentication
SUSPECTED_CARD_TESTING =

The transaction was suspected to be used by a card tester to test for valid card numbers.

Returns:

  • (:suspected_card_testing)
:suspected_card_testing
SUSPECTED_FRAUD =

The transaction was suspected to be fraudulent. Please reach out to support@increase.com for more information.

Returns:

  • (:suspected_fraud)
:suspected_fraud

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Simulations::CardAuthorizationCreateParams::decline_reason]

Returns:

  • (::Array[Increase::Models::Simulations::CardAuthorizationCreateParams::decline_reason])


233
# File 'sig/increase/models/simulations/card_authorization_create_params.rbs', line 233

def self?.values: -> ::Array[Increase::Models::Simulations::CardAuthorizationCreateParams::decline_reason]