Class: Increase::Models::Simulations::CardBalanceInquiryCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::CardBalanceInquiryCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/card_balance_inquiry_create_params.rb
Overview
Defined Under Namespace
Modules: DeclineReason Classes: NetworkDetails
Instance Attribute Summary collapse
-
#balance ⇒ Integer?
The balance amount in cents.
-
#card_id ⇒ String?
The identifier of the Card to be authorized.
-
#decline_reason ⇒ Symbol, ...
Forces a card decline with a specific reason.
-
#digital_wallet_token_id ⇒ String?
The identifier of the Digital Wallet Token to be authorized.
-
#event_subscription_id ⇒ String?
The identifier of the Event Subscription to use.
-
#merchant_acceptor_id ⇒ String?
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String?
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String?
The country the merchant resides in.
-
#merchant_descriptor ⇒ String?
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::Simulations::CardBalanceInquiryCreateParams::NetworkDetails?
Fields specific to a given card network.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
The identifier of the Physical Card to be authorized.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(balance: nil, card_id: nil, decline_reason: nil, digital_wallet_token_id: nil, event_subscription_id: nil, merchant_acceptor_id: nil, merchant_category_code: nil, merchant_city: nil, merchant_country: nil, merchant_descriptor: nil, merchant_state: nil, network_details: nil, network_risk_score: nil, physical_card_id: nil, terminal_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardBalanceInquiryCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance: nil, card_id: nil, decline_reason: nil, digital_wallet_token_id: nil, event_subscription_id: nil, merchant_acceptor_id: nil, merchant_category_code: nil, merchant_city: nil, merchant_country: nil, merchant_descriptor: nil, merchant_state: nil, network_details: nil, network_risk_score: nil, physical_card_id: nil, terminal_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Simulations::CardBalanceInquiryCreateParams for more details.
|
|
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 110
|
Instance Attribute Details
#balance ⇒ Integer?
The balance amount in cents. The account balance will be used if not provided.
15 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 15 optional :balance, Integer |
#card_id ⇒ String?
The identifier of the Card to be authorized.
21 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 21 optional :card_id, String |
#decline_reason ⇒ Symbol, ...
Forces a card decline with a specific reason. No real time decision will be sent.
28 29 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 28 optional :decline_reason, enum: -> { Increase::Simulations::CardBalanceInquiryCreateParams::DeclineReason } |
#digital_wallet_token_id ⇒ String?
The identifier of the Digital Wallet Token to be authorized.
35 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 35 optional :digital_wallet_token_id, String |
#event_subscription_id ⇒ String?
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
44 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 44 optional :event_subscription_id, String |
#merchant_acceptor_id ⇒ String?
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
51 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 51 optional :merchant_acceptor_id, String |
#merchant_category_code ⇒ String?
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
58 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 58 optional :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
64 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 64 optional :merchant_city, String |
#merchant_country ⇒ String?
The country the merchant resides in.
70 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 70 optional :merchant_country, String |
#merchant_descriptor ⇒ String?
The merchant descriptor of the merchant the card is transacting with.
76 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 76 optional :merchant_descriptor, String |
#merchant_state ⇒ String?
The state the merchant resides in.
82 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 82 optional :merchant_state, String |
#network_details ⇒ Increase::Models::Simulations::CardBalanceInquiryCreateParams::NetworkDetails?
Fields specific to a given card network.
88 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 88 optional :network_details, -> { Increase::Simulations::CardBalanceInquiryCreateParams::NetworkDetails } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
95 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 95 optional :network_risk_score, Integer |
#physical_card_id ⇒ String?
The identifier of the Physical Card to be authorized.
101 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 101 optional :physical_card_id, String |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
108 |
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 108 optional :terminal_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 215
|