Module: Increase::Models::Simulations::CardDisputeActionParams::Visa::Action

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/card_dispute_action_params.rb,
sig/increase/models/simulations/card_dispute_action_params.rbs

Overview

The action to take. Details specific to the action are required under the sub-object with the same identifier as the action.

See Also:

  • Increase::Models::Simulations::CardDisputeActionParams::Visa#action

Constant Summary collapse

ACCEPT_CHARGEBACK =

Simulate the merchant accepting the chargeback. This will move the dispute to a won state.

Returns:

  • (:accept_chargeback)
:accept_chargeback
ACCEPT_USER_SUBMISSION =

Accept the user's submission and transmit it to the network. This will move the dispute to a pending_response state.

Returns:

  • (:accept_user_submission)
:accept_user_submission
DECLINE_USER_PREARBITRATION =

Simulate the merchant declining the user's pre-arbitration. This will move the dispute to a lost state.

Returns:

  • (:decline_user_prearbitration)
:decline_user_prearbitration
RECEIVE_MERCHANT_PREARBITRATION =

Simulate the merchant issuing pre-arbitration. This will move the dispute to a user_submission_required state.

Returns:

  • (:receive_merchant_prearbitration)
:receive_merchant_prearbitration
REPRESENT =

Simulate the merchant re-presenting the dispute. This will move the dispute to a user_submission_required state.

Returns:

  • (:represent)
:represent
REQUEST_FURTHER_INFORMATION =

Simulate further information being requested from the user. This will move the dispute to a user_submission_required state.

Returns:

  • (:request_further_information)
:request_further_information
TIME_OUT_CHARGEBACK =

Simulate the merchant timing out responding to the chargeback. This will move the dispute to a won state.

Returns:

  • (:time_out_chargeback)
:time_out_chargeback
TIME_OUT_MERCHANT_PREARBITRATION =

Simulate the user timing out responding to a merchant pre-arbitration. This will move the dispute to a lost state.

Returns:

  • (:time_out_merchant_prearbitration)
:time_out_merchant_prearbitration
TIME_OUT_REPRESENTMENT =

Simulate the user timing out responding to a merchant re-presentment. This will move the dispute to a lost state.

Returns:

  • (:time_out_representment)
:time_out_representment
TIME_OUT_USER_PREARBITRATION =

Simulate the merchant timing out responding to a user pre-arbitration. This will move the dispute to a win state.

Returns:

  • (:time_out_user_prearbitration)
:time_out_user_prearbitration

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Simulations::CardDisputeActionParams::Visa::action]

Returns:

  • (::Array[Increase::Models::Simulations::CardDisputeActionParams::Visa::action])


202
# File 'sig/increase/models/simulations/card_dispute_action_params.rbs', line 202

def self?.values: -> ::Array[Increase::Models::Simulations::CardDisputeActionParams::Visa::action]