Class: Increase::Models::Simulations::CardIncrementCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::CardIncrementCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/card_increment_create_params.rb,
sig/increase/models/simulations/card_increment_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount of the increment in minor units in the card authorization's currency.
-
#card_payment_id ⇒ String
The identifier of the Card Payment to create an increment on.
-
#event_subscription_id ⇒ String?
The identifier of the Event Subscription to use.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(amount:, card_payment_id:, event_subscription_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, card_payment_id:, event_subscription_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/increase/models/simulations/card_increment_create_params.rb', line 32
|
Instance Attribute Details
#amount ⇒ Integer
The amount of the increment in minor units in the card authorization's currency.
15 |
# File 'lib/increase/models/simulations/card_increment_create_params.rb', line 15 required :amount, Integer |
#card_payment_id ⇒ String
The identifier of the Card Payment to create an increment on.
21 |
# File 'lib/increase/models/simulations/card_increment_create_params.rb', line 21 required :card_payment_id, String |
#event_subscription_id ⇒ String?
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
30 |
# File 'lib/increase/models/simulations/card_increment_create_params.rb', line 30 optional :event_subscription_id, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/increase/models/simulations/card_increment_create_params.rbs', line 31
def to_hash: -> {
|