Class: Increase::Models::Simulations::CardPurchaseSupplementCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::CardPurchaseSupplementCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/card_purchase_supplement_create_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#invoice ⇒ Increase::Models::Simulations::CardPurchaseSupplementCreateParams::Invoice?
Invoice-level information about the payment.
-
#line_items ⇒ Array<Increase::Models::Simulations::CardPurchaseSupplementCreateParams::LineItem>?
Line item information, such as individual products purchased.
-
#transaction_id ⇒ String
The identifier of the Transaction to create a Card Purchase Supplement for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(discount_amount: nil, duty_tax_amount: nil, order_date: nil, shipping_amount: nil, shipping_destination_country_code: nil, shipping_destination_postal_code: nil, shipping_source_postal_code: nil, shipping_tax_amount: nil, shipping_tax_rate: nil, unique_value_added_tax_invoice_reference: nil) ⇒ Object
constructor
Invoice-level information about the payment.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(discount_amount: nil, duty_tax_amount: nil, order_date: nil, shipping_amount: nil, shipping_destination_country_code: nil, shipping_destination_postal_code: nil, shipping_source_postal_code: nil, shipping_tax_amount: nil, shipping_tax_rate: nil, unique_value_added_tax_invoice_reference: nil) ⇒ Object
Invoice-level information about the payment.
|
|
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 105
|
Instance Attribute Details
#invoice ⇒ Increase::Models::Simulations::CardPurchaseSupplementCreateParams::Invoice?
Invoice-level information about the payment.
22 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 22 optional :invoice, -> { Increase::Simulations::CardPurchaseSupplementCreateParams::Invoice } |
#line_items ⇒ Array<Increase::Models::Simulations::CardPurchaseSupplementCreateParams::LineItem>?
Line item information, such as individual products purchased.
28 29 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 28 optional :line_items, -> { Increase::Internal::Type::ArrayOf[Increase::Simulations::CardPurchaseSupplementCreateParams::LineItem] } |
#transaction_id ⇒ String
The identifier of the Transaction to create a Card Purchase Supplement for. The Transaction must have a source of type ‘card_settlement`.
16 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 16 required :transaction_id, String |