Class: Increase::Models::Simulations::CardPurchaseSupplementCreateParams::LineItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::CardPurchaseSupplementCreateParams::LineItem
- Defined in:
- lib/increase/models/simulations/card_purchase_supplement_create_params.rb
Instance Attribute Summary collapse
-
#discount_amount ⇒ Integer?
Discount amount for this specific line item.
-
#item_commodity_code ⇒ String?
Code used to categorize the purchase item.
-
#item_descriptor ⇒ String?
Description of the purchase item.
-
#item_quantity ⇒ String?
The number of units of the product being purchased.
-
#product_code ⇒ String?
Code used to categorize the product being purchased.
-
#sales_tax_amount ⇒ Integer?
Sales tax amount for this line item.
-
#sales_tax_rate ⇒ String?
Sales tax rate for this line item.
-
#total_amount ⇒ Integer?
Total amount of all line items.
-
#unit_cost ⇒ String?
Cost of line item per unit of measure, in major units.
-
#unit_of_measure_code ⇒ String?
Code indicating unit of measure (gallons, etc.).
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(discount_amount: nil, item_commodity_code: nil, item_descriptor: nil, item_quantity: nil, product_code: nil, sales_tax_amount: nil, sales_tax_rate: nil, total_amount: nil, unit_cost: nil, unit_of_measure_code: nil) ⇒ Object
|
|
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 190
|
Instance Attribute Details
#discount_amount ⇒ Integer?
Discount amount for this specific line item.
134 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 134 optional :discount_amount, Integer |
#item_commodity_code ⇒ String?
Code used to categorize the purchase item.
140 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 140 optional :item_commodity_code, String |
#item_descriptor ⇒ String?
Description of the purchase item.
146 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 146 optional :item_descriptor, String |
#item_quantity ⇒ String?
The number of units of the product being purchased.
152 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 152 optional :item_quantity, String |
#product_code ⇒ String?
Code used to categorize the product being purchased.
158 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 158 optional :product_code, String |
#sales_tax_amount ⇒ Integer?
Sales tax amount for this line item.
164 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 164 optional :sales_tax_amount, Integer |
#sales_tax_rate ⇒ String?
Sales tax rate for this line item.
170 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 170 optional :sales_tax_rate, String |
#total_amount ⇒ Integer?
Total amount of all line items.
176 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 176 optional :total_amount, Integer |
#unit_cost ⇒ String?
Cost of line item per unit of measure, in major units.
182 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 182 optional :unit_cost, String |
#unit_of_measure_code ⇒ String?
Code indicating unit of measure (gallons, etc.).
188 |
# File 'lib/increase/models/simulations/card_purchase_supplement_create_params.rb', line 188 optional :unit_of_measure_code, String |