Class: Increase::Models::Simulations::CardSettlementCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/simulations/card_settlement_create_params.rb,
sig/increase/models/simulations/card_settlement_create_params.rbs

Overview

See Also:

  • Increase::Resources::Simulations::CardSettlements#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_id:, amount: nil, pending_transaction_id: nil, request_options: {}) ⇒ Object

Parameters:

  • The identifier of the Card to create a settlement on.

  • (defaults to: nil)

    The amount to be settled. This defaults to the amount of the Pending Transaction being settled, or a random amount if pending_transaction_id is not provided.

  • (defaults to: nil)

    The identifier of the Pending Transaction for the Card Authorization you wish to settle. If not provided, the settlement will be force posted without a Card Authorization.

  • (defaults to: {})


# File 'lib/increase/models/simulations/card_settlement_create_params.rb', line 32


Instance Attribute Details

#amountInteger?

The amount to be settled. This defaults to the amount of the Pending Transaction being settled, or a random amount if pending_transaction_id is not provided.

Parameters:

Returns:



22
# File 'lib/increase/models/simulations/card_settlement_create_params.rb', line 22

optional :amount, Integer

#card_idString

The identifier of the Card to create a settlement on.

Parameters:

Returns:



15
# File 'lib/increase/models/simulations/card_settlement_create_params.rb', line 15

required :card_id, String

#pending_transaction_idString?

The identifier of the Pending Transaction for the Card Authorization you wish to settle. If not provided, the settlement will be force posted without a Card Authorization.

Parameters:

Returns:



30
# File 'lib/increase/models/simulations/card_settlement_create_params.rb', line 30

optional :pending_transaction_id, String

Instance Method Details

#to_hash{

Returns:



29
# File 'sig/increase/models/simulations/card_settlement_create_params.rbs', line 29

def to_hash: -> {