Module: Increase::Models::Simulations::CardTokenCreateParams::Outcome::Result
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/simulations/card_token_create_params.rb
Overview
Whether card push transfers or validations will be approved or declined.
Constant Summary collapse
- APPROVE =
Any card push transfers or validations will be approved.
:approve- DECLINE =
Any card push transfers or validations will be declined.
:decline
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info