Module: Increase::Models::Simulations::CheckDepositAdjustmentParams::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/check_deposit_adjustment_params.rb

Overview

The reason for the adjustment. Defaults to ‘non_conforming_item`, which is often used for a low quality image that the recipient wasn’t able to handle.

Constant Summary collapse

LATE_RETURN =

The return was initiated too late and the receiving institution has responded with a Late Return Claim.

:late_return
WRONG_PAYEE_CREDIT =

The check was deposited to the wrong payee and the depositing institution has reimbursed the funds with a Wrong Payee Credit.

:wrong_payee_credit
ADJUSTED_AMOUNT =

The check was deposited with a different amount than what was written on the check.

:adjusted_amount
NON_CONFORMING_ITEM =

The recipient was not able to process the check. This usually happens for e.g., low quality images.

:non_conforming_item
:paid

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/simulations/check_deposit_adjustment_params.rb', line 65