Class: Increase::Models::Simulations::CheckDepositSubmitParams::Scan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/simulations/check_deposit_submit_params.rb,
sig/increase/models/simulations/check_deposit_submit_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, routing_number:, auxiliary_on_us: nil, serial_number: nil) ⇒ Object

If set, the simulation will use these values for the check's scanned MICR data. If not set, the simulation will use random values.

Parameters:

  • account_number (String)

    The account number to be returned in the check deposit's scan data.

  • routing_number (String)

    The routing number to be returned in the check deposit's scan data.

  • auxiliary_on_us (String) (defaults to: nil)

    The auxiliary on-us data to be returned in the check deposit's scan data. Auxiliary on-us is typically the check number for business checks.

  • serial_number (String) (defaults to: nil)

    The serial number to be returned in the check deposit's scan data. Serial number is typically the check number for consumer checks.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 33

class Scan < Increase::Internal::Type::BaseModel
  # @!attribute account_number
  #   The account number to be returned in the check deposit's scan data.
  #
  #   @return [String]
  required :account_number, String

  # @!attribute routing_number
  #   The routing number to be returned in the check deposit's scan data.
  #
  #   @return [String]
  required :routing_number, String

  # @!attribute auxiliary_on_us
  #   The auxiliary on-us data to be returned in the check deposit's scan data.
  #   Auxiliary on-us is typically the check number for business checks.
  #
  #   @return [String, nil]
  optional :auxiliary_on_us, String

  # @!attribute serial_number
  #   The serial number to be returned in the check deposit's scan data. Serial number
  #   is typically the check number for consumer checks.
  #
  #   @return [String, nil]
  optional :serial_number, String

  # @!method initialize(account_number:, routing_number:, auxiliary_on_us: nil, serial_number: nil)
  #   If set, the simulation will use these values for the check's scanned MICR data.
  #   If not set, the simulation will use random values.
  #
  #   @param account_number [String] The account number to be returned in the check deposit's scan data.
  #
  #   @param routing_number [String] The routing number to be returned in the check deposit's scan data.
  #
  #   @param auxiliary_on_us [String]
  #     The auxiliary on-us data to be returned in the check deposit's scan data.
  #     Auxiliary on-us is typically the check number for business checks.
  #
  #   @param serial_number [String]
  #     The serial number to be returned in the check deposit's scan data. Serial number
  #     is typically the check number for consumer checks.
end

Instance Attribute Details

#account_numberString

The account number to be returned in the check deposit's scan data.

Parameters:

  • value (String)

Returns:

  • (String)


38
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 38

required :account_number, String

#auxiliary_on_usString?

The auxiliary on-us data to be returned in the check deposit's scan data. Auxiliary on-us is typically the check number for business checks.

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 51

optional :auxiliary_on_us, String

#routing_numberString

The routing number to be returned in the check deposit's scan data.

Parameters:

  • value (String)

Returns:

  • (String)


44
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 44

required :routing_number, String

#serial_numberString?

The serial number to be returned in the check deposit's scan data. Serial number is typically the check number for consumer checks.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 58

optional :serial_number, String

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/increase/models/simulations/check_deposit_submit_params.rbs', line 63

def to_hash: -> {