Module: Increase::Models::Simulations::DigitalWalletTokenRequestCreateResponse::DeclineReason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/digital_wallet_token_request_create_response.rb,
sig/increase/models/simulations/digital_wallet_token_request_create_response.rbs

Overview

If the simulated tokenization attempt was declined, this field contains details as to why.

See Also:

  • Increase::Models::Simulations::DigitalWalletTokenRequestCreateResponse#decline_reason

Constant Summary collapse

CARD_NOT_ACTIVE =

The card is not active.

Returns:

  • (:card_not_active)
:card_not_active
NO_VERIFICATION_METHOD =

The card does not have a two-factor authentication method.

Returns:

  • (:no_verification_method)
:no_verification_method
WEBHOOK_TIMED_OUT =

Your webhook timed out when evaluating the token provisioning attempt.

Returns:

  • (:webhook_timed_out)
:webhook_timed_out
WEBHOOK_DECLINED =

Your webhook declined the token provisioning attempt.

Returns:

  • (:webhook_declined)
:webhook_declined
INCORRECT_CARD_VERIFICATION_CODE =

The tokenization attempt failed because the Card Verification Code (CVC) was incorrect.

Returns:

  • (:incorrect_card_verification_code)
:incorrect_card_verification_code
DECLINED_BY_TOKEN_REQUESTOR =

The tokenization attempt was declined by the token requestor.

Returns:

  • (:declined_by_token_requestor)
:declined_by_token_requestor

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Simulations::DigitalWalletTokenRequestCreateResponse::decline_reason]

Returns:

  • (::Array[Increase::Models::Simulations::DigitalWalletTokenRequestCreateResponse::decline_reason])


59
# File 'sig/increase/models/simulations/digital_wallet_token_request_create_response.rbs', line 59

def self?.values: -> ::Array[Increase::Models::Simulations::DigitalWalletTokenRequestCreateResponse::decline_reason]