Class: Increase::Models::Simulations::EntityUpdateValidationParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::EntityUpdateValidationParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/entity_update_validation_params.rb,
sig/increase/models/simulations/entity_update_validation_params.rbs
Overview
Defined Under Namespace
Classes: Issue
Instance Attribute Summary collapse
-
#entity_id ⇒ String
The identifier of the Entity whose validation status to update.
-
#issues ⇒ Array<Increase::Models::Simulations::EntityUpdateValidationParams::Issue>
The validation issues to attach.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
19 |
# File 'sig/increase/models/simulations/entity_update_validation_params.rbs', line 19
def initialize: (
|
Instance Attribute Details
#entity_id ⇒ String
The identifier of the Entity whose validation status to update.
15 |
# File 'lib/increase/models/simulations/entity_update_validation_params.rb', line 15 required :entity_id, String |
#issues ⇒ Array<Increase::Models::Simulations::EntityUpdateValidationParams::Issue>
The validation issues to attach. If no issues are provided, the validation
status will be set to valid.
22 23 |
# File 'lib/increase/models/simulations/entity_update_validation_params.rb', line 22 required :issues, -> { Increase::Internal::Type::ArrayOf[Increase::Simulations::EntityUpdateValidationParams::Issue] } |
Instance Method Details
#to_hash ⇒ {
25 |
# File 'sig/increase/models/simulations/entity_update_validation_params.rbs', line 25
def to_hash: -> {
|