Module: Increase::Models::Simulations::EntityUpdateValidationParams::Issue::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/entity_update_validation_params.rb,
sig/increase/models/simulations/entity_update_validation_params.rbs

Overview

The type of issue.

See Also:

  • Increase::Models::Simulations::EntityUpdateValidationParams::Issue#category

Constant Summary collapse

ENTITY_TAX_IDENTIFIER =

The entity's tax identifier could not be verified. Update the tax ID with the update an entity API.

:entity_tax_identifier
ENTITY_ADDRESS =

The entity's address could not be validated. Update the address with the update an entity API.

:entity_address
ENTITY_IDENTITY =

The entity's identity could not be verified. Update the identification with the update an entity API.

:entity_identity
BENEFICIAL_OWNER_IDENTITY =

A beneficial owner's identity could not be verified. Update the identification with the update a beneficial owner API.

:beneficial_owner_identity
BENEFICIAL_OWNER_ADDRESS =

A beneficial owner's address could not be validated. Update the address with the update a beneficial owner API.

:beneficial_owner_address

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/simulations/entity_update_validation_params.rb', line 66


Instance Method Details

#self?.values::Array[Increase::Models::Simulations::EntityUpdateValidationParams::Issue::category]



72
# File 'sig/increase/models/simulations/entity_update_validation_params.rbs', line 72

def self?.values: -> ::Array[Increase::Models::Simulations::EntityUpdateValidationParams::Issue::category]