Class: Increase::Models::Simulations::InboundCheckDepositAdjustmentParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb,
sig/increase/models/simulations/inbound_check_deposit_adjustment_params.rbs

Overview

See Also:

  • Increase::Resources::Simulations::InboundCheckDeposits#adjustment

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inbound_check_deposit_id:, amount: nil, reason: nil, request_options: {}) ⇒ Object

Parameters:

  • The identifier of the Inbound Check Deposit to adjust.

  • (defaults to: nil)

    The adjustment amount in cents. A positive amount means that the funds are being returned to you by the other bank and is a credit to your account, as happens for a wrong_payee_credit. A negative amount is a debit to your account, as happens for a late_return. Defaults to the amount of the Inbound Check Deposit.

  • (defaults to: nil)

    The reason for the adjustment. Defaults to wrong_payee_credit.

  • (defaults to: {})


# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 33


Instance Attribute Details

#amountInteger?

The adjustment amount in cents. A positive amount means that the funds are being returned to you by the other bank and is a credit to your account, as happens for a wrong_payee_credit. A negative amount is a debit to your account, as happens for a late_return. Defaults to the amount of the Inbound Check Deposit.

Parameters:

Returns:



25
# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 25

optional :amount, Integer

#inbound_check_deposit_idString

The identifier of the Inbound Check Deposit to adjust.

Parameters:

Returns:



15
# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 15

required :inbound_check_deposit_id, String

#reasonSymbol, ...

The reason for the adjustment. Defaults to wrong_payee_credit.

Returns:



31
# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 31

optional :reason, enum: -> { Increase::Simulations::InboundCheckDepositAdjustmentParams::Reason }

Instance Method Details

#to_hash{

Returns:



35
# File 'sig/increase/models/simulations/inbound_check_deposit_adjustment_params.rbs', line 35

def to_hash: -> {