Class: Increase::Models::Simulations::InboundCheckDepositCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/simulations/inbound_check_deposit_create_params.rb,
sig/increase/models/simulations/inbound_check_deposit_create_params.rbs

Overview

See Also:

  • Increase::Resources::Simulations::InboundCheckDeposits#create

Defined Under Namespace

Modules: PayeeNameAnalysis

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number_id:, amount:, check_number:, payee_name_analysis: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Simulations::InboundCheckDepositCreateParams for more details.

Parameters:



# File 'lib/increase/models/simulations/inbound_check_deposit_create_params.rb', line 38

Instance Attribute Details

#account_number_idString

The identifier of the Account Number the Inbound Check Deposit will be against.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/increase/models/simulations/inbound_check_deposit_create_params.rb', line 15

required :account_number_id, String

#amountInteger

The check amount in cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


21
# File 'lib/increase/models/simulations/inbound_check_deposit_create_params.rb', line 21

required :amount, Integer

#check_numberString

The check number on the check to be deposited.

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/increase/models/simulations/inbound_check_deposit_create_params.rb', line 27

required :check_number, String

#payee_name_analysisSymbol, ...

Simulate the outcome of payee name checking. Defaults to not_evaluated.



35
36
# File 'lib/increase/models/simulations/inbound_check_deposit_create_params.rb', line 35

optional :payee_name_analysis,
enum: -> { Increase::Simulations::InboundCheckDepositCreateParams::PayeeNameAnalysis }

Instance Method Details

#to_hash{

Returns:

  • ({)


37
# File 'sig/increase/models/simulations/inbound_check_deposit_create_params.rbs', line 37

def to_hash: -> {