Class: Increase::Models::Simulations::InboundRealTimePaymentsTransferCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb,
sig/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rbs

Overview

See Also:

  • Increase::Resources::Simulations::InboundRealTimePaymentsTransfers#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number_id:, amount:, debtor_account_number: nil, debtor_name: nil, debtor_routing_number: nil, request_for_payment_id: nil, unstructured_remittance_information: nil, request_options: {}) ⇒ Object



# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 54

Instance Attribute Details

#account_number_idString

The identifier of the Account Number the inbound Real-Time Payments Transfer is for.



16
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 16

required :account_number_id, String

#amountInteger

The transfer amount in USD cents. Must be positive.



22
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 22

required :amount, Integer

#debtor_account_numberString?

The account number of the account that sent the transfer.



28
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 28

optional :debtor_account_number, String

#debtor_nameString?

The name provided by the sender of the transfer.



34
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 34

optional :debtor_name, String

#debtor_routing_numberString?

The routing number of the account that sent the transfer.



40
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 40

optional :debtor_routing_number, String

#request_for_payment_idString?

The identifier of a pending Request for Payment that this transfer will fulfill.



46
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 46

optional :request_for_payment_id, String

#unstructured_remittance_informationString?

Additional information included with the transfer.



52
# File 'lib/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rb', line 52

optional :unstructured_remittance_information, String

Instance Method Details

#to_hash{



55
# File 'sig/increase/models/simulations/inbound_real_time_payments_transfer_create_params.rbs', line 55

def to_hash: -> {