Module: Increase::Models::Simulations::PhysicalCardAdvanceShipmentParams::ShipmentStatus

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/physical_card_advance_shipment_params.rb,
sig/increase/models/simulations/physical_card_advance_shipment_params.rbs

Overview

The shipment status to move the Physical Card to.

Constant Summary collapse

PENDING =

The physical card has not yet been shipped.

Returns:

  • (:pending)
:pending
CANCELED =

The physical card shipment was canceled prior to submission.

Returns:

  • (:canceled)
:canceled
SUBMITTED =

The physical card shipment has been submitted to the card fulfillment provider.

Returns:

  • (:submitted)
:submitted
ACKNOWLEDGED =

The physical card shipment has been acknowledged by the card fulfillment provider and will be processed in their next batch.

Returns:

  • (:acknowledged)
:acknowledged
REJECTED =

The physical card shipment was rejected by the card printer due to an error.

Returns:

  • (:rejected)
:rejected
SHIPPED =

The physical card has been shipped.

Returns:

  • (:shipped)
:shipped
RETURNED =

The physical card shipment was returned to the sender and destroyed by the production facility.

Returns:

  • (:returned)
:returned
REQUIRES_ATTENTION =

The physical card shipment requires attention from Increase before progressing.

Returns:

  • (:requires_attention)
:requires_attention

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/simulations/physical_card_advance_shipment_params.rb', line 59

Instance Method Details

#self?.values::Array[Increase::Models::Simulations::PhysicalCardAdvanceShipmentParams::shipment_status]

Returns:

  • (::Array[Increase::Models::Simulations::PhysicalCardAdvanceShipmentParams::shipment_status])


68
# File 'sig/increase/models/simulations/physical_card_advance_shipment_params.rbs', line 68

def self?.values: -> ::Array[Increase::Models::Simulations::PhysicalCardAdvanceShipmentParams::shipment_status]