Module: Increase::Models::Simulations::PhysicalCardCreateParams::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/simulations/physical_card_create_params.rb

Overview

The type of tracking event.

Constant Summary collapse

IN_TRANSIT =

The physical card is in transit.

:in_transit
PROCESSED_FOR_DELIVERY =

The physical card has been processed for delivery.

:processed_for_delivery
DELIVERED =

The physical card has been delivered.

:delivered
DELIVERY_ISSUE =

There is an issue preventing delivery. The delivery will be attempted again if possible. If the issue cannot be resolved, the physical card will be returned to sender.

:delivery_issue
RETURNED_TO_SENDER =

Delivery failed and the physical card was returned to sender.

:returned_to_sender

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/simulations/physical_card_create_params.rb', line 85