Class: Increase::Models::Simulations::ProgramCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::ProgramCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/program_create_params.rb,
sig/increase/models/simulations/program_create_params.rbs
Overview
Defined Under Namespace
Modules: Bank
Instance Attribute Summary collapse
-
#bank ⇒ Symbol, ...
The bank for the program's accounts, defaults to First Internet Bank.
-
#lending_maximum_extendable_credit ⇒ Integer?
The maximum extendable credit of the program being added.
-
#loan_accounts_require_loan_offers ⇒ Boolean?
Whether opening a loan Account under this Program requires an accepted Loan Offer.
-
#name ⇒ String
The name of the program being added.
-
#reserve_account_id ⇒ String?
The identifier of the Account the Program should be added to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(name:, bank: nil, lending_maximum_extendable_credit: nil, loan_accounts_require_loan_offers: nil, reserve_account_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, bank: nil, lending_maximum_extendable_credit: nil, loan_accounts_require_loan_offers: nil, reserve_account_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/increase/models/simulations/program_create_params.rb', line 42
|
Instance Attribute Details
#bank ⇒ Symbol, ...
The bank for the program's accounts, defaults to First Internet Bank.
21 |
# File 'lib/increase/models/simulations/program_create_params.rb', line 21 optional :bank, enum: -> { Increase::Simulations::ProgramCreateParams::Bank } |
#lending_maximum_extendable_credit ⇒ Integer?
The maximum extendable credit of the program being added.
27 |
# File 'lib/increase/models/simulations/program_create_params.rb', line 27 optional :lending_maximum_extendable_credit, Integer |
#loan_accounts_require_loan_offers ⇒ Boolean?
Whether opening a loan Account under this Program requires an accepted Loan
Offer. Requires lending_maximum_extendable_credit. Defaults to false.
34 |
# File 'lib/increase/models/simulations/program_create_params.rb', line 34 optional :loan_accounts_require_loan_offers, Increase::Internal::Type::Boolean |
#name ⇒ String
The name of the program being added.
15 |
# File 'lib/increase/models/simulations/program_create_params.rb', line 15 required :name, String |
#reserve_account_id ⇒ String?
The identifier of the Account the Program should be added to.
40 |
# File 'lib/increase/models/simulations/program_create_params.rb', line 40 optional :reserve_account_id, String |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/increase/models/simulations/program_create_params.rbs', line 47
def to_hash: -> {
|