Class: Increase::Models::SwiftTransferCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/swift_transfer_create_params.rb

Overview

Defined Under Namespace

Modules: InstructedCurrency Classes: CreditorAddress, DebtorAddress

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil) ⇒ Object

Some parameter documentations has been truncated, see DebtorAddress for more details.

The debtor’s address.

Parameters:

  • city (String)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alp

  • line1 (String)

    The first line of the address. This is usually the street number and street.

  • line2 (String) (defaults to: nil)

    The second line of the address. This might be the floor or room number.

  • postal_code (String) (defaults to: nil)

    The ZIP or postal code of the address. Required in certain countries.

  • state (String) (defaults to: nil)

    The state, province, or region of the address. Required in certain countries.



# File 'lib/increase/models/swift_transfer_create_params.rb', line 163

Instance Attribute Details

#account_idString

The identifier for the account that will send the transfer.

Returns:

  • (String)


14
# File 'lib/increase/models/swift_transfer_create_params.rb', line 14

required :account_id, String

#account_numberString

The creditor’s account number.

Returns:

  • (String)


20
# File 'lib/increase/models/swift_transfer_create_params.rb', line 20

required :account_number, String

#bank_identification_codeString

The bank identification code (BIC) of the creditor. If it ends with the three-character branch code, this must be 11 characters long. Otherwise this must be 8 characters and the branch code will be assumed to be ‘XXX`.

Returns:

  • (String)


28
# File 'lib/increase/models/swift_transfer_create_params.rb', line 28

required :bank_identification_code, String

#creditor_addressIncrease::Models::SwiftTransferCreateParams::CreditorAddress

The creditor’s address.



34
# File 'lib/increase/models/swift_transfer_create_params.rb', line 34

required :creditor_address, -> { Increase::SwiftTransferCreateParams::CreditorAddress }

#creditor_nameString

The creditor’s name.

Returns:

  • (String)


40
# File 'lib/increase/models/swift_transfer_create_params.rb', line 40

required :creditor_name, String

#debtor_addressIncrease::Models::SwiftTransferCreateParams::DebtorAddress

The debtor’s address.



46
# File 'lib/increase/models/swift_transfer_create_params.rb', line 46

required :debtor_address, -> { Increase::SwiftTransferCreateParams::DebtorAddress }

#debtor_nameString

The debtor’s name.

Returns:

  • (String)


52
# File 'lib/increase/models/swift_transfer_create_params.rb', line 52

required :debtor_name, String

#instructed_amountInteger

The amount, in minor units of ‘instructed_currency`, to send to the creditor.

Returns:

  • (Integer)


58
# File 'lib/increase/models/swift_transfer_create_params.rb', line 58

required :instructed_amount, Integer

#instructed_currencySymbol, Increase::Models::SwiftTransferCreateParams::InstructedCurrency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) currency code of the instructed amount.



65
# File 'lib/increase/models/swift_transfer_create_params.rb', line 65

required :instructed_currency, enum: -> { Increase::SwiftTransferCreateParams::InstructedCurrency }

#require_approvalBoolean?

Whether the transfer requires explicit approval via the dashboard or API.

Returns:

  • (Boolean, nil)


83
# File 'lib/increase/models/swift_transfer_create_params.rb', line 83

optional :require_approval, Increase::Internal::Type::Boolean

#routing_numberString?

The creditor’s bank account routing or transit number. Required in certain countries.

Returns:

  • (String, nil)


90
# File 'lib/increase/models/swift_transfer_create_params.rb', line 90

optional :routing_number, String

#source_account_number_idString

The Account Number to include in the transfer as the debtor’s account number.

Returns:

  • (String)


71
# File 'lib/increase/models/swift_transfer_create_params.rb', line 71

required :source_account_number_id, String

#unstructured_remittance_informationString

Unstructured remittance information to include in the transfer.

Returns:

  • (String)


77
# File 'lib/increase/models/swift_transfer_create_params.rb', line 77

required :unstructured_remittance_information, String