Class: Increase::Models::SwiftTransferCreateParams::CreditorAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/swift_transfer_create_params.rb,
sig/increase/models/swift_transfer_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, account_number:, bank_identification_code:, creditor_address:, creditor_name:, debtor_address:, debtor_name:, instructed_amount:, instructed_currency:, source_account_number_id:, unstructured_remittance_information:, intermediary_bank_identification_code: nil, require_approval: nil, routing_number: nil, request_options: {}) ⇒ Object

Parameters:

  • account_id (String)

    The identifier for the account that will send the transfer.

  • account_number (String)

    The creditor's account number.

  • bank_identification_code (String)

    The bank identification code (BIC) of the creditor. If it ends with the three-character branch code, this must be 11 characters long. Otherwise this must be 8 characters and the branch code will be assumed to be XXX.

  • creditor_address (Increase::Models::SwiftTransferCreateParams::CreditorAddress)

    The creditor's address.

  • creditor_name (String)

    The creditor's name.

  • debtor_address (Increase::Models::SwiftTransferCreateParams::DebtorAddress)

    The debtor's address.

  • debtor_name (String)

    The debtor's name.

  • instructed_amount (Integer)

    The amount, in minor units of instructed_currency, to send to the creditor.

  • instructed_currency (Symbol, Increase::Models::SwiftTransferCreateParams::InstructedCurrency)

    The ISO 4217 currency code of the instructed amount.

  • source_account_number_id (String)

    The Account Number to include in the transfer as the debtor's account number.

  • unstructured_remittance_information (String)

    Unstructured remittance information to include in the transfer.

  • intermediary_bank_identification_code (String) (defaults to: nil)

    The bank identification code (BIC) of the intermediary bank, if the transfer should be routed through one.

  • require_approval (Boolean) (defaults to: nil)

    Whether the transfer requires explicit approval via the dashboard or API.

  • routing_number (String) (defaults to: nil)

    The creditor's bank account routing or transit number. Required in certain countries.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/increase/models/swift_transfer_create_params.rb', line 144

class CreditorAddress < Increase::Internal::Type::BaseModel
  # @!attribute city
  #   The city, district, town, or village of the address.
  #
  #   @return [String]
  required :city, String

  # @!attribute country
  #   The two-letter
  #   [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for
  #   the country of the address.
  #
  #   @return [String]
  required :country, String

  # @!attribute line1
  #   The first line of the address. This is usually the street number and street.
  #
  #   @return [String]
  required :line1, String

  # @!attribute line2
  #   The second line of the address. This might be the floor or room number.
  #
  #   @return [String, nil]
  optional :line2, String

  # @!attribute postal_code
  #   The ZIP or postal code of the address. Required in certain countries.
  #
  #   @return [String, nil]
  optional :postal_code, String

  # @!attribute state
  #   The state, province, or region of the address. Required in certain countries.
  #
  #   @return [String, nil]
  optional :state, String

  # @!method initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil)
  #   The creditor's address.
  #
  #   @param city [String] The city, district, town, or village of the address.
  #
  #   @param country [String]
  #     The two-letter
  #     [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for
  #     the country of the address.
  #
  #   @param line1 [String] The first line of the address. This is usually the street number and street.
  #
  #   @param line2 [String] The second line of the address. This might be the floor or room number.
  #
  #   @param postal_code [String] The ZIP or postal code of the address. Required in certain countries.
  #
  #   @param state [String] The state, province, or region of the address. Required in certain countries.
end

Instance Attribute Details

#cityString

The city, district, town, or village of the address.

Parameters:

  • value (String)

Returns:

  • (String)


149
# File 'lib/increase/models/swift_transfer_create_params.rb', line 149

required :city, String

#countryString

The two-letter ISO 3166-1 alpha-2 code for the country of the address.

Parameters:

  • value (String)

Returns:

  • (String)


157
# File 'lib/increase/models/swift_transfer_create_params.rb', line 157

required :country, String

#line1String

The first line of the address. This is usually the street number and street.

Parameters:

  • value (String)

Returns:

  • (String)


163
# File 'lib/increase/models/swift_transfer_create_params.rb', line 163

required :line1, String

#line2String?

The second line of the address. This might be the floor or room number.

Parameters:

  • (String)

Returns:

  • (String, nil)


169
# File 'lib/increase/models/swift_transfer_create_params.rb', line 169

optional :line2, String

#postal_codeString?

The ZIP or postal code of the address. Required in certain countries.

Parameters:

  • (String)

Returns:

  • (String, nil)


175
# File 'lib/increase/models/swift_transfer_create_params.rb', line 175

optional :postal_code, String

#stateString?

The state, province, or region of the address. Required in certain countries.

Parameters:

  • (String)

Returns:

  • (String, nil)


181
# File 'lib/increase/models/swift_transfer_create_params.rb', line 181

optional :state, String

Instance Method Details

#to_hash{

Returns:

  • ({)


134
# File 'sig/increase/models/swift_transfer_create_params.rbs', line 134

def to_hash: -> {