Class: Increase::Models::Transaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Resources::Transactions#retrieve

Defined Under Namespace

Modules: Currency, RouteType, Type Classes: Source

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, amount:, message_to_recipient:, routing_number:, transfer_id:) ⇒ Object

A Wire Transfer Intention object. This field will be present in the JSON response if and only if category is equal to wire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.

Parameters:

  • account_number (String)

    The destination account number.

  • amount (Integer)

    The transfer amount in USD cents.

  • message_to_recipient (String)

    The message that will show on the recipient's bank statement.

  • routing_number (String)

    The American Bankers' Association (ABA) Routing Transit Number (RTN).

  • transfer_id (String)

    The identifier of the Wire Transfer that led to this Transaction.



# File 'lib/increase/models/transaction.rb', line 78

Instance Attribute Details

#account_idString

The identifier for the Account the Transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/increase/models/transaction.rb', line 17

required :account_id, String

#amountInteger

The Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


24
# File 'lib/increase/models/transaction.rb', line 24

required :amount, Integer

#created_atTime

The ISO 8601 date and time at which the Transaction occurred.

Parameters:

  • value (Time)

Returns:

  • (Time)


31
# File 'lib/increase/models/transaction.rb', line 31

required :created_at, Time

#currencySymbol, Increase::Models::Transaction::Currency

The ISO 4217 code for the Transaction's currency. This will match the currency on the Transaction's Account.

Parameters:

  • value (Increase::Models::Transaction::currency)

Returns:



39
# File 'lib/increase/models/transaction.rb', line 39

required :currency, enum: -> { Increase::Transaction::Currency }

#descriptionString

An informational message describing this transaction. Use the fields in source to get more detailed information. This field appears as the line-item on the statement.

Parameters:

  • value (String)

Returns:

  • (String)


47
# File 'lib/increase/models/transaction.rb', line 47

required :description, String

#idString

The Transaction identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/transaction.rb', line 11

required :id, String

#route_idString?

The identifier for the route this Transaction came through. Routes are things like cards and ACH details.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


54
# File 'lib/increase/models/transaction.rb', line 54

required :route_id, String, nil?: true

#route_typeSymbol, ...

The type of the route this Transaction came through.

Parameters:

  • value (Increase::Models::Transaction::route_type, nil)

Returns:



60
# File 'lib/increase/models/transaction.rb', line 60

required :route_type, enum: -> { Increase::Transaction::RouteType }, nil?: true

#sourceIncrease::Models::Transaction::Source

This is an object giving more details on the network-level event that caused the Transaction. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.

Parameters:

  • value (Increase::Transaction::Source)

Returns:



69
# File 'lib/increase/models/transaction.rb', line 69

required :source, -> { Increase::Transaction::Source }

#typeSymbol, Increase::Models::Transaction::Type

A constant representing the object's type. For this resource it will always be transaction.

Parameters:

  • value (Increase::Models::Transaction::type_)

Returns:



76
# File 'lib/increase/models/transaction.rb', line 76

required :type, enum: -> { Increase::Transaction::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 117

Instance Method Details

#to_hash{

Returns:

  • ({)


51
# File 'sig/increase/models/transaction.rbs', line 51

def to_hash: -> {