Class: Increase::Models::Transaction::Source

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction#source

Defined Under Namespace

Modules: Category Classes: ACHTransferIntention, ACHTransferRejection, ACHTransferReturn, AccountRevenuePayment, AccountTransferIntention, BlockchainOfframpTransferSettlement, BlockchainOnrampTransferIntention, CardDisputeAcceptance, CardDisputeFinancial, CardDisputeLoss, CardFinancial, CardPushTransferAcceptance, CardRefund, CardRevenuePayment, CardSettlement, CashbackPayment, CheckDepositAcceptance, CheckDepositReturn, CheckTransferDeposit, FednowTransferAcknowledgement, FeePayment, InboundACHTransfer, InboundACHTransferReturnIntention, InboundCheckAdjustment, InboundCheckDepositReturnIntention, InboundFednowTransferConfirmation, InboundRealTimePaymentsTransferConfirmation, InboundWireReversal, InboundWireTransfer, InboundWireTransferReversal, InterestPayment, InternalSource, Other, RealTimePaymentsTransferAcknowledgement, SampleFunds, SwiftTransferIntention, SwiftTransferReturn, WireTransferIntention

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transfer_id:) ⇒ Object

A Swift Transfer Return object. This field will be present in the JSON response if and only if category is equal to swift_transfer_return. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.

Parameters:

  • transfer_id (String)

    The identifier of the Swift Transfer that led to this Transaction.



# File 'lib/increase/models/transaction.rb', line 565

Instance Attribute Details

#account_revenue_paymentIncrease::Models::Transaction::Source::AccountRevenuePayment?

An Account Revenue Payment object. This field will be present in the JSON response if and only if category is equal to account_revenue_payment. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.

Parameters:

  • value (Increase::Transaction::Source::AccountRevenuePayment, nil)

Returns:



172
173
174
175
176
# File 'lib/increase/models/transaction.rb', line 172

optional :account_revenue_payment,
-> {
  Increase::Transaction::Source::AccountRevenuePayment
},
nil?: true

#account_transfer_intentionIncrease::Models::Transaction::Source::AccountTransferIntention?

An Account Transfer Intention object. This field will be present in the JSON response if and only if category is equal to account_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.

Parameters:

  • value (Increase::Transaction::Source::AccountTransferIntention, nil)

Returns:



185
186
187
# File 'lib/increase/models/transaction.rb', line 185

optional :account_transfer_intention,
-> { Increase::Transaction::Source::AccountTransferIntention },
nil?: true

#ach_transfer_intentionIncrease::Models::Transaction::Source::ACHTransferIntention?

An ACH Transfer Intention object. This field will be present in the JSON response if and only if category is equal to ach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.

Parameters:

  • value (Increase::Transaction::Source::ACHTransferIntention, nil)

Returns:



196
197
198
199
200
# File 'lib/increase/models/transaction.rb', line 196

optional :ach_transfer_intention,
-> {
  Increase::Transaction::Source::ACHTransferIntention
},
nil?: true

#ach_transfer_rejectionIncrease::Models::Transaction::Source::ACHTransferRejection?

An ACH Transfer Rejection object. This field will be present in the JSON response if and only if category is equal to ach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.

Parameters:

  • value (Increase::Transaction::Source::ACHTransferRejection, nil)

Returns:



209
210
211
212
213
# File 'lib/increase/models/transaction.rb', line 209

optional :ach_transfer_rejection,
-> {
  Increase::Transaction::Source::ACHTransferRejection
},
nil?: true

#ach_transfer_returnIncrease::Models::Transaction::Source::ACHTransferReturn?

An ACH Transfer Return object. This field will be present in the JSON response if and only if category is equal to ach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later. The return appears as a new posted Transaction; no Pending Transaction is created.

Parameters:

  • value (Increase::Transaction::Source::ACHTransferReturn, nil)

Returns:



225
# File 'lib/increase/models/transaction.rb', line 225

optional :ach_transfer_return, -> { Increase::Transaction::Source::ACHTransferReturn }, nil?: true

#blockchain_offramp_transfer_settlementIncrease::Models::Transaction::Source::BlockchainOfframpTransferSettlement?

A Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if category is equal to blockchain_offramp_transfer_settlement.

Parameters:

  • value (Increase::Transaction::Source::BlockchainOfframpTransferSettlement, nil)

Returns:



233
234
235
# File 'lib/increase/models/transaction.rb', line 233

optional :blockchain_offramp_transfer_settlement,
-> { Increase::Transaction::Source::BlockchainOfframpTransferSettlement },
nil?: true

#blockchain_onramp_transfer_intentionIncrease::Models::Transaction::Source::BlockchainOnrampTransferIntention?

A Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if category is equal to blockchain_onramp_transfer_intention.

Parameters:

  • value (Increase::Transaction::Source::BlockchainOnrampTransferIntention, nil)

Returns:



243
244
245
# File 'lib/increase/models/transaction.rb', line 243

optional :blockchain_onramp_transfer_intention,
-> { Increase::Transaction::Source::BlockchainOnrampTransferIntention },
nil?: true

#card_dispute_acceptanceIncrease::Models::Transaction::Source::CardDisputeAcceptance?

A Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if category is equal to card_dispute_acceptance. Contains the details of a successful Card Dispute.

Parameters:

  • value (Increase::Transaction::Source::CardDisputeAcceptance, nil)

Returns:



253
254
255
256
257
# File 'lib/increase/models/transaction.rb', line 253

optional :card_dispute_acceptance,
-> {
  Increase::Transaction::Source::CardDisputeAcceptance
},
nil?: true

#card_dispute_financialIncrease::Models::Transaction::Source::CardDisputeFinancial?

A Card Dispute Financial object. This field will be present in the JSON response if and only if category is equal to card_dispute_financial. Financial event related to a Card Dispute.

Parameters:

  • value (Increase::Transaction::Source::CardDisputeFinancial, nil)

Returns:



265
266
267
268
269
# File 'lib/increase/models/transaction.rb', line 265

optional :card_dispute_financial,
-> {
  Increase::Transaction::Source::CardDisputeFinancial
},
nil?: true

#card_dispute_lossIncrease::Models::Transaction::Source::CardDisputeLoss?

A Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if category is equal to card_dispute_loss. Contains the details of a lost Card Dispute.

Parameters:

  • value (Increase::Transaction::Source::CardDisputeLoss, nil)

Returns:



277
# File 'lib/increase/models/transaction.rb', line 277

optional :card_dispute_loss, -> { Increase::Transaction::Source::CardDisputeLoss }, nil?: true

#card_financialIncrease::Models::Transaction::Source::CardFinancial?

A Card Financial object. This field will be present in the JSON response if and only if category is equal to card_financial. Card Financials are card transactions that have cleared and settled. Unlike a Card Settlement, which clears a previous authorization, a Card Financial is authorized and cleared in a single message.

Parameters:

  • value (Increase::Transaction::Source::CardFinancial, nil)

Returns:



287
# File 'lib/increase/models/transaction.rb', line 287

optional :card_financial, -> { Increase::Transaction::Source::CardFinancial }, nil?: true

#card_push_transfer_acceptanceIncrease::Models::Transaction::Source::CardPushTransferAcceptance?

A Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if category is equal to card_push_transfer_acceptance. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.

Parameters:

  • value (Increase::Transaction::Source::CardPushTransferAcceptance, nil)

Returns:



296
297
298
# File 'lib/increase/models/transaction.rb', line 296

optional :card_push_transfer_acceptance,
-> { Increase::Transaction::Source::CardPushTransferAcceptance },
nil?: true

#card_refundIncrease::Models::Transaction::Source::CardRefund?

A Card Refund object. This field will be present in the JSON response if and only if category is equal to card_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.

Parameters:

  • value (Increase::Transaction::Source::CardRefund, nil)

Returns:



308
# File 'lib/increase/models/transaction.rb', line 308

optional :card_refund, -> { Increase::Transaction::Source::CardRefund }, nil?: true

#card_revenue_paymentIncrease::Models::Transaction::Source::CardRevenuePayment?

A Card Revenue Payment object. This field will be present in the JSON response if and only if category is equal to card_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.

Parameters:

  • value (Increase::Transaction::Source::CardRevenuePayment, nil)

Returns:



316
# File 'lib/increase/models/transaction.rb', line 316

optional :card_revenue_payment, -> { Increase::Transaction::Source::CardRevenuePayment }, nil?: true

#card_settlementIncrease::Models::Transaction::Source::CardSettlement?

A Card Settlement object. This field will be present in the JSON response if and only if category is equal to card_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.

Parameters:

  • value (Increase::Transaction::Source::CardSettlement, nil)

Returns:



326
# File 'lib/increase/models/transaction.rb', line 326

optional :card_settlement, -> { Increase::Transaction::Source::CardSettlement }, nil?: true

#cashback_paymentIncrease::Models::Transaction::Source::CashbackPayment?

A Cashback Payment object. This field will be present in the JSON response if and only if category is equal to cashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.

Parameters:

  • value (Increase::Transaction::Source::CashbackPayment, nil)

Returns:



335
# File 'lib/increase/models/transaction.rb', line 335

optional :cashback_payment, -> { Increase::Transaction::Source::CashbackPayment }, nil?: true

#categorySymbol, Increase::Models::Transaction::Source::Category

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

Parameters:

  • value (Increase::Models::Transaction::Source::category)

Returns:



163
# File 'lib/increase/models/transaction.rb', line 163

required :category, enum: -> { Increase::Transaction::Source::Category }

#check_deposit_acceptanceIncrease::Models::Transaction::Source::CheckDepositAcceptance?

A Check Deposit Acceptance object. This field will be present in the JSON response if and only if category is equal to check_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.

Parameters:

  • value (Increase::Transaction::Source::CheckDepositAcceptance, nil)

Returns:



345
346
347
# File 'lib/increase/models/transaction.rb', line 345

optional :check_deposit_acceptance,
-> { Increase::Transaction::Source::CheckDepositAcceptance },
nil?: true

#check_deposit_returnIncrease::Models::Transaction::Source::CheckDepositReturn?

A Check Deposit Return object. This field will be present in the JSON response if and only if category is equal to check_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.

Parameters:

  • value (Increase::Transaction::Source::CheckDepositReturn, nil)

Returns:



358
# File 'lib/increase/models/transaction.rb', line 358

optional :check_deposit_return, -> { Increase::Transaction::Source::CheckDepositReturn }, nil?: true

#check_transfer_depositIncrease::Models::Transaction::Source::CheckTransferDeposit?

A Check Transfer Deposit object. This field will be present in the JSON response if and only if category is equal to check_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.

Parameters:

  • value (Increase::Transaction::Source::CheckTransferDeposit, nil)

Returns:



367
368
369
370
371
# File 'lib/increase/models/transaction.rb', line 367

optional :check_transfer_deposit,
-> {
  Increase::Transaction::Source::CheckTransferDeposit
},
nil?: true

#fednow_transfer_acknowledgementIncrease::Models::Transaction::Source::FednowTransferAcknowledgement?

A FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if category is equal to fednow_transfer_acknowledgement. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.

Parameters:

  • value (Increase::Transaction::Source::FednowTransferAcknowledgement, nil)

Returns:



380
381
382
# File 'lib/increase/models/transaction.rb', line 380

optional :fednow_transfer_acknowledgement,
-> { Increase::Transaction::Source::FednowTransferAcknowledgement },
nil?: true

#fee_paymentIncrease::Models::Transaction::Source::FeePayment?

A Fee Payment object. This field will be present in the JSON response if and only if category is equal to fee_payment. A Fee Payment represents a payment made to Increase.

Parameters:

  • value (Increase::Transaction::Source::FeePayment, nil)

Returns:



390
# File 'lib/increase/models/transaction.rb', line 390

optional :fee_payment, -> { Increase::Transaction::Source::FeePayment }, nil?: true

#inbound_ach_transferIncrease::Models::Transaction::Source::InboundACHTransfer?

An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if category is equal to inbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.

Parameters:

  • value (Increase::Transaction::Source::InboundACHTransfer, nil)

Returns:



399
# File 'lib/increase/models/transaction.rb', line 399

optional :inbound_ach_transfer, -> { Increase::Transaction::Source::InboundACHTransfer }, nil?: true

#inbound_ach_transfer_return_intentionIncrease::Models::Transaction::Source::InboundACHTransferReturnIntention?

An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if category is equal to inbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.

Parameters:

  • value (Increase::Transaction::Source::InboundACHTransferReturnIntention, nil)

Returns:



409
410
411
# File 'lib/increase/models/transaction.rb', line 409

optional :inbound_ach_transfer_return_intention,
-> { Increase::Transaction::Source::InboundACHTransferReturnIntention },
nil?: true

#inbound_check_adjustmentIncrease::Models::Transaction::Source::InboundCheckAdjustment?

An Inbound Check Adjustment object. This field will be present in the JSON response if and only if category is equal to inbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.

Parameters:

  • value (Increase::Transaction::Source::InboundCheckAdjustment, nil)

Returns:



420
421
422
# File 'lib/increase/models/transaction.rb', line 420

optional :inbound_check_adjustment,
-> { Increase::Transaction::Source::InboundCheckAdjustment },
nil?: true

#inbound_check_deposit_return_intentionIncrease::Models::Transaction::Source::InboundCheckDepositReturnIntention?

An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if category is equal to inbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.

Parameters:

  • value (Increase::Transaction::Source::InboundCheckDepositReturnIntention, nil)

Returns:



432
433
434
# File 'lib/increase/models/transaction.rb', line 432

optional :inbound_check_deposit_return_intention,
-> { Increase::Transaction::Source::InboundCheckDepositReturnIntention },
nil?: true

#inbound_fednow_transfer_confirmationIncrease::Models::Transaction::Source::InboundFednowTransferConfirmation?

An Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if category is equal to inbound_fednow_transfer_confirmation. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.

Parameters:

  • value (Increase::Transaction::Source::InboundFednowTransferConfirmation, nil)

Returns:



444
445
446
# File 'lib/increase/models/transaction.rb', line 444

optional :inbound_fednow_transfer_confirmation,
-> { Increase::Transaction::Source::InboundFednowTransferConfirmation },
nil?: true

#inbound_real_time_payments_transfer_confirmationIncrease::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation?

An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if category is equal to inbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.

Parameters:

  • value (Increase::Transaction::Source::InboundRealTimePaymentsTransferConfirmation, nil)

Returns:



456
457
458
# File 'lib/increase/models/transaction.rb', line 456

optional :inbound_real_time_payments_transfer_confirmation,
-> { Increase::Transaction::Source::InboundRealTimePaymentsTransferConfirmation },
nil?: true

#inbound_wire_reversalIncrease::Models::Transaction::Source::InboundWireReversal?

An Inbound Wire Reversal object. This field will be present in the JSON response if and only if category is equal to inbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.

Parameters:

  • value (Increase::Transaction::Source::InboundWireReversal, nil)

Returns:



468
# File 'lib/increase/models/transaction.rb', line 468

optional :inbound_wire_reversal, -> { Increase::Transaction::Source::InboundWireReversal }, nil?: true

#inbound_wire_transferIncrease::Models::Transaction::Source::InboundWireTransfer?

An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if category is equal to inbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.

Parameters:

  • value (Increase::Transaction::Source::InboundWireTransfer, nil)

Returns:



477
# File 'lib/increase/models/transaction.rb', line 477

optional :inbound_wire_transfer, -> { Increase::Transaction::Source::InboundWireTransfer }, nil?: true

#inbound_wire_transfer_reversalIncrease::Models::Transaction::Source::InboundWireTransferReversal?

An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if category is equal to inbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.

Parameters:

  • value (Increase::Transaction::Source::InboundWireTransferReversal, nil)

Returns:



487
488
489
# File 'lib/increase/models/transaction.rb', line 487

optional :inbound_wire_transfer_reversal,
-> { Increase::Transaction::Source::InboundWireTransferReversal },
nil?: true

#interest_paymentIncrease::Models::Transaction::Source::InterestPayment?

An Interest Payment object. This field will be present in the JSON response if and only if category is equal to interest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.

Parameters:

  • value (Increase::Transaction::Source::InterestPayment, nil)

Returns:



498
# File 'lib/increase/models/transaction.rb', line 498

optional :interest_payment, -> { Increase::Transaction::Source::InterestPayment }, nil?: true

#internal_sourceIncrease::Models::Transaction::Source::InternalSource?

An Internal Source object. This field will be present in the JSON response if and only if category is equal to internal_source. A transaction between the user and Increase. See the reason attribute for more information.

Parameters:

  • value (Increase::Transaction::Source::InternalSource, nil)

Returns:



506
# File 'lib/increase/models/transaction.rb', line 506

optional :internal_source, -> { Increase::Transaction::Source::InternalSource }, nil?: true

#otherIncrease::Models::Transaction::Source::Other?

If the category of this Transaction source is equal to other, this field will contain an empty object, otherwise it will contain null.

Parameters:

  • value (Increase::Transaction::Source::Other, nil)

Returns:



513
# File 'lib/increase/models/transaction.rb', line 513

optional :other, -> { Increase::Transaction::Source::Other }, nil?: true

#real_time_payments_transfer_acknowledgementIncrease::Models::Transaction::Source::RealTimePaymentsTransferAcknowledgement?

A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if category is equal to real_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.

Parameters:

  • value (Increase::Transaction::Source::RealTimePaymentsTransferAcknowledgement, nil)

Returns:



523
524
525
# File 'lib/increase/models/transaction.rb', line 523

optional :real_time_payments_transfer_acknowledgement,
-> { Increase::Transaction::Source::RealTimePaymentsTransferAcknowledgement },
nil?: true

#sample_fundsIncrease::Models::Transaction::Source::SampleFunds?

A Sample Funds object. This field will be present in the JSON response if and only if category is equal to sample_funds. Sample funds for testing purposes.

Parameters:

  • value (Increase::Transaction::Source::SampleFunds, nil)

Returns:



533
# File 'lib/increase/models/transaction.rb', line 533

optional :sample_funds, -> { Increase::Transaction::Source::SampleFunds }, nil?: true

#swift_transfer_intentionIncrease::Models::Transaction::Source::SwiftTransferIntention?

A Swift Transfer Intention object. This field will be present in the JSON response if and only if category is equal to swift_transfer_intention. A Swift Transfer initiated via Increase.

Parameters:

  • value (Increase::Transaction::Source::SwiftTransferIntention, nil)

Returns:



541
542
543
# File 'lib/increase/models/transaction.rb', line 541

optional :swift_transfer_intention,
-> { Increase::Transaction::Source::SwiftTransferIntention },
nil?: true

#swift_transfer_returnIncrease::Models::Transaction::Source::SwiftTransferReturn?

A Swift Transfer Return object. This field will be present in the JSON response if and only if category is equal to swift_transfer_return. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.

Parameters:

  • value (Increase::Transaction::Source::SwiftTransferReturn, nil)

Returns:



551
# File 'lib/increase/models/transaction.rb', line 551

optional :swift_transfer_return, -> { Increase::Transaction::Source::SwiftTransferReturn }, nil?: true

#wire_transfer_intentionIncrease::Models::Transaction::Source::WireTransferIntention?

A Wire Transfer Intention object. This field will be present in the JSON response if and only if category is equal to wire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.

Parameters:

  • value (Increase::Transaction::Source::WireTransferIntention, nil)

Returns:



559
560
561
562
563
# File 'lib/increase/models/transaction.rb', line 559

optional :wire_transfer_intention,
-> {
  Increase::Transaction::Source::WireTransferIntention
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 926

Instance Method Details

#to_hash{

Returns:

  • ({)


256
# File 'sig/increase/models/transaction.rbs', line 256

def to_hash: -> {