Class: Increase::Models::Transaction::Source::ACHTransferIntention
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::ACHTransferIntention
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#account_number ⇒ String
The account number for the destination account.
-
#amount ⇒ Integer
The amount in the minor unit of the transaction's currency.
-
#routing_number ⇒ String
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
#statement_descriptor ⇒ String
A description set when the ACH Transfer was created.
-
#transfer_id ⇒ String
The identifier of the ACH Transfer that led to this Transaction.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
558 |
# File 'sig/increase/models/transaction.rbs', line 558
def initialize: (
|
Instance Attribute Details
#account_number ⇒ String
The account number for the destination account.
877 |
# File 'lib/increase/models/transaction.rb', line 877 required :account_number, String |
#amount ⇒ Integer
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
884 |
# File 'lib/increase/models/transaction.rb', line 884 required :amount, Integer |
#routing_number ⇒ String
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
891 |
# File 'lib/increase/models/transaction.rb', line 891 required :routing_number, String |
#statement_descriptor ⇒ String
A description set when the ACH Transfer was created.
897 |
# File 'lib/increase/models/transaction.rb', line 897 required :statement_descriptor, String |
#transfer_id ⇒ String
The identifier of the ACH Transfer that led to this Transaction.
903 |
# File 'lib/increase/models/transaction.rb', line 903 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
566 |
# File 'sig/increase/models/transaction.rbs', line 566
def to_hash: -> {
|