Class: Increase::Models::Transaction::Source::AccountTransferIntention

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#account_transfer_intention

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, description:, destination_account_id:, source_account_id:, transfer_id:) ⇒ Object

An Account Transfer Intention object. This field will be present in the JSON response if and only if category is equal to account_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.



# File 'lib/increase/models/transaction.rb', line 1069


Instance Attribute Details

#amountInteger

The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.



1036
# File 'lib/increase/models/transaction.rb', line 1036

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::AccountTransferIntention::Currency

The ISO 4217 code for the destination account currency.



1043
# File 'lib/increase/models/transaction.rb', line 1043

required :currency, enum: -> { Increase::Transaction::Source::AccountTransferIntention::Currency }

#descriptionString

The description you chose to give the transfer.



1049
# File 'lib/increase/models/transaction.rb', line 1049

required :description, String

#destination_account_idString

The identifier of the Account to where the Account Transfer was sent.



1055
# File 'lib/increase/models/transaction.rb', line 1055

required :destination_account_id, String

#source_account_idString

The identifier of the Account from where the Account Transfer was sent.



1061
# File 'lib/increase/models/transaction.rb', line 1061

required :source_account_id, String

#transfer_idString

The identifier of the Account Transfer that led to this Pending Transaction.



1067
# File 'lib/increase/models/transaction.rb', line 1067

required :transfer_id, String

Instance Method Details

#to_hash{



544
# File 'sig/increase/models/transaction.rbs', line 544

def to_hash: -> {