Class: Increase::Models::Transaction::Source::BlockchainOfframpTransferSettlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::BlockchainOfframpTransferSettlement
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#source_blockchain_address_id ⇒ String
The identifier of the Blockchain Address the funds were received at.
-
#transfer_id ⇒ String
The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
923 |
# File 'sig/increase/models/transaction.rbs', line 923
def initialize: (
|
Instance Attribute Details
#source_blockchain_address_id ⇒ String
The identifier of the Blockchain Address the funds were received at.
1242 |
# File 'lib/increase/models/transaction.rb', line 1242 required :source_blockchain_address_id, String |
#transfer_id ⇒ String
The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction.
1248 |
# File 'lib/increase/models/transaction.rb', line 1248 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
928 |
# File 'sig/increase/models/transaction.rbs', line 928
def to_hash: -> {
|