Class: Increase::Models::Transaction::Source::CardDisputeAcceptance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#card_dispute_acceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeCardDisputeAcceptance

Returns a new instance of CardDisputeAcceptance.

Parameters:

  • accepted_at: (Time)
  • transaction_id: (String)


961
# File 'sig/increase/models/transaction.rbs', line 961

def initialize: (accepted_at: Time, transaction_id: String) -> void

Instance Attribute Details

#accepted_atTime

The ISO 8601 date and time at which the Card Dispute was accepted.

Parameters:

  • value (Time)

Returns:

  • (Time)


1295
# File 'lib/increase/models/transaction.rb', line 1295

required :accepted_at, Time

#transaction_idString

The identifier of the Transaction that was created to return the disputed funds to your account.

Parameters:

  • value (String)

Returns:

  • (String)


1302
# File 'lib/increase/models/transaction.rb', line 1302

required :transaction_id, String

Instance Method Details

#to_hash{ accepted_at: Time, transaction_id: String }

Returns:

  • ({ accepted_at: Time, transaction_id: String })


963
# File 'sig/increase/models/transaction.rbs', line 963

def to_hash: -> { accepted_at: Time, transaction_id: String }