Class: Increase::Models::Transaction::Source::CardFinancial

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#card_financial

Defined Under Namespace

Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/transaction.rb', line 1921


Instance Attribute Details

#actionerSymbol, Increase::Models::Transaction::Source::CardFinancial::Actioner

Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.

Parameters:

Returns:



1744
# File 'lib/increase/models/transaction.rb', line 1744

required :actioner, enum: -> { Increase::Transaction::Source::CardFinancial::Actioner }

#additional_amountsIncrease::Models::Transaction::Source::CardFinancial::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharge fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

Returns:



1752
# File 'lib/increase/models/transaction.rb', line 1752

required :additional_amounts, -> { Increase::Transaction::Source::CardFinancial::AdditionalAmounts }

#amountInteger

The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

Returns:



1759
# File 'lib/increase/models/transaction.rb', line 1759

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

Returns:



1765
# File 'lib/increase/models/transaction.rb', line 1765

required :card_payment_id, String

#currencySymbol, Increase::Models::Transaction::Source::CardFinancial::Currency

The ISO 4217 code for the transaction's currency.

Parameters:

Returns:



1772
# File 'lib/increase/models/transaction.rb', line 1772

required :currency, enum: -> { Increase::Transaction::Source::CardFinancial::Currency }

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Parameters:

Returns:



1779
# File 'lib/increase/models/transaction.rb', line 1779

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::Transaction::Source::CardFinancial::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.

Parameters:

Returns:



1786
# File 'lib/increase/models/transaction.rb', line 1786

required :direction, enum: -> { Increase::Transaction::Source::CardFinancial::Direction }

#idString

The Card Financial identifier.

Parameters:

Returns:



1737
# File 'lib/increase/models/transaction.rb', line 1737

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

Returns:



1793
# File 'lib/increase/models/transaction.rb', line 1793

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

Returns:



1800
# File 'lib/increase/models/transaction.rb', line 1800

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

Returns:



1806
# File 'lib/increase/models/transaction.rb', line 1806

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Parameters:

Returns:



1812
# File 'lib/increase/models/transaction.rb', line 1812

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

Returns:



1818
# File 'lib/increase/models/transaction.rb', line 1818

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

Returns:



1825
# File 'lib/increase/models/transaction.rb', line 1825

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

Returns:



1831
# File 'lib/increase/models/transaction.rb', line 1831

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::Transaction::Source::CardFinancial::NetworkDetails

Fields specific to the network.

Parameters:

Returns:



1837
# File 'lib/increase/models/transaction.rb', line 1837

required :network_details, -> { Increase::Transaction::Source::CardFinancial::NetworkDetails }

#network_identifiersIncrease::Models::Transaction::Source::CardFinancial::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

Returns:



1843
# File 'lib/increase/models/transaction.rb', line 1843

required :network_identifiers, -> { Increase::Transaction::Source::CardFinancial::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Parameters:

Returns:



1851
# File 'lib/increase/models/transaction.rb', line 1851

required :network_risk_score, Integer, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Parameters:

Returns:



1858
# File 'lib/increase/models/transaction.rb', line 1858

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The pending amount in the minor unit of the transaction's presentment currency.

Parameters:

Returns:



1864
# File 'lib/increase/models/transaction.rb', line 1864

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

Returns:



1871
# File 'lib/increase/models/transaction.rb', line 1871

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::Transaction::Source::CardFinancial::ProcessingCategory

The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.

Parameters:

Returns:



1878
1879
# File 'lib/increase/models/transaction.rb', line 1878

required :processing_category,
enum: -> { Increase::Transaction::Source::CardFinancial::ProcessingCategory }

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this transaction.

Parameters:

Returns:



1886
# File 'lib/increase/models/transaction.rb', line 1886

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::Transaction::Source::CardFinancial::SchemeFee>

The scheme fees associated with this card financial.

Parameters:

Returns:



1892
1893
# File 'lib/increase/models/transaction.rb', line 1892

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardFinancial::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

Returns:



1900
# File 'lib/increase/models/transaction.rb', line 1900

required :terminal_id, String, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Parameters:

Returns:



1906
# File 'lib/increase/models/transaction.rb', line 1906

required :transaction_id, String

#typeSymbol, Increase::Models::Transaction::Source::CardFinancial::Type

A constant representing the object's type. For this resource it will always be card_financial.

Parameters:

Returns:



1913
# File 'lib/increase/models/transaction.rb', line 1913

required :type, enum: -> { Increase::Transaction::Source::CardFinancial::Type }

#verificationIncrease::Models::Transaction::Source::CardFinancial::Verification

Fields related to verification of cardholder-provided values.

Parameters:

Returns:



1919
# File 'lib/increase/models/transaction.rb', line 1919

required :verification, -> { Increase::Transaction::Source::CardFinancial::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/increase/models/transaction.rb', line 2039


Instance Method Details

#to_hash{

Returns:



1240
# File 'sig/increase/models/transaction.rbs', line 1240

def to_hash: -> {