Module: Increase::Models::Transaction::Source::CardFinancial::ProcessingCategory

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.

See Also:

  • Increase::Models::Transaction::Source::CardFinancial#processing_category

Constant Summary collapse

ACCOUNT_FUNDING =

Account funding transactions are transactions used to e.g., fund an account or transfer funds between accounts.

Returns:

  • (:account_funding)
:account_funding
AUTOMATIC_FUEL_DISPENSER =

Automatic fuel dispenser authorizations occur when a card is used at a gas pump, prior to the actual transaction amount being known. They are followed by an advice message that updates the amount of the pending transaction.

Returns:

  • (:automatic_fuel_dispenser)
:automatic_fuel_dispenser
BILL_PAYMENT =

A transaction used to pay a bill.

Returns:

  • (:bill_payment)
:bill_payment
ORIGINAL_CREDIT =

Original credit transactions are used to send money to a cardholder.

Returns:

  • (:original_credit)
:original_credit
PURCHASE =

A regular purchase.

Returns:

  • (:purchase)
:purchase
QUASI_CASH =

Quasi-cash transactions represent purchases of items which may be convertible to cash.

Returns:

  • (:quasi_cash)
:quasi_cash
REFUND =

A refund card authorization, sometimes referred to as a credit voucher authorization, where funds are credited to the cardholder.

Returns:

  • (:refund)
:refund
CASH_DISBURSEMENT =

Cash disbursement transactions are used to withdraw cash from an ATM or a point of sale.

Returns:

  • (:cash_disbursement)
:cash_disbursement
CASH_DEPOSIT =

Cash deposit transactions are used to deposit cash at an ATM or a point of sale.

Returns:

  • (:cash_deposit)
:cash_deposit
BALANCE_INQUIRY =

A balance inquiry transaction is used to check the balance of an account associated with a card.

Returns:

  • (:balance_inquiry)
:balance_inquiry
UNKNOWN =

The processing category is unknown.

Returns:

  • (:unknown)
:unknown

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Transaction::Source::CardFinancial::processing_category]

Returns:

  • (::Array[Increase::Models::Transaction::Source::CardFinancial::processing_category])


1793
# File 'sig/increase/models/transaction.rbs', line 1793

def self?.values: -> ::Array[Increase::Models::Transaction::Source::CardFinancial::processing_category]