Class: Increase::Models::Transaction::Source::CardRefund

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#card_refund

Defined Under Namespace

Modules: Currency, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object

Network-specific identifiers for this refund.



# File 'lib/increase/models/transaction.rb', line 3420


Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.



3299
# File 'lib/increase/models/transaction.rb', line 3299

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.



3305
# File 'lib/increase/models/transaction.rb', line 3305

required :card_payment_id, String

#cashbackIncrease::Models::Transaction::Source::CardRefund::Cashback?

Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.



3312
# File 'lib/increase/models/transaction.rb', line 3312

required :cashback, -> { Increase::Transaction::Source::CardRefund::Cashback }, nil?: true

#currencySymbol, Increase::Models::Transaction::Source::CardRefund::Currency

The ISO 4217 code for the transaction's settlement currency.



3319
# File 'lib/increase/models/transaction.rb', line 3319

required :currency, enum: -> { Increase::Transaction::Source::CardRefund::Currency }

#idString

The Card Refund identifier.



3292
# File 'lib/increase/models/transaction.rb', line 3292

required :id, String

#interchangeIncrease::Models::Transaction::Source::CardRefund::Interchange?

Interchange assessed as a part of this transaction.



3325
# File 'lib/increase/models/transaction.rb', line 3325

required :interchange, -> { Increase::Transaction::Source::CardRefund::Interchange }, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.



3332
# File 'lib/increase/models/transaction.rb', line 3332

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant's business.



3338
# File 'lib/increase/models/transaction.rb', line 3338

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.



3344
# File 'lib/increase/models/transaction.rb', line 3344

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.



3350
# File 'lib/increase/models/transaction.rb', line 3350

required :merchant_country, String

#merchant_nameString

The name of the merchant.



3356
# File 'lib/increase/models/transaction.rb', line 3356

required :merchant_name, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is always a 5-digit ZIP code.



3362
# File 'lib/increase/models/transaction.rb', line 3362

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.



3368
# File 'lib/increase/models/transaction.rb', line 3368

required :merchant_state, String, nil?: true

#network_identifiersIncrease::Models::Transaction::Source::CardRefund::NetworkIdentifiers

Network-specific identifiers for this refund.



3374
# File 'lib/increase/models/transaction.rb', line 3374

required :network_identifiers, -> { Increase::Transaction::Source::CardRefund::NetworkIdentifiers }

#presentment_amountInteger

The amount in the minor unit of the transaction's presentment currency.



3380
# File 'lib/increase/models/transaction.rb', line 3380

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.



3387
# File 'lib/increase/models/transaction.rb', line 3387

required :presentment_currency, String

#purchase_detailsIncrease::Models::Transaction::Source::CardRefund::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.



3394
3395
3396
3397
3398
# File 'lib/increase/models/transaction.rb', line 3394

required :purchase_details,
-> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails
},
nil?: true

#scheme_feesArray<Increase::Models::Transaction::Source::CardRefund::SchemeFee>

The scheme fees associated with this card refund.



3404
3405
# File 'lib/increase/models/transaction.rb', line 3404

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardRefund::SchemeFee] }

#transaction_idString

The identifier of the Transaction associated with this Transaction.



3411
# File 'lib/increase/models/transaction.rb', line 3411

required :transaction_id, String

#typeSymbol, Increase::Models::Transaction::Source::CardRefund::Type

A constant representing the object's type. For this resource it will always be card_refund.



3418
# File 'lib/increase/models/transaction.rb', line 3418

required :type, enum: -> { Increase::Transaction::Source::CardRefund::Type }

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/transaction.rb', line 3523


Instance Method Details

#to_hash{



2277
# File 'sig/increase/models/transaction.rbs', line 2277

def to_hash: -> {