Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardRefund::PurchaseDetails
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel
Instance Attribute Summary collapse
-
#car_rental ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental?
Fields specific to car rentals.
-
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
-
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
-
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#lodging ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging?
Fields specific to lodging.
-
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
-
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
-
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
-
#travel ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel?
Fields specific to travel.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
constructor
Additional details about the card purchase, such as tax and industry-specific fields.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
Additional details about the card purchase, such as tax and industry-specific fields.
|
|
# File 'lib/increase/models/transaction.rb', line 3721
|
Instance Attribute Details
#car_rental ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental?
Fields specific to car rentals.
3649 3650 3651 |
# File 'lib/increase/models/transaction.rb', line 3649 required :car_rental, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental }, nil?: true |
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
3657 |
# File 'lib/increase/models/transaction.rb', line 3657 required :customer_reference_identifier, String, nil?: true |
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
3663 |
# File 'lib/increase/models/transaction.rb', line 3663 required :local_tax_amount, Integer, nil?: true |
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
3670 |
# File 'lib/increase/models/transaction.rb', line 3670 required :local_tax_currency, String, nil?: true |
#lodging ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging?
Fields specific to lodging.
3676 3677 3678 3679 3680 |
# File 'lib/increase/models/transaction.rb', line 3676 required :lodging, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Lodging }, nil?: true |
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
3686 |
# File 'lib/increase/models/transaction.rb', line 3686 required :national_tax_amount, Integer, nil?: true |
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
3693 |
# File 'lib/increase/models/transaction.rb', line 3693 required :national_tax_currency, String, nil?: true |
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
3699 |
# File 'lib/increase/models/transaction.rb', line 3699 required :purchase_identifier, String, nil?: true |
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
3705 3706 3707 3708 3709 |
# File 'lib/increase/models/transaction.rb', line 3705 required :purchase_identifier_format, enum: -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::PurchaseIdentifierFormat }, nil?: true |
#travel ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel?
Fields specific to travel.
3715 3716 3717 3718 3719 |
# File 'lib/increase/models/transaction.rb', line 3715 required :travel, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 3962
|
Instance Method Details
#to_hash ⇒ {
2462 |
# File 'sig/increase/models/transaction.rbs', line 2462 def to_hash: -> { |