Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source::CardRefund::PurchaseDetails#car_rental

Defined Under Namespace

Modules: ExtraCharges, NoShowIndicator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(car_class_code:, checkout_date:, daily_rental_rate_amount:, daily_rental_rate_currency:, days_rented:, extra_charges:, fuel_charges_amount:, fuel_charges_currency:, insurance_charges_amount:, insurance_charges_currency:, no_show_indicator:, one_way_drop_off_charges_amount:, one_way_drop_off_charges_currency:, renter_name:, weekly_rental_rate_amount:, weekly_rental_rate_currency:) ⇒ Object

Fields specific to car rentals.



# File 'lib/increase/models/transaction.rb', line 3869


Instance Attribute Details

#car_class_codeString?

Code indicating the vehicle's class.



3761
# File 'lib/increase/models/transaction.rb', line 3761

required :car_class_code, String, nil?: true

#checkout_dateDate?

Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.



3768
# File 'lib/increase/models/transaction.rb', line 3768

required :checkout_date, Date, nil?: true

#daily_rental_rate_amountInteger?

Daily rate being charged for the vehicle.



3774
# File 'lib/increase/models/transaction.rb', line 3774

required :daily_rental_rate_amount, Integer, nil?: true

#daily_rental_rate_currencyString?

The ISO 4217 code for the daily rental rate.



3781
# File 'lib/increase/models/transaction.rb', line 3781

required :daily_rental_rate_currency, String, nil?: true

#days_rentedInteger?

Number of days the vehicle was rented.



3787
# File 'lib/increase/models/transaction.rb', line 3787

required :days_rented, Integer, nil?: true

#extra_chargesSymbol, ...

Additional charges (gas, late fee, etc.) being billed.



3793
3794
3795
3796
3797
# File 'lib/increase/models/transaction.rb', line 3793

required :extra_charges,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental::ExtraCharges
},
nil?: true

#fuel_charges_amountInteger?

Fuel charges for the vehicle.



3803
# File 'lib/increase/models/transaction.rb', line 3803

required :fuel_charges_amount, Integer, nil?: true

#fuel_charges_currencyString?

The ISO 4217 code for the fuel charges assessed.



3810
# File 'lib/increase/models/transaction.rb', line 3810

required :fuel_charges_currency, String, nil?: true

#insurance_charges_amountInteger?

Any insurance being charged for the vehicle.



3816
# File 'lib/increase/models/transaction.rb', line 3816

required :insurance_charges_amount, Integer, nil?: true

#insurance_charges_currencyString?

The ISO 4217 code for the insurance charges assessed.



3823
# File 'lib/increase/models/transaction.rb', line 3823

required :insurance_charges_currency, String, nil?: true

#no_show_indicatorSymbol, ...

An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).



3830
3831
3832
3833
3834
# File 'lib/increase/models/transaction.rb', line 3830

required :no_show_indicator,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental::NoShowIndicator
},
nil?: true

#one_way_drop_off_charges_amountInteger?

Charges for returning the vehicle at a different location than where it was picked up.



3841
# File 'lib/increase/models/transaction.rb', line 3841

required :one_way_drop_off_charges_amount, Integer, nil?: true

#one_way_drop_off_charges_currencyString?

The ISO 4217 code for the one-way drop-off charges assessed.



3848
# File 'lib/increase/models/transaction.rb', line 3848

required :one_way_drop_off_charges_currency, String, nil?: true

#renter_nameString?

Name of the person renting the vehicle.



3854
# File 'lib/increase/models/transaction.rb', line 3854

required :renter_name, String, nil?: true

#weekly_rental_rate_amountInteger?

Weekly rate being charged for the vehicle.



3860
# File 'lib/increase/models/transaction.rb', line 3860

required :weekly_rental_rate_amount, Integer, nil?: true

#weekly_rental_rate_currencyString?

The ISO 4217 code for the weekly rental rate.



3867
# File 'lib/increase/models/transaction.rb', line 3867

required :weekly_rental_rate_currency, String, nil?: true

Class Method Details

.valuesArray<Symbol>



# File 'lib/increase/models/transaction.rb', line 3945


Instance Method Details

#to_hash{



2547
# File 'sig/increase/models/transaction.rbs', line 2547

def to_hash: -> {