Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: CreditReasonIndicator, RestrictedTicketIndicator, TicketChangeIndicator Classes: Ancillary, TripLeg
Instance Attribute Summary collapse
-
#ancillary ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
-
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
-
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
-
#departure_date ⇒ Date?
Date of departure.
-
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
-
#passenger_name ⇒ String?
Name of the passenger.
-
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
-
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
-
#ticket_number ⇒ String?
Ticket number.
-
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
-
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
-
#trip_legs ⇒ Array<Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
constructor
Fields specific to travel.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
Fields specific to travel.
|
|
# File 'lib/increase/models/transaction.rb', line 3896
|
Instance Attribute Details
#ancillary ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
3810 3811 3812 |
# File 'lib/increase/models/transaction.rb', line 3810 required :ancillary, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel::Ancillary }, nil?: true |
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
3818 |
# File 'lib/increase/models/transaction.rb', line 3818 required :computerized_reservation_system, String, nil?: true |
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
3824 3825 3826 3827 3828 |
# File 'lib/increase/models/transaction.rb', line 3824 required :credit_reason_indicator, enum: -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel::CreditReasonIndicator }, nil?: true |
#departure_date ⇒ Date?
Date of departure.
3834 |
# File 'lib/increase/models/transaction.rb', line 3834 required :departure_date, Date, nil?: true |
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
3840 |
# File 'lib/increase/models/transaction.rb', line 3840 required :origination_city_airport_code, String, nil?: true |
#passenger_name ⇒ String?
Name of the passenger.
3846 |
# File 'lib/increase/models/transaction.rb', line 3846 required :passenger_name, String, nil?: true |
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
3852 3853 3854 3855 3856 |
# File 'lib/increase/models/transaction.rb', line 3852 required :restricted_ticket_indicator, enum: -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel::RestrictedTicketIndicator }, nil?: true |
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
3862 3863 3864 3865 3866 |
# File 'lib/increase/models/transaction.rb', line 3862 required :ticket_change_indicator, enum: -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel::TicketChangeIndicator }, nil?: true |
#ticket_number ⇒ String?
Ticket number.
3872 |
# File 'lib/increase/models/transaction.rb', line 3872 required :ticket_number, String, nil?: true |
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
3878 |
# File 'lib/increase/models/transaction.rb', line 3878 required :travel_agency_code, String, nil?: true |
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
3884 |
# File 'lib/increase/models/transaction.rb', line 3884 required :travel_agency_name, String, nil?: true |
#trip_legs ⇒ Array<Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
3890 3891 3892 3893 3894 |
# File 'lib/increase/models/transaction.rb', line 3890 required :trip_legs, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel::TripLeg] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 4103
|