Class: Increase::Models::Transaction::Source::CardRevenuePayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#card_revenue_payment

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, period_end:, period_start:, transacted_on_account_id:) ⇒ Object

A Card Revenue Payment object. This field will be present in the JSON response if and only if category is equal to card_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.

Parameters:

  • The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

  • The ISO 4217 code for the transaction currency.

  • The end of the period for which this transaction paid interest.

  • The start of the period for which this transaction paid interest.

  • The account the card belonged to.



# File 'lib/increase/models/transaction.rb', line 4888


Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

Returns:



4861
# File 'lib/increase/models/transaction.rb', line 4861

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::CardRevenuePayment::Currency

The ISO 4217 code for the transaction currency.

Parameters:

Returns:



4868
# File 'lib/increase/models/transaction.rb', line 4868

required :currency, enum: -> { Increase::Transaction::Source::CardRevenuePayment::Currency }

#period_endTime

The end of the period for which this transaction paid interest.

Parameters:

Returns:



4874
# File 'lib/increase/models/transaction.rb', line 4874

required :period_end, Time

#period_startTime

The start of the period for which this transaction paid interest.

Parameters:

Returns:



4880
# File 'lib/increase/models/transaction.rb', line 4880

required :period_start, Time

#transacted_on_account_idString?

The account the card belonged to.

Parameters:

Returns:



4886
# File 'lib/increase/models/transaction.rb', line 4886

required :transacted_on_account_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:



3385
# File 'sig/increase/models/transaction.rbs', line 3385

def to_hash: -> {