Class: Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel
Instance Attribute Summary collapse
-
#car_rental ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::CarRental?
Fields specific to car rentals.
-
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
-
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
-
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#lodging ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Lodging?
Fields specific to lodging.
-
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
-
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
-
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
-
#travel ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel?
Fields specific to travel.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
constructor
Additional details about the card purchase, such as tax and industry-specific fields.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
Additional details about the card purchase, such as tax and industry-specific fields.
|
|
# File 'lib/increase/models/transaction.rb', line 5409
|
Instance Attribute Details
#car_rental ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::CarRental?
Fields specific to car rentals.
5341 5342 5343 |
# File 'lib/increase/models/transaction.rb', line 5341 required :car_rental, -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::CarRental }, nil?: true |
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
5349 |
# File 'lib/increase/models/transaction.rb', line 5349 required :customer_reference_identifier, String, nil?: true |
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
5355 |
# File 'lib/increase/models/transaction.rb', line 5355 required :local_tax_amount, Integer, nil?: true |
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
5362 |
# File 'lib/increase/models/transaction.rb', line 5362 required :local_tax_currency, String, nil?: true |
#lodging ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Lodging?
Fields specific to lodging.
5368 5369 5370 |
# File 'lib/increase/models/transaction.rb', line 5368 required :lodging, -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Lodging }, nil?: true |
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
5376 |
# File 'lib/increase/models/transaction.rb', line 5376 required :national_tax_amount, Integer, nil?: true |
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
5383 |
# File 'lib/increase/models/transaction.rb', line 5383 required :national_tax_currency, String, nil?: true |
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
5389 |
# File 'lib/increase/models/transaction.rb', line 5389 required :purchase_identifier, String, nil?: true |
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
5395 5396 5397 5398 5399 |
# File 'lib/increase/models/transaction.rb', line 5395 required :purchase_identifier_format, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::PurchaseIdentifierFormat }, nil?: true |
#travel ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel?
Fields specific to travel.
5405 5406 5407 |
# File 'lib/increase/models/transaction.rb', line 5405 required :travel, -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 5650
|
Instance Method Details
#to_hash ⇒ {
3712 |
# File 'sig/increase/models/transaction.rbs', line 3712 def to_hash: -> { |