Class: Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::CarRental
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::CarRental
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: ExtraCharges, NoShowIndicator
Instance Attribute Summary collapse
-
#car_class_code ⇒ String?
Code indicating the vehicle's class.
-
#checkout_date ⇒ Date?
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
-
#daily_rental_rate_amount ⇒ Integer?
Daily rate being charged for the vehicle.
-
#daily_rental_rate_currency ⇒ String?
The ISO 4217 code for the daily rental rate.
-
#days_rented ⇒ Integer?
Number of days the vehicle was rented.
-
#extra_charges ⇒ Symbol, ...
Additional charges (gas, late fee, etc.) being billed.
-
#fuel_charges_amount ⇒ Integer?
Fuel charges for the vehicle.
-
#fuel_charges_currency ⇒ String?
The ISO 4217 code for the fuel charges assessed.
-
#insurance_charges_amount ⇒ Integer?
Any insurance being charged for the vehicle.
-
#insurance_charges_currency ⇒ String?
The ISO 4217 code for the insurance charges assessed.
-
#no_show_indicator ⇒ Symbol, ...
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
-
#one_way_drop_off_charges_amount ⇒ Integer?
Charges for returning the vehicle at a different location than where it was picked up.
-
#one_way_drop_off_charges_currency ⇒ String?
The ISO 4217 code for the one-way drop-off charges assessed.
-
#renter_name ⇒ String?
Name of the person renting the vehicle.
-
#weekly_rental_rate_amount ⇒ Integer?
Weekly rate being charged for the vehicle.
-
#weekly_rental_rate_currency ⇒ String?
The ISO 4217 code for the weekly rental rate.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_class_code:, checkout_date:, daily_rental_rate_amount:, daily_rental_rate_currency:, days_rented:, extra_charges:, fuel_charges_amount:, fuel_charges_currency:, insurance_charges_amount:, insurance_charges_currency:, no_show_indicator:, one_way_drop_off_charges_amount:, one_way_drop_off_charges_currency:, renter_name:, weekly_rental_rate_amount:, weekly_rental_rate_currency:) ⇒ Object
constructor
Fields specific to car rentals.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_class_code:, checkout_date:, daily_rental_rate_amount:, daily_rental_rate_currency:, days_rented:, extra_charges:, fuel_charges_amount:, fuel_charges_currency:, insurance_charges_amount:, insurance_charges_currency:, no_show_indicator:, one_way_drop_off_charges_amount:, one_way_drop_off_charges_currency:, renter_name:, weekly_rental_rate_amount:, weekly_rental_rate_currency:) ⇒ Object
Fields specific to car rentals.
|
|
# File 'lib/increase/models/transaction.rb', line 5472
|
Instance Attribute Details
#car_class_code ⇒ String?
Code indicating the vehicle's class.
5364 |
# File 'lib/increase/models/transaction.rb', line 5364 required :car_class_code, String, nil?: true |
#checkout_date ⇒ Date?
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
5371 |
# File 'lib/increase/models/transaction.rb', line 5371 required :checkout_date, Date, nil?: true |
#daily_rental_rate_amount ⇒ Integer?
Daily rate being charged for the vehicle.
5377 |
# File 'lib/increase/models/transaction.rb', line 5377 required :daily_rental_rate_amount, Integer, nil?: true |
#daily_rental_rate_currency ⇒ String?
The ISO 4217 code for the daily rental rate.
5384 |
# File 'lib/increase/models/transaction.rb', line 5384 required :daily_rental_rate_currency, String, nil?: true |
#days_rented ⇒ Integer?
Number of days the vehicle was rented.
5390 |
# File 'lib/increase/models/transaction.rb', line 5390 required :days_rented, Integer, nil?: true |
#extra_charges ⇒ Symbol, ...
Additional charges (gas, late fee, etc.) being billed.
5396 5397 5398 5399 5400 |
# File 'lib/increase/models/transaction.rb', line 5396 required :extra_charges, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::CarRental::ExtraCharges }, nil?: true |
#fuel_charges_amount ⇒ Integer?
Fuel charges for the vehicle.
5406 |
# File 'lib/increase/models/transaction.rb', line 5406 required :fuel_charges_amount, Integer, nil?: true |
#fuel_charges_currency ⇒ String?
The ISO 4217 code for the fuel charges assessed.
5413 |
# File 'lib/increase/models/transaction.rb', line 5413 required :fuel_charges_currency, String, nil?: true |
#insurance_charges_amount ⇒ Integer?
Any insurance being charged for the vehicle.
5419 |
# File 'lib/increase/models/transaction.rb', line 5419 required :insurance_charges_amount, Integer, nil?: true |
#insurance_charges_currency ⇒ String?
The ISO 4217 code for the insurance charges assessed.
5426 |
# File 'lib/increase/models/transaction.rb', line 5426 required :insurance_charges_currency, String, nil?: true |
#no_show_indicator ⇒ Symbol, ...
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
5433 5434 5435 5436 5437 |
# File 'lib/increase/models/transaction.rb', line 5433 required :no_show_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::CarRental::NoShowIndicator }, nil?: true |
#one_way_drop_off_charges_amount ⇒ Integer?
Charges for returning the vehicle at a different location than where it was picked up.
5444 |
# File 'lib/increase/models/transaction.rb', line 5444 required :one_way_drop_off_charges_amount, Integer, nil?: true |
#one_way_drop_off_charges_currency ⇒ String?
The ISO 4217 code for the one-way drop-off charges assessed.
5451 |
# File 'lib/increase/models/transaction.rb', line 5451 required :one_way_drop_off_charges_currency, String, nil?: true |
#renter_name ⇒ String?
Name of the person renting the vehicle.
5457 |
# File 'lib/increase/models/transaction.rb', line 5457 required :renter_name, String, nil?: true |
#weekly_rental_rate_amount ⇒ Integer?
Weekly rate being charged for the vehicle.
5463 |
# File 'lib/increase/models/transaction.rb', line 5463 required :weekly_rental_rate_amount, Integer, nil?: true |
#weekly_rental_rate_currency ⇒ String?
The ISO 4217 code for the weekly rental rate.
5470 |
# File 'lib/increase/models/transaction.rb', line 5470 required :weekly_rental_rate_currency, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 5548
|
Instance Method Details
#to_hash ⇒ {
3765 |
# File 'sig/increase/models/transaction.rbs', line 3765
def to_hash: -> {
|