Class: Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Lodging
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Lodging
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: ExtraCharges, NoShowIndicator
Instance Attribute Summary collapse
-
#check_in_date ⇒ Date?
Date the customer checked in.
-
#daily_room_rate_amount ⇒ Integer?
Daily rate being charged for the room.
-
#daily_room_rate_currency ⇒ String?
The ISO 4217 code for the daily room rate.
-
#extra_charges ⇒ Symbol, ...
Additional charges (phone, late check-out, etc.) being billed.
-
#folio_cash_advances_amount ⇒ Integer?
Folio cash advances for the room.
-
#folio_cash_advances_currency ⇒ String?
The ISO 4217 code for the folio cash advances.
-
#food_beverage_charges_amount ⇒ Integer?
Food and beverage charges for the room.
-
#food_beverage_charges_currency ⇒ String?
The ISO 4217 code for the food and beverage charges.
-
#no_show_indicator ⇒ Symbol, ...
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
#prepaid_expenses_amount ⇒ Integer?
Prepaid expenses being charged for the room.
-
#prepaid_expenses_currency ⇒ String?
The ISO 4217 code for the prepaid expenses.
-
#room_nights ⇒ Integer?
Number of nights the room was rented.
-
#total_room_tax_amount ⇒ Integer?
Total room tax being charged.
-
#total_room_tax_currency ⇒ String?
The ISO 4217 code for the total room tax.
-
#total_tax_amount ⇒ Integer?
Total tax being charged for the room.
-
#total_tax_currency ⇒ String?
The ISO 4217 code for the total tax assessed.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object
constructor
Fields specific to lodging.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object
Fields specific to lodging.
|
|
# File 'lib/increase/models/transaction.rb', line 5768
|
Instance Attribute Details
#check_in_date ⇒ Date?
Date the customer checked in.
5661 |
# File 'lib/increase/models/transaction.rb', line 5661 required :check_in_date, Date, nil?: true |
#daily_room_rate_amount ⇒ Integer?
Daily rate being charged for the room.
5667 |
# File 'lib/increase/models/transaction.rb', line 5667 required :daily_room_rate_amount, Integer, nil?: true |
#daily_room_rate_currency ⇒ String?
The ISO 4217 code for the daily room rate.
5674 |
# File 'lib/increase/models/transaction.rb', line 5674 required :daily_room_rate_currency, String, nil?: true |
#extra_charges ⇒ Symbol, ...
Additional charges (phone, late check-out, etc.) being billed.
5680 5681 5682 5683 5684 |
# File 'lib/increase/models/transaction.rb', line 5680 required :extra_charges, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Lodging::ExtraCharges }, nil?: true |
#folio_cash_advances_amount ⇒ Integer?
Folio cash advances for the room.
5690 |
# File 'lib/increase/models/transaction.rb', line 5690 required :folio_cash_advances_amount, Integer, nil?: true |
#folio_cash_advances_currency ⇒ String?
The ISO 4217 code for the folio cash advances.
5697 |
# File 'lib/increase/models/transaction.rb', line 5697 required :folio_cash_advances_currency, String, nil?: true |
#food_beverage_charges_amount ⇒ Integer?
Food and beverage charges for the room.
5703 |
# File 'lib/increase/models/transaction.rb', line 5703 required :food_beverage_charges_amount, Integer, nil?: true |
#food_beverage_charges_currency ⇒ String?
The ISO 4217 code for the food and beverage charges.
5710 |
# File 'lib/increase/models/transaction.rb', line 5710 required :food_beverage_charges_currency, String, nil?: true |
#no_show_indicator ⇒ Symbol, ...
Indicator that the cardholder is being billed for a reserved room that was not actually used.
5717 5718 5719 5720 5721 |
# File 'lib/increase/models/transaction.rb', line 5717 required :no_show_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Lodging::NoShowIndicator }, nil?: true |
#prepaid_expenses_amount ⇒ Integer?
Prepaid expenses being charged for the room.
5727 |
# File 'lib/increase/models/transaction.rb', line 5727 required :prepaid_expenses_amount, Integer, nil?: true |
#prepaid_expenses_currency ⇒ String?
The ISO 4217 code for the prepaid expenses.
5734 |
# File 'lib/increase/models/transaction.rb', line 5734 required :prepaid_expenses_currency, String, nil?: true |
#room_nights ⇒ Integer?
Number of nights the room was rented.
5740 |
# File 'lib/increase/models/transaction.rb', line 5740 required :room_nights, Integer, nil?: true |
#total_room_tax_amount ⇒ Integer?
Total room tax being charged.
5746 |
# File 'lib/increase/models/transaction.rb', line 5746 required :total_room_tax_amount, Integer, nil?: true |
#total_room_tax_currency ⇒ String?
The ISO 4217 code for the total room tax.
5753 |
# File 'lib/increase/models/transaction.rb', line 5753 required :total_room_tax_currency, String, nil?: true |
#total_tax_amount ⇒ Integer?
Total tax being charged for the room.
5759 |
# File 'lib/increase/models/transaction.rb', line 5759 required :total_tax_amount, Integer, nil?: true |
#total_tax_currency ⇒ String?
The ISO 4217 code for the total tax assessed.
5766 |
# File 'lib/increase/models/transaction.rb', line 5766 required :total_tax_currency, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 5845
|
Instance Method Details
#to_hash ⇒ {
3936 |
# File 'sig/increase/models/transaction.rbs', line 3936 def to_hash: -> { |