Class: Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: CreditReasonIndicator, RestrictedTicketIndicator, TicketChangeIndicator Classes: Ancillary, TripLeg
Instance Attribute Summary collapse
-
#ancillary ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
-
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
-
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
-
#departure_date ⇒ Date?
Date of departure.
-
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
-
#passenger_name ⇒ String?
Name of the passenger.
-
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
-
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
-
#ticket_number ⇒ String?
Ticket number.
-
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
-
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
-
#trip_legs ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
constructor
Fields specific to travel.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
Fields specific to travel.
|
|
# File 'lib/increase/models/transaction.rb', line 5920
|
Instance Attribute Details
#ancillary ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
5832 5833 5834 5835 5836 |
# File 'lib/increase/models/transaction.rb', line 5832 required :ancillary, -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary }, nil?: true |
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
5842 |
# File 'lib/increase/models/transaction.rb', line 5842 required :computerized_reservation_system, String, nil?: true |
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
5848 5849 5850 5851 5852 |
# File 'lib/increase/models/transaction.rb', line 5848 required :credit_reason_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::CreditReasonIndicator }, nil?: true |
#departure_date ⇒ Date?
Date of departure.
5858 |
# File 'lib/increase/models/transaction.rb', line 5858 required :departure_date, Date, nil?: true |
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
5864 |
# File 'lib/increase/models/transaction.rb', line 5864 required :origination_city_airport_code, String, nil?: true |
#passenger_name ⇒ String?
Name of the passenger.
5870 |
# File 'lib/increase/models/transaction.rb', line 5870 required :passenger_name, String, nil?: true |
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
5876 5877 5878 5879 5880 |
# File 'lib/increase/models/transaction.rb', line 5876 required :restricted_ticket_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::RestrictedTicketIndicator }, nil?: true |
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
5886 5887 5888 5889 5890 |
# File 'lib/increase/models/transaction.rb', line 5886 required :ticket_change_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TicketChangeIndicator }, nil?: true |
#ticket_number ⇒ String?
Ticket number.
5896 |
# File 'lib/increase/models/transaction.rb', line 5896 required :ticket_number, String, nil?: true |
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
5902 |
# File 'lib/increase/models/transaction.rb', line 5902 required :travel_agency_code, String, nil?: true |
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
5908 |
# File 'lib/increase/models/transaction.rb', line 5908 required :travel_agency_name, String, nil?: true |
#trip_legs ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
5914 5915 5916 5917 5918 |
# File 'lib/increase/models/transaction.rb', line 5914 required :trip_legs, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TripLeg] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 6138
|
Instance Method Details
#to_hash ⇒ {
4063 |
# File 'sig/increase/models/transaction.rbs', line 4063
def to_hash: -> {
|