Class: Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: CreditReasonIndicator Classes: Service
Instance Attribute Summary collapse
-
#connected_ticket_document_number ⇒ String?
If this purchase has a connection or relationship to another purchase, such as a baggage fee for a passenger transport ticket, this field should contain the ticket document number for the other purchase.
-
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
-
#passenger_name_or_description ⇒ String?
Name of the passenger or description of the ancillary purchase.
-
#services ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary::Service>
Additional travel charges, such as baggage fees.
-
#ticket_document_number ⇒ String?
Ticket document number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(connected_ticket_document_number:, credit_reason_indicator:, passenger_name_or_description:, services:, ticket_document_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Ancillary for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connected_ticket_document_number:, credit_reason_indicator:, passenger_name_or_description:, services:, ticket_document_number:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary for more details.
Ancillary purchases in addition to the airfare.
|
|
# File 'lib/increase/models/transaction.rb', line 5569
|
Instance Attribute Details
#connected_ticket_document_number ⇒ String?
If this purchase has a connection or relationship to another purchase, such as a baggage fee for a passenger transport ticket, this field should contain the ticket document number for the other purchase.
5538 |
# File 'lib/increase/models/transaction.rb', line 5538 required :connected_ticket_document_number, String, nil?: true |
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
5544 5545 5546 5547 5548 |
# File 'lib/increase/models/transaction.rb', line 5544 required :credit_reason_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary::CreditReasonIndicator }, nil?: true |
#passenger_name_or_description ⇒ String?
Name of the passenger or description of the ancillary purchase.
5554 |
# File 'lib/increase/models/transaction.rb', line 5554 required :passenger_name_or_description, String, nil?: true |
#services ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary::Service>
Additional travel charges, such as baggage fees.
5560 5561 |
# File 'lib/increase/models/transaction.rb', line 5560 required :services, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary::Service] } |
#ticket_document_number ⇒ String?
Ticket document number.
5567 |
# File 'lib/increase/models/transaction.rb', line 5567 required :ticket_document_number, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 5606
|