Class: Increase::Models::Transaction::Source::CardSettlement::SchemeFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Defined Under Namespace

Modules: Currency, FeeType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, created_at:, currency:, fee_type:, fixed_component:, variable_rate:) ⇒ Object

Parameters:

  • The fee amount given as a string containing a decimal number.

  • The ISO 8601 time at which the fee was created.

  • The ISO 4217 code for the fee reimbursement.

  • The type of fee being assessed.

  • The fixed component of the fee, if applicable, given in major units of the fee amount.

  • The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).



# File 'lib/increase/models/transaction.rb', line 6393


Instance Attribute Details

#amountString

The fee amount given as a string containing a decimal number.

Parameters:

Returns:



6357
# File 'lib/increase/models/transaction.rb', line 6357

required :amount, String

#created_atTime

The ISO 8601 time at which the fee was created.

Parameters:

Returns:



6364
# File 'lib/increase/models/transaction.rb', line 6364

required :created_at, Time

#currencySymbol, Increase::Models::Transaction::Source::CardSettlement::SchemeFee::Currency

The ISO 4217 code for the fee reimbursement.

Parameters:

Returns:



6371
# File 'lib/increase/models/transaction.rb', line 6371

required :currency, enum: -> { Increase::Transaction::Source::CardSettlement::SchemeFee::Currency }

#fee_typeSymbol, Increase::Models::Transaction::Source::CardSettlement::SchemeFee::FeeType

The type of fee being assessed.

Parameters:

Returns:



6377
# File 'lib/increase/models/transaction.rb', line 6377

required :fee_type, enum: -> { Increase::Transaction::Source::CardSettlement::SchemeFee::FeeType }

#fixed_componentString?

The fixed component of the fee, if applicable, given in major units of the fee amount.

Parameters:

Returns:



6384
# File 'lib/increase/models/transaction.rb', line 6384

required :fixed_component, String, nil?: true

#variable_rateString?

The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).

Parameters:

Returns:



6391
# File 'lib/increase/models/transaction.rb', line 6391

required :variable_rate, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/increase/models/transaction.rb', line 6425


Instance Method Details

#to_hash{

Returns:



4451
# File 'sig/increase/models/transaction.rbs', line 4451

def to_hash: -> {