Class: Increase::Models::Transaction::Source::CashbackPayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#cashback_payment

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accrued_on_card_id:, amount:, currency:, period_end:, period_start:) ⇒ Object

A Cashback Payment object. This field will be present in the JSON response if and only if category is equal to cashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.

Parameters:

  • The card on which the cashback was accrued.

  • The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

  • The ISO 4217 code for the transaction currency.

  • The end of the period for which this transaction paid cashback.

  • The start of the period for which this transaction paid cashback.



# File 'lib/increase/models/transaction.rb', line 6605


Instance Attribute Details

#accrued_on_card_idString?

The card on which the cashback was accrued.

Parameters:

Returns:



6577
# File 'lib/increase/models/transaction.rb', line 6577

required :accrued_on_card_id, String, nil?: true

#amountInteger

The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

Returns:



6584
# File 'lib/increase/models/transaction.rb', line 6584

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::CashbackPayment::Currency

The ISO 4217 code for the transaction currency.

Parameters:

Returns:



6591
# File 'lib/increase/models/transaction.rb', line 6591

required :currency, enum: -> { Increase::Transaction::Source::CashbackPayment::Currency }

#period_endTime

The end of the period for which this transaction paid cashback.

Parameters:

Returns:



6597
# File 'lib/increase/models/transaction.rb', line 6597

required :period_end, Time

#period_startTime

The start of the period for which this transaction paid cashback.

Parameters:

Returns:



6603
# File 'lib/increase/models/transaction.rb', line 6603

required :period_start, Time

Instance Method Details

#to_hash{

Returns:



4650
# File 'sig/increase/models/transaction.rbs', line 4650

def to_hash: -> {