Module: Increase::Models::Transaction::Source::Category

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.

See Also:

  • Increase::Models::Transaction::Source#category

Constant Summary collapse

ACCOUNT_TRANSFER_INTENTION =

Account Transfer Intention: details will be under the account_transfer_intention object.

Returns:

  • (:account_transfer_intention)
:account_transfer_intention
ACH_TRANSFER_INTENTION =

ACH Transfer Intention: details will be under the ach_transfer_intention object.

Returns:

  • (:ach_transfer_intention)
:ach_transfer_intention
ACH_TRANSFER_REJECTION =

ACH Transfer Rejection: details will be under the ach_transfer_rejection object.

Returns:

  • (:ach_transfer_rejection)
:ach_transfer_rejection
ACH_TRANSFER_RETURN =

ACH Transfer Return: details will be under the ach_transfer_return object.

Returns:

  • (:ach_transfer_return)
:ach_transfer_return
CASHBACK_PAYMENT =

Cashback Payment: details will be under the cashback_payment object.

Returns:

  • (:cashback_payment)
:cashback_payment
CARD_DISPUTE_ACCEPTANCE =

Legacy Card Dispute Acceptance: details will be under the card_dispute_acceptance object.

Returns:

  • (:card_dispute_acceptance)
:card_dispute_acceptance
CARD_DISPUTE_FINANCIAL =

Card Dispute Financial: details will be under the card_dispute_financial object.

Returns:

  • (:card_dispute_financial)
:card_dispute_financial
CARD_DISPUTE_LOSS =

Legacy Card Dispute Loss: details will be under the card_dispute_loss object.

Returns:

  • (:card_dispute_loss)
:card_dispute_loss
CARD_REFUND =

Card Refund: details will be under the card_refund object.

Returns:

  • (:card_refund)
:card_refund
CARD_SETTLEMENT =

Card Settlement: details will be under the card_settlement object.

Returns:

  • (:card_settlement)
:card_settlement
CARD_FINANCIAL =

Card Financial: details will be under the card_financial object.

Returns:

  • (:card_financial)
:card_financial
CARD_REVENUE_PAYMENT =

Card Revenue Payment: details will be under the card_revenue_payment object.

Returns:

  • (:card_revenue_payment)
:card_revenue_payment
CHECK_DEPOSIT_ACCEPTANCE =

Check Deposit Acceptance: details will be under the check_deposit_acceptance object.

Returns:

  • (:check_deposit_acceptance)
:check_deposit_acceptance
CHECK_DEPOSIT_RETURN =

Check Deposit Return: details will be under the check_deposit_return object.

Returns:

  • (:check_deposit_return)
:check_deposit_return
FEDNOW_TRANSFER_ACKNOWLEDGEMENT =

FedNow Transfer Acknowledgement: details will be under the fednow_transfer_acknowledgement object.

Returns:

  • (:fednow_transfer_acknowledgement)
:fednow_transfer_acknowledgement
CHECK_TRANSFER_DEPOSIT =

Check Transfer Deposit: details will be under the check_transfer_deposit object.

Returns:

  • (:check_transfer_deposit)
:check_transfer_deposit
FEE_PAYMENT =

Fee Payment: details will be under the fee_payment object.

Returns:

  • (:fee_payment)
:fee_payment
INBOUND_ACH_TRANSFER =

Inbound ACH Transfer Intention: details will be under the inbound_ach_transfer object.

Returns:

  • (:inbound_ach_transfer)
:inbound_ach_transfer
INBOUND_ACH_TRANSFER_RETURN_INTENTION =

Inbound ACH Transfer Return Intention: details will be under the inbound_ach_transfer_return_intention object.

Returns:

  • (:inbound_ach_transfer_return_intention)
:inbound_ach_transfer_return_intention
INBOUND_CHECK_DEPOSIT_RETURN_INTENTION =

Inbound Check Deposit Return Intention: details will be under the inbound_check_deposit_return_intention object.

Returns:

  • (:inbound_check_deposit_return_intention)
:inbound_check_deposit_return_intention
INBOUND_CHECK_ADJUSTMENT =

Inbound Check Adjustment: details will be under the inbound_check_adjustment object.

Returns:

  • (:inbound_check_adjustment)
:inbound_check_adjustment
INBOUND_FEDNOW_TRANSFER_CONFIRMATION =

Inbound FedNow Transfer Confirmation: details will be under the inbound_fednow_transfer_confirmation object.

Returns:

  • (:inbound_fednow_transfer_confirmation)
:inbound_fednow_transfer_confirmation
INBOUND_REAL_TIME_PAYMENTS_TRANSFER_CONFIRMATION =

Inbound Real-Time Payments Transfer Confirmation: details will be under the inbound_real_time_payments_transfer_confirmation object.

Returns:

  • (:inbound_real_time_payments_transfer_confirmation)
:inbound_real_time_payments_transfer_confirmation
INBOUND_WIRE_REVERSAL =

Inbound Wire Reversal: details will be under the inbound_wire_reversal object.

Returns:

  • (:inbound_wire_reversal)
:inbound_wire_reversal
INBOUND_WIRE_TRANSFER =

Inbound Wire Transfer Intention: details will be under the inbound_wire_transfer object.

Returns:

  • (:inbound_wire_transfer)
:inbound_wire_transfer
INBOUND_WIRE_TRANSFER_REVERSAL =

Inbound Wire Transfer Reversal Intention: details will be under the inbound_wire_transfer_reversal object.

Returns:

  • (:inbound_wire_transfer_reversal)
:inbound_wire_transfer_reversal
INTEREST_PAYMENT =

Interest Payment: details will be under the interest_payment object.

Returns:

  • (:interest_payment)
:interest_payment
INTERNAL_SOURCE =

Internal Source: details will be under the internal_source object.

Returns:

  • (:internal_source)
:internal_source
REAL_TIME_PAYMENTS_TRANSFER_ACKNOWLEDGEMENT =

Real-Time Payments Transfer Acknowledgement: details will be under the real_time_payments_transfer_acknowledgement object.

Returns:

  • (:real_time_payments_transfer_acknowledgement)
:real_time_payments_transfer_acknowledgement
SAMPLE_FUNDS =

Sample Funds: details will be under the sample_funds object.

Returns:

  • (:sample_funds)
:sample_funds
WIRE_TRANSFER_INTENTION =

Wire Transfer Intention: details will be under the wire_transfer_intention object.

Returns:

  • (:wire_transfer_intention)
:wire_transfer_intention
SWIFT_TRANSFER_INTENTION =

Swift Transfer Intention: details will be under the swift_transfer_intention object.

Returns:

  • (:swift_transfer_intention)
:swift_transfer_intention
SWIFT_TRANSFER_RETURN =

Swift Transfer Return: details will be under the swift_transfer_return object.

Returns:

  • (:swift_transfer_return)
:swift_transfer_return
CARD_PUSH_TRANSFER_ACCEPTANCE =

Card Push Transfer Acceptance: details will be under the card_push_transfer_acceptance object.

Returns:

  • (:card_push_transfer_acceptance)
:card_push_transfer_acceptance
ACCOUNT_REVENUE_PAYMENT =

Account Revenue Payment: details will be under the account_revenue_payment object.

Returns:

  • (:account_revenue_payment)
:account_revenue_payment
BLOCKCHAIN_ONRAMP_TRANSFER_INTENTION =

Blockchain On-Ramp Transfer Intention: details will be under the blockchain_onramp_transfer_intention object.

Returns:

  • (:blockchain_onramp_transfer_intention)
:blockchain_onramp_transfer_intention
BLOCKCHAIN_OFFRAMP_TRANSFER_SETTLEMENT =

Blockchain Off-Ramp Transfer Settlement: details will be under the blockchain_offramp_transfer_settlement object.

Returns:

  • (:blockchain_offramp_transfer_settlement)
:blockchain_offramp_transfer_settlement
OTHER =

The Transaction was made for an undocumented or deprecated reason.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Transaction::Source::category]

Returns:

  • (::Array[Increase::Models::Transaction::Source::category])


455
# File 'sig/increase/models/transaction.rbs', line 455

def self?.values: -> ::Array[Increase::Models::Transaction::Source::category]