Class: Increase::Models::Transaction::Source::CheckDepositReturn

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#check_deposit_return

Defined Under Namespace

Modules: Currency, ReturnReason

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, check_deposit_id:, currency:, return_reason:, returned_at:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CheckDepositReturn for more details.

A Check Deposit Return object. This field will be present in the JSON response if and only if category is equal to check_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.

Parameters:



# File 'lib/increase/models/transaction.rb', line 6283

Instance Attribute Details

#amountInteger

The returned amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


6247
# File 'lib/increase/models/transaction.rb', line 6247

required :amount, Integer

#check_deposit_idString

The identifier of the Check Deposit that was returned.

Parameters:

  • value (String)

Returns:

  • (String)


6253
# File 'lib/increase/models/transaction.rb', line 6253

required :check_deposit_id, String

#currencySymbol, Increase::Models::Transaction::Source::CheckDepositReturn::Currency

The ISO 4217 code for the transaction's currency.

Parameters:

  • value (Increase::Models::Transaction::Source::CheckDepositReturn::currency)

Returns:



6260
# File 'lib/increase/models/transaction.rb', line 6260

required :currency, enum: -> { Increase::Transaction::Source::CheckDepositReturn::Currency }

#return_reasonSymbol, Increase::Models::Transaction::Source::CheckDepositReturn::ReturnReason

Why this check was returned by the bank holding the account it was drawn against.

Parameters:

  • value (Increase::Models::Transaction::Source::CheckDepositReturn::return_reason)

Returns:



6267
# File 'lib/increase/models/transaction.rb', line 6267

required :return_reason, enum: -> { Increase::Transaction::Source::CheckDepositReturn::ReturnReason }

#returned_atTime

The ISO 8601 date and time at which the check deposit was returned.

Parameters:

  • value (Time)

Returns:

  • (Time)


6274
# File 'lib/increase/models/transaction.rb', line 6274

required :returned_at, Time

#transaction_idString

The identifier of the transaction that reversed the original check deposit transaction.

Parameters:

  • value (String)

Returns:

  • (String)


6281
# File 'lib/increase/models/transaction.rb', line 6281

required :transaction_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 6316

Instance Method Details

#to_hash{

Returns:

  • ({)


4728
# File 'sig/increase/models/transaction.rbs', line 4728

def to_hash: -> {