Module: Increase::Models::Transaction::Source::CheckDepositReturn::ReturnReason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

Why this check was returned by the bank holding the account it was drawn against.

See Also:

  • Increase::Models::Transaction::Source::CheckDepositReturn#return_reason

Constant Summary collapse

ACH_CONVERSION_NOT_SUPPORTED =

The check doesn't allow ACH conversion.

:ach_conversion_not_supported
CLOSED_ACCOUNT =

The account is closed. (Check21 return code D)

:closed_account
DUPLICATE_SUBMISSION =

The check has already been deposited. (Check21 return code Y)

:duplicate_submission
INSUFFICIENT_FUNDS =

Insufficient funds (Check21 return code A)

:insufficient_funds
NO_ACCOUNT =

No account was found matching the check details. (Check21 return code E)

:no_account
NOT_AUTHORIZED =

The check was not authorized. (Check21 return code Q)

:not_authorized
STALE_DATED =

The check is too old. (Check21 return code G)

:stale_dated
STOP_PAYMENT =

The payment has been stopped by the account holder. (Check21 return code C)

:stop_payment
UNKNOWN_REASON =

The reason for the return is unknown.

:unknown_reason
UNMATCHED_DETAILS =

The image doesn't match the details submitted.

:unmatched_details
UNREADABLE_IMAGE =

The image could not be read. (Check21 return code U)

:unreadable_image
ENDORSEMENT_IRREGULAR =

The check endorsement was irregular. (Check21 return code J)

:endorsement_irregular
ALTERED_OR_FICTITIOUS_ITEM =

The check present was either altered or fake. (Check21 return code N)

:altered_or_fictitious_item
FROZEN_OR_BLOCKED_ACCOUNT =

The account this check is drawn on is frozen. (Check21 return code F)

:frozen_or_blocked_account
POST_DATED =

The check is post dated. (Check21 return code H)

:post_dated
ENDORSEMENT_MISSING =

The endorsement was missing. (Check21 return code I)

:endorsement_missing
SIGNATURE_MISSING =

The check signature was missing. (Check21 return code K)

:signature_missing
STOP_PAYMENT_SUSPECT =

The bank suspects a stop payment will be placed. (Check21 return code T)

:stop_payment_suspect
UNUSABLE_IMAGE =

The bank cannot read the image. (Check21 return code U)

:unusable_image
IMAGE_FAILS_SECURITY_CHECK =

The check image fails the bank's security check. (Check21 return code V)

:image_fails_security_check
CANNOT_DETERMINE_AMOUNT =

The bank cannot determine the amount. (Check21 return code W)

:cannot_determine_amount
SIGNATURE_IRREGULAR =

The signature is inconsistent with prior signatures. (Check21 return code L)

:signature_irregular
NON_CASH_ITEM =

The check is a non-cash item and cannot be drawn against the account. (Check21 return code M)

:non_cash_item
UNABLE_TO_PROCESS =

The bank is unable to process this check. (Check21 return code O)

:unable_to_process
ITEM_EXCEEDS_DOLLAR_LIMIT =

The check exceeds the bank or customer's limit. (Check21 return code P)

:item_exceeds_dollar_limit
BRANCH_OR_ACCOUNT_SOLD =

The bank sold this account and no longer services this customer. (Check21 return code R)

:branch_or_account_sold

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Transaction::Source::CheckDepositReturn::return_reason]



4889
# File 'sig/increase/models/transaction.rbs', line 4889

def self?.values: -> ::Array[Increase::Models::Transaction::Source::CheckDepositReturn::return_reason]