Class: Increase::Models::Transaction::Source::CheckTransferDeposit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#check_transfer_deposit

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(back_image_file_id:, bank_of_first_deposit_routing_number:, deposited_at:, front_image_file_id:, inbound_check_deposit_id:, transaction_id:, transfer_id:, type:) ⇒ Object

A Check Transfer Deposit object. This field will be present in the JSON response if and only if category is equal to check_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.

Parameters:

  • back_image_file_id (String, nil)

    The identifier of the API File object containing an image of the back of the deposited check.

  • bank_of_first_deposit_routing_number (String, nil)

    The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.

  • deposited_at (Time)

    When the check was deposited.

  • front_image_file_id (String, nil)

    The identifier of the API File object containing an image of the front of the deposited check.

  • inbound_check_deposit_id (String, nil)

    The identifier of the Inbound Check Deposit object associated with this transaction.

  • transaction_id (String, nil)

    The identifier of the Transaction object created when the check was deposited.

  • transfer_id (String, nil)

    The identifier of the Check Transfer object that was deposited.

  • type (Symbol, Increase::Models::Transaction::Source::CheckTransferDeposit::Type)

    A constant representing the object's type. For this resource it will always be check_transfer_deposit.



# File 'lib/increase/models/transaction.rb', line 6883

Instance Attribute Details

#back_image_file_idString?

The identifier of the API File object containing an image of the back of the deposited check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6834
# File 'lib/increase/models/transaction.rb', line 6834

required :back_image_file_id, String, nil?: true

#bank_of_first_deposit_routing_numberString?

The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6842
# File 'lib/increase/models/transaction.rb', line 6842

required :bank_of_first_deposit_routing_number, String, nil?: true

#deposited_atTime

When the check was deposited.

Parameters:

  • value (Time)

Returns:

  • (Time)


6848
# File 'lib/increase/models/transaction.rb', line 6848

required :deposited_at, Time

#front_image_file_idString?

The identifier of the API File object containing an image of the front of the deposited check.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6855
# File 'lib/increase/models/transaction.rb', line 6855

required :front_image_file_id, String, nil?: true

#inbound_check_deposit_idString?

The identifier of the Inbound Check Deposit object associated with this transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6862
# File 'lib/increase/models/transaction.rb', line 6862

required :inbound_check_deposit_id, String, nil?: true

#transaction_idString?

The identifier of the Transaction object created when the check was deposited.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6868
# File 'lib/increase/models/transaction.rb', line 6868

required :transaction_id, String, nil?: true

#transfer_idString?

The identifier of the Check Transfer object that was deposited.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6874
# File 'lib/increase/models/transaction.rb', line 6874

required :transfer_id, String, nil?: true

#typeSymbol, Increase::Models::Transaction::Source::CheckTransferDeposit::Type

A constant representing the object's type. For this resource it will always be check_transfer_deposit.

Parameters:

  • value (Increase::Models::Transaction::Source::CheckTransferDeposit::type_)

Returns:



6881
# File 'lib/increase/models/transaction.rb', line 6881

required :type, enum: -> { Increase::Transaction::Source::CheckTransferDeposit::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


4901
# File 'sig/increase/models/transaction.rbs', line 4901

def to_hash: -> {