Class: Increase::Models::Transaction::Source::FednowTransferReturn

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#fednow_transfer_return

Defined Under Namespace

Modules: ReturnReasonCode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, return_reason_additional_information:, return_reason_code:, transfer_id:) ⇒ Object

A FedNow Transfer Return object. This field will be present in the JSON response if and only if category is equal to fednow_transfer_return. A FedNow Transfer Return is created when a FedNow Transfer sent from Increase is returned by the recipient's bank.

Parameters:

  • amount (Integer)

    The returned amount in USD cents. This is always a positive number.

  • return_reason_additional_information (String, nil)

    Additional information about the return provided by the recipient's bank.

  • return_reason_code (Symbol, Increase::Models::Transaction::Source::FednowTransferReturn::ReturnReasonCode)

    The reason the transfer was returned as provided by the recipient's bank.

  • transfer_id (String)

    The identifier of the FedNow Transfer that led to this Transaction.



# File 'lib/increase/models/transaction.rb', line 7060


Instance Attribute Details

#amountInteger

The returned amount in USD cents. This is always a positive number.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


7039
# File 'lib/increase/models/transaction.rb', line 7039

required :amount, Integer

#return_reason_additional_informationString?

Additional information about the return provided by the recipient's bank.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7045
# File 'lib/increase/models/transaction.rb', line 7045

required :return_reason_additional_information, String, nil?: true

#return_reason_codeSymbol, Increase::Models::Transaction::Source::FednowTransferReturn::ReturnReasonCode

The reason the transfer was returned as provided by the recipient's bank.

Parameters:

  • value (Increase::Models::Transaction::Source::FednowTransferReturn::return_reason_code)

Returns:



7051
7052
# File 'lib/increase/models/transaction.rb', line 7051

required :return_reason_code,
enum: -> { Increase::Transaction::Source::FednowTransferReturn::ReturnReasonCode }

#transfer_idString

The identifier of the FedNow Transfer that led to this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


7058
# File 'lib/increase/models/transaction.rb', line 7058

required :transfer_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


4989
# File 'sig/increase/models/transaction.rbs', line 4989

def to_hash: -> {