Class: Increase::Models::Transaction::Source::FeePayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#fee_payment

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, fee_period_start:, program_id:) ⇒ Object

A Fee Payment object. This field will be present in the JSON response if and only if category is equal to fee_payment. A Fee Payment represents a payment made to Increase.

Parameters:

  • The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

  • The ISO 4217 code for the transaction currency.

  • The start of this payment's fee period, usually the first day of a month.

  • The Program for which this fee was incurred.



# File 'lib/increase/models/transaction.rb', line 7163


Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

Returns:



7142
# File 'lib/increase/models/transaction.rb', line 7142

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::FeePayment::Currency

The ISO 4217 code for the transaction currency.

Parameters:

Returns:



7149
# File 'lib/increase/models/transaction.rb', line 7149

required :currency, enum: -> { Increase::Transaction::Source::FeePayment::Currency }

#fee_period_startDate

The start of this payment's fee period, usually the first day of a month.

Parameters:

Returns:



7155
# File 'lib/increase/models/transaction.rb', line 7155

required :fee_period_start, Date

#program_idString?

The Program for which this fee was incurred.

Parameters:

Returns:



7161
# File 'lib/increase/models/transaction.rb', line 7161

required :program_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:



5093
# File 'sig/increase/models/transaction.rbs', line 5093

def to_hash: -> {