Class: Increase::Models::Transaction::Source::InboundACHTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundACHTransfer
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Classes: Addenda
Instance Attribute Summary collapse
-
#addenda ⇒ Increase::Models::Transaction::Source::InboundACHTransfer::Addenda?
Additional information sent from the originator.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#originator_company_descriptive_date ⇒ String?
The description of the date of the transfer, usually in the format
YYMMDD. -
#originator_company_discretionary_data ⇒ String?
Data set by the originator.
-
#originator_company_entry_description ⇒ String
An informational description of the transfer.
-
#originator_company_id ⇒ String
An identifier for the originating company.
-
#originator_company_name ⇒ String
A name set by the originator to identify themselves.
-
#receiver_id_number ⇒ String?
The originator's identifier for the transfer recipient.
-
#receiver_name ⇒ String?
The name of the transfer recipient.
-
#trace_number ⇒ String
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank.
-
#transfer_id ⇒ String
The Inbound ACH Transfer's identifier.
Instance Method Summary collapse
-
#initialize(addenda:, amount:, originator_company_descriptive_date:, originator_company_discretionary_data:, originator_company_entry_description:, originator_company_id:, originator_company_name:, receiver_id_number:, receiver_name:, trace_number:, transfer_id:) ⇒ Object
constructor
An Inbound ACH Transfer Intention object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(addenda:, amount:, originator_company_descriptive_date:, originator_company_discretionary_data:, originator_company_entry_description:, originator_company_id:, originator_company_name:, receiver_id_number:, receiver_name:, trace_number:, transfer_id:) ⇒ Object
An Inbound ACH Transfer Intention object. This field will be present in the JSON
response if and only if category is equal to inbound_ach_transfer. An
Inbound ACH Transfer Intention is created when an ACH transfer is initiated at
another bank and received by Increase.
|
|
# File 'lib/increase/models/transaction.rb', line 7269
|
Instance Attribute Details
#addenda ⇒ Increase::Models::Transaction::Source::InboundACHTransfer::Addenda?
Additional information sent from the originator.
7201 |
# File 'lib/increase/models/transaction.rb', line 7201 required :addenda, -> { Increase::Transaction::Source::InboundACHTransfer::Addenda }, nil?: true |
#amount ⇒ Integer
The transfer amount in USD cents.
7207 |
# File 'lib/increase/models/transaction.rb', line 7207 required :amount, Integer |
#originator_company_descriptive_date ⇒ String?
The description of the date of the transfer, usually in the format YYMMDD.
7213 |
# File 'lib/increase/models/transaction.rb', line 7213 required :originator_company_descriptive_date, String, nil?: true |
#originator_company_discretionary_data ⇒ String?
Data set by the originator.
7219 |
# File 'lib/increase/models/transaction.rb', line 7219 required :originator_company_discretionary_data, String, nil?: true |
#originator_company_entry_description ⇒ String
An informational description of the transfer.
7225 |
# File 'lib/increase/models/transaction.rb', line 7225 required :originator_company_entry_description, String |
#originator_company_id ⇒ String
An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.
7232 |
# File 'lib/increase/models/transaction.rb', line 7232 required :originator_company_id, String |
#originator_company_name ⇒ String
A name set by the originator to identify themselves.
7238 |
# File 'lib/increase/models/transaction.rb', line 7238 required :originator_company_name, String |
#receiver_id_number ⇒ String?
The originator's identifier for the transfer recipient.
7244 |
# File 'lib/increase/models/transaction.rb', line 7244 required :receiver_id_number, String, nil?: true |
#receiver_name ⇒ String?
The name of the transfer recipient. This value is informational and not verified by Increase.
7251 |
# File 'lib/increase/models/transaction.rb', line 7251 required :receiver_name, String, nil?: true |
#trace_number ⇒ String
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are used to correlate returns.
7261 |
# File 'lib/increase/models/transaction.rb', line 7261 required :trace_number, String |
#transfer_id ⇒ String
The Inbound ACH Transfer's identifier.
7267 |
# File 'lib/increase/models/transaction.rb', line 7267 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
5164 |
# File 'sig/increase/models/transaction.rbs', line 5164 def to_hash: -> { |