Class: Increase::Models::Transaction::Source::InboundCheckAdjustment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundCheckAdjustment
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#adjusted_transaction_id ⇒ String
The ID of the transaction that was adjusted.
-
#amount ⇒ Integer
The amount of the check adjustment.
-
#reason ⇒ Symbol, Increase::Models::Transaction::Source::InboundCheckAdjustment::Reason
The reason for the adjustment.
Instance Method Summary collapse
-
#initialize(adjusted_transaction_id:, amount:, reason:) ⇒ Object
constructor
An Inbound Check Adjustment object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(adjusted_transaction_id:, amount:, reason:) ⇒ Object
An Inbound Check Adjustment object. This field will be present in the JSON
response if and only if category is equal to inbound_check_adjustment. An
Inbound Check Adjustment is created when Increase receives an adjustment for a
check or return deposited through Check21.
|
|
# File 'lib/increase/models/transaction.rb', line 6788
|
Instance Attribute Details
#adjusted_transaction_id ⇒ String
The ID of the transaction that was adjusted.
6774 |
# File 'lib/increase/models/transaction.rb', line 6774 required :adjusted_transaction_id, String |
#amount ⇒ Integer
The amount of the check adjustment.
6780 |
# File 'lib/increase/models/transaction.rb', line 6780 required :amount, Integer |
#reason ⇒ Symbol, Increase::Models::Transaction::Source::InboundCheckAdjustment::Reason
The reason for the adjustment.
6786 |
# File 'lib/increase/models/transaction.rb', line 6786 required :reason, enum: -> { Increase::Transaction::Source::InboundCheckAdjustment::Reason } |
Instance Method Details
#to_hash ⇒ {
5134 |
# File 'sig/increase/models/transaction.rbs', line 5134
def to_hash: -> {
|