Module: Increase::Models::Transaction::Source::InboundCheckAdjustment::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

The reason for the adjustment.

See Also:

  • Increase::Models::Transaction::Source::InboundCheckAdjustment#reason

Constant Summary collapse

LATE_RETURN =

The return was initiated too late and the receiving institution has responded with a Late Return Claim.

Returns:

  • (:late_return)
:late_return
WRONG_PAYEE_CREDIT =

The check was deposited to the wrong payee and the depositing institution has reimbursed the funds with a Wrong Payee Credit.

Returns:

  • (:wrong_payee_credit)
:wrong_payee_credit
ADJUSTED_AMOUNT =

The check was deposited with a different amount than what was written on the check.

Returns:

  • (:adjusted_amount)
:adjusted_amount
NON_CONFORMING_ITEM =

The recipient was not able to process the check. This usually happens for e.g., low quality images.

Returns:

  • (:non_conforming_item)
:non_conforming_item
:paid

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::Transaction::Source::InboundCheckAdjustment::reason]

Returns:

  • (::Array[Increase::Models::Transaction::Source::InboundCheckAdjustment::reason])


5165
# File 'sig/increase/models/transaction.rbs', line 5165

def self?.values: -> ::Array[Increase::Models::Transaction::Source::InboundCheckAdjustment::reason]