Class: Increase::Models::Transaction::Source::InboundCheckDepositReturnIntention
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundCheckDepositReturnIntention
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#inbound_check_deposit_id ⇒ String
The ID of the Inbound Check Deposit that is being returned.
-
#transfer_id ⇒ String?
The identifier of the Check Transfer object that was deposited.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
5177 |
# File 'sig/increase/models/transaction.rbs', line 5177
def initialize: (
|
Instance Attribute Details
#inbound_check_deposit_id ⇒ String
The ID of the Inbound Check Deposit that is being returned.
6832 |
# File 'lib/increase/models/transaction.rb', line 6832 required :inbound_check_deposit_id, String |
#transfer_id ⇒ String?
The identifier of the Check Transfer object that was deposited.
6838 |
# File 'lib/increase/models/transaction.rb', line 6838 required :transfer_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
5182 |
# File 'sig/increase/models/transaction.rbs', line 5182
def to_hash: -> {
|