Class: Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: Currency
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transfer’s currency.
-
#creditor_name ⇒ String
The name the sender of the transfer specified as the recipient of the transfer.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code of the transfer’s currency.
-
#debtor_account_number ⇒ String
The account number of the account that sent the transfer.
-
#debtor_name ⇒ String
The name provided by the sender of the transfer.
-
#debtor_routing_number ⇒ String
The routing number of the account that sent the transfer.
-
#transaction_identification ⇒ String
The Real-Time Payments network identification of the transfer.
-
#transfer_id ⇒ String
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
#unstructured_remittance_information ⇒ String?
Additional information included with the transfer.
Instance Method Summary collapse
-
#initialize(amount:, creditor_name:, currency:, debtor_account_number:, debtor_name:, debtor_routing_number:, transaction_identification:, transfer_id:, unstructured_remittance_information:) ⇒ Object
constructor
Some parameter documentations has been truncated, see InboundRealTimePaymentsTransferConfirmation for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, creditor_name:, currency:, debtor_account_number:, debtor_name:, debtor_routing_number:, transaction_identification:, transfer_id:, unstructured_remittance_information:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation for more details.
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_real_time_payments_transfer_confirmation`. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
|
|
# File 'lib/increase/models/transaction.rb', line 6919
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transfer’s currency. For dollars, for example, this is cents.
6867 |
# File 'lib/increase/models/transaction.rb', line 6867 required :amount, Integer |
#creditor_name ⇒ String
The name the sender of the transfer specified as the recipient of the transfer.
6873 |
# File 'lib/increase/models/transaction.rb', line 6873 required :creditor_name, String |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code of the transfer’s currency. This will always be “USD” for a Real-Time Payments transfer.
6880 6881 |
# File 'lib/increase/models/transaction.rb', line 6880 required :currency, enum: -> { Increase::Transaction::Source::InboundRealTimePaymentsTransferConfirmation::Currency } |
#debtor_account_number ⇒ String
The account number of the account that sent the transfer.
6887 |
# File 'lib/increase/models/transaction.rb', line 6887 required :debtor_account_number, String |
#debtor_name ⇒ String
The name provided by the sender of the transfer.
6893 |
# File 'lib/increase/models/transaction.rb', line 6893 required :debtor_name, String |
#debtor_routing_number ⇒ String
The routing number of the account that sent the transfer.
6899 |
# File 'lib/increase/models/transaction.rb', line 6899 required :debtor_routing_number, String |
#transaction_identification ⇒ String
The Real-Time Payments network identification of the transfer.
6905 |
# File 'lib/increase/models/transaction.rb', line 6905 required :transaction_identification, String |
#transfer_id ⇒ String
The identifier of the Real-Time Payments Transfer that led to this Transaction.
6911 |
# File 'lib/increase/models/transaction.rb', line 6911 required :transfer_id, String |
#unstructured_remittance_information ⇒ String?
Additional information included with the transfer.
6917 |
# File 'lib/increase/models/transaction.rb', line 6917 required :unstructured_remittance_information, String, nil?: true |