Class: Increase::Models::Transaction::Source::InboundWireTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#inbound_wire_transfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



5543
# File 'sig/increase/models/transaction.rbs', line 5543

def initialize: (

Instance Attribute Details

#amountInteger

The amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


7747
# File 'lib/increase/models/transaction.rb', line 7747

required :amount, Integer

#creditor_address_line1String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7753
# File 'lib/increase/models/transaction.rb', line 7753

required :creditor_address_line1, String, nil?: true

#creditor_address_line2String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7759
# File 'lib/increase/models/transaction.rb', line 7759

required :creditor_address_line2, String, nil?: true

#creditor_address_line3String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7765
# File 'lib/increase/models/transaction.rb', line 7765

required :creditor_address_line3, String, nil?: true

#creditor_nameString?

A name set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7771
# File 'lib/increase/models/transaction.rb', line 7771

required :creditor_name, String, nil?: true

#debtor_address_line1String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7777
# File 'lib/increase/models/transaction.rb', line 7777

required :debtor_address_line1, String, nil?: true

#debtor_address_line2String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7783
# File 'lib/increase/models/transaction.rb', line 7783

required :debtor_address_line2, String, nil?: true

#debtor_address_line3String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7789
# File 'lib/increase/models/transaction.rb', line 7789

required :debtor_address_line3, String, nil?: true

#debtor_nameString?

A name set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7795
# File 'lib/increase/models/transaction.rb', line 7795

required :debtor_name, String, nil?: true

#descriptionString

An Increase-constructed description of the transfer.

Parameters:

  • value (String)

Returns:

  • (String)


7801
# File 'lib/increase/models/transaction.rb', line 7801

required :description, String

#end_to_end_identificationString?

A free-form reference string set by the sender, to help identify the transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7807
# File 'lib/increase/models/transaction.rb', line 7807

required :end_to_end_identification, String, nil?: true

#input_message_accountability_dataString?

A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7815
# File 'lib/increase/models/transaction.rb', line 7815

required :input_message_accountability_data, String, nil?: true

#instructing_agent_routing_numberString?

The American Bankers' Association (ABA) routing number of the bank that sent the wire.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7822
# File 'lib/increase/models/transaction.rb', line 7822

required :instructing_agent_routing_number, String, nil?: true

#instruction_identificationString?

The sending bank's identifier for the wire transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7828
# File 'lib/increase/models/transaction.rb', line 7828

required :instruction_identification, String, nil?: true

#purposeString?

The reason for the wire transfer, as set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7834
# File 'lib/increase/models/transaction.rb', line 7834

required :purpose, String, nil?: true

#transfer_idString

The ID of the Inbound Wire Transfer object that resulted in this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


7840
# File 'lib/increase/models/transaction.rb', line 7840

required :transfer_id, String

#unique_end_to_end_transaction_referenceString?

The Unique End-to-end Transaction Reference (UETR) of the transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7848
# File 'lib/increase/models/transaction.rb', line 7848

required :unique_end_to_end_transaction_reference, String, nil?: true

#unstructured_remittance_informationString?

A free-form message set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7854
# File 'lib/increase/models/transaction.rb', line 7854

required :unstructured_remittance_information, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


5564
# File 'sig/increase/models/transaction.rbs', line 5564

def to_hash: -> {