Class: Increase::Models::Transaction::Source::InboundWireTransferReversal
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundWireTransferReversal
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#inbound_wire_transfer_id ⇒ String
The ID of the Inbound Wire Transfer that is being reversed.
Instance Method Summary collapse
-
#initialize ⇒ InboundWireTransferReversal
constructor
A new instance of InboundWireTransferReversal.
- #to_hash ⇒ { inbound_wire_transfer_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ InboundWireTransferReversal
Returns a new instance of InboundWireTransferReversal.
5456 |
# File 'sig/increase/models/transaction.rbs', line 5456
def initialize: (inbound_wire_transfer_id: String) -> void
|
Instance Attribute Details
#inbound_wire_transfer_id ⇒ String
The ID of the Inbound Wire Transfer that is being reversed.
7269 |
# File 'lib/increase/models/transaction.rb', line 7269 required :inbound_wire_transfer_id, String |
Instance Method Details
#to_hash ⇒ { inbound_wire_transfer_id: String }
5458 |
# File 'sig/increase/models/transaction.rbs', line 5458
def to_hash: -> { inbound_wire_transfer_id: String }
|