Class: Increase::Models::Transaction::Source::InterestPayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accrued_on_account_id:, amount:, currency:, period_end:, period_start:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::InterestPayment for more details.

An Interest Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `interest_payment`. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.

Parameters:

  • accrued_on_account_id (String)

    The account on which the interest was accrued.

  • amount (Integer)

    The amount in the minor unit of the transaction’s currency. For dollars, for exa

  • currency (Symbol, Increase::Models::Transaction::Source::InterestPayment::Currency)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction

  • period_end (Time)

    The end of the period for which this transaction paid interest.

  • period_start (Time)

    The start of the period for which this transaction paid interest.



# File 'lib/increase/models/transaction.rb', line 7297

Instance Attribute Details

#accrued_on_account_idString

The account on which the interest was accrued.

Returns:

  • (String)


7269
# File 'lib/increase/models/transaction.rb', line 7269

required :accrued_on_account_id, String

#amountInteger

The amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


7276
# File 'lib/increase/models/transaction.rb', line 7276

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::InterestPayment::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction currency.



7283
# File 'lib/increase/models/transaction.rb', line 7283

required :currency, enum: -> { Increase::Transaction::Source::InterestPayment::Currency }

#period_endTime

The end of the period for which this transaction paid interest.

Returns:

  • (Time)


7289
# File 'lib/increase/models/transaction.rb', line 7289

required :period_end, Time

#period_startTime

The start of the period for which this transaction paid interest.

Returns:

  • (Time)


7295
# File 'lib/increase/models/transaction.rb', line 7295

required :period_start, Time