Class: Increase::Models::Transaction::Source::InternalSource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#internal_source

Defined Under Namespace

Modules: Currency, Reason

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, reason:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::InternalSource for more details.

An Internal Source object. This field will be present in the JSON response if and only if category is equal to internal_source. A transaction between the user and Increase. See the reason attribute for more information.

Parameters:



# File 'lib/increase/models/transaction.rb', line 7372

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


7356
# File 'lib/increase/models/transaction.rb', line 7356

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::InternalSource::Currency

The ISO 4217 code for the transaction currency.

Parameters:

  • value (Increase::Models::Transaction::Source::InternalSource::currency)

Returns:



7363
# File 'lib/increase/models/transaction.rb', line 7363

required :currency, enum: -> { Increase::Transaction::Source::InternalSource::Currency }

#reasonSymbol, Increase::Models::Transaction::Source::InternalSource::Reason

An Internal Source is a transaction between you and Increase. This describes the reason for the transaction.

Parameters:

  • value (Increase::Models::Transaction::Source::InternalSource::reason)

Returns:



7370
# File 'lib/increase/models/transaction.rb', line 7370

required :reason, enum: -> { Increase::Transaction::Source::InternalSource::Reason }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 7396

Instance Method Details

#to_hash{

Returns:

  • ({)


5529
# File 'sig/increase/models/transaction.rbs', line 5529

def to_hash: -> {