Class: Increase::Models::Transaction::Source::WireTransferIntention
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::WireTransferIntention
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#account_number ⇒ String
The destination account number.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#message_to_recipient ⇒ String
The message that will show on the recipient's bank statement.
-
#routing_number ⇒ String
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
#transfer_id ⇒ String
The identifier of the Wire Transfer that led to this Transaction.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
5727 |
# File 'sig/increase/models/transaction.rbs', line 5727
def initialize: (
|
Instance Attribute Details
#account_number ⇒ String
The destination account number.
8057 |
# File 'lib/increase/models/transaction.rb', line 8057 required :account_number, String |
#amount ⇒ Integer
The transfer amount in USD cents.
8063 |
# File 'lib/increase/models/transaction.rb', line 8063 required :amount, Integer |
#message_to_recipient ⇒ String
The message that will show on the recipient's bank statement.
8069 |
# File 'lib/increase/models/transaction.rb', line 8069 required :message_to_recipient, String |
#routing_number ⇒ String
The American Bankers' Association (ABA) Routing Transit Number (RTN).
8075 |
# File 'lib/increase/models/transaction.rb', line 8075 required :routing_number, String |
#transfer_id ⇒ String
The identifier of the Wire Transfer that led to this Transaction.
8081 |
# File 'lib/increase/models/transaction.rb', line 8081 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
5735 |
# File 'sig/increase/models/transaction.rbs', line 5735
def to_hash: -> {
|