Class: Increase::Models::UnwrapWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/unwrap_webhook_event.rb

Defined Under Namespace

Modules: Category, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, associated_object_id:, associated_object_type:, category:, created_at:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::UnwrapWebhookEvent for more details.

Events are records of things that happened to objects at Increase. Events are accessible via the List Events endpoint and can be delivered to your application via webhooks. For more information, see our [webhooks guide](increase.com/documentation/webhooks).

Parameters:

  • id (String)

    The Event identifier.

  • associated_object_id (String)

    The identifier of the object that generated this Event.

  • associated_object_type (String)

    The type of the object that generated this Event.

  • category (Symbol, Increase::Models::UnwrapWebhookEvent::Category)

    The category of the Event. We may add additional possible values for this enum o

  • created_at (Time)

    The time the Event was created.

  • type (Symbol, Increase::Models::UnwrapWebhookEvent::Type)

    A constant representing the object’s type. For this resource it will always be ‘



# File 'lib/increase/models/unwrap_webhook_event.rb', line 44

Instance Attribute Details

#associated_object_idString

The identifier of the object that generated this Event.

Returns:

  • (String)


16
# File 'lib/increase/models/unwrap_webhook_event.rb', line 16

required :associated_object_id, String

#associated_object_typeString

The type of the object that generated this Event.

Returns:

  • (String)


22
# File 'lib/increase/models/unwrap_webhook_event.rb', line 22

required :associated_object_type, String

#categorySymbol, Increase::Models::UnwrapWebhookEvent::Category

The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.



29
# File 'lib/increase/models/unwrap_webhook_event.rb', line 29

required :category, enum: -> { Increase::UnwrapWebhookEvent::Category }

#created_atTime

The time the Event was created.

Returns:

  • (Time)


35
# File 'lib/increase/models/unwrap_webhook_event.rb', line 35

required :created_at, Time

#idString

The Event identifier.

Returns:

  • (String)


10
# File 'lib/increase/models/unwrap_webhook_event.rb', line 10

required :id, String

#typeSymbol, Increase::Models::UnwrapWebhookEvent::Type

A constant representing the object’s type. For this resource it will always be event.



42
# File 'lib/increase/models/unwrap_webhook_event.rb', line 42

required :type, enum: -> { Increase::UnwrapWebhookEvent::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/unwrap_webhook_event.rb', line 401