Class: Increase::Models::WireDrawdownRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireDrawdownRequest
- Defined in:
- lib/increase/models/wire_drawdown_request.rb,
sig/increase/models/wire_drawdown_request.rbs
Overview
Defined Under Namespace
Modules: Status, Type Classes: CreditorAddress, DebtorAddress, Submission
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account to which the debtor—the recipient of this request—is being requested to send funds.
-
#account_number_id ⇒ String
The Account Number to which the debtor—the recipient of this request—is being requested to send funds.
-
#amount ⇒ Integer
The amount being requested in cents.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the wire drawdown request was created.
-
#creditor_address ⇒ Increase::Models::WireDrawdownRequest::CreditorAddress
The creditor's address.
-
#creditor_name ⇒ String
The creditor's name.
-
#currency ⇒ String
The ISO 4217 code for the amount being requested.
-
#debtor_account_number ⇒ String
The debtor's account number.
-
#debtor_address ⇒ Increase::Models::WireDrawdownRequest::DebtorAddress
The debtor's address.
-
#debtor_external_account_id ⇒ String?
The debtor's external account identifier.
-
#debtor_name ⇒ String
The debtor's name.
-
#debtor_routing_number ⇒ String
The debtor's routing number.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to be mirrored back in the subsequent wire transfer.
-
#fulfillment_inbound_wire_transfer_id ⇒ String?
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
#id ⇒ String
The Wire drawdown request identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#status ⇒ Symbol, Increase::Models::WireDrawdownRequest::Status
The lifecycle status of the drawdown request.
-
#submission ⇒ Increase::Models::WireDrawdownRequest::Submission?
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
#type ⇒ Symbol, Increase::Models::WireDrawdownRequest::Type
A constant representing the object's type.
-
#unique_end_to_end_transaction_reference ⇒ String?
The unique end-to-end transaction reference (UETR) of the drawdown request.
-
#unstructured_remittance_information ⇒ String
Remittance information the debtor will see as part of the drawdown request.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(input_message_accountability_data:) ⇒ Object
constructor
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input_message_accountability_data:) ⇒ Object
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
|
|
# File 'lib/increase/models/wire_drawdown_request.rb', line 145
|
Instance Attribute Details
#account_id ⇒ String
The Account to which the debtor—the recipient of this request—is being requested to send funds.
18 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 18 required :account_id, String |
#account_number_id ⇒ String
The Account Number to which the debtor—the recipient of this request—is being requested to send funds.
25 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 25 required :account_number_id, String |
#amount ⇒ Integer
The amount being requested in cents.
31 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 31 required :amount, Integer |
#created_at ⇒ Time
The ISO 8601 date and time at which the wire drawdown request was created.
38 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 38 required :created_at, Time |
#creditor_address ⇒ Increase::Models::WireDrawdownRequest::CreditorAddress
The creditor's address.
44 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 44 required :creditor_address, -> { Increase::WireDrawdownRequest::CreditorAddress } |
#creditor_name ⇒ String
The creditor's name.
50 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 50 required :creditor_name, String |
#currency ⇒ String
The ISO 4217 code for the amount being requested. Will always be "USD".
57 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 57 required :currency, String |
#debtor_account_number ⇒ String
The debtor's account number.
63 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 63 required :debtor_account_number, String |
#debtor_address ⇒ Increase::Models::WireDrawdownRequest::DebtorAddress
The debtor's address.
69 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 69 required :debtor_address, -> { Increase::WireDrawdownRequest::DebtorAddress } |
#debtor_external_account_id ⇒ String?
The debtor's external account identifier.
75 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 75 required :debtor_external_account_id, String, nil?: true |
#debtor_name ⇒ String
The debtor's name.
81 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 81 required :debtor_name, String |
#debtor_routing_number ⇒ String
The debtor's routing number.
87 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 87 required :debtor_routing_number, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to be mirrored back in the subsequent wire transfer.
94 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 94 required :end_to_end_identification, String, nil?: true |
#fulfillment_inbound_wire_transfer_id ⇒ String?
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
101 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 101 required :fulfillment_inbound_wire_transfer_id, String, nil?: true |
#id ⇒ String
The Wire drawdown request identifier.
11 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
109 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 109 required :idempotency_key, String, nil?: true |
#status ⇒ Symbol, Increase::Models::WireDrawdownRequest::Status
The lifecycle status of the drawdown request.
115 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 115 required :status, enum: -> { Increase::WireDrawdownRequest::Status } |
#submission ⇒ Increase::Models::WireDrawdownRequest::Submission?
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
122 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 122 required :submission, -> { Increase::WireDrawdownRequest::Submission }, nil?: true |
#type ⇒ Symbol, Increase::Models::WireDrawdownRequest::Type
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
129 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 129 required :type, enum: -> { Increase::WireDrawdownRequest::Type } |
#unique_end_to_end_transaction_reference ⇒ String?
The unique end-to-end transaction reference (UETR) of the drawdown request.
137 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 137 required :unique_end_to_end_transaction_reference, String, nil?: true |
#unstructured_remittance_information ⇒ String
Remittance information the debtor will see as part of the drawdown request.
143 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 143 required :unstructured_remittance_information, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/wire_drawdown_request.rb', line 355
|
Instance Method Details
#to_hash ⇒ {
95 |
# File 'sig/increase/models/wire_drawdown_request.rbs', line 95 def to_hash: -> { |