Class: Increase::Models::WireDrawdownRequest::CreditorAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireDrawdownRequest::CreditorAddress
- Defined in:
- lib/increase/models/wire_drawdown_request.rb,
sig/increase/models/wire_drawdown_request.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#postal_code ⇒ String?
The ZIP code of the address.
-
#state ⇒ String?
The address state.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
137 |
# File 'sig/increase/models/wire_drawdown_request.rbs', line 137
def initialize: (
|
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
195 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 195 required :city, String |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
203 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 203 required :country, String |
#line1 ⇒ String
The first line of the address.
209 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 209 required :line1, String |
#line2 ⇒ String?
The second line of the address.
215 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 215 required :line2, String, nil?: true |
#postal_code ⇒ String?
The ZIP code of the address.
221 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 221 required :postal_code, String, nil?: true |
#state ⇒ String?
The address state.
227 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 227 required :state, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
146 |
# File 'sig/increase/models/wire_drawdown_request.rbs', line 146
def to_hash: -> {
|