Class: Increase::Models::WireDrawdownRequest::DebtorAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireDrawdownRequest::DebtorAddress
- Defined in:
- lib/increase/models/wire_drawdown_request.rb,
sig/increase/models/wire_drawdown_request.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#postal_code ⇒ String?
The ZIP code of the address.
-
#state ⇒ String?
The address state.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
179 |
# File 'sig/increase/models/wire_drawdown_request.rbs', line 179
def initialize: (
|
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
254 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 254 required :city, String |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
262 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 262 required :country, String |
#line1 ⇒ String
The first line of the address.
268 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 268 required :line1, String |
#line2 ⇒ String?
The second line of the address.
274 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 274 required :line2, String, nil?: true |
#postal_code ⇒ String?
The ZIP code of the address.
280 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 280 required :postal_code, String, nil?: true |
#state ⇒ String?
The address state.
286 |
# File 'lib/increase/models/wire_drawdown_request.rb', line 286 required :state, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
188 |
# File 'sig/increase/models/wire_drawdown_request.rbs', line 188
def to_hash: -> {
|