Class: Increase::Models::WireDrawdownRequestCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireDrawdownRequestCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/wire_drawdown_request_create_params.rb
Overview
Defined Under Namespace
Modules: ChargeBearer Classes: CreditorAddress, DebtorAddress
Instance Attribute Summary collapse
-
#account_number_id ⇒ String
The Account Number to which the debtor should send funds.
-
#amount ⇒ Integer
The amount requested from the debtor, in USD cents.
-
#charge_bearer ⇒ Symbol, ...
Determines who bears the cost of the drawdown request.
-
#creditor_address ⇒ Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress
The creditor’s address.
-
#creditor_name ⇒ String
The creditor’s name.
-
#debtor_account_number ⇒ String?
The debtor’s account number.
-
#debtor_address ⇒ Increase::Models::WireDrawdownRequestCreateParams::DebtorAddress
The debtor’s address.
-
#debtor_external_account_id ⇒ String?
The ID of an External Account to initiate a transfer to.
-
#debtor_name ⇒ String
The debtor’s name.
-
#debtor_routing_number ⇒ String?
The debtor’s routing number.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender mirrored back in the subsequent wire transfer.
-
#unstructured_remittance_information ⇒ String
Remittance information the debtor will see as part of the request.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DebtorAddress for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil) ⇒ Object
Some parameter documentations has been truncated, see DebtorAddress for more details.
The debtor’s address.
|
|
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 154
|
Instance Attribute Details
#account_number_id ⇒ String
The Account Number to which the debtor should send funds.
14 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 14 required :account_number_id, String |
#amount ⇒ Integer
The amount requested from the debtor, in USD cents.
20 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 20 required :amount, Integer |
#charge_bearer ⇒ Symbol, ...
Determines who bears the cost of the drawdown request. Defaults to ‘shared` if not specified.
57 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 57 optional :charge_bearer, enum: -> { Increase::WireDrawdownRequestCreateParams::ChargeBearer } |
#creditor_address ⇒ Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress
The creditor’s address.
26 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 26 required :creditor_address, -> { Increase::WireDrawdownRequestCreateParams::CreditorAddress } |
#creditor_name ⇒ String
The creditor’s name.
32 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 32 required :creditor_name, String |
#debtor_account_number ⇒ String?
The debtor’s account number.
63 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 63 optional :debtor_account_number, String |
#debtor_address ⇒ Increase::Models::WireDrawdownRequestCreateParams::DebtorAddress
The debtor’s address.
38 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 38 required :debtor_address, -> { Increase::WireDrawdownRequestCreateParams::DebtorAddress } |
#debtor_external_account_id ⇒ String?
The ID of an External Account to initiate a transfer to. If this parameter is provided, ‘debtor_account_number` and `debtor_routing_number` must be absent.
70 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 70 optional :debtor_external_account_id, String |
#debtor_name ⇒ String
The debtor’s name.
44 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 44 required :debtor_name, String |
#debtor_routing_number ⇒ String?
The debtor’s routing number.
76 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 76 optional :debtor_routing_number, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender mirrored back in the subsequent wire transfer.
83 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 83 optional :end_to_end_identification, String |
#unstructured_remittance_information ⇒ String
Remittance information the debtor will see as part of the request.
50 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 50 required :unstructured_remittance_information, String |