Class: Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/wire_drawdown_request_create_params.rb,
sig/increase/models/wire_drawdown_request_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number_id:, amount:, creditor_address:, creditor_name:, debtor_address:, debtor_name:, unstructured_remittance_information:, charge_bearer: nil, debtor_account_number: nil, debtor_external_account_id: nil, debtor_routing_number: nil, end_to_end_identification: nil, request_options: {}) ⇒ Object

Parameters:

  • account_number_id (String)

    The Account Number to which the debtor should send funds.

  • amount (Integer)

    The amount requested from the debtor, in USD cents.

  • creditor_address (Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress)

    The creditor's address.

  • creditor_name (String)

    The creditor's name.

  • debtor_address (Increase::Models::WireDrawdownRequestCreateParams::DebtorAddress)

    The debtor's address.

  • debtor_name (String)

    The debtor's name.

  • unstructured_remittance_information (String)

    Remittance information the debtor will see as part of the request.

  • charge_bearer (Symbol, Increase::Models::WireDrawdownRequestCreateParams::ChargeBearer) (defaults to: nil)

    Determines who bears the cost of the drawdown request. Defaults to shared if not specified.

  • debtor_account_number (String) (defaults to: nil)

    The debtor's account number.

  • debtor_external_account_id (String) (defaults to: nil)

    The ID of an External Account to initiate a transfer to. If this parameter is provided, debtor_account_number and debtor_routing_number must be absent.

  • debtor_routing_number (String) (defaults to: nil)

    The debtor's routing number.

  • end_to_end_identification (String) (defaults to: nil)

    A free-form reference string set by the sender mirrored back in the subsequent wire transfer.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 121

class CreditorAddress < Increase::Internal::Type::BaseModel
  # @!attribute city
  #   The city, district, town, or village of the address.
  #
  #   @return [String]
  required :city, String

  # @!attribute country
  #   The two-letter
  #   [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for
  #   the country of the address.
  #
  #   @return [String]
  required :country, String

  # @!attribute line1
  #   The first line of the address. This is usually the street number and street.
  #
  #   @return [String]
  required :line1, String

  # @!attribute line2
  #   The second line of the address. This might be the floor or room number.
  #
  #   @return [String, nil]
  optional :line2, String

  # @!attribute postal_code
  #   The ZIP code of the address.
  #
  #   @return [String, nil]
  optional :postal_code, String

  # @!attribute state
  #   The address state.
  #
  #   @return [String, nil]
  optional :state, String

  # @!method initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil)
  #   The creditor's address.
  #
  #   @param city [String] The city, district, town, or village of the address.
  #
  #   @param country [String]
  #     The two-letter
  #     [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for
  #     the country of the address.
  #
  #   @param line1 [String] The first line of the address. This is usually the street number and street.
  #
  #   @param line2 [String] The second line of the address. This might be the floor or room number.
  #
  #   @param postal_code [String] The ZIP code of the address.
  #
  #   @param state [String] The address state.
end

Instance Attribute Details

#cityString

The city, district, town, or village of the address.

Parameters:

  • value (String)

Returns:

  • (String)


126
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 126

required :city, String

#countryString

The two-letter ISO 3166-1 alpha-2 code for the country of the address.

Parameters:

  • value (String)

Returns:

  • (String)


134
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 134

required :country, String

#line1String

The first line of the address. This is usually the street number and street.

Parameters:

  • value (String)

Returns:

  • (String)


140
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 140

required :line1, String

#line2String?

The second line of the address. This might be the floor or room number.

Parameters:

  • (String)

Returns:

  • (String, nil)


146
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 146

optional :line2, String

#postal_codeString?

The ZIP code of the address.

Parameters:

  • (String)

Returns:

  • (String, nil)


152
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 152

optional :postal_code, String

#stateString?

The address state.

Parameters:

  • (String)

Returns:

  • (String, nil)


158
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 158

optional :state, String

Instance Method Details

#to_hash{

Returns:

  • ({)


130
# File 'sig/increase/models/wire_drawdown_request_create_params.rbs', line 130

def to_hash: -> {