Class: Increase::Models::WireDrawdownRequestCreateParams::DebtorAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireDrawdownRequestCreateParams::DebtorAddress
- Defined in:
- lib/increase/models/wire_drawdown_request_create_params.rb,
sig/increase/models/wire_drawdown_request_create_params.rbs
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#postal_code ⇒ String?
The ZIP code of the address.
-
#state ⇒ String?
The address state.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
169 |
# File 'sig/increase/models/wire_drawdown_request_create_params.rbs', line 169
def initialize: (
|
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
179 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 179 required :city, String |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
187 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 187 required :country, String |
#line1 ⇒ String
The first line of the address. This is usually the street number and street.
193 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 193 required :line1, String |
#line2 ⇒ String?
The second line of the address. This might be the floor or room number.
199 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 199 optional :line2, String |
#postal_code ⇒ String?
The ZIP code of the address.
205 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 205 optional :postal_code, String |
#state ⇒ String?
The address state.
211 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 211 optional :state, String |
Instance Method Details
#to_hash ⇒ {
178 |
# File 'sig/increase/models/wire_drawdown_request_create_params.rbs', line 178
def to_hash: -> {
|