Class: Increase::Models::WireTransfer::Remittance::Tax
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireTransfer::Remittance::Tax
- Defined in:
- lib/increase/models/wire_transfer.rb,
sig/increase/models/wire_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#date ⇒ Date
The month and year the tax payment is for, in YYYY-MM-DD format.
-
#identification_number ⇒ String
The 9-digit Tax Identification Number (TIN) or Employer Identification Number (EIN).
-
#type_code ⇒ String
The 5-character tax type code.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
431 |
# File 'sig/increase/models/wire_transfer.rbs', line 431
def initialize: (
|
Instance Attribute Details
#date ⇒ Date
The month and year the tax payment is for, in YYYY-MM-DD format. The day is ignored.
598 |
# File 'lib/increase/models/wire_transfer.rb', line 598 required :date, Date |
#identification_number ⇒ String
The 9-digit Tax Identification Number (TIN) or Employer Identification Number (EIN).
605 |
# File 'lib/increase/models/wire_transfer.rb', line 605 required :identification_number, String |
#type_code ⇒ String
The 5-character tax type code.
611 |
# File 'lib/increase/models/wire_transfer.rb', line 611 required :type_code, String |
Instance Method Details
#to_hash ⇒ {
437 |
# File 'sig/increase/models/wire_transfer.rbs', line 437
def to_hash: -> {
|