Class: Increase::Models::WireTransferCreateParams::Debtor::Address::Structured

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/wire_transfer_create_params.rb,
sig/increase/models/wire_transfer_create_params.rbs

Overview

See Also:

  • Increase::Models::WireTransferCreateParams::Debtor::Address#structured

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object

Structured address components. City and country are required.

Parameters:

  • city (String)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String) (defaults to: nil)

    The first line of the address.

  • line2 (String) (defaults to: nil)

    The second line of the address.

  • postal_code (String) (defaults to: nil)

    The postal code of the address.

  • state (String) (defaults to: nil)

    The address state.



# File 'lib/increase/models/wire_transfer_create_params.rb', line 396

Instance Attribute Details

#cityString

The city, district, town, or village of the address.

Parameters:

  • value (String)

Returns:

  • (String)


362
# File 'lib/increase/models/wire_transfer_create_params.rb', line 362

required :city, String

#countryString

The two-letter ISO 3166-1 alpha-2 code for the country of the address.

Parameters:

  • value (String)

Returns:

  • (String)


370
# File 'lib/increase/models/wire_transfer_create_params.rb', line 370

required :country, String

#line1String?

The first line of the address.

Parameters:

  • (String)

Returns:

  • (String, nil)


376
# File 'lib/increase/models/wire_transfer_create_params.rb', line 376

optional :line1, String

#line2String?

The second line of the address.

Parameters:

  • (String)

Returns:

  • (String, nil)


382
# File 'lib/increase/models/wire_transfer_create_params.rb', line 382

optional :line2, String

#postal_codeString?

The postal code of the address.

Parameters:

  • (String)

Returns:

  • (String, nil)


388
# File 'lib/increase/models/wire_transfer_create_params.rb', line 388

optional :postal_code, String

#stateString?

The address state.

Parameters:

  • (String)

Returns:

  • (String, nil)


394
# File 'lib/increase/models/wire_transfer_create_params.rb', line 394

optional :state, String

Instance Method Details

#to_hash{

Returns:

  • ({)


355
# File 'sig/increase/models/wire_transfer_create_params.rbs', line 355

def to_hash: -> {