Class: Increase::Resources::BeneficialOwners

Inherits:
Object
  • Object
show all
Defined in:
lib/increase/resources/beneficial_owners.rb,
sig/increase/resources/beneficial_owners.rbs

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ BeneficialOwners

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of BeneficialOwners.

Parameters:



164
165
166
# File 'lib/increase/resources/beneficial_owners.rb', line 164

def initialize(client:)
  @client = client
end

Instance Method Details

#archive(entity_beneficial_owner_id, request_options: {}) ⇒ Increase::Models::EntityBeneficialOwner

Archive a Beneficial Owner

Parameters:

  • entity_beneficial_owner_id (String)

    The identifier of the Beneficial Owner to archive.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



152
153
154
155
156
157
158
159
# File 'lib/increase/resources/beneficial_owners.rb', line 152

def archive(entity_beneficial_owner_id, params = {})
  @client.request(
    method: :post,
    path: ["entity_beneficial_owners/%1$s/archive", entity_beneficial_owner_id],
    model: Increase::EntityBeneficialOwner,
    options: params[:request_options]
  )
end

#create(entity_id:, individual:, prongs:, company_title: nil, request_options: {}) ⇒ Increase::Models::EntityBeneficialOwner

Create a Beneficial Owner

Parameters:

  • entity_id (String)

    The identifier of the Entity to associate with the new Beneficial Owner. Only corporation entities have beneficial owners.

  • individual (Increase::Models::BeneficialOwnerCreateParams::Individual)

    Personal details for the beneficial owner.

  • prongs (Array<Symbol, Increase::Models::BeneficialOwnerCreateParams::Prong>)

    Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both.

  • company_title (String)

    This person's role or title within the entity.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



29
30
31
32
33
34
35
36
37
38
# File 'lib/increase/resources/beneficial_owners.rb', line 29

def create(params)
  parsed, options = Increase::BeneficialOwnerCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "entity_beneficial_owners",
    body: parsed,
    model: Increase::EntityBeneficialOwner,
    options: options
  )
end

#list(entity_id:, cursor: nil, idempotency_key: nil, limit: nil, request_options: {}) ⇒ Increase::Internal::Page<Increase::Models::EntityBeneficialOwner>

List Beneficial Owners

Parameters:

  • entity_id (String)

    The identifier of the Entity to list beneficial owners for. Only corporation entities have beneficial owners.

  • cursor (String)

    Return the page of entries after this one.

  • idempotency_key (String)

    Filter records to the one with the specified idempotency_key you chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

  • limit (Integer)

    Limit the size of the list that is returned. The default (and maximum) is 100 objects.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/increase/resources/beneficial_owners.rb', line 128

def list(params)
  parsed, options = Increase::BeneficialOwnerListParams.dump_request(params)
  query = Increase::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "entity_beneficial_owners",
    query: query,
    page: Increase::Internal::Page,
    model: Increase::EntityBeneficialOwner,
    options: options
  )
end

#retrieve(entity_beneficial_owner_id, request_options: {}) ⇒ Increase::Models::EntityBeneficialOwner

Retrieve a Beneficial Owner

Parameters:

  • entity_beneficial_owner_id (String)

    The identifier of the Beneficial Owner to retrieve.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



51
52
53
54
55
56
57
58
# File 'lib/increase/resources/beneficial_owners.rb', line 51

def retrieve(entity_beneficial_owner_id, params = {})
  @client.request(
    method: :get,
    path: ["entity_beneficial_owners/%1$s", entity_beneficial_owner_id],
    model: Increase::EntityBeneficialOwner,
    options: params[:request_options]
  )
end

#update(entity_beneficial_owner_id, address: nil, confirmed_no_us_tax_id: nil, identification: nil, name: nil, prongs: nil, request_options: {}) ⇒ Increase::Models::EntityBeneficialOwner

Update a Beneficial Owner

Parameters:

  • entity_beneficial_owner_id (String)

    The identifier of the Beneficial Owner to update.

  • address (Increase::Models::BeneficialOwnerUpdateParams::Address)

    The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.

  • confirmed_no_us_tax_id (Boolean)

    The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).

  • identification (Increase::Models::BeneficialOwnerUpdateParams::Identification)

    A means of verifying the person's identity.

  • name (String)

    The individual's legal name.

  • prongs (Array<Symbol, Increase::Models::BeneficialOwnerUpdateParams::Prong>)

    Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both. Providing this replaces the beneficial owner's current prongs.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



92
93
94
95
96
97
98
99
100
101
# File 'lib/increase/resources/beneficial_owners.rb', line 92

def update(entity_beneficial_owner_id, params = {})
  parsed, options = Increase::BeneficialOwnerUpdateParams.dump_request(params)
  @client.request(
    method: :patch,
    path: ["entity_beneficial_owners/%1$s", entity_beneficial_owner_id],
    body: parsed,
    model: Increase::EntityBeneficialOwner,
    options: options
  )
end