Class: Increase::Resources::IntrafiExclusions

Inherits:
Object
  • Object
show all
Defined in:
lib/increase/resources/intrafi_exclusions.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ IntrafiExclusions

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of IntrafiExclusions.

Parameters:



112
113
114
# File 'lib/increase/resources/intrafi_exclusions.rb', line 112

def initialize(client:)
  @client = client
end

Instance Method Details

#archive(intrafi_exclusion_id, request_options: {}) ⇒ Increase::Models::IntrafiExclusion

Some parameter documentations has been truncated, see Models::IntrafiExclusionArchiveParams for more details.

Archive an IntraFi Exclusion

Parameters:

  • intrafi_exclusion_id (String)

    The identifier of the IntraFi Exclusion request to archive. It may take 5 busine

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



100
101
102
103
104
105
106
107
# File 'lib/increase/resources/intrafi_exclusions.rb', line 100

def archive(intrafi_exclusion_id, params = {})
  @client.request(
    method: :post,
    path: ["intrafi_exclusions/%1$s/archive", intrafi_exclusion_id],
    model: Increase::IntrafiExclusion,
    options: params[:request_options]
  )
end

#create(entity_id:, fdic_certificate_number:, request_options: {}) ⇒ Increase::Models::IntrafiExclusion

Some parameter documentations has been truncated, see Models::IntrafiExclusionCreateParams for more details.

Create an IntraFi Exclusion

Parameters:

  • entity_id (String)

    The identifier of the Entity whose deposits will be excluded.

  • fdic_certificate_number (String)

    The FDIC certificate number of the financial institution to be excluded. An FDIC

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



22
23
24
25
26
27
28
29
30
31
# File 'lib/increase/resources/intrafi_exclusions.rb', line 22

def create(params)
  parsed, options = Increase::IntrafiExclusionCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "intrafi_exclusions",
    body: parsed,
    model: Increase::IntrafiExclusion,
    options: options
  )
end

#list(cursor: nil, entity_id: nil, idempotency_key: nil, limit: nil, request_options: {}) ⇒ Increase::Internal::Page<Increase::Models::IntrafiExclusion>

Some parameter documentations has been truncated, see Models::IntrafiExclusionListParams for more details.

List IntraFi Exclusions

Parameters:

  • cursor (String)

    Return the page of entries after this one.

  • entity_id (String)

    Filter IntraFi Exclusions for those belonging to the specified Entity.

  • idempotency_key (String)

    Filter records to the one with the specified ‘idempotency_key` you chose for tha

  • limit (Integer)

    Limit the size of the list that is returned. The default (and maximum) is 100 ob

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/increase/resources/intrafi_exclusions.rb', line 73

def list(params = {})
  parsed, options = Increase::IntrafiExclusionListParams.dump_request(params)
  query = Increase::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "intrafi_exclusions",
    query: query,
    page: Increase::Internal::Page,
    model: Increase::IntrafiExclusion,
    options: options
  )
end

#retrieve(intrafi_exclusion_id, request_options: {}) ⇒ Increase::Models::IntrafiExclusion

Get an IntraFi Exclusion

Parameters:

  • intrafi_exclusion_id (String)

    The identifier of the IntraFi Exclusion to retrieve.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



44
45
46
47
48
49
50
51
# File 'lib/increase/resources/intrafi_exclusions.rb', line 44

def retrieve(intrafi_exclusion_id, params = {})
  @client.request(
    method: :get,
    path: ["intrafi_exclusions/%1$s", intrafi_exclusion_id],
    model: Increase::IntrafiExclusion,
    options: params[:request_options]
  )
end