Class: Increase::Resources::PhysicalCardProfiles

Inherits:
Object
  • Object
show all
Defined in:
lib/increase/resources/physical_card_profiles.rb,
sig/increase/resources/physical_card_profiles.rbs

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ PhysicalCardProfiles

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of PhysicalCardProfiles.

Parameters:



157
158
159
# File 'lib/increase/resources/physical_card_profiles.rb', line 157

def initialize(client:)
  @client = client
end

Instance Method Details

#archive(physical_card_profile_id, request_options: {}) ⇒ Increase::Models::PhysicalCardProfile

Archive a Physical Card Profile

Parameters:

  • physical_card_profile_id (String)

    The identifier of the Physical Card Profile to archive.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



108
109
110
111
112
113
114
115
# File 'lib/increase/resources/physical_card_profiles.rb', line 108

def archive(physical_card_profile_id, params = {})
  @client.request(
    method: :post,
    path: ["physical_card_profiles/%1$s/archive", physical_card_profile_id],
    model: Increase::PhysicalCardProfile,
    options: params[:request_options]
  )
end

#clone_(physical_card_profile_id, carrier_image_file_id: nil, contact_phone: nil, description: nil, front_image_file_id: nil, front_text: nil, program_id: nil, request_options: {}) ⇒ Increase::Models::PhysicalCardProfile

Clone a Physical Card Profile

Parameters:

  • physical_card_profile_id (String)

    The identifier of the Physical Card Profile to clone.

  • carrier_image_file_id (String)

    The identifier of the File containing the physical card's carrier image.

  • contact_phone (String)

    A phone number the user can contact to receive support for their card.

  • description (String)

    A description you can use to identify the Card Profile.

  • front_image_file_id (String)

    The identifier of the File containing the physical card's front image.

  • front_text (Increase::Models::PhysicalCardProfileCloneParams::FrontText)

    Text printed on the front of the card. Reach out to support@increase.com for more information.

  • program_id (String)

    The identifier of the Program to use for the cloned Physical Card Profile.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



143
144
145
146
147
148
149
150
151
152
# File 'lib/increase/resources/physical_card_profiles.rb', line 143

def clone_(physical_card_profile_id, params = {})
  parsed, options = Increase::PhysicalCardProfileCloneParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["physical_card_profiles/%1$s/clone", physical_card_profile_id],
    body: parsed,
    model: Increase::PhysicalCardProfile,
    options: options
  )
end

#create(carrier_image_file_id:, contact_phone:, description:, front_image_file_id:, program_id:, front_text: nil, request_options: {}) ⇒ Increase::Models::PhysicalCardProfile

Create a Physical Card Profile

Parameters:

  • carrier_image_file_id (String)

    The identifier of the File containing the physical card's carrier image.

  • contact_phone (String)

    A phone number the user can contact to receive support for their card.

  • description (String)

    A description you can use to identify the Card Profile.

  • front_image_file_id (String)

    The identifier of the File containing the physical card's front image.

  • program_id (String)

    The identifier for the Program that this Physical Card Profile falls under.

  • front_text (Increase::Models::PhysicalCardProfileCreateParams::FrontText)

    Text printed on the front of the card. Reach out to support@increase.com for more information.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



30
31
32
33
34
35
36
37
38
39
# File 'lib/increase/resources/physical_card_profiles.rb', line 30

def create(params)
  parsed, options = Increase::PhysicalCardProfileCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "physical_card_profiles",
    body: parsed,
    model: Increase::PhysicalCardProfile,
    options: options
  )
end

#list(cursor: nil, idempotency_key: nil, limit: nil, status: nil, request_options: {}) ⇒ Increase::Internal::Page<Increase::Models::PhysicalCardProfile>

List Physical Card Profiles

Parameters:

  • cursor (String)

    Return the page of entries after this one.

  • idempotency_key (String)

    Filter records to the one with the specified idempotency_key you chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

  • limit (Integer)

    Limit the size of the list that is returned. The default (and maximum) is 100 objects.

  • status (Increase::Models::PhysicalCardProfileListParams::Status)
  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/increase/resources/physical_card_profiles.rb', line 84

def list(params = {})
  parsed, options = Increase::PhysicalCardProfileListParams.dump_request(params)
  query = Increase::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "physical_card_profiles",
    query: query,
    page: Increase::Internal::Page,
    model: Increase::PhysicalCardProfile,
    options: options
  )
end

#retrieve(physical_card_profile_id, request_options: {}) ⇒ Increase::Models::PhysicalCardProfile

Retrieve a Card Profile

Parameters:

  • physical_card_profile_id (String)

    The identifier of the Card Profile.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



52
53
54
55
56
57
58
59
# File 'lib/increase/resources/physical_card_profiles.rb', line 52

def retrieve(physical_card_profile_id, params = {})
  @client.request(
    method: :get,
    path: ["physical_card_profiles/%1$s", physical_card_profile_id],
    model: Increase::PhysicalCardProfile,
    options: params[:request_options]
  )
end