Class: Increase::Resources::Simulations::CardPurchaseSupplements

Inherits:
Object
  • Object
show all
Defined in:
lib/increase/resources/simulations/card_purchase_supplements.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ CardPurchaseSupplements

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of CardPurchaseSupplements.

Parameters:



42
43
44
# File 'lib/increase/resources/simulations/card_purchase_supplements.rb', line 42

def initialize(client:)
  @client = client
end

Instance Method Details

#create(transaction_id:, invoice: nil, line_items: nil, request_options: {}) ⇒ Increase::Models::CardPurchaseSupplement

Some parameter documentations has been truncated, see Models::Simulations::CardPurchaseSupplementCreateParams for more details.

Simulates the creation of a Card Purchase Supplement (Level 3 data) for a card settlement. This happens asynchronously in production when Visa sends enhanced transaction data about a purchase.

Parameters:

Returns:

See Also:



28
29
30
31
32
33
34
35
36
37
# File 'lib/increase/resources/simulations/card_purchase_supplements.rb', line 28

def create(params)
  parsed, options = Increase::Simulations::CardPurchaseSupplementCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "simulations/card_purchase_supplements",
    body: parsed,
    model: Increase::CardPurchaseSupplement,
    options: options
  )
end