Class: Increase::Resources::Simulations::Exports

Inherits:
Object
  • Object
show all
Defined in:
lib/increase/resources/simulations/exports.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Exports

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Exports.

Parameters:



40
41
42
# File 'lib/increase/resources/simulations/exports.rb', line 40

def initialize(client:)
  @client = client
end

Instance Method Details

#create(category:, form_1099_int: nil, request_options: {}) ⇒ Increase::Models::Export

Some parameter documentations has been truncated, see Models::Simulations::ExportCreateParams for more details.

Many exports are created by you via POST /exports or in the Dashboard. Some exports are created automatically by Increase. For example, tax documents are published once a year. In sandbox, you can trigger the arrival of an export that would normally only be created automatically via this simulation.

Parameters:

Returns:

See Also:



26
27
28
29
30
31
32
33
34
35
# File 'lib/increase/resources/simulations/exports.rb', line 26

def create(params)
  parsed, options = Increase::Simulations::ExportCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "simulations/exports",
    body: parsed,
    model: Increase::Export,
    options: options
  )
end