Module: Increase::Models::ACHPrenotification::StandardEntryClassCode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/ach_prenotification.rb
Overview
The [Standard Entry Class (SEC) code](/documentation/ach-standard-entry-class-codes) to use for the ACH Prenotification.
Constant Summary collapse
- CORPORATE_CREDIT_OR_DEBIT =
Corporate Credit and Debit (CCD) is used for business-to-business payments.
:corporate_credit_or_debit- CORPORATE_TRADE_EXCHANGE =
Corporate Trade Exchange (CTX) allows for including extensive remittance information with business-to-business payments.
:corporate_trade_exchange- PREARRANGED_PAYMENTS_AND_DEPOSIT =
Prearranged Payments and Deposits (PPD) is used for credits or debits originated by an organization to a consumer, such as payroll direct deposits.
:prearranged_payments_and_deposit- INTERNET_INITIATED =
Internet Initiated (WEB) is used for consumer payments initiated or authorized via the Internet. Debits can only be initiated by non-consumers to debit a consumer’s account. Credits can only be used for consumer to consumer transactions.
:internet_initiated
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info