Class: Increase::Models::ACHTransfer::InboundFundsHold
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ACHTransfer::InboundFundsHold
- Defined in:
- lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs
Overview
Defined Under Namespace
Modules: Currency, Status, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The held amount in the minor unit of the account's currency.
-
#automatically_releases_at ⇒ Time
When the hold will be released automatically.
-
#created_at ⇒ Time
The ISO 8601 time at which the hold was created.
-
#currency ⇒ Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Currency
The ISO 4217 code for the hold's currency.
-
#held_transaction_id ⇒ String?
The ID of the Transaction for which funds were held.
-
#pending_transaction_id ⇒ String?
The ID of the Pending Transaction representing the held funds.
-
#released_at ⇒ Time?
When the hold was released (if it has been released).
-
#status ⇒ Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Status
The status of the hold.
-
#type ⇒ Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object
constructor
Increase will sometimes hold the funds for ACH debit transfers.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
|
|
# File 'lib/increase/models/ach_transfer.rb', line 804
|
Instance Attribute Details
#amount ⇒ Integer
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
750 |
# File 'lib/increase/models/ach_transfer.rb', line 750 required :amount, Integer |
#automatically_releases_at ⇒ Time
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
757 |
# File 'lib/increase/models/ach_transfer.rb', line 757 required :automatically_releases_at, Time |
#created_at ⇒ Time
The ISO 8601 time at which the hold was created.
764 |
# File 'lib/increase/models/ach_transfer.rb', line 764 required :created_at, Time |
#currency ⇒ Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Currency
The ISO 4217 code for the hold's currency.
771 |
# File 'lib/increase/models/ach_transfer.rb', line 771 required :currency, enum: -> { Increase::ACHTransfer::InboundFundsHold::Currency } |
#held_transaction_id ⇒ String?
The ID of the Transaction for which funds were held.
777 |
# File 'lib/increase/models/ach_transfer.rb', line 777 required :held_transaction_id, String, nil?: true |
#pending_transaction_id ⇒ String?
The ID of the Pending Transaction representing the held funds.
783 |
# File 'lib/increase/models/ach_transfer.rb', line 783 required :pending_transaction_id, String, nil?: true |
#released_at ⇒ Time?
When the hold was released (if it has been released).
789 |
# File 'lib/increase/models/ach_transfer.rb', line 789 required :released_at, Time, nil?: true |
#status ⇒ Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Status
The status of the hold.
795 |
# File 'lib/increase/models/ach_transfer.rb', line 795 required :status, enum: -> { Increase::ACHTransfer::InboundFundsHold::Status } |
#type ⇒ Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Type
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
802 |
# File 'lib/increase/models/ach_transfer.rb', line 802 required :type, enum: -> { Increase::ACHTransfer::InboundFundsHold::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/ach_transfer.rb', line 846
|
Instance Method Details
#to_hash ⇒ {
500 |
# File 'sig/increase/models/ach_transfer.rbs', line 500
def to_hash: -> {
|