Class: Increase::Models::ACHTransfer::InboundFundsHold

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs

Overview

See Also:

  • Increase::Models::ACHTransfer#inbound_funds_hold

Defined Under Namespace

Modules: Currency, Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::ACHTransfer::InboundFundsHold for more details.

Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.

Parameters:

  • amount (Integer)

    The held amount in the minor unit of the account's currency. For dollars, for ex

  • automatically_releases_at (Time)

    When the hold will be released automatically. Certain conditions may cause it to

  • created_at (Time)

    The ISO 8601 time at which the hold wa

  • currency (Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Currency)

    The ISO 4217 code for the hold's curre

  • held_transaction_id (String, nil)

    The ID of the Transaction for which funds were held.

  • pending_transaction_id (String, nil)

    The ID of the Pending Transaction representing the held funds.

  • released_at (Time, nil)

    When the hold was released (if it has been released).

  • status (Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Status)

    The status of the hold.

  • type (Symbol, Increase::Models::ACHTransfer::InboundFundsHold::Type)

    A constant representing the object's type. For this resource it will always be `



# File 'lib/increase/models/ach_transfer.rb', line 746

Instance Attribute Details

#amountInteger

The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


692
# File 'lib/increase/models/ach_transfer.rb', line 692

required :amount, Integer

#automatically_releases_atTime

When the hold will be released automatically. Certain conditions may cause it to be released before this time.

Parameters:

  • value (Time)

Returns:

  • (Time)


699
# File 'lib/increase/models/ach_transfer.rb', line 699

required :automatically_releases_at, Time

#created_atTime

The ISO 8601 time at which the hold was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


706
# File 'lib/increase/models/ach_transfer.rb', line 706

required :created_at, Time

#currencySymbol, Increase::Models::ACHTransfer::InboundFundsHold::Currency

The ISO 4217 code for the hold's currency.

Parameters:

  • value (Increase::Models::ACHTransfer::InboundFundsHold::currency)

Returns:



713
# File 'lib/increase/models/ach_transfer.rb', line 713

required :currency, enum: -> { Increase::ACHTransfer::InboundFundsHold::Currency }

#held_transaction_idString?

The ID of the Transaction for which funds were held.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


719
# File 'lib/increase/models/ach_transfer.rb', line 719

required :held_transaction_id, String, nil?: true

#pending_transaction_idString?

The ID of the Pending Transaction representing the held funds.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


725
# File 'lib/increase/models/ach_transfer.rb', line 725

required :pending_transaction_id, String, nil?: true

#released_atTime?

When the hold was released (if it has been released).

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


731
# File 'lib/increase/models/ach_transfer.rb', line 731

required :released_at, Time, nil?: true

#statusSymbol, Increase::Models::ACHTransfer::InboundFundsHold::Status

The status of the hold.

Parameters:

  • value (Increase::Models::ACHTransfer::InboundFundsHold::status)

Returns:



737
# File 'lib/increase/models/ach_transfer.rb', line 737

required :status, enum: -> { Increase::ACHTransfer::InboundFundsHold::Status }

#typeSymbol, Increase::Models::ACHTransfer::InboundFundsHold::Type

A constant representing the object's type. For this resource it will always be inbound_funds_hold.

Parameters:

  • value (Increase::Models::ACHTransfer::InboundFundsHold::type_)

Returns:



744
# File 'lib/increase/models/ach_transfer.rb', line 744

required :type, enum: -> { Increase::ACHTransfer::InboundFundsHold::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/ach_transfer.rb', line 781

Instance Method Details

#to_hash{

Returns:

  • ({)


500
# File 'sig/increase/models/ach_transfer.rbs', line 500

def to_hash: -> {