Class: Increase::Models::ACHTransfer::InboundFundsHold

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer.rb

Overview

Defined Under Namespace

Modules: Currency, Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::ACHTransfer::InboundFundsHold for more details.

Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.

Parameters:



# File 'lib/increase/models/ach_transfer.rb', line 743

Instance Attribute Details

#amountInteger

The held amount in the minor unit of the account’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


689
# File 'lib/increase/models/ach_transfer.rb', line 689

required :amount, Integer

#automatically_releases_atTime

When the hold will be released automatically. Certain conditions may cause it to be released before this time.

Returns:

  • (Time)


696
# File 'lib/increase/models/ach_transfer.rb', line 696

required :automatically_releases_at, Time

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the hold was created.

Returns:

  • (Time)


703
# File 'lib/increase/models/ach_transfer.rb', line 703

required :created_at, Time

#currencySymbol, Increase::Models::ACHTransfer::InboundFundsHold::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the hold’s currency.



710
# File 'lib/increase/models/ach_transfer.rb', line 710

required :currency, enum: -> { Increase::ACHTransfer::InboundFundsHold::Currency }

#held_transaction_idString?

The ID of the Transaction for which funds were held.

Returns:

  • (String, nil)


716
# File 'lib/increase/models/ach_transfer.rb', line 716

required :held_transaction_id, String, nil?: true

#pending_transaction_idString?

The ID of the Pending Transaction representing the held funds.

Returns:

  • (String, nil)


722
# File 'lib/increase/models/ach_transfer.rb', line 722

required :pending_transaction_id, String, nil?: true

#released_atTime?

When the hold was released (if it has been released).

Returns:

  • (Time, nil)


728
# File 'lib/increase/models/ach_transfer.rb', line 728

required :released_at, Time, nil?: true

#statusSymbol, Increase::Models::ACHTransfer::InboundFundsHold::Status

The status of the hold.



734
# File 'lib/increase/models/ach_transfer.rb', line 734

required :status, enum: -> { Increase::ACHTransfer::InboundFundsHold::Status }

#typeSymbol, Increase::Models::ACHTransfer::InboundFundsHold::Type

A constant representing the object’s type. For this resource it will always be ‘inbound_funds_hold`.



741
# File 'lib/increase/models/ach_transfer.rb', line 741

required :type, enum: -> { Increase::ACHTransfer::InboundFundsHold::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/ach_transfer.rb', line 778