Class: Increase::Models::ACHTransfer::NotificationsOfChange

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer.rb

Defined Under Namespace

Modules: ChangeCode, CorrectedAccountFunding

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(change_code:, corrected_account_funding:, corrected_account_number:, corrected_individual_id:, corrected_routing_number:, created_at:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::ACHTransfer::NotificationsOfChange for more details.

Parameters:



# File 'lib/increase/models/ach_transfer.rb', line 866

Instance Attribute Details

#change_codeSymbol, Increase::Models::ACHTransfer::NotificationsOfChange::ChangeCode

The required type of change that is being signaled by the receiving financial institution.



830
# File 'lib/increase/models/ach_transfer.rb', line 830

required :change_code, enum: -> { Increase::ACHTransfer::NotificationsOfChange::ChangeCode }

#corrected_account_fundingSymbol, ...

The corrected account funding type that should be used in future ACHs to this account. This is derived from the corrected transaction code.



837
838
839
# File 'lib/increase/models/ach_transfer.rb', line 837

required :corrected_account_funding,
enum: -> { Increase::ACHTransfer::NotificationsOfChange::CorrectedAccountFunding },
nil?: true

#corrected_account_numberString?

The corrected account number that should be used in future ACHs to this account.

Returns:

  • (String, nil)


845
# File 'lib/increase/models/ach_transfer.rb', line 845

required :corrected_account_number, String, nil?: true

#corrected_individual_idString?

The corrected individual identifier that should be used in future ACHs.

Returns:

  • (String, nil)


851
# File 'lib/increase/models/ach_transfer.rb', line 851

required :corrected_individual_id, String, nil?: true

#corrected_routing_numberString?

The corrected routing number that should be used in future ACHs to this account.

Returns:

  • (String, nil)


857
# File 'lib/increase/models/ach_transfer.rb', line 857

required :corrected_routing_number, String, nil?: true

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the notification occurred.

Returns:

  • (Time)


864
# File 'lib/increase/models/ach_transfer.rb', line 864

required :created_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/ach_transfer.rb', line 952