Class: Increase::Models::ACHTransfer::Return
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ACHTransfer::Return
- Defined in:
- lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs
Overview
Defined Under Namespace
Modules: ReturnReasonCode
Instance Attribute Summary collapse
-
#addenda_information ⇒ String?
Additional free-form information included by the receiving bank in the return's addenda record.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the transfer was created.
-
#raw_return_reason_code ⇒ String
The three character ACH return code, in the range R01 to R85.
-
#return_reason_code ⇒ Symbol, Increase::Models::ACHTransfer::Return::ReturnReasonCode
Why the ACH Transfer was returned.
-
#trace_number ⇒ String
A 15 digit number that was generated by the bank that initiated the return.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this return.
-
#transfer_id ⇒ String
The identifier of the ACH Transfer associated with this return.
Instance Method Summary collapse
-
#initialize(addenda_information:, created_at:, raw_return_reason_code:, return_reason_code:, trace_number:, transaction_id:, transfer_id:) ⇒ Object
constructor
If your transfer is returned, this will contain details of the return.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(addenda_information:, created_at:, raw_return_reason_code:, return_reason_code:, trace_number:, transaction_id:, transfer_id:) ⇒ Object
If your transfer is returned, this will contain details of the return.
|
|
# File 'lib/increase/models/ach_transfer.rb', line 1159
|
Instance Attribute Details
#addenda_information ⇒ String?
Additional free-form information included by the receiving bank in the return's
addenda record. This is raw, uninterpreted text whose presence and format are
not guaranteed. For a file_record_edit_criteria (R17) return the receiving
bank may set this to QUESTIONABLE (optionally followed by more text) to
indicate it believes the transfer was initiated under questionable
circumstances.
1115 |
# File 'lib/increase/models/ach_transfer.rb', line 1115 required :addenda_information, String, nil?: true |
#created_at ⇒ Time
The ISO 8601 date and time at which the transfer was created.
1122 |
# File 'lib/increase/models/ach_transfer.rb', line 1122 required :created_at, Time |
#raw_return_reason_code ⇒ String
The three character ACH return code, in the range R01 to R85.
1128 |
# File 'lib/increase/models/ach_transfer.rb', line 1128 required :raw_return_reason_code, String |
#return_reason_code ⇒ Symbol, Increase::Models::ACHTransfer::Return::ReturnReasonCode
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
1135 |
# File 'lib/increase/models/ach_transfer.rb', line 1135 required :return_reason_code, enum: -> { Increase::ACHTransfer::Return::ReturnReasonCode } |
#trace_number ⇒ String
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
1144 |
# File 'lib/increase/models/ach_transfer.rb', line 1144 required :trace_number, String |
#transaction_id ⇒ String
The identifier of the Transaction associated with this return.
1150 |
# File 'lib/increase/models/ach_transfer.rb', line 1150 required :transaction_id, String |
#transfer_id ⇒ String
The identifier of the ACH Transfer associated with this return. This matches the
original Transaction's source.ach_transfer_intention.transfer_id.
1157 |
# File 'lib/increase/models/ach_transfer.rb', line 1157 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
780 |
# File 'sig/increase/models/ach_transfer.rbs', line 780
def to_hash: -> {
|