Class: Increase::Models::ACHTransfer::Return

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer.rb,
sig/increase/models/ach_transfer.rbs

Overview

See Also:

  • Increase::Models::ACHTransfer#return_

Defined Under Namespace

Modules: ReturnReasonCode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, raw_return_reason_code:, return_reason_code:, trace_number:, transaction_id:, transfer_id:) ⇒ Object

If your transfer is returned, this will contain details of the return.

Parameters:

  • created_at (Time)

    The ISO 8601 date and time at which the transfer was created.

  • raw_return_reason_code (String)

    The three character ACH return code, in the range R01 to R85.

  • return_reason_code (Symbol, Increase::Models::ACHTransfer::Return::ReturnReasonCode)

    Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.

  • trace_number (String)

    A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.

  • transaction_id (String)

    The identifier of the Transaction associated with this return.

  • transfer_id (String)

    The identifier of the ACH Transfer associated with this return. This matches the original Transaction's source.ach_transfer_intention.transfer_id.



# File 'lib/increase/models/ach_transfer.rb', line 1148

Instance Attribute Details

#created_atTime

The ISO 8601 date and time at which the transfer was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


1111
# File 'lib/increase/models/ach_transfer.rb', line 1111

required :created_at, Time

#raw_return_reason_codeString

The three character ACH return code, in the range R01 to R85.

Parameters:

  • value (String)

Returns:

  • (String)


1117
# File 'lib/increase/models/ach_transfer.rb', line 1117

required :raw_return_reason_code, String

#return_reason_codeSymbol, Increase::Models::ACHTransfer::Return::ReturnReasonCode

Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.

Parameters:

  • value (Increase::Models::ACHTransfer::Return::return_reason_code)

Returns:



1124
# File 'lib/increase/models/ach_transfer.rb', line 1124

required :return_reason_code, enum: -> { Increase::ACHTransfer::Return::ReturnReasonCode }

#trace_numberString

A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.

Parameters:

  • value (String)

Returns:

  • (String)


1133
# File 'lib/increase/models/ach_transfer.rb', line 1133

required :trace_number, String

#transaction_idString

The identifier of the Transaction associated with this return.

Parameters:

  • value (String)

Returns:

  • (String)


1139
# File 'lib/increase/models/ach_transfer.rb', line 1139

required :transaction_id, String

#transfer_idString

The identifier of the ACH Transfer associated with this return. This matches the original Transaction's source.ach_transfer_intention.transfer_id.

Parameters:

  • value (String)

Returns:

  • (String)


1146
# File 'lib/increase/models/ach_transfer.rb', line 1146

required :transfer_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


776
# File 'sig/increase/models/ach_transfer.rbs', line 776

def to_hash: -> {