Class: Increase::Models::ACHTransferCreateParams::Addenda::Freeform
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ACHTransferCreateParams::Addenda::Freeform
- Defined in:
- lib/increase/models/ach_transfer_create_params.rb,
sig/increase/models/ach_transfer_create_params.rbs
Overview
Defined Under Namespace
Classes: Entry
Instance Attribute Summary collapse
-
#entries ⇒ Array<Increase::Models::ACHTransferCreateParams::Addenda::Freeform::Entry>
Each entry represents an addendum sent with the transfer.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
215 |
# File 'sig/increase/models/ach_transfer_create_params.rbs', line 215
def initialize: (
|
Instance Attribute Details
#entries ⇒ Array<Increase::Models::ACHTransferCreateParams::Addenda::Freeform::Entry>
Each entry represents an addendum sent with the transfer. Sending more than one
addendum is only supported for transfers with standard_entry_class_code of
corporate_trade_exchange (CTX).
264 265 |
# File 'lib/increase/models/ach_transfer_create_params.rb', line 264 required :entries, -> { Increase::Internal::Type::ArrayOf[Increase::ACHTransferCreateParams::Addenda::Freeform::Entry] } |
Instance Method Details
#to_hash ⇒ {
219 |
# File 'sig/increase/models/ach_transfer_create_params.rbs', line 219
def to_hash: -> {
|