Class: Increase::Models::ACHTransferCreateParams::Addenda::Freeform

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/ach_transfer_create_params.rb

Overview

See Also:

Defined Under Namespace

Classes: Entry

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#entriesArray<Increase::Models::ACHTransferCreateParams::Addenda::Freeform::Entry>

Each entry represents an addendum sent with the transfer. In general, you should send at most one addendum–most ACH recipients cannot access beyond the first 80 characters sent. Please reach out to [support@increase.com](support@increase.com) to send 2 or more addenda to a recipient expecting a specific addendum format.



254
255
# File 'lib/increase/models/ach_transfer_create_params.rb', line 254

required :entries,
-> { Increase::Internal::Type::ArrayOf[Increase::ACHTransferCreateParams::Addenda::Freeform::Entry] }