Class: Increase::Models::Account
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Account
- Defined in:
- lib/increase/models/account.rb
Overview
Defined Under Namespace
Modules: Bank, Currency, Funding, Status, Type Classes: Loan
Instance Attribute Summary collapse
-
#account_revenue_rate ⇒ String?
The account revenue rate currently being earned on the account, as a string containing a decimal number.
-
#bank ⇒ Symbol, Increase::Models::Account::Bank
The bank the Account is with.
-
#closed_at ⇒ Time?
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Account was closed.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Account was created.
-
#currency ⇒ Symbol, Increase::Models::Account::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the Account currency.
-
#entity_id ⇒ String
The identifier for the Entity the Account belongs to.
-
#funding ⇒ Symbol, Increase::Models::Account::Funding
Whether the Account is funded by a loan or by deposits.
-
#id ⇒ String
The Account identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#informational_entity_id ⇒ String?
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
#interest_rate ⇒ String
The interest rate currently being earned on the account, as a string containing a decimal number.
-
#loan ⇒ Increase::Models::Account::Loan?
The Account’s loan-related information, if the Account is a loan account.
-
#name ⇒ String
The name you choose for the Account.
-
#program_id ⇒ String
The identifier of the Program determining the compliance and commercial terms of this Account.
-
#status ⇒ Symbol, Increase::Models::Account::Status
The status of the Account.
-
#type ⇒ Symbol, Increase::Models::Account::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, account_revenue_rate:, bank:, closed_at:, created_at:, currency:, entity_id:, funding:, idempotency_key:, informational_entity_id:, interest_rate:, loan:, name:, program_id:, status:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Account for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_revenue_rate:, bank:, closed_at:, created_at:, currency:, entity_id:, funding:, idempotency_key:, informational_entity_id:, interest_rate:, loan:, name:, program_id:, status:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Account for more details.
Accounts are your bank accounts with Increase. They store money, receive transfers, and send payments. They earn interest and have depository insurance.
|
|
# File 'lib/increase/models/account.rb', line 116
|
Instance Attribute Details
#account_revenue_rate ⇒ String?
The account revenue rate currently being earned on the account, as a string containing a decimal number. For example, a 1% account revenue rate would be represented as “0.01”. Account revenue is a type of non-interest income accrued on the account.
20 |
# File 'lib/increase/models/account.rb', line 20 required :account_revenue_rate, String, nil?: true |
#bank ⇒ Symbol, Increase::Models::Account::Bank
The bank the Account is with.
26 |
# File 'lib/increase/models/account.rb', line 26 required :bank, enum: -> { Increase::Account::Bank } |
#closed_at ⇒ Time?
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Account was closed.
33 |
# File 'lib/increase/models/account.rb', line 33 required :closed_at, Time, nil?: true |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Account was created.
40 |
# File 'lib/increase/models/account.rb', line 40 required :created_at, Time |
#currency ⇒ Symbol, Increase::Models::Account::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the Account currency.
47 |
# File 'lib/increase/models/account.rb', line 47 required :currency, enum: -> { Increase::Account::Currency } |
#entity_id ⇒ String
The identifier for the Entity the Account belongs to.
53 |
# File 'lib/increase/models/account.rb', line 53 required :entity_id, String |
#funding ⇒ Symbol, Increase::Models::Account::Funding
Whether the Account is funded by a loan or by deposits.
59 |
# File 'lib/increase/models/account.rb', line 59 required :funding, enum: -> { Increase::Account::Funding } |
#id ⇒ String
The Account identifier.
11 |
# File 'lib/increase/models/account.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
67 |
# File 'lib/increase/models/account.rb', line 67 required :idempotency_key, String, nil?: true |
#informational_entity_id ⇒ String?
The identifier of an Entity that, while not owning the Account, is associated with its activity.
74 |
# File 'lib/increase/models/account.rb', line 74 required :informational_entity_id, String, nil?: true |
#interest_rate ⇒ String
The interest rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as “0.01”.
82 |
# File 'lib/increase/models/account.rb', line 82 required :interest_rate, String |
#loan ⇒ Increase::Models::Account::Loan?
The Account’s loan-related information, if the Account is a loan account.
88 |
# File 'lib/increase/models/account.rb', line 88 required :loan, -> { Increase::Account::Loan }, nil?: true |
#name ⇒ String
The name you choose for the Account.
94 |
# File 'lib/increase/models/account.rb', line 94 required :name, String |
#program_id ⇒ String
The identifier of the Program determining the compliance and commercial terms of this Account.
101 |
# File 'lib/increase/models/account.rb', line 101 required :program_id, String |
#status ⇒ Symbol, Increase::Models::Account::Status
The status of the Account.
107 |
# File 'lib/increase/models/account.rb', line 107 required :status, enum: -> { Increase::Account::Status } |
#type ⇒ Symbol, Increase::Models::Account::Type
A constant representing the object’s type. For this resource it will always be ‘account`.
114 |
# File 'lib/increase/models/account.rb', line 114 required :type, enum: -> { Increase::Account::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/account.rb', line 170
|