Class: Increase::Models::Account::Loan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account.rb

Overview

See Also:

Defined Under Namespace

Modules: StatementPaymentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_limit:, grace_period_days:, maturity_date:, statement_day_of_month:, statement_payment_type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Account::Loan for more details.

The Account’s loan-related information, if the Account is a loan account.

Parameters:

  • credit_limit (Integer)

    The maximum amount of money that can be borrowed on the Account.

  • grace_period_days (Integer)

    The number of days after the statement date that the Account can be past due bef

  • maturity_date (Date, nil)

    The date on which the loan matures.

  • statement_day_of_month (Integer)

    The day of the month on which the loan statement is generated.

  • statement_payment_type (Symbol, Increase::Models::Account::Loan::StatementPaymentType)

    The type of payment for the loan.



# File 'lib/increase/models/account.rb', line 237

Instance Attribute Details

#credit_limitInteger

The maximum amount of money that can be borrowed on the Account.

Returns:

  • (Integer)


210
# File 'lib/increase/models/account.rb', line 210

required :credit_limit, Integer

#grace_period_daysInteger

The number of days after the statement date that the Account can be past due before being considered delinquent.

Returns:

  • (Integer)


217
# File 'lib/increase/models/account.rb', line 217

required :grace_period_days, Integer

#maturity_dateDate?

The date on which the loan matures.

Returns:

  • (Date, nil)


223
# File 'lib/increase/models/account.rb', line 223

required :maturity_date, Date, nil?: true

#statement_day_of_monthInteger

The day of the month on which the loan statement is generated.

Returns:

  • (Integer)


229
# File 'lib/increase/models/account.rb', line 229

required :statement_day_of_month, Integer

#statement_payment_typeSymbol, Increase::Models::Account::Loan::StatementPaymentType

The type of payment for the loan.



235
# File 'lib/increase/models/account.rb', line 235

required :statement_payment_type, enum: -> { Increase::Account::Loan::StatementPaymentType }