Class: Increase::Models::AccountCreateParams::Loan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account_create_params.rb

Defined Under Namespace

Modules: StatementPaymentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(credit_limit:, grace_period_days:, statement_day_of_month:, statement_payment_type:, maturity_date: nil) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::AccountCreateParams::Loan for more details.

The loan details for the account.

Parameters:

  • credit_limit (Integer)

    The maximum amount of money that can be drawn from the Account.

  • grace_period_days (Integer)

    The number of days after the statement date that the Account can be past due bef

  • statement_day_of_month (Integer)

    The day of the month on which the loan statement is generated.

  • statement_payment_type (Symbol, Increase::Models::AccountCreateParams::Loan::StatementPaymentType)

    The type of statement payment for the account.

  • maturity_date (Date) (defaults to: nil)

    The date on which the loan matures.



# File 'lib/increase/models/account_create_params.rb', line 112

Instance Attribute Details

#credit_limitInteger

The maximum amount of money that can be drawn from the Account.

Returns:

  • (Integer)


85
# File 'lib/increase/models/account_create_params.rb', line 85

required :credit_limit, Integer

#grace_period_daysInteger

The number of days after the statement date that the Account can be past due before being considered delinquent.

Returns:

  • (Integer)


92
# File 'lib/increase/models/account_create_params.rb', line 92

required :grace_period_days, Integer

#maturity_dateDate?

The date on which the loan matures.

Returns:

  • (Date, nil)


110
# File 'lib/increase/models/account_create_params.rb', line 110

optional :maturity_date, Date

#statement_day_of_monthInteger

The day of the month on which the loan statement is generated.

Returns:

  • (Integer)


98
# File 'lib/increase/models/account_create_params.rb', line 98

required :statement_day_of_month, Integer

#statement_payment_typeSymbol, Increase::Models::AccountCreateParams::Loan::StatementPaymentType

The type of statement payment for the account.



104
# File 'lib/increase/models/account_create_params.rb', line 104

required :statement_payment_type, enum: -> { Increase::AccountCreateParams::Loan::StatementPaymentType }