Module: Increase::Models::AccountCreateParams::Loan::StatementPaymentType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/account_create_params.rb
Overview
The type of statement payment for the account.
Constant Summary collapse
- BALANCE =
The borrower must pay the full balance of the loan at the end of the statement period.
:balance- INTEREST_UNTIL_MATURITY =
The borrower must pay the accrued interest at the end of the statement period.
:interest_until_maturity
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/account_create_params.rb', line 140
|