Class: Increase::Models::AccountNumberUpdateParams::InboundACH
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::AccountNumberUpdateParams::InboundACH
- Defined in:
- lib/increase/models/account_number_update_params.rb,
sig/increase/models/account_number_update_params.rbs
Defined Under Namespace
Modules: DebitStatus
Instance Attribute Summary collapse
-
#debit_status ⇒ Symbol, ...
Whether ACH debits are allowed against this Account Number.
Instance Method Summary collapse
-
#initialize(debit_status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InboundACH for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(debit_status: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::AccountNumberUpdateParams::InboundACH for more details.
Options related to how this Account Number handles inbound ACH transfers.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/increase/models/account_number_update_params.rb', line 57 class InboundACH < Increase::Internal::Type::BaseModel # @!attribute debit_status # Whether ACH debits are allowed against this Account Number. Note that ACH debits # will be declined if this is `allowed` but the Account Number is not active. # # @return [Symbol, Increase::Models::AccountNumberUpdateParams::InboundACH::DebitStatus, nil] optional :debit_status, enum: -> { Increase::AccountNumberUpdateParams::InboundACH::DebitStatus } # @!method initialize(debit_status: nil) # Some parameter documentations has been truncated, see # {Increase::Models::AccountNumberUpdateParams::InboundACH} for more details. # # Options related to how this Account Number handles inbound ACH transfers. # # @param debit_status [Symbol, Increase::Models::AccountNumberUpdateParams::InboundACH::DebitStatus] Whether ACH debits are allowed against this Account Number. Note that ACH debits # Whether ACH debits are allowed against this Account Number. Note that ACH debits # will be declined if this is `allowed` but the Account Number is not active. # # @see Increase::Models::AccountNumberUpdateParams::InboundACH#debit_status module DebitStatus extend Increase::Internal::Type::Enum # ACH Debits are allowed. ALLOWED = :allowed # ACH Debits are blocked. BLOCKED = :blocked # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#debit_status ⇒ Symbol, ...
Whether ACH debits are allowed against this Account Number. Note that ACH debits
will be declined if this is allowed but the Account Number is not active.
63 |
# File 'lib/increase/models/account_number_update_params.rb', line 63 optional :debit_status, enum: -> { Increase::AccountNumberUpdateParams::InboundACH::DebitStatus } |
Instance Method Details
#to_hash ⇒ {
75 |
# File 'sig/increase/models/account_number_update_params.rbs', line 75
def to_hash: -> {
|