Class: Increase::Models::AccountStatement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/account_statement.rb

Overview

Defined Under Namespace

Modules: Type Classes: Loan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(due_at:, due_balance:, past_due_balance:) ⇒ Object

Some parameter documentations has been truncated, see Loan for more details.

The loan balances.

Parameters:

  • due_at (Time, nil)

    The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the loan pa

  • due_balance (Integer)

    The total amount due on the loan.

  • past_due_balance (Integer)

    The amount past due on the loan.



# File 'lib/increase/models/account_statement.rb', line 71

Instance Attribute Details

#account_idString

The identifier for the Account this Account Statement belongs to.

Returns:

  • (String)


17
# File 'lib/increase/models/account_statement.rb', line 17

required :account_id, String

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Account Statement was created.

Returns:

  • (Time)


24
# File 'lib/increase/models/account_statement.rb', line 24

required :created_at, Time

#ending_balanceInteger

The Account’s balance at the end of its statement period.

Returns:

  • (Integer)


30
# File 'lib/increase/models/account_statement.rb', line 30

required :ending_balance, Integer

#file_idString

The identifier of the File containing a PDF of the statement.

Returns:

  • (String)


36
# File 'lib/increase/models/account_statement.rb', line 36

required :file_id, String

#idString

The Account Statement identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/account_statement.rb', line 11

required :id, String

#loanIncrease::Models::AccountStatement::Loan?

The loan balances.



42
# File 'lib/increase/models/account_statement.rb', line 42

required :loan, -> { Increase::AccountStatement::Loan }, nil?: true

#starting_balanceInteger

The Account’s balance at the start of its statement period.

Returns:

  • (Integer)


48
# File 'lib/increase/models/account_statement.rb', line 48

required :starting_balance, Integer

#statement_period_endTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time representing the end of the period the Account Statement covers.

Returns:

  • (Time)


55
# File 'lib/increase/models/account_statement.rb', line 55

required :statement_period_end, Time

#statement_period_startTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time representing the start of the period the Account Statement covers.

Returns:

  • (Time)


62
# File 'lib/increase/models/account_statement.rb', line 62

required :statement_period_start, Time

#typeSymbol, Increase::Models::AccountStatement::Type

A constant representing the object’s type. For this resource it will always be ‘account_statement`.



69
# File 'lib/increase/models/account_statement.rb', line 69

required :type, enum: -> { Increase::AccountStatement::Type }