Class: Increase::Models::BalanceLookup::Loan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/balance_lookup.rb,
sig/increase/models/balance_lookup.rbs

Overview

See Also:

  • Increase::Models::BalanceLookup#loan

Defined Under Namespace

Classes: Receivables

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(due_at:, due_balance:, due_fees:, due_interest:, due_principal:, not_due_fees:, not_due_interest:, not_due_principal:, past_due_balance:, receivables:) ⇒ Object

The loan balances for the Account.

Parameters:

  • due_at (Time, nil)

    The ISO 8601 time at which the loan payment is due.

  • due_balance (Integer)

    The total amount due on the loan.

  • due_fees (Integer, nil)

    The fees on the loan that are due and unpaid.

  • due_interest (Integer, nil)

    The interest on the loan that is due and unpaid.

  • due_principal (Integer, nil)

    The principal on the loan that is due and unpaid.

  • not_due_fees (Integer, nil)

    The fees on the loan that are not yet due.

  • not_due_interest (Integer, nil)

    The interest on the loan that is not yet due.

  • not_due_principal (Integer, nil)

    The principal on the loan that is not yet due.

  • past_due_balance (Integer)

    The amount past due on the loan.

  • receivables (Increase::Models::BalanceLookup::Loan::Receivables, nil)

    The receivables balances for the loan.



# File 'lib/increase/models/balance_lookup.rb', line 123

Instance Attribute Details

#due_atTime?

The ISO 8601 time at which the loan payment is due.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


67
# File 'lib/increase/models/balance_lookup.rb', line 67

required :due_at, Time, nil?: true

#due_balanceInteger

The total amount due on the loan.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


73
# File 'lib/increase/models/balance_lookup.rb', line 73

required :due_balance, Integer

#due_feesInteger?

The fees on the loan that are due and unpaid.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


79
# File 'lib/increase/models/balance_lookup.rb', line 79

required :due_fees, Integer, nil?: true

#due_interestInteger?

The interest on the loan that is due and unpaid.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


85
# File 'lib/increase/models/balance_lookup.rb', line 85

required :due_interest, Integer, nil?: true

#due_principalInteger?

The principal on the loan that is due and unpaid.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


91
# File 'lib/increase/models/balance_lookup.rb', line 91

required :due_principal, Integer, nil?: true

#not_due_feesInteger?

The fees on the loan that are not yet due.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


97
# File 'lib/increase/models/balance_lookup.rb', line 97

required :not_due_fees, Integer, nil?: true

#not_due_interestInteger?

The interest on the loan that is not yet due.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


103
# File 'lib/increase/models/balance_lookup.rb', line 103

required :not_due_interest, Integer, nil?: true

#not_due_principalInteger?

The principal on the loan that is not yet due.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


109
# File 'lib/increase/models/balance_lookup.rb', line 109

required :not_due_principal, Integer, nil?: true

#past_due_balanceInteger

The amount past due on the loan.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


115
# File 'lib/increase/models/balance_lookup.rb', line 115

required :past_due_balance, Integer

#receivablesIncrease::Models::BalanceLookup::Loan::Receivables?

The receivables balances for the loan.

Parameters:

  • value (Increase::BalanceLookup::Loan::Receivables, nil)

Returns:



121
# File 'lib/increase/models/balance_lookup.rb', line 121

required :receivables, -> { Increase::BalanceLookup::Loan::Receivables }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


87
# File 'sig/increase/models/balance_lookup.rbs', line 87

def to_hash: -> {