Class: Increase::Models::BalanceLookup::Loan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BalanceLookup::Loan
- Defined in:
- lib/increase/models/balance_lookup.rb,
sig/increase/models/balance_lookup.rbs
Overview
Instance Attribute Summary collapse
-
#due_fees ⇒ Integer?
The fees on the loan that are due and unpaid.
-
#due_interest ⇒ Integer?
The interest on the loan that is due and unpaid.
-
#due_principal ⇒ Integer?
The principal on the loan that is due and unpaid.
-
#not_due_fees ⇒ Integer?
The fees on the loan that are not yet due.
-
#not_due_interest ⇒ Integer?
The interest on the loan that is not yet due.
-
#not_due_principal ⇒ Integer?
The principal on the loan that is not yet due.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
62 |
# File 'sig/increase/models/balance_lookup.rbs', line 62 def initialize: ( |
Instance Attribute Details
#due_fees ⇒ Integer?
The fees on the loan that are due and unpaid.
66 |
# File 'lib/increase/models/balance_lookup.rb', line 66 required :due_fees, Integer, nil?: true |
#due_interest ⇒ Integer?
The interest on the loan that is due and unpaid.
72 |
# File 'lib/increase/models/balance_lookup.rb', line 72 required :due_interest, Integer, nil?: true |
#due_principal ⇒ Integer?
The principal on the loan that is due and unpaid.
78 |
# File 'lib/increase/models/balance_lookup.rb', line 78 required :due_principal, Integer, nil?: true |
#not_due_fees ⇒ Integer?
The fees on the loan that are not yet due.
84 |
# File 'lib/increase/models/balance_lookup.rb', line 84 required :not_due_fees, Integer, nil?: true |
#not_due_interest ⇒ Integer?
The interest on the loan that is not yet due.
90 |
# File 'lib/increase/models/balance_lookup.rb', line 90 required :not_due_interest, Integer, nil?: true |
#not_due_principal ⇒ Integer?
The principal on the loan that is not yet due.
96 |
# File 'lib/increase/models/balance_lookup.rb', line 96 required :not_due_principal, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/increase/models/balance_lookup.rbs', line 71 def to_hash: -> { |