Class: Increase::Models::BalanceLookup::Loan::Receivables
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BalanceLookup::Loan::Receivables
- Defined in:
- lib/increase/models/balance_lookup.rb
Overview
Instance Attribute Summary collapse
-
#purchasable_balance ⇒ Integer
The balance of seasoned receivables available to be purchased.
-
#purchased_balance ⇒ Integer
The balance of receivables that have been purchased.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#purchasable_balance ⇒ Integer
The balance of seasoned receivables available to be purchased.
104 |
# File 'lib/increase/models/balance_lookup.rb', line 104 required :purchasable_balance, Integer |
#purchased_balance ⇒ Integer
The balance of receivables that have been purchased.
110 |
# File 'lib/increase/models/balance_lookup.rb', line 110 required :purchased_balance, Integer |