Class: Increase::Models::BeneficialOwnerCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/beneficial_owner_create_params.rb
Overview
Defined Under Namespace
Modules: Prong Classes: Individual
Instance Attribute Summary collapse
-
#company_title ⇒ String?
This person’s role or title within the entity.
-
#entity_id ⇒ String
The identifier of the Entity to associate with the new Beneficial Owner.
-
#individual ⇒ Increase::Models::BeneficialOwnerCreateParams::Individual
Personal details for the beneficial owner.
-
#prongs ⇒ Array<Symbol, Increase::Models::BeneficialOwnerCreateParams::Prong>
Why this person is considered a beneficial owner of the entity.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(country:, expiration_date:, file_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Individual::Identification::Passport for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, expiration_date:, file_id:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::BeneficialOwnerCreateParams::Individual::Identification::Passport for more details.
Information about the passport used for identification. Required if ‘method` is equal to `passport`.
|
|
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 356
|
Instance Attribute Details
#company_title ⇒ String?
This person’s role or title within the entity.
35 |
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 35 optional :company_title, String |
#entity_id ⇒ String
The identifier of the Entity to associate with the new Beneficial Owner.
14 |
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 14 required :entity_id, String |
#individual ⇒ Increase::Models::BeneficialOwnerCreateParams::Individual
Personal details for the beneficial owner.
20 |
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 20 required :individual, -> { Increase::BeneficialOwnerCreateParams::Individual } |
#prongs ⇒ Array<Symbol, Increase::Models::BeneficialOwnerCreateParams::Prong>
Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both.
28 29 |
# File 'lib/increase/models/beneficial_owner_create_params.rb', line 28 required :prongs, -> { Increase::Internal::Type::ArrayOf[enum: Increase::BeneficialOwnerCreateParams::Prong] } |