Class: Increase::Models::BeneficialOwnerUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/beneficial_owner_update_params.rb

Overview

Defined Under Namespace

Classes: Address, Identification

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The individual’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.

Parameters:

  • city (String)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address. This is usually the street number and street.

  • line2 (String) (defaults to: nil)

    The second line of the address. This might be the floor or room number.

  • state (String) (defaults to: nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String) (defaults to: nil)

    The ZIP or postal code of the address. Required in certain countries.



# File 'lib/increase/models/beneficial_owner_update_params.rb', line 98

Instance Attribute Details

#addressIncrease::Models::BeneficialOwnerUpdateParams::Address?

The individual’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.



21
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 21

optional :address, -> { Increase::BeneficialOwnerUpdateParams::Address }

#confirmed_no_us_tax_idBoolean?

The identification method for an individual can only be a passport, driver’s license, or other document if you’ve confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).

Returns:

  • (Boolean, nil)


30
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 30

optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean

#entity_beneficial_owner_idString

The identifier of the Beneficial Owner to update.

Returns:

  • (String)


14
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 14

required :entity_beneficial_owner_id, String

#identificationIncrease::Models::BeneficialOwnerUpdateParams::Identification?

A means of verifying the person’s identity.



36
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 36

optional :identification, -> { Increase::BeneficialOwnerUpdateParams::Identification }

#nameString?

The individual’s legal name.

Returns:

  • (String, nil)


42
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 42

optional :name, String