Class: Increase::Models::BeneficialOwnerUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/beneficial_owner_update_params.rb
Overview
Defined Under Namespace
Classes: Address, Identification
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::BeneficialOwnerUpdateParams::Address?
The individual’s physical address.
-
#confirmed_no_us_tax_id ⇒ Boolean?
The identification method for an individual can only be a passport, driver’s license, or other document if you’ve confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
#entity_beneficial_owner_id ⇒ String
The identifier of the Beneficial Owner to update.
-
#identification ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification?
A means of verifying the person’s identity.
-
#name ⇒ String?
The individual’s legal name.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The individual’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
|
|
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 98
|
Instance Attribute Details
#address ⇒ Increase::Models::BeneficialOwnerUpdateParams::Address?
The individual’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
21 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 21 optional :address, -> { Increase::BeneficialOwnerUpdateParams::Address } |
#confirmed_no_us_tax_id ⇒ Boolean?
The identification method for an individual can only be a passport, driver’s license, or other document if you’ve confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
30 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 30 optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean |
#entity_beneficial_owner_id ⇒ String
The identifier of the Beneficial Owner to update.
14 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 14 required :entity_beneficial_owner_id, String |
#identification ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification?
A means of verifying the person’s identity.
36 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 36 optional :identification, -> { Increase::BeneficialOwnerUpdateParams::Identification } |
#name ⇒ String?
The individual’s legal name.
42 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 42 optional :name, String |