Class: Increase::Models::BeneficialOwnerUpdateParams::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/beneficial_owner_update_params.rb,
sig/increase/models/beneficial_owner_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(entity_beneficial_owner_id:, address: nil, confirmed_no_us_tax_id: nil, identification: nil, name: nil, prongs: nil, request_options: {}) ⇒ Object

Parameters:

  • entity_beneficial_owner_id (String)

    The identifier of the Beneficial Owner to update.

  • address (Increase::Models::BeneficialOwnerUpdateParams::Address) (defaults to: nil)

    The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.

  • confirmed_no_us_tax_id (Boolean) (defaults to: nil)

    The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).

  • identification (Increase::Models::BeneficialOwnerUpdateParams::Identification) (defaults to: nil)

    A means of verifying the person's identity.

  • name (String) (defaults to: nil)

    The individual's legal name.

  • prongs (Array<Symbol, Increase::Models::BeneficialOwnerUpdateParams::Prong>) (defaults to: nil)

    Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both. Providing this replaces the beneficial owner's current prongs.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 80

class Address < Increase::Internal::Type::BaseModel
  # @!attribute city
  #   The city, district, town, or village of the address.
  #
  #   @return [String]
  required :city, String

  # @!attribute country
  #   The two-letter ISO 3166-1 alpha-2 code for the country of the address.
  #
  #   @return [String]
  required :country, String

  # @!attribute line1
  #   The first line of the address. This is usually the street number and street.
  #
  #   @return [String]
  required :line1, String

  # @!attribute line2
  #   The second line of the address. This might be the floor or room number.
  #
  #   @return [String, nil]
  optional :line2, String

  # @!attribute state
  #   The two-letter United States Postal Service (USPS) abbreviation for the US
  #   state, province, or region of the address. Required in certain countries.
  #
  #   @return [String, nil]
  optional :state, String

  # @!attribute zip
  #   The ZIP or postal code of the address. Required in certain countries.
  #
  #   @return [String, nil]
  optional :zip, String

  # @!method initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil)
  #   The individual's physical address. Mail receiving locations like PO Boxes and
  #   PMB's are disallowed.
  #
  #   @param city [String] The city, district, town, or village of the address.
  #
  #   @param country [String] The two-letter ISO 3166-1 alpha-2 code for the country of the address.
  #
  #   @param line1 [String] The first line of the address. This is usually the street number and street.
  #
  #   @param line2 [String] The second line of the address. This might be the floor or room number.
  #
  #   @param state [String]
  #     The two-letter United States Postal Service (USPS) abbreviation for the US
  #     state, province, or region of the address. Required in certain countries.
  #
  #   @param zip [String] The ZIP or postal code of the address. Required in certain countries.
end

Instance Attribute Details

#cityString

The city, district, town, or village of the address.

Parameters:

  • value (String)

Returns:

  • (String)


85
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 85

required :city, String

#countryString

The two-letter ISO 3166-1 alpha-2 code for the country of the address.

Parameters:

  • value (String)

Returns:

  • (String)


91
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 91

required :country, String

#line1String

The first line of the address. This is usually the street number and street.

Parameters:

  • value (String)

Returns:

  • (String)


97
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 97

required :line1, String

#line2String?

The second line of the address. This might be the floor or room number.

Parameters:

  • (String)

Returns:

  • (String, nil)


103
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 103

optional :line2, String

#stateString?

The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. Required in certain countries.

Parameters:

  • (String)

Returns:

  • (String, nil)


110
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 110

optional :state, String

#zipString?

The ZIP or postal code of the address. Required in certain countries.

Parameters:

  • (String)

Returns:

  • (String, nil)


116
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 116

optional :zip, String

Instance Method Details

#to_hash{

Returns:

  • ({)


104
# File 'sig/increase/models/beneficial_owner_update_params.rbs', line 104

def to_hash: -> {