Class: Increase::Models::BeneficialOwnerUpdateParams::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerUpdateParams::Address
- Defined in:
- lib/increase/models/beneficial_owner_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
-
#zip ⇒ String?
The ZIP or postal code of the address.
Instance Method Summary collapse
-
#initialize(entity_beneficial_owner_id:, address: nil, confirmed_no_us_tax_id: nil, identification: nil, name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Increase::Models::BeneficialOwnerUpdateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(entity_beneficial_owner_id:, address: nil, confirmed_no_us_tax_id: nil, identification: nil, name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::BeneficialOwnerUpdateParams for more details.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 60 class Address < Increase::Internal::Type::BaseModel # @!attribute city # The city, district, town, or village of the address. # # @return [String] required :city, String # @!attribute country # The two-letter ISO 3166-1 alpha-2 code for the country of the address. # # @return [String] required :country, String # @!attribute line1 # The first line of the address. This is usually the street number and street. # # @return [String] required :line1, String # @!attribute line2 # The second line of the address. This might be the floor or room number. # # @return [String, nil] optional :line2, String # @!attribute state # The two-letter United States Postal Service (USPS) abbreviation for the US # state, province, or region of the address. Required in certain countries. # # @return [String, nil] optional :state, String # @!attribute zip # The ZIP or postal code of the address. Required in certain countries. # # @return [String, nil] optional :zip, String # @!method initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) # Some parameter documentations has been truncated, see # {Increase::Models::BeneficialOwnerUpdateParams::Address} for more details. # # The individual's physical address. Mail receiving locations like PO Boxes and # PMB's are disallowed. # # @param city [String] The city, district, town, or village of the address. # # @param country [String] The two-letter ISO 3166-1 alpha-2 code for the country of the address. # # @param line1 [String] The first line of the address. This is usually the street number and street. # # @param line2 [String] The second line of the address. This might be the floor or room number. # # @param state [String] The two-letter United States Postal Service (USPS) abbreviation for the US state # # @param zip [String] The ZIP or postal code of the address. Required in certain countries. end |
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
65 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 65 required :city, String |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
71 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 71 required :country, String |
#line1 ⇒ String
The first line of the address. This is usually the street number and street.
77 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 77 required :line1, String |
#line2 ⇒ String?
The second line of the address. This might be the floor or room number.
83 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 83 optional :line2, String |
#state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. Required in certain countries.
90 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 90 optional :state, String |
#zip ⇒ String?
The ZIP or postal code of the address. Required in certain countries.
96 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 96 optional :zip, String |