Class: Increase::Models::BeneficialOwnerUpdateParams::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerUpdateParams::Identification
- Defined in:
- lib/increase/models/beneficial_owner_update_params.rb,
sig/increase/models/beneficial_owner_update_params.rbs
Defined Under Namespace
Modules: Method Classes: DriversLicense, Other, Passport
Instance Attribute Summary collapse
-
#drivers_license ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::DriversLicense?
Information about the United States driver's license used for identification.
-
#method_ ⇒ Symbol, Increase::Models::BeneficialOwnerUpdateParams::Identification::Method
A method that can be used to verify the individual's identity.
-
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number.
-
#other ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Other?
Information about the identification document provided.
-
#passport ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport?
Information about the passport used for identification.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
constructor
Information about the identification document provided.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
Information about the identification document provided. Required if method is
equal to other.
|
|
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 180
|
Instance Attribute Details
#drivers_license ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::DriversLicense?
Information about the United States driver's license used for identification.
Required if method is equal to drivers_license.
164 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 164 optional :drivers_license, -> { Increase::BeneficialOwnerUpdateParams::Identification::DriversLicense } |
#method_ ⇒ Symbol, Increase::Models::BeneficialOwnerUpdateParams::Identification::Method
A method that can be used to verify the individual's identity.
145 146 147 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 145 required :method_, enum: -> { Increase::BeneficialOwnerUpdateParams::Identification::Method }, api_name: :method |
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.
157 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 157 required :number, String |
#other ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Other?
Information about the identification document provided. Required if method is
equal to other.
171 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 171 optional :other, -> { Increase::BeneficialOwnerUpdateParams::Identification::Other } |
#passport ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport?
Information about the passport used for identification. Required if method is
equal to passport.
178 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 178 optional :passport, -> { Increase::BeneficialOwnerUpdateParams::Identification::Passport } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 226
|
Instance Method Details
#to_hash ⇒ {
156 |
# File 'sig/increase/models/beneficial_owner_update_params.rbs', line 156
def to_hash: -> {
|