Class: Increase::Models::BeneficialOwnerUpdateParams::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::BeneficialOwnerUpdateParams::Identification
- Defined in:
- lib/increase/models/beneficial_owner_update_params.rb,
sig/increase/models/beneficial_owner_update_params.rbs
Defined Under Namespace
Modules: Method Classes: DriversLicense, Other, Passport
Instance Attribute Summary collapse
-
#drivers_license ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::DriversLicense?
Information about the United States driver's license used for identification.
-
#method_ ⇒ Symbol, Increase::Models::BeneficialOwnerUpdateParams::Identification::Method
A method that can be used to verify the individual's identity.
-
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number.
-
#other ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Other?
Information about the identification document provided.
-
#passport ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport?
Information about the passport used for identification.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Other for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
Some parameter documentations has been truncated, see Other for more details.
Information about the identification document provided. Required if method is
equal to other.
|
|
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 170
|
Instance Attribute Details
#drivers_license ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::DriversLicense?
Information about the United States driver's license used for identification.
Required if method is equal to drivers_license.
154 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 154 optional :drivers_license, -> { Increase::BeneficialOwnerUpdateParams::Identification::DriversLicense } |
#method_ ⇒ Symbol, Increase::Models::BeneficialOwnerUpdateParams::Identification::Method
A method that can be used to verify the individual's identity.
135 136 137 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 135 required :method_, enum: -> { Increase::BeneficialOwnerUpdateParams::Identification::Method }, api_name: :method |
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.
147 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 147 required :number, String |
#other ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Other?
Information about the identification document provided. Required if method is
equal to other.
161 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 161 optional :other, -> { Increase::BeneficialOwnerUpdateParams::Identification::Other } |
#passport ⇒ Increase::Models::BeneficialOwnerUpdateParams::Identification::Passport?
Information about the passport used for identification. Required if method is
equal to passport.
168 |
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 168 optional :passport, -> { Increase::BeneficialOwnerUpdateParams::Identification::Passport } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/beneficial_owner_update_params.rb', line 208
|
Instance Method Details
#to_hash ⇒ {
154 |
# File 'sig/increase/models/beneficial_owner_update_params.rbs', line 154
def to_hash: -> {
|