Class: Increase::Models::Card::AuthorizationControls
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Card::AuthorizationControls
- Defined in:
- lib/increase/models/card.rb
Overview
Defined Under Namespace
Classes: MerchantAcceptorIdentifier, MerchantCategoryCode, MerchantCountry, Usage
Instance Attribute Summary collapse
-
#merchant_acceptor_identifier ⇒ Increase::Models::Card::AuthorizationControls::MerchantAcceptorIdentifier?
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
#merchant_category_code ⇒ Increase::Models::Card::AuthorizationControls::MerchantCategoryCode?
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
#merchant_country ⇒ Increase::Models::Card::AuthorizationControls::MerchantCountry?
Restricts which merchant countries are allowed or blocked for authorizations on this card.
-
#usage ⇒ Increase::Models::Card::AuthorizationControls::Usage?
Controls how many times this card can be used.
Instance Method Summary collapse
- #initialize(country:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:) ⇒ Object
|
|
# File 'lib/increase/models/card.rb', line 168
|
Instance Attribute Details
#merchant_acceptor_identifier ⇒ Increase::Models::Card::AuthorizationControls::MerchantAcceptorIdentifier?
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
142 143 144 |
# File 'lib/increase/models/card.rb', line 142 required :merchant_acceptor_identifier, -> { Increase::Card::AuthorizationControls::MerchantAcceptorIdentifier }, nil?: true |
#merchant_category_code ⇒ Increase::Models::Card::AuthorizationControls::MerchantCategoryCode?
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
151 152 153 |
# File 'lib/increase/models/card.rb', line 151 required :merchant_category_code, -> { Increase::Card::AuthorizationControls::MerchantCategoryCode }, nil?: true |
#merchant_country ⇒ Increase::Models::Card::AuthorizationControls::MerchantCountry?
Restricts which merchant countries are allowed or blocked for authorizations on this card.
160 |
# File 'lib/increase/models/card.rb', line 160 required :merchant_country, -> { Increase::Card::AuthorizationControls::MerchantCountry }, nil?: true |
#usage ⇒ Increase::Models::Card::AuthorizationControls::Usage?
Controls how many times this card can be used.
166 |
# File 'lib/increase/models/card.rb', line 166 required :usage, -> { Increase::Card::AuthorizationControls::Usage }, nil?: true |