Class: Increase::Models::Card::AuthorizationControls::MerchantCategoryCode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Card::AuthorizationControls::MerchantCategoryCode
- Defined in:
- lib/increase/models/card.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#allowed ⇒ Array<Increase::Models::Card::AuthorizationControls::MerchantCategoryCode::Allowed>?
The Merchant Category Codes that are allowed for authorizations on this card.
-
#blocked ⇒ Array<Increase::Models::Card::AuthorizationControls::MerchantCategoryCode::Blocked>?
The Merchant Category Codes that are blocked for authorizations on this card.
Instance Method Summary collapse
- #initialize(code:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:) ⇒ Object
|
|
# File 'lib/increase/models/card.rb', line 272
|
Instance Attribute Details
#allowed ⇒ Array<Increase::Models::Card::AuthorizationControls::MerchantCategoryCode::Allowed>?
The Merchant Category Codes that are allowed for authorizations on this card.
241 242 243 244 245 |
# File 'lib/increase/models/card.rb', line 241 required :allowed, -> { Increase::Internal::Type::ArrayOf[Increase::Card::AuthorizationControls::MerchantCategoryCode::Allowed] }, nil?: true |
#blocked ⇒ Array<Increase::Models::Card::AuthorizationControls::MerchantCategoryCode::Blocked>?
The Merchant Category Codes that are blocked for authorizations on this card.
251 252 253 254 255 |
# File 'lib/increase/models/card.rb', line 251 required :blocked, -> { Increase::Internal::Type::ArrayOf[Increase::Card::AuthorizationControls::MerchantCategoryCode::Blocked] }, nil?: true |