Module: Increase::Models::Card::AuthorizationControls::Usage::MultiUse::SpendingLimit::Interval
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card.rb
Overview
The interval at which the spending limit is enforced.
Constant Summary collapse
- ALL_TIME =
The spending limit applies over the lifetime of the card.
:all_time- PER_TRANSACTION =
The spending limit applies per transaction.
:per_transaction- PER_DAY =
The spending limit applies per day. Resets nightly at midnight UTC.
:per_day- PER_WEEK =
The spending limit applies per week. Resets weekly on Mondays at midnight UTC.
:per_week- PER_MONTH =
The spending limit applies per month. Resets on the first of the month, midnight UTC.
:per_month
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info