Class: Increase::Models::CardCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/card_create_params.rb
Overview
Defined Under Namespace
Classes: AuthorizationControls, BillingAddress, DigitalWallet
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account the card should belong to.
-
#authorization_controls ⇒ Increase::Models::CardCreateParams::AuthorizationControls?
Controls that restrict how this card can be used.
-
#billing_address ⇒ Increase::Models::CardCreateParams::BillingAddress?
The card’s billing address.
-
#description ⇒ String?
The description you choose to give the card.
-
#digital_wallet ⇒ Increase::Models::CardCreateParams::DigitalWallet?
The contact information used in the two-factor steps for digital wallet card creation.
-
#entity_id ⇒ String?
The Entity the card belongs to.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, line1:, postal_code:, state:, line2: nil) ⇒ Object
constructor
The card’s billing address.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, line1:, postal_code:, state:, line2: nil) ⇒ Object
The card’s billing address.
|
|
# File 'lib/increase/models/card_create_params.rb', line 500
|
Instance Attribute Details
#account_id ⇒ String
The Account the card should belong to.
14 |
# File 'lib/increase/models/card_create_params.rb', line 14 required :account_id, String |
#authorization_controls ⇒ Increase::Models::CardCreateParams::AuthorizationControls?
Controls that restrict how this card can be used.
20 |
# File 'lib/increase/models/card_create_params.rb', line 20 optional :authorization_controls, -> { Increase::CardCreateParams::AuthorizationControls } |
#billing_address ⇒ Increase::Models::CardCreateParams::BillingAddress?
The card’s billing address.
26 |
# File 'lib/increase/models/card_create_params.rb', line 26 optional :billing_address, -> { Increase::CardCreateParams::BillingAddress } |
#description ⇒ String?
The description you choose to give the card.
32 |
# File 'lib/increase/models/card_create_params.rb', line 32 optional :description, String |
#digital_wallet ⇒ Increase::Models::CardCreateParams::DigitalWallet?
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category ‘digital_wallet_token_requested` or `digital_wallet_authentication_requested`.
42 |
# File 'lib/increase/models/card_create_params.rb', line 42 optional :digital_wallet, -> { Increase::CardCreateParams::DigitalWallet } |
#entity_id ⇒ String?
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
49 |
# File 'lib/increase/models/card_create_params.rb', line 49 optional :entity_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_create_params.rb', line 461
|