Class: Increase::Models::CardDispute

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

See Also:

  • Increase::Resources::CardDisputes#create

Defined Under Namespace

Modules: Network, Status, Type Classes: Loss, Rejection, Visa, Win, Withdrawal

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(won_at:) ⇒ Object

Some parameter documentations has been truncated, see Win for more details.

If the Card Dispute's status is won, this will contain details of the won dispute.

Parameters:

  • won_at (Time)

    The ISO 8601 date and time at which th



# File 'lib/increase/models/card_dispute.rb', line 110

Instance Attribute Details

#amountInteger

The amount of the dispute.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


17
# File 'lib/increase/models/card_dispute.rb', line 17

required :amount, Integer

#card_idString

The Card that the Card Dispute is associated with.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/increase/models/card_dispute.rb', line 23

required :card_id, String

#created_atTime

The ISO 8601 date and time at which the Card Dispute was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


30
# File 'lib/increase/models/card_dispute.rb', line 30

required :created_at, Time

#disputed_transaction_idString

The identifier of the Transaction that was disputed.

Parameters:

  • value (String)

Returns:

  • (String)


36
# File 'lib/increase/models/card_dispute.rb', line 36

required :disputed_transaction_id, String

#idString

The Card Dispute identifier.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/increase/models/card_dispute.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


44
# File 'lib/increase/models/card_dispute.rb', line 44

required :idempotency_key, String, nil?: true

#lossIncrease::Models::CardDispute::Loss?

If the Card Dispute's status is lost, this will contain details of the lost dispute.

Parameters:

  • value (Increase::CardDispute::Loss, nil)

Returns:



51
# File 'lib/increase/models/card_dispute.rb', line 51

required :loss, -> { Increase::CardDispute::Loss }, nil?: true

#networkSymbol, Increase::Models::CardDispute::Network

The network that the Card Dispute is associated with.

Parameters:

  • value (Increase::Models::CardDispute::network)

Returns:



57
# File 'lib/increase/models/card_dispute.rb', line 57

required :network, enum: -> { Increase::CardDispute::Network }

#rejectionIncrease::Models::CardDispute::Rejection?

If the Card Dispute has been rejected, this will contain details of the rejection.

Parameters:

  • value (Increase::CardDispute::Rejection, nil)

Returns:



64
# File 'lib/increase/models/card_dispute.rb', line 64

required :rejection, -> { Increase::CardDispute::Rejection }, nil?: true

#statusSymbol, Increase::Models::CardDispute::Status

The status of the Card Dispute.

Parameters:

  • value (Increase::Models::CardDispute::status)

Returns:



70
# File 'lib/increase/models/card_dispute.rb', line 70

required :status, enum: -> { Increase::CardDispute::Status }

#typeSymbol, Increase::Models::CardDispute::Type

A constant representing the object's type. For this resource it will always be card_dispute.

Parameters:

  • value (Increase::Models::CardDispute::type_)

Returns:



77
# File 'lib/increase/models/card_dispute.rb', line 77

required :type, enum: -> { Increase::CardDispute::Type }

#user_submission_required_byTime?

The ISO 8601 date and time at which the user submission is required by. Present only if status is user_submission_required and a user submission is required by a certain time. Otherwise, this will be nil.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


86
# File 'lib/increase/models/card_dispute.rb', line 86

required :user_submission_required_by, Time, nil?: true

#visaIncrease::Models::CardDispute::Visa?

Card Dispute information for card payments processed over Visa's network. This field will be present in the JSON response if and only if network is equal to visa.

Parameters:

  • value (Increase::CardDispute::Visa, nil)

Returns:



94
# File 'lib/increase/models/card_dispute.rb', line 94

required :visa, -> { Increase::CardDispute::Visa }, nil?: true

#winIncrease::Models::CardDispute::Win?

If the Card Dispute's status is won, this will contain details of the won dispute.

Parameters:

  • value (Increase::CardDispute::Win, nil)

Returns:



101
# File 'lib/increase/models/card_dispute.rb', line 101

required :win, -> { Increase::CardDispute::Win }, nil?: true

#withdrawalIncrease::Models::CardDispute::Withdrawal?

If the Card Dispute has been withdrawn, this will contain details of the withdrawal.

Parameters:

  • value (Increase::CardDispute::Withdrawal, nil)

Returns:



108
# File 'lib/increase/models/card_dispute.rb', line 108

required :withdrawal, -> { Increase::CardDispute::Withdrawal }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_dispute.rb', line 185

Instance Method Details

#to_hash{

Returns:

  • ({)


71
# File 'sig/increase/models/card_dispute.rbs', line 71

def to_hash: -> {