Class: Increase::Models::CardDispute
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Overview
Defined Under Namespace
Modules: Network, Status, Type Classes: Loss, Rejection, Visa, Win, Withdrawal
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount of the dispute.
-
#card_id ⇒ String
The Card that the Card Dispute is associated with.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the Card Dispute was created.
-
#disputed_transaction_id ⇒ String
The identifier of the Transaction that was disputed.
-
#id ⇒ String
The Card Dispute identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#loss ⇒ Increase::Models::CardDispute::Loss?
If the Card Dispute's status is
lost, this will contain details of the lost dispute. -
#network ⇒ Symbol, Increase::Models::CardDispute::Network
The network that the Card Dispute is associated with.
-
#rejection ⇒ Increase::Models::CardDispute::Rejection?
If the Card Dispute has been rejected, this will contain details of the rejection.
-
#status ⇒ Symbol, Increase::Models::CardDispute::Status
The status of the Card Dispute.
-
#type ⇒ Symbol, Increase::Models::CardDispute::Type
A constant representing the object's type.
-
#user_submission_required_by ⇒ Time?
The ISO 8601 date and time at which the user submission is required by.
-
#visa ⇒ Increase::Models::CardDispute::Visa?
Card Dispute information for card payments processed over Visa's network.
-
#win ⇒ Increase::Models::CardDispute::Win?
If the Card Dispute's status is
won, this will contain details of the won dispute. -
#withdrawal ⇒ Increase::Models::CardDispute::Withdrawal?
If the Card Dispute has been withdrawn, this will contain details of the withdrawal.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(won_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Win for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(won_at:) ⇒ Object
Some parameter documentations has been truncated, see Win for more details.
If the Card Dispute's status is won, this will contain details of the won
dispute.
|
|
# File 'lib/increase/models/card_dispute.rb', line 110
|
Instance Attribute Details
#amount ⇒ Integer
The amount of the dispute.
17 |
# File 'lib/increase/models/card_dispute.rb', line 17 required :amount, Integer |
#card_id ⇒ String
The Card that the Card Dispute is associated with.
23 |
# File 'lib/increase/models/card_dispute.rb', line 23 required :card_id, String |
#created_at ⇒ Time
The ISO 8601 date and time at which the Card Dispute was created.
30 |
# File 'lib/increase/models/card_dispute.rb', line 30 required :created_at, Time |
#disputed_transaction_id ⇒ String
The identifier of the Transaction that was disputed.
36 |
# File 'lib/increase/models/card_dispute.rb', line 36 required :disputed_transaction_id, String |
#id ⇒ String
The Card Dispute identifier.
11 |
# File 'lib/increase/models/card_dispute.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
44 |
# File 'lib/increase/models/card_dispute.rb', line 44 required :idempotency_key, String, nil?: true |
#loss ⇒ Increase::Models::CardDispute::Loss?
If the Card Dispute's status is lost, this will contain details of the lost
dispute.
51 |
# File 'lib/increase/models/card_dispute.rb', line 51 required :loss, -> { Increase::CardDispute::Loss }, nil?: true |
#network ⇒ Symbol, Increase::Models::CardDispute::Network
The network that the Card Dispute is associated with.
57 |
# File 'lib/increase/models/card_dispute.rb', line 57 required :network, enum: -> { Increase::CardDispute::Network } |
#rejection ⇒ Increase::Models::CardDispute::Rejection?
If the Card Dispute has been rejected, this will contain details of the rejection.
64 |
# File 'lib/increase/models/card_dispute.rb', line 64 required :rejection, -> { Increase::CardDispute::Rejection }, nil?: true |
#status ⇒ Symbol, Increase::Models::CardDispute::Status
The status of the Card Dispute.
70 |
# File 'lib/increase/models/card_dispute.rb', line 70 required :status, enum: -> { Increase::CardDispute::Status } |
#type ⇒ Symbol, Increase::Models::CardDispute::Type
A constant representing the object's type. For this resource it will always be
card_dispute.
77 |
# File 'lib/increase/models/card_dispute.rb', line 77 required :type, enum: -> { Increase::CardDispute::Type } |
#user_submission_required_by ⇒ Time?
The ISO 8601 date and time at which
the user submission is required by. Present only if status is
user_submission_required and a user submission is required by a certain time.
Otherwise, this will be nil.
86 |
# File 'lib/increase/models/card_dispute.rb', line 86 required :user_submission_required_by, Time, nil?: true |
#visa ⇒ Increase::Models::CardDispute::Visa?
Card Dispute information for card payments processed over Visa's network. This
field will be present in the JSON response if and only if network is equal to
visa.
94 |
# File 'lib/increase/models/card_dispute.rb', line 94 required :visa, -> { Increase::CardDispute::Visa }, nil?: true |
#win ⇒ Increase::Models::CardDispute::Win?
If the Card Dispute's status is won, this will contain details of the won
dispute.
101 |
# File 'lib/increase/models/card_dispute.rb', line 101 required :win, -> { Increase::CardDispute::Win }, nil?: true |
#withdrawal ⇒ Increase::Models::CardDispute::Withdrawal?
If the Card Dispute has been withdrawn, this will contain details of the withdrawal.
108 |
# File 'lib/increase/models/card_dispute.rb', line 108 required :withdrawal, -> { Increase::CardDispute::Withdrawal }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute.rb', line 185
|
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/increase/models/card_dispute.rbs', line 71
def to_hash: -> {
|