Class: Increase::Models::CardDispute::Visa::NetworkEvent::Represented::CreditOrReversalProcessed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs

Overview

See Also:

  • Increase::Models::CardDispute::Visa::NetworkEvent::Represented#credit_or_reversal_processed

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



831
# File 'sig/increase/models/card_dispute.rbs', line 831

def initialize: (

Instance Attribute Details

#amountInteger

The amount of the credit or reversal in the minor unit of its currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1214
# File 'lib/increase/models/card_dispute.rb', line 1214

required :amount, Integer

#currencyString

The ISO 4217 code for the credit or reversal's currency.

Parameters:

  • value (String)

Returns:

  • (String)


1221
# File 'lib/increase/models/card_dispute.rb', line 1221

required :currency, String

#explanationString?

Explanation for why the merchant believes the credit or reversal was processed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1227
# File 'lib/increase/models/card_dispute.rb', line 1227

required :explanation, String, nil?: true

#processed_atDate

The date the credit or reversal was processed.

Parameters:

  • value (Date)

Returns:

  • (Date)


1233
# File 'lib/increase/models/card_dispute.rb', line 1233

required :processed_at, Date

Instance Method Details

#to_hash{

Returns:

  • ({)


838
# File 'sig/increase/models/card_dispute.rbs', line 838

def to_hash: -> {