Class: Increase::Models::CardDispute::Visa::UserSubmission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDispute::Visa::UserSubmission
- Defined in:
- lib/increase/models/card_dispute.rb,
sig/increase/models/card_dispute.rbs
Defined Under Namespace
Modules: Category, Status Classes: AttachmentFile, Chargeback, MerchantPrearbitrationDecline, UserPrearbitration
Instance Attribute Summary collapse
-
#accepted_at ⇒ Time?
The date and time at which the Visa Card Dispute User Submission was reviewed and accepted.
-
#amount ⇒ Integer?
The amount of the dispute if it is different from the amount of a prior user submission or the disputed transaction.
-
#attachment_files ⇒ Array<Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile>
The files attached to the Visa Card Dispute User Submission.
-
#category ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Category
The category of the user submission.
-
#chargeback ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback?
A Visa Card Dispute Chargeback User Submission Chargeback Details object.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was created.
-
#explanation ⇒ String?
The free-form explanation provided to Increase to provide more context for the user submission.
-
#further_information_requested_at ⇒ Time?
The date and time at which Increase requested further information from the user for the Visa Card Dispute.
-
#further_information_requested_reason ⇒ String?
The reason for Increase requesting further information from the user for the Visa Card Dispute.
-
#merchant_prearbitration_decline ⇒ Increase::Models::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline?
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
-
#status ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Status
The status of the Visa Card Dispute User Submission.
-
#updated_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was updated.
-
#user_prearbitration ⇒ Increase::Models::CardDispute::Visa::UserSubmission::UserPrearbitration?
A Visa Card Dispute User-Initiated Pre-Arbitration User Submission object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(reason:) ⇒ Object
constructor
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reason:) ⇒ Object
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
This field will be present in the JSON response if and only if category is
equal to merchant_prearbitration_decline. Contains the details specific to a
merchant prearbitration decline Visa Card Dispute User Submission.
|
|
# File 'lib/increase/models/card_dispute.rb', line 1857
|
Instance Attribute Details
#accepted_at ⇒ Time?
The date and time at which the Visa Card Dispute User Submission was reviewed and accepted.
1696 |
# File 'lib/increase/models/card_dispute.rb', line 1696 required :accepted_at, Time, nil?: true |
#amount ⇒ Integer?
The amount of the dispute if it is different from the amount of a prior user submission or the disputed transaction.
1703 |
# File 'lib/increase/models/card_dispute.rb', line 1703 required :amount, Integer, nil?: true |
#attachment_files ⇒ Array<Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile>
The files attached to the Visa Card Dispute User Submission.
1709 1710 |
# File 'lib/increase/models/card_dispute.rb', line 1709 required :attachment_files, -> { Increase::Internal::Type::ArrayOf[Increase::CardDispute::Visa::UserSubmission::AttachmentFile] } |
#category ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Category
The category of the user submission. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
1718 |
# File 'lib/increase/models/card_dispute.rb', line 1718 required :category, enum: -> { Increase::CardDispute::Visa::UserSubmission::Category } |
#chargeback ⇒ Increase::Models::CardDispute::Visa::UserSubmission::Chargeback?
A Visa Card Dispute Chargeback User Submission Chargeback Details object. This
field will be present in the JSON response if and only if category is equal to
chargeback. Contains the details specific to a Visa chargeback User Submission
for a Card Dispute.
1768 |
# File 'lib/increase/models/card_dispute.rb', line 1768 optional :chargeback, -> { Increase::CardDispute::Visa::UserSubmission::Chargeback }, nil?: true |
#created_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was created.
1725 |
# File 'lib/increase/models/card_dispute.rb', line 1725 required :created_at, Time |
#explanation ⇒ String?
The free-form explanation provided to Increase to provide more context for the user submission. This field is not sent directly to the card networks.
1732 |
# File 'lib/increase/models/card_dispute.rb', line 1732 required :explanation, String, nil?: true |
#further_information_requested_at ⇒ Time?
The date and time at which Increase requested further information from the user for the Visa Card Dispute.
1739 |
# File 'lib/increase/models/card_dispute.rb', line 1739 required :further_information_requested_at, Time, nil?: true |
#further_information_requested_reason ⇒ String?
The reason for Increase requesting further information from the user for the Visa Card Dispute.
1746 |
# File 'lib/increase/models/card_dispute.rb', line 1746 required :further_information_requested_reason, String, nil?: true |
#merchant_prearbitration_decline ⇒ Increase::Models::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline?
A Visa Card Dispute Merchant Pre-Arbitration Decline User Submission object.
This field will be present in the JSON response if and only if category is
equal to merchant_prearbitration_decline. Contains the details specific to a
merchant prearbitration decline Visa Card Dispute User Submission.
1777 1778 1779 |
# File 'lib/increase/models/card_dispute.rb', line 1777 optional :merchant_prearbitration_decline, -> { Increase::CardDispute::Visa::UserSubmission::MerchantPrearbitrationDecline }, nil?: true |
#status ⇒ Symbol, Increase::Models::CardDispute::Visa::UserSubmission::Status
The status of the Visa Card Dispute User Submission.
1752 |
# File 'lib/increase/models/card_dispute.rb', line 1752 required :status, enum: -> { Increase::CardDispute::Visa::UserSubmission::Status } |
#updated_at ⇒ Time
The ISO 8601 date and time at which the Visa Card Dispute User Submission was updated.
1759 |
# File 'lib/increase/models/card_dispute.rb', line 1759 required :updated_at, Time |
#user_prearbitration ⇒ Increase::Models::CardDispute::Visa::UserSubmission::UserPrearbitration?
A Visa Card Dispute User-Initiated Pre-Arbitration User Submission object. This
field will be present in the JSON response if and only if category is equal to
user_prearbitration. Contains the details specific to a user-initiated
pre-arbitration Visa Card Dispute User Submission.
1788 1789 1790 |
# File 'lib/increase/models/card_dispute.rb', line 1788 optional :user_prearbitration, -> { Increase::CardDispute::Visa::UserSubmission::UserPrearbitration }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute.rb', line 1878
|
Instance Method Details
#to_hash ⇒ {
1231 |
# File 'sig/increase/models/card_dispute.rbs', line 1231
def to_hash: -> {
|