Class: Increase::Models::CardDispute::Visa::UserSubmission::AttachmentFile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_dispute.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accepted_at:, amount:, attachment_files:, category:, created_at:, explanation:, further_information_requested_at:, further_information_requested_reason:, status:, updated_at:, chargeback: nil, merchant_prearbitration_decline: nil, user_prearbitration: nil) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardDispute::Visa::UserSubmission for more details.

Parameters:



1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
# File 'lib/increase/models/card_dispute.rb', line 1674

class AttachmentFile < Increase::Internal::Type::BaseModel
  # @!attribute file_id
  #   The ID of the file attached to the Card Dispute.
  #
  #   @return [String]
  required :file_id, String

  # @!method initialize(file_id:)
  #   @param file_id [String] The ID of the file attached to the Card Dispute.
end

Instance Attribute Details

#file_idString

The ID of the file attached to the Card Dispute.

Returns:

  • (String)


1679
# File 'lib/increase/models/card_dispute.rb', line 1679

required :file_id, String