Class: Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices
- Defined in:
- lib/increase/models/card_dispute_create_params.rb
Overview
Defined Under Namespace
Modules: CardholderPaidToHaveWorkRedone, NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription, RestaurantFoodRelated Classes: CardholderCancellation, OngoingNegotiations
Instance Attribute Summary collapse
-
#cardholder_cancellation ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderCancellation
Cardholder cancellation.
-
#cardholder_paid_to_have_work_redone ⇒ Symbol, ...
Cardholder paid to have work redone.
-
#non_fiat_currency_or_non_fungible_token_related_and_not_matching_description ⇒ Symbol, Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription
Non-fiat currency or non-fungible token related and not matching description.
-
#ongoing_negotiations ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::OngoingNegotiations?
Ongoing negotiations.
-
#purchase_info_and_quality_issue ⇒ String
Purchase information and quality issue.
-
#restaurant_food_related ⇒ Symbol, ...
Whether the dispute is related to the quality of food from an eating place or restaurant.
-
#services_received_at ⇒ Date
Services received at.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(explanation:, issuer_first_notified_at:, started_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see OngoingNegotiations for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(explanation:, issuer_first_notified_at:, started_at:) ⇒ Object
Some parameter documentations has been truncated, see OngoingNegotiations for more details.
Ongoing negotiations. Exclude if there is no evidence of ongoing negotiations.
|
|
# File 'lib/increase/models/card_dispute_create_params.rb', line 2597
|
Instance Attribute Details
#cardholder_cancellation ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderCancellation
Cardholder cancellation.
2552 2553 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2552 required :cardholder_cancellation, -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderCancellation } |
#cardholder_paid_to_have_work_redone ⇒ Symbol, ...
Cardholder paid to have work redone.
2578 2579 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2578 optional :cardholder_paid_to_have_work_redone, enum: -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::CardholderPaidToHaveWorkRedone } |
#non_fiat_currency_or_non_fungible_token_related_and_not_matching_description ⇒ Symbol, Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription
Non-fiat currency or non-fungible token related and not matching description.
2559 2560 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2559 required :non_fiat_currency_or_non_fungible_token_related_and_not_matching_description, enum: -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::NonFiatCurrencyOrNonFungibleTokenRelatedAndNotMatchingDescription } |
#ongoing_negotiations ⇒ Increase::Models::CardDisputeCreateParams::Visa::ConsumerQualityServices::OngoingNegotiations?
Ongoing negotiations. Exclude if there is no evidence of ongoing negotiations.
2585 2586 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2585 optional :ongoing_negotiations, -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::OngoingNegotiations } |
#purchase_info_and_quality_issue ⇒ String
Purchase information and quality issue.
2566 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2566 required :purchase_info_and_quality_issue, String |
#restaurant_food_related ⇒ Symbol, ...
Whether the dispute is related to the quality of food from an eating place or restaurant. Must be provided when Merchant Category Code (MCC) is 5812, 5813 or 5814.
2594 2595 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2594 optional :restaurant_food_related, enum: -> { Increase::CardDisputeCreateParams::Visa::ConsumerQualityServices::RestaurantFoodRelated } |
#services_received_at ⇒ Date
Services received at.
2572 |
# File 'lib/increase/models/card_dispute_create_params.rb', line 2572 required :services_received_at, Date |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute_create_params.rb', line 2661
|