Module: Increase::Models::CardDisputeListParams::Status::In
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_dispute_list_params.rb,
sig/increase/models/card_dispute_list_params.rbs
Constant Summary collapse
- USER_SUBMISSION_REQUIRED =
A User Submission is required to continue with the Card Dispute.
:user_submission_required- PENDING_USER_SUBMISSION_REVIEWING =
The most recent User Submission is being reviewed.
:pending_user_submission_reviewing- PENDING_USER_SUBMISSION_SUBMITTING =
The most recent User Submission is being submitted to the network.
:pending_user_submission_submitting- PENDING_USER_WITHDRAWAL_SUBMITTING =
The user's withdrawal of the Card Dispute is being submitted to the network.
:pending_user_withdrawal_submitting- PENDING_RESPONSE =
The Card Dispute is pending a response from the network.
:pending_response- LOST =
The Card Dispute has been lost and funds previously credited from the acceptance have been debited.
:lost- WON =
The Card Dispute has been won and no further action can be taken.
:won- REJECTED =
The Card Dispute has been reviewed and rejected, please review the explanation for more details.
:rejected
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(in_: nil) ⇒ Object
- #self?.values ⇒ ::Array[Increase::Models::CardDisputeListParams::Status::in_]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_dispute_list_params.rb', line 152
|
Instance Method Details
#initialize(in_: nil) ⇒ Object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/increase/models/card_dispute_list_params.rb', line 125 module In extend Increase::Internal::Type::Enum # A User Submission is required to continue with the Card Dispute. USER_SUBMISSION_REQUIRED = :user_submission_required # The most recent User Submission is being reviewed. PENDING_USER_SUBMISSION_REVIEWING = :pending_user_submission_reviewing # The most recent User Submission is being submitted to the network. PENDING_USER_SUBMISSION_SUBMITTING = :pending_user_submission_submitting # The user's withdrawal of the Card Dispute is being submitted to the network. PENDING_USER_WITHDRAWAL_SUBMITTING = :pending_user_withdrawal_submitting # The Card Dispute is pending a response from the network. PENDING_RESPONSE = :pending_response # The Card Dispute has been lost and funds previously credited from the acceptance have been debited. LOST = :lost # The Card Dispute has been won and no further action can be taken. WON = :won # The Card Dispute has been reviewed and rejected, please review the explanation for more details. REJECTED = :rejected # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[Increase::Models::CardDisputeListParams::Status::in_]
149 |
# File 'sig/increase/models/card_dispute_list_params.rbs', line 149
def self?.values: -> ::Array[Increase::Models::CardDisputeListParams::Status::in_]
|