Class: Increase::Models::CardPayment::Element::CardAuthentication
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthentication
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: DenyReason, RequestorAuthenticationIndicator, RequestorChallengeIndicator, Status, Type Classes: Challenge, DeviceChannel, MessageCategory
Instance Attribute Summary collapse
-
#access_control_server_transaction_identifier ⇒ String
A unique identifier assigned by the Access Control Server (us) for this transaction.
-
#billing_address_city ⇒ String?
The city of the cardholder billing address associated with the card used for this purchase.
-
#billing_address_country ⇒ String?
The country of the cardholder billing address associated with the card used for this purchase.
-
#billing_address_line1 ⇒ String?
The first line of the cardholder billing address associated with the card used for this purchase.
-
#billing_address_line2 ⇒ String?
The second line of the cardholder billing address associated with the card used for this purchase.
-
#billing_address_line3 ⇒ String?
The third line of the cardholder billing address associated with the card used for this purchase.
-
#billing_address_postal_code ⇒ String?
The postal code of the cardholder billing address associated with the card used for this purchase.
-
#billing_address_state ⇒ String?
The US state of the cardholder billing address associated with the card used for this purchase.
-
#card_id ⇒ String
The identifier of the Card.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cardholder_email ⇒ String?
The email address of the cardholder.
-
#cardholder_name ⇒ String?
The name of the cardholder.
-
#challenge ⇒ Increase::Models::CardPayment::Element::CardAuthentication::Challenge?
Details about the challenge, if one was requested.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Card Authentication was attempted.
-
#deny_reason ⇒ Symbol, ...
The reason why this authentication attempt was denied, if it was.
-
#device_channel ⇒ Increase::Models::CardPayment::Element::CardAuthentication::DeviceChannel
The device channel of the card authentication attempt.
-
#directory_server_transaction_identifier ⇒ String
A unique identifier assigned by the Directory Server (the card network) for this transaction.
-
#id ⇒ String
The Card Authentication identifier.
-
#merchant_acceptor_id ⇒ String?
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String?
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_country ⇒ String?
The country the merchant resides in.
-
#merchant_name ⇒ String?
The name of the merchant.
-
#message_category ⇒ Increase::Models::CardPayment::Element::CardAuthentication::MessageCategory
The message category of the card authentication attempt.
-
#prior_authenticated_card_payment_id ⇒ String?
The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
#requestor_authentication_indicator ⇒ Symbol, ...
The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.
-
#requestor_challenge_indicator ⇒ Symbol, ...
Indicates whether a challenge is requested for this transaction.
-
#requestor_name ⇒ String
The name of the 3DS requestor.
-
#requestor_url ⇒ String
The URL of the 3DS requestor.
-
#shipping_address_city ⇒ String?
The city of the shipping address associated with this purchase.
-
#shipping_address_country ⇒ String?
The country of the shipping address associated with this purchase.
-
#shipping_address_line1 ⇒ String?
The first line of the shipping address associated with this purchase.
-
#shipping_address_line2 ⇒ String?
The second line of the shipping address associated with this purchase.
-
#shipping_address_line3 ⇒ String?
The third line of the shipping address associated with this purchase.
-
#shipping_address_postal_code ⇒ String?
The postal code of the shipping address associated with this purchase.
-
#shipping_address_state ⇒ String?
The US state of the shipping address associated with this purchase.
-
#status ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthentication::Status
The status of the card authentication.
-
#three_d_secure_server_transaction_identifier ⇒ String
A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthentication::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, access_control_server_transaction_identifier:, billing_address_city:, billing_address_country:, billing_address_line1:, billing_address_line2:, billing_address_line3:, billing_address_postal_code:, billing_address_state:, card_id:, card_payment_id:, cardholder_email:, cardholder_name:, challenge:, created_at:, deny_reason:, device_channel:, directory_server_transaction_identifier:, merchant_acceptor_id:, merchant_category_code:, merchant_country:, merchant_name:, message_category:, prior_authenticated_card_payment_id:, real_time_decision_id:, requestor_authentication_indicator:, requestor_challenge_indicator:, requestor_name:, requestor_url:, shipping_address_city:, shipping_address_country:, shipping_address_line1:, shipping_address_line2:, shipping_address_line3:, shipping_address_postal_code:, shipping_address_state:, status:, three_d_secure_server_transaction_identifier:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardAuthentication for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, access_control_server_transaction_identifier:, billing_address_city:, billing_address_country:, billing_address_line1:, billing_address_line2:, billing_address_line3:, billing_address_postal_code:, billing_address_state:, card_id:, card_payment_id:, cardholder_email:, cardholder_name:, challenge:, created_at:, deny_reason:, device_channel:, directory_server_transaction_identifier:, merchant_acceptor_id:, merchant_category_code:, merchant_country:, merchant_name:, message_category:, prior_authenticated_card_payment_id:, real_time_decision_id:, requestor_authentication_indicator:, requestor_challenge_indicator:, requestor_name:, requestor_url:, shipping_address_city:, shipping_address_country:, shipping_address_line1:, shipping_address_line2:, shipping_address_line3:, shipping_address_postal_code:, shipping_address_state:, status:, three_d_secure_server_transaction_identifier:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardAuthentication for more details.
A Card Authentication object. This field will be present in the JSON response if and only if ‘category` is equal to `card_authentication`. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
|
|
# File 'lib/increase/models/card_payment.rb', line 572
|
Instance Attribute Details
#access_control_server_transaction_identifier ⇒ String
A unique identifier assigned by the Access Control Server (us) for this transaction.
318 |
# File 'lib/increase/models/card_payment.rb', line 318 required :access_control_server_transaction_identifier, String |
#billing_address_city ⇒ String?
The city of the cardholder billing address associated with the card used for this purchase.
325 |
# File 'lib/increase/models/card_payment.rb', line 325 required :billing_address_city, String, nil?: true |
#billing_address_country ⇒ String?
The country of the cardholder billing address associated with the card used for this purchase.
332 |
# File 'lib/increase/models/card_payment.rb', line 332 required :billing_address_country, String, nil?: true |
#billing_address_line1 ⇒ String?
The first line of the cardholder billing address associated with the card used for this purchase.
339 |
# File 'lib/increase/models/card_payment.rb', line 339 required :billing_address_line1, String, nil?: true |
#billing_address_line2 ⇒ String?
The second line of the cardholder billing address associated with the card used for this purchase.
346 |
# File 'lib/increase/models/card_payment.rb', line 346 required :billing_address_line2, String, nil?: true |
#billing_address_line3 ⇒ String?
The third line of the cardholder billing address associated with the card used for this purchase.
353 |
# File 'lib/increase/models/card_payment.rb', line 353 required :billing_address_line3, String, nil?: true |
#billing_address_postal_code ⇒ String?
The postal code of the cardholder billing address associated with the card used for this purchase.
360 |
# File 'lib/increase/models/card_payment.rb', line 360 required :billing_address_postal_code, String, nil?: true |
#billing_address_state ⇒ String?
The US state of the cardholder billing address associated with the card used for this purchase.
367 |
# File 'lib/increase/models/card_payment.rb', line 367 required :billing_address_state, String, nil?: true |
#card_id ⇒ String
The identifier of the Card.
373 |
# File 'lib/increase/models/card_payment.rb', line 373 required :card_id, String |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
379 |
# File 'lib/increase/models/card_payment.rb', line 379 required :card_payment_id, String |
#cardholder_email ⇒ String?
The email address of the cardholder.
385 |
# File 'lib/increase/models/card_payment.rb', line 385 required :cardholder_email, String, nil?: true |
#cardholder_name ⇒ String?
The name of the cardholder.
391 |
# File 'lib/increase/models/card_payment.rb', line 391 required :cardholder_name, String, nil?: true |
#challenge ⇒ Increase::Models::CardPayment::Element::CardAuthentication::Challenge?
Details about the challenge, if one was requested.
397 398 399 400 401 |
# File 'lib/increase/models/card_payment.rb', line 397 required :challenge, -> { Increase::CardPayment::Element::CardAuthentication::Challenge }, nil?: true |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Card Authentication was attempted.
408 |
# File 'lib/increase/models/card_payment.rb', line 408 required :created_at, Time |
#deny_reason ⇒ Symbol, ...
The reason why this authentication attempt was denied, if it was.
414 415 416 |
# File 'lib/increase/models/card_payment.rb', line 414 required :deny_reason, enum: -> { Increase::CardPayment::Element::CardAuthentication::DenyReason }, nil?: true |
#device_channel ⇒ Increase::Models::CardPayment::Element::CardAuthentication::DeviceChannel
The device channel of the card authentication attempt.
422 |
# File 'lib/increase/models/card_payment.rb', line 422 required :device_channel, -> { Increase::CardPayment::Element::CardAuthentication::DeviceChannel } |
#directory_server_transaction_identifier ⇒ String
A unique identifier assigned by the Directory Server (the card network) for this transaction.
429 |
# File 'lib/increase/models/card_payment.rb', line 429 required :directory_server_transaction_identifier, String |
#id ⇒ String
The Card Authentication identifier.
311 |
# File 'lib/increase/models/card_payment.rb', line 311 required :id, String |
#merchant_acceptor_id ⇒ String?
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
436 |
# File 'lib/increase/models/card_payment.rb', line 436 required :merchant_acceptor_id, String, nil?: true |
#merchant_category_code ⇒ String?
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
443 |
# File 'lib/increase/models/card_payment.rb', line 443 required :merchant_category_code, String, nil?: true |
#merchant_country ⇒ String?
The country the merchant resides in.
449 |
# File 'lib/increase/models/card_payment.rb', line 449 required :merchant_country, String, nil?: true |
#merchant_name ⇒ String?
The name of the merchant.
455 |
# File 'lib/increase/models/card_payment.rb', line 455 required :merchant_name, String, nil?: true |
#message_category ⇒ Increase::Models::CardPayment::Element::CardAuthentication::MessageCategory
The message category of the card authentication attempt.
461 |
# File 'lib/increase/models/card_payment.rb', line 461 required :message_category, -> { Increase::CardPayment::Element::CardAuthentication::MessageCategory } |
#prior_authenticated_card_payment_id ⇒ String?
The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction.
468 |
# File 'lib/increase/models/card_payment.rb', line 468 required :prior_authenticated_card_payment_id, String, nil?: true |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
475 |
# File 'lib/increase/models/card_payment.rb', line 475 required :real_time_decision_id, String, nil?: true |
#requestor_authentication_indicator ⇒ Symbol, ...
The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.
482 483 484 485 486 |
# File 'lib/increase/models/card_payment.rb', line 482 required :requestor_authentication_indicator, enum: -> { Increase::CardPayment::Element::CardAuthentication::RequestorAuthenticationIndicator }, nil?: true |
#requestor_challenge_indicator ⇒ Symbol, ...
Indicates whether a challenge is requested for this transaction.
492 493 494 495 496 |
# File 'lib/increase/models/card_payment.rb', line 492 required :requestor_challenge_indicator, enum: -> { Increase::CardPayment::Element::CardAuthentication::RequestorChallengeIndicator }, nil?: true |
#requestor_name ⇒ String
The name of the 3DS requestor.
502 |
# File 'lib/increase/models/card_payment.rb', line 502 required :requestor_name, String |
#requestor_url ⇒ String
The URL of the 3DS requestor.
508 |
# File 'lib/increase/models/card_payment.rb', line 508 required :requestor_url, String |
#shipping_address_city ⇒ String?
The city of the shipping address associated with this purchase.
514 |
# File 'lib/increase/models/card_payment.rb', line 514 required :shipping_address_city, String, nil?: true |
#shipping_address_country ⇒ String?
The country of the shipping address associated with this purchase.
520 |
# File 'lib/increase/models/card_payment.rb', line 520 required :shipping_address_country, String, nil?: true |
#shipping_address_line1 ⇒ String?
The first line of the shipping address associated with this purchase.
526 |
# File 'lib/increase/models/card_payment.rb', line 526 required :shipping_address_line1, String, nil?: true |
#shipping_address_line2 ⇒ String?
The second line of the shipping address associated with this purchase.
532 |
# File 'lib/increase/models/card_payment.rb', line 532 required :shipping_address_line2, String, nil?: true |
#shipping_address_line3 ⇒ String?
The third line of the shipping address associated with this purchase.
538 |
# File 'lib/increase/models/card_payment.rb', line 538 required :shipping_address_line3, String, nil?: true |
#shipping_address_postal_code ⇒ String?
The postal code of the shipping address associated with this purchase.
544 |
# File 'lib/increase/models/card_payment.rb', line 544 required :shipping_address_postal_code, String, nil?: true |
#shipping_address_state ⇒ String?
The US state of the shipping address associated with this purchase.
550 |
# File 'lib/increase/models/card_payment.rb', line 550 required :shipping_address_state, String, nil?: true |
#status ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthentication::Status
The status of the card authentication.
556 |
# File 'lib/increase/models/card_payment.rb', line 556 required :status, enum: -> { Increase::CardPayment::Element::CardAuthentication::Status } |
#three_d_secure_server_transaction_identifier ⇒ String
A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction.
563 |
# File 'lib/increase/models/card_payment.rb', line 563 required :three_d_secure_server_transaction_identifier, String |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthentication::Type
A constant representing the object’s type. For this resource it will always be ‘card_authentication`.
570 |
# File 'lib/increase/models/card_payment.rb', line 570 required :type, enum: -> { Increase::CardPayment::Element::CardAuthentication::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 775
|