Class: Increase::Models::CardPayment::Element::CardAuthentication::Challenge
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthentication::Challenge
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: VerificationMethod Classes: Attempt
Instance Attribute Summary collapse
-
#attempts ⇒ Array<Increase::Models::CardPayment::Element::CardAuthentication::Challenge::Attempt>
Details about the challenge verification attempts, if any happened.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Card Authentication Challenge was started.
-
#one_time_code ⇒ String
The one-time code used for the Card Authentication Challenge.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision used to deliver this challenge.
-
#verification_method ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthentication::Challenge::VerificationMethod
The method used to verify the Card Authentication Challenge.
-
#verification_value ⇒ String?
E.g., the email address or phone number used for the Card Authentication Challenge.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#attempts ⇒ Array<Increase::Models::CardPayment::Element::CardAuthentication::Challenge::Attempt>
Details about the challenge verification attempts, if any happened.
664 665 |
# File 'lib/increase/models/card_payment.rb', line 664 required :attempts, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardAuthentication::Challenge::Attempt] } |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Card Authentication Challenge was started.
672 |
# File 'lib/increase/models/card_payment.rb', line 672 required :created_at, Time |
#one_time_code ⇒ String
The one-time code used for the Card Authentication Challenge.
678 |
# File 'lib/increase/models/card_payment.rb', line 678 required :one_time_code, String |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision used to deliver this challenge.
684 |
# File 'lib/increase/models/card_payment.rb', line 684 required :real_time_decision_id, String, nil?: true |
#verification_method ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthentication::Challenge::VerificationMethod
The method used to verify the Card Authentication Challenge.
690 691 |
# File 'lib/increase/models/card_payment.rb', line 690 required :verification_method, enum: -> { Increase::CardPayment::Element::CardAuthentication::Challenge::VerificationMethod } |
#verification_value ⇒ String?
E.g., the email address or phone number used for the Card Authentication Challenge.
698 |
# File 'lib/increase/models/card_payment.rb', line 698 required :verification_value, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 755
|