Class: Increase::Models::CardPayment::Element::CardAuthorization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_authorization

Defined Under Namespace

Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, Healthcare, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/card_payment.rb', line 1583

Instance Attribute Details

#actionerSymbol, Increase::Models::CardPayment::Element::CardAuthorization::Actioner

Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardAuthorization::actioner)

Returns:



1387
# File 'lib/increase/models/card_payment.rb', line 1387

required :actioner, enum: -> { Increase::CardPayment::Element::CardAuthorization::Actioner }

#additional_amountsIncrease::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts)

Returns:



1395
# File 'lib/increase/models/card_payment.rb', line 1395

required :additional_amounts, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts }

#amountInteger

The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1402
# File 'lib/increase/models/card_payment.rb', line 1402

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


1408
# File 'lib/increase/models/card_payment.rb', line 1408

required :card_payment_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardAuthorization::Currency

The ISO 4217 code for the transaction's currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardAuthorization::currency)

Returns:



1415
# File 'lib/increase/models/card_payment.rb', line 1415

required :currency, enum: -> { Increase::CardPayment::Element::CardAuthorization::Currency }

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1422
# File 'lib/increase/models/card_payment.rb', line 1422

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::CardPayment::Element::CardAuthorization::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardAuthorization::direction)

Returns:



1429
# File 'lib/increase/models/card_payment.rb', line 1429

required :direction, enum: -> { Increase::CardPayment::Element::CardAuthorization::Direction }

#expires_atTime

The ISO 8601 when this authorization will expire and the pending transaction will be released.

Parameters:

  • value (Time)

Returns:

  • (Time)


1436
# File 'lib/increase/models/card_payment.rb', line 1436

required :expires_at, Time

#healthcareIncrease::Models::CardPayment::Element::CardAuthorization::Healthcare?

The healthcare-related fields for this authorization. Only present for specific programs.

Parameters:

  • value (Increase::CardPayment::Element::CardAuthorization::Healthcare, nil)

Returns:



1443
1444
1445
1446
1447
# File 'lib/increase/models/card_payment.rb', line 1443

required :healthcare,
-> {
  Increase::CardPayment::Element::CardAuthorization::Healthcare
},
nil?: true

#idString

The Card Authorization identifier.

Parameters:

  • value (String)

Returns:

  • (String)


1380
# File 'lib/increase/models/card_payment.rb', line 1380

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1454
# File 'lib/increase/models/card_payment.rb', line 1454

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1461
# File 'lib/increase/models/card_payment.rb', line 1461

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1467
# File 'lib/increase/models/card_payment.rb', line 1467

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


1473
# File 'lib/increase/models/card_payment.rb', line 1473

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1479
# File 'lib/increase/models/card_payment.rb', line 1479

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1486
# File 'lib/increase/models/card_payment.rb', line 1486

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1492
# File 'lib/increase/models/card_payment.rb', line 1492

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::CardPayment::Element::CardAuthorization::NetworkDetails

Fields specific to the network.

Parameters:

  • value (Increase::CardPayment::Element::CardAuthorization::NetworkDetails)

Returns:



1498
# File 'lib/increase/models/card_payment.rb', line 1498

required :network_details, -> { Increase::CardPayment::Element::CardAuthorization::NetworkDetails }

#network_identifiersIncrease::Models::CardPayment::Element::CardAuthorization::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardAuthorization::NetworkIdentifiers)

Returns:



1504
1505
# File 'lib/increase/models/card_payment.rb', line 1504

required :network_identifiers,
-> { Increase::CardPayment::Element::CardAuthorization::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


1513
# File 'lib/increase/models/card_payment.rb', line 1513

required :network_risk_score, Integer, nil?: true

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1519
# File 'lib/increase/models/card_payment.rb', line 1519

required :pending_transaction_id, String, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1526
# File 'lib/increase/models/card_payment.rb', line 1526

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The pending amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1532
# File 'lib/increase/models/card_payment.rb', line 1532

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


1539
# File 'lib/increase/models/card_payment.rb', line 1539

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::CardPayment::Element::CardAuthorization::ProcessingCategory

The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardAuthorization::processing_category)

Returns:



1546
1547
# File 'lib/increase/models/card_payment.rb', line 1546

required :processing_category,
enum: -> { Increase::CardPayment::Element::CardAuthorization::ProcessingCategory }

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1554
# File 'lib/increase/models/card_payment.rb', line 1554

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardAuthorization::SchemeFee>

The scheme fees associated with this card authorization.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardAuthorization::SchemeFee])

Returns:



1560
1561
# File 'lib/increase/models/card_payment.rb', line 1560

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardAuthorization::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1568
# File 'lib/increase/models/card_payment.rb', line 1568

required :terminal_id, String, nil?: true

#typeSymbol, Increase::Models::CardPayment::Element::CardAuthorization::Type

A constant representing the object's type. For this resource it will always be card_authorization.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardAuthorization::type_)

Returns:



1575
# File 'lib/increase/models/card_payment.rb', line 1575

required :type, enum: -> { Increase::CardPayment::Element::CardAuthorization::Type }

#verificationIncrease::Models::CardPayment::Element::CardAuthorization::Verification

Fields related to verification of cardholder-provided values.

Parameters:

  • value (Increase::CardPayment::Element::CardAuthorization::Verification)

Returns:



1581
# File 'lib/increase/models/card_payment.rb', line 1581

required :verification, -> { Increase::CardPayment::Element::CardAuthorization::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 1709

Instance Method Details

#to_hash{

Returns:

  • ({)


1107
# File 'sig/increase/models/card_payment.rbs', line 1107

def to_hash: -> {