Class: Increase::Models::CardPayment::Element::CardAuthorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthorization
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The pending amount in the minor unit of the transaction’s currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s currency.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#expires_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) when this authorization will expire and the pending transaction will be released.
-
#id ⇒ String
The Card Authorization identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::CardPayment::Element::CardAuthorization::NetworkDetails
Fields specific to the ‘network`.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardAuthorization::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction’s presentment currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
-
#processing_category ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardAuthorization::SchemeFee>
The scheme fees associated with this card authorization.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Type
A constant representing the object’s type.
-
#verification ⇒ Increase::Models::CardPayment::Element::CardAuthorization::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 1464
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
1279 |
# File 'lib/increase/models/card_payment.rb', line 1279 required :actioner, enum: -> { Increase::CardPayment::Element::CardAuthorization::Actioner } |
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.
1287 |
# File 'lib/increase/models/card_payment.rb', line 1287 required :additional_amounts, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts } |
#amount ⇒ Integer
The pending amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
1294 |
# File 'lib/increase/models/card_payment.rb', line 1294 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
1300 |
# File 'lib/increase/models/card_payment.rb', line 1300 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s currency.
1307 |
# File 'lib/increase/models/card_payment.rb', line 1307 required :currency, enum: -> { Increase::CardPayment::Element::CardAuthorization::Currency } |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
1314 |
# File 'lib/increase/models/card_payment.rb', line 1314 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
1321 |
# File 'lib/increase/models/card_payment.rb', line 1321 required :direction, enum: -> { Increase::CardPayment::Element::CardAuthorization::Direction } |
#expires_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) when this authorization will expire and the pending transaction will be released.
1328 |
# File 'lib/increase/models/card_payment.rb', line 1328 required :expires_at, Time |
#id ⇒ String
The Card Authorization identifier.
1272 |
# File 'lib/increase/models/card_payment.rb', line 1272 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
1335 |
# File 'lib/increase/models/card_payment.rb', line 1335 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
1342 |
# File 'lib/increase/models/card_payment.rb', line 1342 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
1348 |
# File 'lib/increase/models/card_payment.rb', line 1348 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
1354 |
# File 'lib/increase/models/card_payment.rb', line 1354 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
1360 |
# File 'lib/increase/models/card_payment.rb', line 1360 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
1367 |
# File 'lib/increase/models/card_payment.rb', line 1367 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
1373 |
# File 'lib/increase/models/card_payment.rb', line 1373 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::CardPayment::Element::CardAuthorization::NetworkDetails
Fields specific to the ‘network`.
1379 |
# File 'lib/increase/models/card_payment.rb', line 1379 required :network_details, -> { Increase::CardPayment::Element::CardAuthorization::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardAuthorization::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
1385 1386 |
# File 'lib/increase/models/card_payment.rb', line 1385 required :network_identifiers, -> { Increase::CardPayment::Element::CardAuthorization::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
1394 |
# File 'lib/increase/models/card_payment.rb', line 1394 required :network_risk_score, Integer, nil?: true |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
1400 |
# File 'lib/increase/models/card_payment.rb', line 1400 required :pending_transaction_id, String, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
1407 |
# File 'lib/increase/models/card_payment.rb', line 1407 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction’s presentment currency.
1413 |
# File 'lib/increase/models/card_payment.rb', line 1413 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
1420 |
# File 'lib/increase/models/card_payment.rb', line 1420 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
1427 1428 |
# File 'lib/increase/models/card_payment.rb', line 1427 required :processing_category, enum: -> { Increase::CardPayment::Element::CardAuthorization::ProcessingCategory } |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
1435 |
# File 'lib/increase/models/card_payment.rb', line 1435 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardAuthorization::SchemeFee>
The scheme fees associated with this card authorization.
1441 1442 |
# File 'lib/increase/models/card_payment.rb', line 1441 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardAuthorization::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
1449 |
# File 'lib/increase/models/card_payment.rb', line 1449 required :terminal_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardAuthorization::Type
A constant representing the object’s type. For this resource it will always be ‘card_authorization`.
1456 |
# File 'lib/increase/models/card_payment.rb', line 1456 required :type, enum: -> { Increase::CardPayment::Element::CardAuthorization::Type } |
#verification ⇒ Increase::Models::CardPayment::Element::CardAuthorization::Verification
Fields related to verification of cardholder-provided values.
1462 |
# File 'lib/increase/models/card_payment.rb', line 1462 required :verification, -> { Increase::CardPayment::Element::CardAuthorization::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 1547
|