Class: Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision
Instance Attribute Summary collapse
-
#clinic ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
-
#dental ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
-
#original ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Original?
The original pre-authorized amount.
-
#prescription ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
-
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
-
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
-
#transit ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
-
#unknown ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Unknown?
An unknown additional amount.
-
#vision ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
Instance Method Summary collapse
-
#initialize(amount:, currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Unknown for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:) ⇒ Object
Some parameter documentations has been truncated, see Unknown for more details.
An unknown additional amount.
|
|
# File 'lib/increase/models/card_payment.rb', line 1639
|
Instance Attribute Details
#clinic ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
1557 1558 1559 |
# File 'lib/increase/models/card_payment.rb', line 1557 required :clinic, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Clinic }, nil?: true |
#dental ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
1565 1566 1567 |
# File 'lib/increase/models/card_payment.rb', line 1565 required :dental, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Dental }, nil?: true |
#original ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Original?
The original pre-authorized amount.
1573 1574 1575 |
# File 'lib/increase/models/card_payment.rb', line 1573 required :original, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Original }, nil?: true |
#prescription ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
1581 1582 1583 1584 1585 |
# File 'lib/increase/models/card_payment.rb', line 1581 required :prescription, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Prescription }, nil?: true |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
1591 1592 1593 |
# File 'lib/increase/models/card_payment.rb', line 1591 required :surcharge, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Surcharge }, nil?: true |
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
1599 1600 1601 1602 1603 |
# File 'lib/increase/models/card_payment.rb', line 1599 required :total_cumulative, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalCumulative }, nil?: true |
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
1609 1610 1611 1612 1613 |
# File 'lib/increase/models/card_payment.rb', line 1609 required :total_healthcare, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::TotalHealthcare }, nil?: true |
#transit ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
1619 1620 1621 |
# File 'lib/increase/models/card_payment.rb', line 1619 required :transit, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Transit }, nil?: true |
#unknown ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Unknown?
An unknown additional amount.
1627 1628 1629 |
# File 'lib/increase/models/card_payment.rb', line 1627 required :unknown, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Unknown }, nil?: true |
#vision ⇒ Increase::Models::CardPayment::Element::CardAuthorization::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
1635 1636 1637 |
# File 'lib/increase/models/card_payment.rb', line 1635 required :vision, -> { Increase::CardPayment::Element::CardAuthorization::AdditionalAmounts::Vision }, nil?: true |