Class: Increase::Models::CardPayment::Element::CardAuthorization::NetworkDetails::Visa

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardAuthorization::NetworkDetails::Visa for more details.

Fields specific to the ‘visa` network.

Parameters:



# File 'lib/increase/models/card_payment.rb', line 2155

Instance Attribute Details

#electronic_commerce_indicatorSymbol, ...

For electronic commerce transactions, this identifies the level of security used in obtaining the customer’s payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.



2113
2114
2115
2116
2117
# File 'lib/increase/models/card_payment.rb', line 2113

required :electronic_commerce_indicator,
enum: -> {
  Increase::CardPayment::Element::CardAuthorization::NetworkDetails::Visa::ElectronicCommerceIndicator
},
nil?: true

#point_of_service_entry_modeSymbol, ...

The method used to enter the cardholder’s primary account number and card expiration date.



2124
2125
2126
2127
2128
# File 'lib/increase/models/card_payment.rb', line 2124

required :point_of_service_entry_mode,
enum: -> {
  Increase::CardPayment::Element::CardAuthorization::NetworkDetails::Visa::PointOfServiceEntryMode
},
nil?: true

#stand_in_processing_reasonSymbol, ...

Only present when ‘actioner: network`. Describes why a card authorization was approved or declined by Visa through stand-in processing.



2135
2136
2137
2138
2139
# File 'lib/increase/models/card_payment.rb', line 2135

required :stand_in_processing_reason,
enum: -> {
  Increase::CardPayment::Element::CardAuthorization::NetworkDetails::Visa::StandInProcessingReason
},
nil?: true

#terminal_entry_capabilitySymbol, ...

The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.



2149
2150
2151
2152
2153
# File 'lib/increase/models/card_payment.rb', line 2149

required :terminal_entry_capability,
enum: -> {
  Increase::CardPayment::Element::CardAuthorization::NetworkDetails::Visa::TerminalEntryCapability
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 2203