Class: Increase::Models::CardPayment::Element::CardBalanceInquiry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardBalanceInquiry
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: Currency, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#balance ⇒ Integer
The balance amount in the minor unit of the account's currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Currency
The ISO 4217 code for the account's currency.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#id ⇒ String
The Card Balance Inquiry identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::NetworkDetails
Fields specific to the
network. -
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardBalanceInquiry::SchemeFee>
The scheme fees associated with this card balance inquiry.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Type
A constant representing the object's type.
-
#verification ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for a specific request or transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 3238
|
Instance Attribute Details
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM
surcharges fees. These are usually a subset of the amount field and are used
to provide more detailed information about the transaction.
3102 |
# File 'lib/increase/models/card_payment.rb', line 3102 required :additional_amounts, -> { Increase::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts } |
#balance ⇒ Integer
The balance amount in the minor unit of the account's currency. For dollars, for example, this is cents.
3109 |
# File 'lib/increase/models/card_payment.rb', line 3109 required :balance, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
3115 |
# File 'lib/increase/models/card_payment.rb', line 3115 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Currency
The ISO 4217 code for the account's currency.
3122 |
# File 'lib/increase/models/card_payment.rb', line 3122 required :currency, enum: -> { Increase::CardPayment::Element::CardBalanceInquiry::Currency } |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
3129 |
# File 'lib/increase/models/card_payment.rb', line 3129 required :digital_wallet_token_id, String, nil?: true |
#id ⇒ String
The Card Balance Inquiry identifier.
3094 |
# File 'lib/increase/models/card_payment.rb', line 3094 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
3136 |
# File 'lib/increase/models/card_payment.rb', line 3136 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
3143 |
# File 'lib/increase/models/card_payment.rb', line 3143 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
3149 |
# File 'lib/increase/models/card_payment.rb', line 3149 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
3155 |
# File 'lib/increase/models/card_payment.rb', line 3155 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
3161 |
# File 'lib/increase/models/card_payment.rb', line 3161 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
3168 |
# File 'lib/increase/models/card_payment.rb', line 3168 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
3174 |
# File 'lib/increase/models/card_payment.rb', line 3174 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::NetworkDetails
Fields specific to the network.
3180 |
# File 'lib/increase/models/card_payment.rb', line 3180 required :network_details, -> { Increase::CardPayment::Element::CardBalanceInquiry::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
3186 3187 |
# File 'lib/increase/models/card_payment.rb', line 3186 required :network_identifiers, -> { Increase::CardPayment::Element::CardBalanceInquiry::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
3195 |
# File 'lib/increase/models/card_payment.rb', line 3195 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
3202 |
# File 'lib/increase/models/card_payment.rb', line 3202 required :physical_card_id, String, nil?: true |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
3209 |
# File 'lib/increase/models/card_payment.rb', line 3209 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardBalanceInquiry::SchemeFee>
The scheme fees associated with this card balance inquiry.
3215 3216 |
# File 'lib/increase/models/card_payment.rb', line 3215 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardBalanceInquiry::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
3223 |
# File 'lib/increase/models/card_payment.rb', line 3223 required :terminal_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Type
A constant representing the object's type. For this resource it will always be
card_balance_inquiry.
3230 |
# File 'lib/increase/models/card_payment.rb', line 3230 required :type, enum: -> { Increase::CardPayment::Element::CardBalanceInquiry::Type } |
#verification ⇒ Increase::Models::CardPayment::Element::CardBalanceInquiry::Verification
Fields related to verification of cardholder-provided values.
3236 |
# File 'lib/increase/models/card_payment.rb', line 3236 required :verification, -> { Increase::CardPayment::Element::CardBalanceInquiry::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 3753
|
Instance Method Details
#to_hash ⇒ {
2246 |
# File 'sig/increase/models/card_payment.rbs', line 2246
def to_hash: -> {
|