Class: Increase::Models::CardPayment::Element::CardBalanceInquiry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

Defined Under Namespace

Modules: Currency, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see NetworkIdentifiers for more details.

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code se

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expec

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used acro



# File 'lib/increase/models/card_payment.rb', line 2986

Instance Attribute Details

#additional_amountsIncrease::Models::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.



2850
# File 'lib/increase/models/card_payment.rb', line 2850

required :additional_amounts, -> { Increase::CardPayment::Element::CardBalanceInquiry::AdditionalAmounts }

#balanceInteger

The balance amount in the minor unit of the account’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


2857
# File 'lib/increase/models/card_payment.rb', line 2857

required :balance, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Returns:

  • (String)


2863
# File 'lib/increase/models/card_payment.rb', line 2863

required :card_payment_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the account’s currency.



2870
# File 'lib/increase/models/card_payment.rb', line 2870

required :currency, enum: -> { Increase::CardPayment::Element::CardBalanceInquiry::Currency }

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Returns:

  • (String, nil)


2877
# File 'lib/increase/models/card_payment.rb', line 2877

required :digital_wallet_token_id, String, nil?: true

#idString

The Card Balance Inquiry identifier.

Returns:

  • (String)


2842
# File 'lib/increase/models/card_payment.rb', line 2842

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


2884
# File 'lib/increase/models/card_payment.rb', line 2884

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Returns:

  • (String)


2891
# File 'lib/increase/models/card_payment.rb', line 2891

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Returns:

  • (String, nil)


2897
# File 'lib/increase/models/card_payment.rb', line 2897

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


2903
# File 'lib/increase/models/card_payment.rb', line 2903

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Returns:

  • (String)


2909
# File 'lib/increase/models/card_payment.rb', line 2909

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Returns:

  • (String, nil)


2916
# File 'lib/increase/models/card_payment.rb', line 2916

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


2922
# File 'lib/increase/models/card_payment.rb', line 2922

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::CardPayment::Element::CardBalanceInquiry::NetworkDetails

Fields specific to the ‘network`.



2928
# File 'lib/increase/models/card_payment.rb', line 2928

required :network_details, -> { Increase::CardPayment::Element::CardBalanceInquiry::NetworkDetails }

#network_identifiersIncrease::Models::CardPayment::Element::CardBalanceInquiry::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.



2934
2935
# File 'lib/increase/models/card_payment.rb', line 2934

required :network_identifiers,
-> { Increase::CardPayment::Element::CardBalanceInquiry::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Returns:

  • (Integer, nil)


2943
# File 'lib/increase/models/card_payment.rb', line 2943

required :network_risk_score, Integer, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Returns:

  • (String, nil)


2950
# File 'lib/increase/models/card_payment.rb', line 2950

required :physical_card_id, String, nil?: true

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this transaction.

Returns:

  • (String, nil)


2957
# File 'lib/increase/models/card_payment.rb', line 2957

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardBalanceInquiry::SchemeFee>

The scheme fees associated with this card balance inquiry.



2963
2964
# File 'lib/increase/models/card_payment.rb', line 2963

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardBalanceInquiry::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Returns:

  • (String, nil)


2971
# File 'lib/increase/models/card_payment.rb', line 2971

required :terminal_id, String, nil?: true

#typeSymbol, Increase::Models::CardPayment::Element::CardBalanceInquiry::Type

A constant representing the object’s type. For this resource it will always be ‘card_balance_inquiry`.



2978
# File 'lib/increase/models/card_payment.rb', line 2978

required :type, enum: -> { Increase::CardPayment::Element::CardBalanceInquiry::Type }

#verificationIncrease::Models::CardPayment::Element::CardBalanceInquiry::Verification

Fields related to verification of cardholder-provided values.



2984
# File 'lib/increase/models/card_payment.rb', line 2984

required :verification, -> { Increase::CardPayment::Element::CardBalanceInquiry::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 3458