Class: Increase::Models::CardPayment::Element::CardDecline
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardDecline
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: Actioner, Currency, Direction, ProcessingCategory, RealTimeDecisionReason, Reason Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The declined amount in the minor unit of the destination account currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the destination account currency.
-
#declined_transaction_id ⇒ String
The identifier of the declined transaction created for this Card Decline.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#id ⇒ String
The Card Decline identifier.
-
#incremented_card_authorization_id ⇒ String?
The identifier of the card authorization this request attempted to incrementally authorize.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::CardPayment::Element::CardDecline::NetworkDetails
Fields specific to the ‘network`.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardDecline::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The declined amount in the minor unit of the transaction’s presentment currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
-
#processing_category ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#real_time_decision_reason ⇒ Symbol, ...
This is present if a specific decline reason was given in the real-time decision.
-
#reason ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Reason
Why the transaction was declined.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardDecline::SchemeFee>
The scheme fees associated with this card decline.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#verification ⇒ Increase::Models::CardPayment::Element::CardDecline::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 4420
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
4228 |
# File 'lib/increase/models/card_payment.rb', line 4228 required :actioner, enum: -> { Increase::CardPayment::Element::CardDecline::Actioner } |
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardDecline::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.
4236 |
# File 'lib/increase/models/card_payment.rb', line 4236 required :additional_amounts, -> { Increase::CardPayment::Element::CardDecline::AdditionalAmounts } |
#amount ⇒ Integer
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
4243 |
# File 'lib/increase/models/card_payment.rb', line 4243 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
4249 |
# File 'lib/increase/models/card_payment.rb', line 4249 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the destination account currency.
4256 |
# File 'lib/increase/models/card_payment.rb', line 4256 required :currency, enum: -> { Increase::CardPayment::Element::CardDecline::Currency } |
#declined_transaction_id ⇒ String
The identifier of the declined transaction created for this Card Decline.
4262 |
# File 'lib/increase/models/card_payment.rb', line 4262 required :declined_transaction_id, String |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
4269 |
# File 'lib/increase/models/card_payment.rb', line 4269 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
4276 |
# File 'lib/increase/models/card_payment.rb', line 4276 required :direction, enum: -> { Increase::CardPayment::Element::CardDecline::Direction } |
#id ⇒ String
The Card Decline identifier.
4221 |
# File 'lib/increase/models/card_payment.rb', line 4221 required :id, String |
#incremented_card_authorization_id ⇒ String?
The identifier of the card authorization this request attempted to incrementally authorize.
4283 |
# File 'lib/increase/models/card_payment.rb', line 4283 required :incremented_card_authorization_id, String, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
4290 |
# File 'lib/increase/models/card_payment.rb', line 4290 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
4297 |
# File 'lib/increase/models/card_payment.rb', line 4297 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
4303 |
# File 'lib/increase/models/card_payment.rb', line 4303 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
4309 |
# File 'lib/increase/models/card_payment.rb', line 4309 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
4315 |
# File 'lib/increase/models/card_payment.rb', line 4315 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
4322 |
# File 'lib/increase/models/card_payment.rb', line 4322 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
4328 |
# File 'lib/increase/models/card_payment.rb', line 4328 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::CardPayment::Element::CardDecline::NetworkDetails
Fields specific to the ‘network`.
4334 |
# File 'lib/increase/models/card_payment.rb', line 4334 required :network_details, -> { Increase::CardPayment::Element::CardDecline::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardDecline::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
4340 |
# File 'lib/increase/models/card_payment.rb', line 4340 required :network_identifiers, -> { Increase::CardPayment::Element::CardDecline::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
4348 |
# File 'lib/increase/models/card_payment.rb', line 4348 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
4355 |
# File 'lib/increase/models/card_payment.rb', line 4355 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The declined amount in the minor unit of the transaction’s presentment currency.
4361 |
# File 'lib/increase/models/card_payment.rb', line 4361 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
4368 |
# File 'lib/increase/models/card_payment.rb', line 4368 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
4375 4376 |
# File 'lib/increase/models/card_payment.rb', line 4375 required :processing_category, enum: -> { Increase::CardPayment::Element::CardDecline::ProcessingCategory } |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
4383 |
# File 'lib/increase/models/card_payment.rb', line 4383 required :real_time_decision_id, String, nil?: true |
#real_time_decision_reason ⇒ Symbol, ...
This is present if a specific decline reason was given in the real-time decision.
4390 4391 4392 |
# File 'lib/increase/models/card_payment.rb', line 4390 required :real_time_decision_reason, enum: -> { Increase::CardPayment::Element::CardDecline::RealTimeDecisionReason }, nil?: true |
#reason ⇒ Symbol, Increase::Models::CardPayment::Element::CardDecline::Reason
Why the transaction was declined.
4398 |
# File 'lib/increase/models/card_payment.rb', line 4398 required :reason, enum: -> { Increase::CardPayment::Element::CardDecline::Reason } |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardDecline::SchemeFee>
The scheme fees associated with this card decline.
4404 4405 |
# File 'lib/increase/models/card_payment.rb', line 4404 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardDecline::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
4412 |
# File 'lib/increase/models/card_payment.rb', line 4412 required :terminal_id, String, nil?: true |
#verification ⇒ Increase::Models::CardPayment::Element::CardDecline::Verification
Fields related to verification of cardholder-provided values.
4418 |
# File 'lib/increase/models/card_payment.rb', line 4418 required :verification, -> { Increase::CardPayment::Element::CardDecline::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 4503
|