Class: Increase::Models::CardPayment::Element::CardDecline::NetworkDetails::Visa
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardDecline::NetworkDetails::Visa
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability
Instance Attribute Summary collapse
-
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential.
-
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder's primary account number and card expiration date.
-
#stand_in_processing_reason ⇒ Symbol, ...
Only present when
actioner: network. -
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
constructor
Fields specific to the
visanetwork. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
Fields specific to the visa network.
|
|
# File 'lib/increase/models/card_payment.rb', line 5372
|
Instance Attribute Details
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
5330 5331 5332 5333 5334 |
# File 'lib/increase/models/card_payment.rb', line 5330 required :electronic_commerce_indicator, enum: -> { Increase::CardPayment::Element::CardDecline::NetworkDetails::Visa::ElectronicCommerceIndicator }, nil?: true |
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder's primary account number and card expiration date.
5341 5342 5343 5344 5345 |
# File 'lib/increase/models/card_payment.rb', line 5341 required :point_of_service_entry_mode, enum: -> { Increase::CardPayment::Element::CardDecline::NetworkDetails::Visa::PointOfServiceEntryMode }, nil?: true |
#stand_in_processing_reason ⇒ Symbol, ...
Only present when actioner: network. Describes why a card authorization was
approved or declined by Visa through stand-in processing.
5352 5353 5354 5355 5356 |
# File 'lib/increase/models/card_payment.rb', line 5352 required :stand_in_processing_reason, enum: -> { Increase::CardPayment::Element::CardDecline::NetworkDetails::Visa::StandInProcessingReason }, nil?: true |
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
5366 5367 5368 5369 5370 |
# File 'lib/increase/models/card_payment.rb', line 5366 required :terminal_entry_capability, enum: -> { Increase::CardPayment::Element::CardDecline::NetworkDetails::Visa::TerminalEntryCapability }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 5428
|
Instance Method Details
#to_hash ⇒ {
3547 |
# File 'sig/increase/models/card_payment.rbs', line 3547
def to_hash: -> {
|