Class: Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision
Instance Attribute Summary collapse
-
#clinic ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
-
#dental ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
-
#original ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Original?
The original pre-authorized amount.
-
#prescription ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
-
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
-
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
-
#transit ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
-
#unknown ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Unknown?
An unknown additional amount.
-
#vision ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
Instance Method Summary collapse
-
#initialize(amount:, currency:) ⇒ Object
constructor
An unknown additional amount.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:) ⇒ Object
An unknown additional amount.
|
|
# File 'lib/increase/models/card_payment.rb', line 6512
|
Instance Attribute Details
#clinic ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
6436 6437 6438 |
# File 'lib/increase/models/card_payment.rb', line 6436 required :clinic, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Clinic }, nil?: true |
#dental ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
6444 6445 6446 |
# File 'lib/increase/models/card_payment.rb', line 6444 required :dental, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Dental }, nil?: true |
#original ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Original?
The original pre-authorized amount.
6452 6453 6454 |
# File 'lib/increase/models/card_payment.rb', line 6452 required :original, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Original }, nil?: true |
#prescription ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
6460 6461 6462 |
# File 'lib/increase/models/card_payment.rb', line 6460 required :prescription, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Prescription }, nil?: true |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
6468 6469 6470 |
# File 'lib/increase/models/card_payment.rb', line 6468 required :surcharge, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Surcharge }, nil?: true |
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
6476 6477 6478 |
# File 'lib/increase/models/card_payment.rb', line 6476 required :total_cumulative, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalCumulative }, nil?: true |
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
6484 6485 6486 |
# File 'lib/increase/models/card_payment.rb', line 6484 required :total_healthcare, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::TotalHealthcare }, nil?: true |
#transit ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
6492 6493 6494 |
# File 'lib/increase/models/card_payment.rb', line 6492 required :transit, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Transit }, nil?: true |
#unknown ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Unknown?
An unknown additional amount.
6500 6501 6502 |
# File 'lib/increase/models/card_payment.rb', line 6500 required :unknown, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Unknown }, nil?: true |
#vision ⇒ Increase::Models::CardPayment::Element::CardFinancial::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
6508 6509 6510 |
# File 'lib/increase/models/card_payment.rb', line 6508 required :vision, -> { Increase::CardPayment::Element::CardFinancial::AdditionalAmounts::Vision }, nil?: true |
Instance Method Details
#to_hash ⇒ {
4483 |
# File 'sig/increase/models/card_payment.rbs', line 4483
def to_hash: -> {
|