Class: Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails::Visa

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails#visa

Defined Under Namespace

Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object

Fields specific to the visa network.

Parameters:



# File 'lib/increase/models/card_payment.rb', line 6991

Instance Attribute Details

#electronic_commerce_indicatorSymbol, ...

For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails::Visa::electronic_commerce_indicator, nil)

Returns:



6949
6950
6951
6952
6953
# File 'lib/increase/models/card_payment.rb', line 6949

required :electronic_commerce_indicator,
enum: -> {
  Increase::CardPayment::Element::CardFinancial::NetworkDetails::Visa::ElectronicCommerceIndicator
},
nil?: true

#point_of_service_entry_modeSymbol, ...

The method used to enter the cardholder's primary account number and card expiration date.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails::Visa::point_of_service_entry_mode, nil)

Returns:



6960
6961
6962
6963
6964
# File 'lib/increase/models/card_payment.rb', line 6960

required :point_of_service_entry_mode,
enum: -> {
  Increase::CardPayment::Element::CardFinancial::NetworkDetails::Visa::PointOfServiceEntryMode
},
nil?: true

#stand_in_processing_reasonSymbol, ...

Only present when actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails::Visa::stand_in_processing_reason, nil)

Returns:



6971
6972
6973
6974
6975
# File 'lib/increase/models/card_payment.rb', line 6971

required :stand_in_processing_reason,
enum: -> {
  Increase::CardPayment::Element::CardFinancial::NetworkDetails::Visa::StandInProcessingReason
},
nil?: true

#terminal_entry_capabilitySymbol, ...

The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardFinancial::NetworkDetails::Visa::terminal_entry_capability, nil)

Returns:



6985
6986
6987
6988
6989
# File 'lib/increase/models/card_payment.rb', line 6985

required :terminal_entry_capability,
enum: -> {
  Increase::CardPayment::Element::CardFinancial::NetworkDetails::Visa::TerminalEntryCapability
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 7047

Instance Method Details

#to_hash{

Returns:

  • ({)


4714
# File 'sig/increase/models/card_payment.rbs', line 4714

def to_hash: -> {