Class: Increase::Models::CardPayment::Element::CardFuelConfirmation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

Defined Under Namespace

Modules: Currency, Network, Type Classes: NetworkIdentifiers, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see NetworkIdentifiers for more details.

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code se

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expec

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used acro



# File 'lib/increase/models/card_payment.rb', line 7221

Instance Attribute Details

#card_authorization_idString

The identifier for the Card Authorization this updates.

Returns:

  • (String)


7171
# File 'lib/increase/models/card_payment.rb', line 7171

required :card_authorization_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardFuelConfirmation::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the increment’s currency.



7178
# File 'lib/increase/models/card_payment.rb', line 7178

required :currency, enum: -> { Increase::CardPayment::Element::CardFuelConfirmation::Currency }

#idString

The Card Fuel Confirmation identifier.

Returns:

  • (String)


7165
# File 'lib/increase/models/card_payment.rb', line 7165

required :id, String

#networkSymbol, Increase::Models::CardPayment::Element::CardFuelConfirmation::Network

The card network used to process this card authorization.



7184
# File 'lib/increase/models/card_payment.rb', line 7184

required :network, enum: -> { Increase::CardPayment::Element::CardFuelConfirmation::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardFuelConfirmation::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.



7190
7191
# File 'lib/increase/models/card_payment.rb', line 7190

required :network_identifiers,
-> { Increase::CardPayment::Element::CardFuelConfirmation::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Card Fuel Confirmation.

Returns:

  • (String, nil)


7198
# File 'lib/increase/models/card_payment.rb', line 7198

required :pending_transaction_id, String, nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardFuelConfirmation::SchemeFee>

The scheme fees associated with this card fuel confirmation.



7204
7205
# File 'lib/increase/models/card_payment.rb', line 7204

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardFuelConfirmation::SchemeFee] }

#typeSymbol, Increase::Models::CardPayment::Element::CardFuelConfirmation::Type

A constant representing the object’s type. For this resource it will always be ‘card_fuel_confirmation`.



7212
# File 'lib/increase/models/card_payment.rb', line 7212

required :type, enum: -> { Increase::CardPayment::Element::CardFuelConfirmation::Type }

#updated_authorization_amountInteger

The updated authorization amount after this fuel confirmation, in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


7219
# File 'lib/increase/models/card_payment.rb', line 7219

required :updated_authorization_amount, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 7258