Class: Increase::Models::CardPayment::Element::CardIncrement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: Actioner, Currency, Network, Type Classes: AdditionalAmounts, NetworkIdentifiers, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see NetworkIdentifiers for more details.

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code se

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expec

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used acro



# File 'lib/increase/models/card_payment.rb', line 7622

Instance Attribute Details

#actionerSymbol, Increase::Models::CardPayment::Element::CardIncrement::Actioner

Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.



7525
# File 'lib/increase/models/card_payment.rb', line 7525

required :actioner, enum: -> { Increase::CardPayment::Element::CardIncrement::Actioner }

#additional_amountsIncrease::Models::CardPayment::Element::CardIncrement::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.



7533
# File 'lib/increase/models/card_payment.rb', line 7533

required :additional_amounts, -> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts }

#amountInteger

The amount of this increment in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


7540
# File 'lib/increase/models/card_payment.rb', line 7540

required :amount, Integer

#card_authorization_idString

The identifier for the Card Authorization this increments.

Returns:

  • (String)


7546
# File 'lib/increase/models/card_payment.rb', line 7546

required :card_authorization_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardIncrement::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the increment’s currency.



7553
# File 'lib/increase/models/card_payment.rb', line 7553

required :currency, enum: -> { Increase::CardPayment::Element::CardIncrement::Currency }

#idString

The Card Increment identifier.

Returns:

  • (String)


7518
# File 'lib/increase/models/card_payment.rb', line 7518

required :id, String

#networkSymbol, Increase::Models::CardPayment::Element::CardIncrement::Network

The card network used to process this card authorization.



7559
# File 'lib/increase/models/card_payment.rb', line 7559

required :network, enum: -> { Increase::CardPayment::Element::CardIncrement::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardIncrement::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.



7565
# File 'lib/increase/models/card_payment.rb', line 7565

required :network_identifiers, -> { Increase::CardPayment::Element::CardIncrement::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.

Returns:

  • (Integer, nil)


7572
# File 'lib/increase/models/card_payment.rb', line 7572

required :network_risk_score, Integer, nil?: true

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Card Increment.

Returns:

  • (String, nil)


7578
# File 'lib/increase/models/card_payment.rb', line 7578

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount of this increment in the minor unit of the transaction’s presentment currency.

Returns:

  • (Integer)


7585
# File 'lib/increase/models/card_payment.rb', line 7585

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.

Returns:

  • (String)


7592
# File 'lib/increase/models/card_payment.rb', line 7592

required :presentment_currency, String

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.

Returns:

  • (String, nil)


7599
# File 'lib/increase/models/card_payment.rb', line 7599

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardIncrement::SchemeFee>

The scheme fees associated with this card increment.



7605
7606
# File 'lib/increase/models/card_payment.rb', line 7605

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardIncrement::SchemeFee] }

#typeSymbol, Increase::Models::CardPayment::Element::CardIncrement::Type

A constant representing the object’s type. For this resource it will always be ‘card_increment`.



7613
# File 'lib/increase/models/card_payment.rb', line 7613

required :type, enum: -> { Increase::CardPayment::Element::CardIncrement::Type }

#updated_authorization_amountInteger

The updated authorization amount after this increment, in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


7620
# File 'lib/increase/models/card_payment.rb', line 7620

required :updated_authorization_amount, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 7678