Class: Increase::Models::CardPayment::Element::CardIncrement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardIncrement
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: Actioner, Currency, Network, Type Classes: AdditionalAmounts, NetworkIdentifiers, SchemeFee
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardIncrement::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The amount of this increment in the minor unit of the transaction’s currency.
-
#card_authorization_id ⇒ String
The identifier for the Card Authorization this increments.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the increment’s currency.
-
#id ⇒ String
The Card Increment identifier.
-
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Network
The card network used to process this card authorization.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardIncrement::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Card Increment.
-
#presentment_amount ⇒ Integer
The amount of this increment in the minor unit of the transaction’s presentment currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardIncrement::SchemeFee>
The scheme fees associated with this card increment.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Type
A constant representing the object’s type.
-
#updated_authorization_amount ⇒ Integer
The updated authorization amount after this increment, in the minor unit of the transaction’s currency.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 7622
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
7525 |
# File 'lib/increase/models/card_payment.rb', line 7525 required :actioner, enum: -> { Increase::CardPayment::Element::CardIncrement::Actioner } |
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardIncrement::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.
7533 |
# File 'lib/increase/models/card_payment.rb', line 7533 required :additional_amounts, -> { Increase::CardPayment::Element::CardIncrement::AdditionalAmounts } |
#amount ⇒ Integer
The amount of this increment in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
7540 |
# File 'lib/increase/models/card_payment.rb', line 7540 required :amount, Integer |
#card_authorization_id ⇒ String
The identifier for the Card Authorization this increments.
7546 |
# File 'lib/increase/models/card_payment.rb', line 7546 required :card_authorization_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the increment’s currency.
7553 |
# File 'lib/increase/models/card_payment.rb', line 7553 required :currency, enum: -> { Increase::CardPayment::Element::CardIncrement::Currency } |
#id ⇒ String
The Card Increment identifier.
7518 |
# File 'lib/increase/models/card_payment.rb', line 7518 required :id, String |
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Network
The card network used to process this card authorization.
7559 |
# File 'lib/increase/models/card_payment.rb', line 7559 required :network, enum: -> { Increase::CardPayment::Element::CardIncrement::Network } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardIncrement::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
7565 |
# File 'lib/increase/models/card_payment.rb', line 7565 required :network_identifiers, -> { Increase::CardPayment::Element::CardIncrement::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
7572 |
# File 'lib/increase/models/card_payment.rb', line 7572 required :network_risk_score, Integer, nil?: true |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Card Increment.
7578 |
# File 'lib/increase/models/card_payment.rb', line 7578 required :pending_transaction_id, String, nil?: true |
#presentment_amount ⇒ Integer
The amount of this increment in the minor unit of the transaction’s presentment currency.
7585 |
# File 'lib/increase/models/card_payment.rb', line 7585 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
7592 |
# File 'lib/increase/models/card_payment.rb', line 7592 required :presentment_currency, String |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
7599 |
# File 'lib/increase/models/card_payment.rb', line 7599 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardIncrement::SchemeFee>
The scheme fees associated with this card increment.
7605 7606 |
# File 'lib/increase/models/card_payment.rb', line 7605 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardIncrement::SchemeFee] } |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardIncrement::Type
A constant representing the object’s type. For this resource it will always be ‘card_increment`.
7613 |
# File 'lib/increase/models/card_payment.rb', line 7613 required :type, enum: -> { Increase::CardPayment::Element::CardIncrement::Type } |
#updated_authorization_amount ⇒ Integer
The updated authorization amount after this increment, in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
7620 |
# File 'lib/increase/models/card_payment.rb', line 7620 required :updated_authorization_amount, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 7678
|