Class: Increase::Models::CardPayment::Element::CardRefund

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: Currency, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see NetworkIdentifiers for more details.

Network-specific identifiers for this refund.

Parameters:

  • acquirer_business_id (String)

    A network assigned business ID that identifies the acquirer that processed this

  • acquirer_reference_number (String)

    A globally unique identifier for this settlement.

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code se

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used acro



# File 'lib/increase/models/card_payment.rb', line 8541

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


8420
# File 'lib/increase/models/card_payment.rb', line 8420

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Returns:

  • (String)


8426
# File 'lib/increase/models/card_payment.rb', line 8426

required :card_payment_id, String

#cashbackIncrease::Models::CardPayment::Element::CardRefund::Cashback?

Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.



8433
# File 'lib/increase/models/card_payment.rb', line 8433

required :cashback, -> { Increase::CardPayment::Element::CardRefund::Cashback }, nil?: true

#currencySymbol, Increase::Models::CardPayment::Element::CardRefund::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.



8440
# File 'lib/increase/models/card_payment.rb', line 8440

required :currency, enum: -> { Increase::CardPayment::Element::CardRefund::Currency }

#idString

The Card Refund identifier.

Returns:

  • (String)


8413
# File 'lib/increase/models/card_payment.rb', line 8413

required :id, String

#interchangeIncrease::Models::CardPayment::Element::CardRefund::Interchange?

Interchange assessed as a part of this transaction.



8446
# File 'lib/increase/models/card_payment.rb', line 8446

required :interchange, -> { Increase::CardPayment::Element::CardRefund::Interchange }, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


8453
# File 'lib/increase/models/card_payment.rb', line 8453

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant’s business.

Returns:

  • (String)


8459
# File 'lib/increase/models/card_payment.rb', line 8459

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Returns:

  • (String)


8465
# File 'lib/increase/models/card_payment.rb', line 8465

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


8471
# File 'lib/increase/models/card_payment.rb', line 8471

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Returns:

  • (String)


8477
# File 'lib/increase/models/card_payment.rb', line 8477

required :merchant_name, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.

Returns:

  • (String, nil)


8483
# File 'lib/increase/models/card_payment.rb', line 8483

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


8489
# File 'lib/increase/models/card_payment.rb', line 8489

required :merchant_state, String, nil?: true

#network_identifiersIncrease::Models::CardPayment::Element::CardRefund::NetworkIdentifiers

Network-specific identifiers for this refund.



8495
# File 'lib/increase/models/card_payment.rb', line 8495

required :network_identifiers, -> { Increase::CardPayment::Element::CardRefund::NetworkIdentifiers }

#presentment_amountInteger

The amount in the minor unit of the transaction’s presentment currency.

Returns:

  • (Integer)


8501
# File 'lib/increase/models/card_payment.rb', line 8501

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.

Returns:

  • (String)


8508
# File 'lib/increase/models/card_payment.rb', line 8508

required :presentment_currency, String

#purchase_detailsIncrease::Models::CardPayment::Element::CardRefund::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.



8515
8516
8517
8518
8519
# File 'lib/increase/models/card_payment.rb', line 8515

required :purchase_details,
-> {
  Increase::CardPayment::Element::CardRefund::PurchaseDetails
},
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardRefund::SchemeFee>

The scheme fees associated with this card refund.



8525
8526
# File 'lib/increase/models/card_payment.rb', line 8525

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardRefund::SchemeFee] }

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Returns:

  • (String)


8532
# File 'lib/increase/models/card_payment.rb', line 8532

required :transaction_id, String

#typeSymbol, Increase::Models::CardPayment::Element::CardRefund::Type

A constant representing the object’s type. For this resource it will always be ‘card_refund`.



8539
# File 'lib/increase/models/card_payment.rb', line 8539

required :type, enum: -> { Increase::CardPayment::Element::CardRefund::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 8627