Class: Increase::Models::CardPayment::Element::CardRefund
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardRefund
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: Currency, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction’s settlement currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cashback ⇒ Increase::Models::CardPayment::Element::CardRefund::Cashback?
Cashback debited for this transaction, if eligible.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardRefund::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.
-
#id ⇒ String
The Card Refund identifier.
-
#interchange ⇒ Increase::Models::CardPayment::Element::CardRefund::Interchange?
Interchange assessed as a part of this transaction.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant’s business.
-
#merchant_city ⇒ String
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_name ⇒ String
The name of the merchant.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardRefund::NetworkIdentifiers
Network-specific identifiers for this refund.
-
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction’s presentment currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
-
#purchase_details ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardRefund::SchemeFee>
The scheme fees associated with this card refund.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardRefund::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for this refund.
|
|
# File 'lib/increase/models/card_payment.rb', line 8482
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.
8361 |
# File 'lib/increase/models/card_payment.rb', line 8361 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
8367 |
# File 'lib/increase/models/card_payment.rb', line 8367 required :card_payment_id, String |
#cashback ⇒ Increase::Models::CardPayment::Element::CardRefund::Cashback?
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
8374 |
# File 'lib/increase/models/card_payment.rb', line 8374 required :cashback, -> { Increase::CardPayment::Element::CardRefund::Cashback }, nil?: true |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardRefund::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.
8381 |
# File 'lib/increase/models/card_payment.rb', line 8381 required :currency, enum: -> { Increase::CardPayment::Element::CardRefund::Currency } |
#id ⇒ String
The Card Refund identifier.
8354 |
# File 'lib/increase/models/card_payment.rb', line 8354 required :id, String |
#interchange ⇒ Increase::Models::CardPayment::Element::CardRefund::Interchange?
Interchange assessed as a part of this transaction.
8387 |
# File 'lib/increase/models/card_payment.rb', line 8387 required :interchange, -> { Increase::CardPayment::Element::CardRefund::Interchange }, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
8394 |
# File 'lib/increase/models/card_payment.rb', line 8394 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant’s business.
8400 |
# File 'lib/increase/models/card_payment.rb', line 8400 required :merchant_category_code, String |
#merchant_city ⇒ String
The city the merchant resides in.
8406 |
# File 'lib/increase/models/card_payment.rb', line 8406 required :merchant_city, String |
#merchant_country ⇒ String
The country the merchant resides in.
8412 |
# File 'lib/increase/models/card_payment.rb', line 8412 required :merchant_country, String |
#merchant_name ⇒ String
The name of the merchant.
8418 |
# File 'lib/increase/models/card_payment.rb', line 8418 required :merchant_name, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.
8424 |
# File 'lib/increase/models/card_payment.rb', line 8424 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
8430 |
# File 'lib/increase/models/card_payment.rb', line 8430 required :merchant_state, String, nil?: true |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardRefund::NetworkIdentifiers
Network-specific identifiers for this refund.
8436 |
# File 'lib/increase/models/card_payment.rb', line 8436 required :network_identifiers, -> { Increase::CardPayment::Element::CardRefund::NetworkIdentifiers } |
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction’s presentment currency.
8442 |
# File 'lib/increase/models/card_payment.rb', line 8442 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
8449 |
# File 'lib/increase/models/card_payment.rb', line 8449 required :presentment_currency, String |
#purchase_details ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
8456 8457 8458 8459 8460 |
# File 'lib/increase/models/card_payment.rb', line 8456 required :purchase_details, -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardRefund::SchemeFee>
The scheme fees associated with this card refund.
8466 8467 |
# File 'lib/increase/models/card_payment.rb', line 8466 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardRefund::SchemeFee] } |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
8473 |
# File 'lib/increase/models/card_payment.rb', line 8473 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardRefund::Type
A constant representing the object’s type. For this resource it will always be ‘card_refund`.
8480 |
# File 'lib/increase/models/card_payment.rb', line 8480 required :type, enum: -> { Increase::CardPayment::Element::CardRefund::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 8568
|