Class: Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel
Instance Attribute Summary collapse
-
#car_rental ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::CarRental?
Fields specific to car rentals.
-
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
-
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
-
#local_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.
-
#lodging ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Lodging?
Fields specific to lodging.
-
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
-
#national_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.
-
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
-
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
-
#travel ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel?
Fields specific to travel.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PurchaseDetails for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails for more details.
Additional details about the card purchase, such as tax and industry-specific fields.
|
|
# File 'lib/increase/models/card_payment.rb', line 8762
|
Instance Attribute Details
#car_rental ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::CarRental?
Fields specific to car rentals.
8690 8691 8692 |
# File 'lib/increase/models/card_payment.rb', line 8690 required :car_rental, -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::CarRental }, nil?: true |
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
8698 |
# File 'lib/increase/models/card_payment.rb', line 8698 required :customer_reference_identifier, String, nil?: true |
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
8704 |
# File 'lib/increase/models/card_payment.rb', line 8704 required :local_tax_amount, Integer, nil?: true |
#local_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.
8711 |
# File 'lib/increase/models/card_payment.rb', line 8711 required :local_tax_currency, String, nil?: true |
#lodging ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Lodging?
Fields specific to lodging.
8717 8718 8719 8720 8721 |
# File 'lib/increase/models/card_payment.rb', line 8717 required :lodging, -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Lodging }, nil?: true |
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
8727 |
# File 'lib/increase/models/card_payment.rb', line 8727 required :national_tax_amount, Integer, nil?: true |
#national_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.
8734 |
# File 'lib/increase/models/card_payment.rb', line 8734 required :national_tax_currency, String, nil?: true |
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
8740 |
# File 'lib/increase/models/card_payment.rb', line 8740 required :purchase_identifier, String, nil?: true |
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
8746 8747 8748 8749 8750 |
# File 'lib/increase/models/card_payment.rb', line 8746 required :purchase_identifier_format, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::PurchaseIdentifierFormat }, nil?: true |
#travel ⇒ Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Travel?
Fields specific to travel.
8756 8757 8758 8759 8760 |
# File 'lib/increase/models/card_payment.rb', line 8756 required :travel, -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Travel }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 8984
|