Class: Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::CarRental
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::CarRental
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: ExtraCharges, NoShowIndicator
Instance Attribute Summary collapse
-
#car_class_code ⇒ String?
Code indicating the vehicle’s class.
-
#checkout_date ⇒ Date?
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
-
#daily_rental_rate_amount ⇒ Integer?
Daily rate being charged for the vehicle.
-
#daily_rental_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily rental rate.
-
#days_rented ⇒ Integer?
Number of days the vehicle was rented.
-
#extra_charges ⇒ Symbol, ...
Additional charges (gas, late fee, etc.) being billed.
-
#fuel_charges_amount ⇒ Integer?
Fuel charges for the vehicle.
-
#fuel_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fuel charges assessed.
-
#insurance_charges_amount ⇒ Integer?
Any insurance being charged for the vehicle.
-
#insurance_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the insurance charges assessed.
-
#no_show_indicator ⇒ Symbol, ...
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a “no-show” charge).
-
#one_way_drop_off_charges_amount ⇒ Integer?
Charges for returning the vehicle at a different location than where it was picked up.
-
#one_way_drop_off_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the one-way drop-off charges assessed.
-
#renter_name ⇒ String?
Name of the person renting the vehicle.
-
#weekly_rental_rate_amount ⇒ Integer?
Weekly rate being charged for the vehicle.
-
#weekly_rental_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the weekly rental rate.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_class_code:, checkout_date:, daily_rental_rate_amount:, daily_rental_rate_currency:, days_rented:, extra_charges:, fuel_charges_amount:, fuel_charges_currency:, insurance_charges_amount:, insurance_charges_currency:, no_show_indicator:, one_way_drop_off_charges_amount:, one_way_drop_off_charges_currency:, renter_name:, weekly_rental_rate_amount:, weekly_rental_rate_currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CarRental for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_class_code:, checkout_date:, daily_rental_rate_amount:, daily_rental_rate_currency:, days_rented:, extra_charges:, fuel_charges_amount:, fuel_charges_currency:, insurance_charges_amount:, insurance_charges_currency:, no_show_indicator:, one_way_drop_off_charges_amount:, one_way_drop_off_charges_currency:, renter_name:, weekly_rental_rate_amount:, weekly_rental_rate_currency:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::CarRental for more details.
Fields specific to car rentals.
|
|
# File 'lib/increase/models/card_payment.rb', line 8904
|
Instance Attribute Details
#car_class_code ⇒ String?
Code indicating the vehicle’s class.
8796 |
# File 'lib/increase/models/card_payment.rb', line 8796 required :car_class_code, String, nil?: true |
#checkout_date ⇒ Date?
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
8803 |
# File 'lib/increase/models/card_payment.rb', line 8803 required :checkout_date, Date, nil?: true |
#daily_rental_rate_amount ⇒ Integer?
Daily rate being charged for the vehicle.
8809 |
# File 'lib/increase/models/card_payment.rb', line 8809 required :daily_rental_rate_amount, Integer, nil?: true |
#daily_rental_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily rental rate.
8816 |
# File 'lib/increase/models/card_payment.rb', line 8816 required :daily_rental_rate_currency, String, nil?: true |
#days_rented ⇒ Integer?
Number of days the vehicle was rented.
8822 |
# File 'lib/increase/models/card_payment.rb', line 8822 required :days_rented, Integer, nil?: true |
#extra_charges ⇒ Symbol, ...
Additional charges (gas, late fee, etc.) being billed.
8828 8829 8830 8831 8832 |
# File 'lib/increase/models/card_payment.rb', line 8828 required :extra_charges, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::CarRental::ExtraCharges }, nil?: true |
#fuel_charges_amount ⇒ Integer?
Fuel charges for the vehicle.
8838 |
# File 'lib/increase/models/card_payment.rb', line 8838 required :fuel_charges_amount, Integer, nil?: true |
#fuel_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fuel charges assessed.
8845 |
# File 'lib/increase/models/card_payment.rb', line 8845 required :fuel_charges_currency, String, nil?: true |
#insurance_charges_amount ⇒ Integer?
Any insurance being charged for the vehicle.
8851 |
# File 'lib/increase/models/card_payment.rb', line 8851 required :insurance_charges_amount, Integer, nil?: true |
#insurance_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the insurance charges assessed.
8858 |
# File 'lib/increase/models/card_payment.rb', line 8858 required :insurance_charges_currency, String, nil?: true |
#no_show_indicator ⇒ Symbol, ...
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a “no-show” charge).
8865 8866 8867 8868 8869 |
# File 'lib/increase/models/card_payment.rb', line 8865 required :no_show_indicator, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::CarRental::NoShowIndicator }, nil?: true |
#one_way_drop_off_charges_amount ⇒ Integer?
Charges for returning the vehicle at a different location than where it was picked up.
8876 |
# File 'lib/increase/models/card_payment.rb', line 8876 required :one_way_drop_off_charges_amount, Integer, nil?: true |
#one_way_drop_off_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the one-way drop-off charges assessed.
8883 |
# File 'lib/increase/models/card_payment.rb', line 8883 required :one_way_drop_off_charges_currency, String, nil?: true |
#renter_name ⇒ String?
Name of the person renting the vehicle.
8889 |
# File 'lib/increase/models/card_payment.rb', line 8889 required :renter_name, String, nil?: true |
#weekly_rental_rate_amount ⇒ Integer?
Weekly rate being charged for the vehicle.
8895 |
# File 'lib/increase/models/card_payment.rb', line 8895 required :weekly_rental_rate_amount, Integer, nil?: true |
#weekly_rental_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the weekly rental rate.
8902 |
# File 'lib/increase/models/card_payment.rb', line 8902 required :weekly_rental_rate_currency, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 8967
|