Class: Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Lodging
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Lodging
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: ExtraCharges, NoShowIndicator
Instance Attribute Summary collapse
-
#check_in_date ⇒ Date?
Date the customer checked in.
-
#daily_room_rate_amount ⇒ Integer?
Daily rate being charged for the room.
-
#daily_room_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily room rate.
-
#extra_charges ⇒ Symbol, ...
Additional charges (phone, late check-out, etc.) being billed.
-
#folio_cash_advances_amount ⇒ Integer?
Folio cash advances for the room.
-
#folio_cash_advances_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the folio cash advances.
-
#food_beverage_charges_amount ⇒ Integer?
Food and beverage charges for the room.
-
#food_beverage_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the food and beverage charges.
-
#no_show_indicator ⇒ Symbol, ...
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
#prepaid_expenses_amount ⇒ Integer?
Prepaid expenses being charged for the room.
-
#prepaid_expenses_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the prepaid expenses.
-
#room_nights ⇒ Integer?
Number of nights the room was rented.
-
#total_room_tax_amount ⇒ Integer?
Total room tax being charged.
-
#total_room_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total room tax.
-
#total_tax_amount ⇒ Integer?
Total tax being charged for the room.
-
#total_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total tax assessed.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Lodging for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardRefund::PurchaseDetails::Lodging for more details.
Fields specific to lodging.
|
|
# File 'lib/increase/models/card_payment.rb', line 9102
|
Instance Attribute Details
#check_in_date ⇒ Date?
Date the customer checked in.
8995 |
# File 'lib/increase/models/card_payment.rb', line 8995 required :check_in_date, Date, nil?: true |
#daily_room_rate_amount ⇒ Integer?
Daily rate being charged for the room.
9001 |
# File 'lib/increase/models/card_payment.rb', line 9001 required :daily_room_rate_amount, Integer, nil?: true |
#daily_room_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily room rate.
9008 |
# File 'lib/increase/models/card_payment.rb', line 9008 required :daily_room_rate_currency, String, nil?: true |
#extra_charges ⇒ Symbol, ...
Additional charges (phone, late check-out, etc.) being billed.
9014 9015 9016 9017 9018 |
# File 'lib/increase/models/card_payment.rb', line 9014 required :extra_charges, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Lodging::ExtraCharges }, nil?: true |
#folio_cash_advances_amount ⇒ Integer?
Folio cash advances for the room.
9024 |
# File 'lib/increase/models/card_payment.rb', line 9024 required :folio_cash_advances_amount, Integer, nil?: true |
#folio_cash_advances_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the folio cash advances.
9031 |
# File 'lib/increase/models/card_payment.rb', line 9031 required :folio_cash_advances_currency, String, nil?: true |
#food_beverage_charges_amount ⇒ Integer?
Food and beverage charges for the room.
9037 |
# File 'lib/increase/models/card_payment.rb', line 9037 required :food_beverage_charges_amount, Integer, nil?: true |
#food_beverage_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the food and beverage charges.
9044 |
# File 'lib/increase/models/card_payment.rb', line 9044 required :food_beverage_charges_currency, String, nil?: true |
#no_show_indicator ⇒ Symbol, ...
Indicator that the cardholder is being billed for a reserved room that was not actually used.
9051 9052 9053 9054 9055 |
# File 'lib/increase/models/card_payment.rb', line 9051 required :no_show_indicator, enum: -> { Increase::CardPayment::Element::CardRefund::PurchaseDetails::Lodging::NoShowIndicator }, nil?: true |
#prepaid_expenses_amount ⇒ Integer?
Prepaid expenses being charged for the room.
9061 |
# File 'lib/increase/models/card_payment.rb', line 9061 required :prepaid_expenses_amount, Integer, nil?: true |
#prepaid_expenses_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the prepaid expenses.
9068 |
# File 'lib/increase/models/card_payment.rb', line 9068 required :prepaid_expenses_currency, String, nil?: true |
#room_nights ⇒ Integer?
Number of nights the room was rented.
9074 |
# File 'lib/increase/models/card_payment.rb', line 9074 required :room_nights, Integer, nil?: true |
#total_room_tax_amount ⇒ Integer?
Total room tax being charged.
9080 |
# File 'lib/increase/models/card_payment.rb', line 9080 required :total_room_tax_amount, Integer, nil?: true |
#total_room_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total room tax.
9087 |
# File 'lib/increase/models/card_payment.rb', line 9087 required :total_room_tax_currency, String, nil?: true |
#total_tax_amount ⇒ Integer?
Total tax being charged for the room.
9093 |
# File 'lib/increase/models/card_payment.rb', line 9093 required :total_tax_amount, Integer, nil?: true |
#total_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total tax assessed.
9100 |
# File 'lib/increase/models/card_payment.rb', line 9100 required :total_tax_currency, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 9168
|