Class: Increase::Models::CardPayment::Element::CardReversal

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_reversal

Defined Under Namespace

Modules: Currency, Network, ReversalReason, Type Classes: NetworkIdentifiers, SchemeFee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/card_payment.rb', line 10619

Instance Attribute Details

#card_authorization_idString

The identifier for the Card Authorization this reverses.

Parameters:

  • value (String)

Returns:

  • (String)


10483
# File 'lib/increase/models/card_payment.rb', line 10483

required :card_authorization_id, String

#currencySymbol, Increase::Models::CardPayment::Element::CardReversal::Currency

The ISO 4217 code for the reversal's currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardReversal::currency)

Returns:



10490
# File 'lib/increase/models/card_payment.rb', line 10490

required :currency, enum: -> { Increase::CardPayment::Element::CardReversal::Currency }

#idString

The Card Reversal identifier.

Parameters:

  • value (String)

Returns:

  • (String)


10477
# File 'lib/increase/models/card_payment.rb', line 10477

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


10497
# File 'lib/increase/models/card_payment.rb', line 10497

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


10504
# File 'lib/increase/models/card_payment.rb', line 10504

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10510
# File 'lib/increase/models/card_payment.rb', line 10510

required :merchant_city, String, nil?: true

#merchant_countryString?

The country the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10516
# File 'lib/increase/models/card_payment.rb', line 10516

required :merchant_country, String, nil?: true

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


10522
# File 'lib/increase/models/card_payment.rb', line 10522

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10529
# File 'lib/increase/models/card_payment.rb', line 10529

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10535
# File 'lib/increase/models/card_payment.rb', line 10535

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::CardPayment::Element::CardReversal::Network

The card network used to process this card authorization.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardReversal::network)

Returns:



10541
# File 'lib/increase/models/card_payment.rb', line 10541

required :network, enum: -> { Increase::CardPayment::Element::CardReversal::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardReversal::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardReversal::NetworkIdentifiers)

Returns:



10547
# File 'lib/increase/models/card_payment.rb', line 10547

required :network_identifiers, -> { Increase::CardPayment::Element::CardReversal::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Card Reversal.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10553
# File 'lib/increase/models/card_payment.rb', line 10553

required :pending_transaction_id, String, nil?: true

#presentment_currencyString

The ISO 4217 code for the reversal's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


10560
# File 'lib/increase/models/card_payment.rb', line 10560

required :presentment_currency, String

#reversal_amountInteger

The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


10567
# File 'lib/increase/models/card_payment.rb', line 10567

required :reversal_amount, Integer

#reversal_presentment_amountInteger

The amount of this reversal in the minor unit of the transaction's presentment currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


10574
# File 'lib/increase/models/card_payment.rb', line 10574

required :reversal_presentment_amount, Integer

#reversal_reasonSymbol, ...

Why this reversal was initiated.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardReversal::reversal_reason, nil)

Returns:



10580
10581
10582
# File 'lib/increase/models/card_payment.rb', line 10580

required :reversal_reason,
enum: -> { Increase::CardPayment::Element::CardReversal::ReversalReason },
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardReversal::SchemeFee>

The scheme fees associated with this card reversal.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardReversal::SchemeFee])

Returns:



10588
10589
# File 'lib/increase/models/card_payment.rb', line 10588

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardReversal::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


10596
# File 'lib/increase/models/card_payment.rb', line 10596

required :terminal_id, String, nil?: true

#typeSymbol, Increase::Models::CardPayment::Element::CardReversal::Type

A constant representing the object's type. For this resource it will always be card_reversal.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardReversal::type_)

Returns:



10603
# File 'lib/increase/models/card_payment.rb', line 10603

required :type, enum: -> { Increase::CardPayment::Element::CardReversal::Type }

#updated_authorization_amountInteger

The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


10610
# File 'lib/increase/models/card_payment.rb', line 10610

required :updated_authorization_amount, Integer

#updated_authorization_presentment_amountInteger

The amount left pending on the Card Authorization in the minor unit of the transaction's presentment currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


10617
# File 'lib/increase/models/card_payment.rb', line 10617

required :updated_authorization_presentment_amount, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 10705

Instance Method Details

#to_hash{

Returns:

  • ({)


7420
# File 'sig/increase/models/card_payment.rbs', line 7420

def to_hash: -> {