Class: Increase::Models::CardPayment::Element::CardReversal
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardReversal
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: Currency, Network, ReversalReason, Type Classes: NetworkIdentifiers, SchemeFee
Instance Attribute Summary collapse
-
#card_authorization_id ⇒ String
The identifier for the Card Authorization this reverses.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardReversal::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the reversal’s currency.
-
#id ⇒ String
The Card Reversal identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String?
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardReversal::Network
The card network used to process this card authorization.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardReversal::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Card Reversal.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the reversal’s presentment currency.
-
#reversal_amount ⇒ Integer
The amount of this reversal in the minor unit of the transaction’s currency.
-
#reversal_presentment_amount ⇒ Integer
The amount of this reversal in the minor unit of the transaction’s presentment currency.
-
#reversal_reason ⇒ Symbol, ...
Why this reversal was initiated.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardReversal::SchemeFee>
The scheme fees associated with this card reversal.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardReversal::Type
A constant representing the object’s type.
-
#updated_authorization_amount ⇒ Integer
The amount left pending on the Card Authorization in the minor unit of the transaction’s currency.
-
#updated_authorization_presentment_amount ⇒ Integer
The amount left pending on the Card Authorization in the minor unit of the transaction’s presentment currency.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 9996
|
Instance Attribute Details
#card_authorization_id ⇒ String
The identifier for the Card Authorization this reverses.
9860 |
# File 'lib/increase/models/card_payment.rb', line 9860 required :card_authorization_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardReversal::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the reversal’s currency.
9867 |
# File 'lib/increase/models/card_payment.rb', line 9867 required :currency, enum: -> { Increase::CardPayment::Element::CardReversal::Currency } |
#id ⇒ String
The Card Reversal identifier.
9854 |
# File 'lib/increase/models/card_payment.rb', line 9854 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
9874 |
# File 'lib/increase/models/card_payment.rb', line 9874 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
9881 |
# File 'lib/increase/models/card_payment.rb', line 9881 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
9887 |
# File 'lib/increase/models/card_payment.rb', line 9887 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String?
The country the merchant resides in.
9893 |
# File 'lib/increase/models/card_payment.rb', line 9893 required :merchant_country, String, nil?: true |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
9899 |
# File 'lib/increase/models/card_payment.rb', line 9899 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
9906 |
# File 'lib/increase/models/card_payment.rb', line 9906 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
9912 |
# File 'lib/increase/models/card_payment.rb', line 9912 required :merchant_state, String, nil?: true |
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardReversal::Network
The card network used to process this card authorization.
9918 |
# File 'lib/increase/models/card_payment.rb', line 9918 required :network, enum: -> { Increase::CardPayment::Element::CardReversal::Network } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardReversal::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
9924 |
# File 'lib/increase/models/card_payment.rb', line 9924 required :network_identifiers, -> { Increase::CardPayment::Element::CardReversal::NetworkIdentifiers } |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Card Reversal.
9930 |
# File 'lib/increase/models/card_payment.rb', line 9930 required :pending_transaction_id, String, nil?: true |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the reversal’s presentment currency.
9937 |
# File 'lib/increase/models/card_payment.rb', line 9937 required :presentment_currency, String |
#reversal_amount ⇒ Integer
The amount of this reversal in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
9944 |
# File 'lib/increase/models/card_payment.rb', line 9944 required :reversal_amount, Integer |
#reversal_presentment_amount ⇒ Integer
The amount of this reversal in the minor unit of the transaction’s presentment currency. For dollars, for example, this is cents.
9951 |
# File 'lib/increase/models/card_payment.rb', line 9951 required :reversal_presentment_amount, Integer |
#reversal_reason ⇒ Symbol, ...
Why this reversal was initiated.
9957 9958 9959 |
# File 'lib/increase/models/card_payment.rb', line 9957 required :reversal_reason, enum: -> { Increase::CardPayment::Element::CardReversal::ReversalReason }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardReversal::SchemeFee>
The scheme fees associated with this card reversal.
9965 9966 |
# File 'lib/increase/models/card_payment.rb', line 9965 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardReversal::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
9973 |
# File 'lib/increase/models/card_payment.rb', line 9973 required :terminal_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardReversal::Type
A constant representing the object’s type. For this resource it will always be ‘card_reversal`.
9980 |
# File 'lib/increase/models/card_payment.rb', line 9980 required :type, enum: -> { Increase::CardPayment::Element::CardReversal::Type } |
#updated_authorization_amount ⇒ Integer
The amount left pending on the Card Authorization in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
9987 |
# File 'lib/increase/models/card_payment.rb', line 9987 required :updated_authorization_amount, Integer |
#updated_authorization_presentment_amount ⇒ Integer
The amount left pending on the Card Authorization in the minor unit of the transaction’s presentment currency. For dollars, for example, this is cents.
9994 |
# File 'lib/increase/models/card_payment.rb', line 9994 required :updated_authorization_presentment_amount, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 10058
|