Class: Increase::Models::CardPayment::Element::CardSettlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardSettlement
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction's settlement currency.
-
#card_authorization ⇒ String?
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cashback ⇒ Increase::Models::CardPayment::Element::CardSettlement::Cashback?
Cashback earned on this transaction, if eligible.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Currency
The ISO 4217 code for the transaction's settlement currency.
-
#id ⇒ String
The Card Settlement identifier.
-
#interchange ⇒ Increase::Models::CardPayment::Element::CardSettlement::Interchange?
Interchange assessed as a part of this transaction.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant's business.
-
#merchant_city ⇒ String
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_name ⇒ String
The name of the merchant.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Network
The card network on which this transaction was processed.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers
Network-specific identifiers for this refund.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
-
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#purchase_details ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>
The scheme fees associated with this card settlement.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardSettlement::Surcharge?
Surcharge amount details, if applicable.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, presentment_amount:) ⇒ Object
constructor
Surcharge amount details, if applicable.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, presentment_amount:) ⇒ Object
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
|
|
# File 'lib/increase/models/card_payment.rb', line 11171
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
11021 |
# File 'lib/increase/models/card_payment.rb', line 11021 required :amount, Integer |
#card_authorization ⇒ String?
The Card Authorization that was created prior to this Card Settlement, if one exists.
11028 |
# File 'lib/increase/models/card_payment.rb', line 11028 required :card_authorization, String, nil?: true |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
11034 |
# File 'lib/increase/models/card_payment.rb', line 11034 required :card_payment_id, String |
#cashback ⇒ Increase::Models::CardPayment::Element::CardSettlement::Cashback?
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
11041 |
# File 'lib/increase/models/card_payment.rb', line 11041 required :cashback, -> { Increase::CardPayment::Element::CardSettlement::Cashback }, nil?: true |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Currency
The ISO 4217 code for the transaction's settlement currency.
11048 |
# File 'lib/increase/models/card_payment.rb', line 11048 required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::Currency } |
#id ⇒ String
The Card Settlement identifier.
11014 |
# File 'lib/increase/models/card_payment.rb', line 11014 required :id, String |
#interchange ⇒ Increase::Models::CardPayment::Element::CardSettlement::Interchange?
Interchange assessed as a part of this transaction.
11054 11055 11056 11057 11058 |
# File 'lib/increase/models/card_payment.rb', line 11054 required :interchange, -> { Increase::CardPayment::Element::CardSettlement::Interchange }, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
11065 |
# File 'lib/increase/models/card_payment.rb', line 11065 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant's business.
11071 |
# File 'lib/increase/models/card_payment.rb', line 11071 required :merchant_category_code, String |
#merchant_city ⇒ String
The city the merchant resides in.
11077 |
# File 'lib/increase/models/card_payment.rb', line 11077 required :merchant_city, String |
#merchant_country ⇒ String
The country the merchant resides in.
11083 |
# File 'lib/increase/models/card_payment.rb', line 11083 required :merchant_country, String |
#merchant_name ⇒ String
The name of the merchant.
11089 |
# File 'lib/increase/models/card_payment.rb', line 11089 required :merchant_name, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
11095 |
# File 'lib/increase/models/card_payment.rb', line 11095 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
11101 |
# File 'lib/increase/models/card_payment.rb', line 11101 required :merchant_state, String, nil?: true |
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Network
The card network on which this transaction was processed.
11107 |
# File 'lib/increase/models/card_payment.rb', line 11107 required :network, enum: -> { Increase::CardPayment::Element::CardSettlement::Network } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers
Network-specific identifiers for this refund.
11113 |
# File 'lib/increase/models/card_payment.rb', line 11113 required :network_identifiers, -> { Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers } |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
11119 |
# File 'lib/increase/models/card_payment.rb', line 11119 required :pending_transaction_id, String, nil?: true |
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction's presentment currency.
11125 |
# File 'lib/increase/models/card_payment.rb', line 11125 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
11132 |
# File 'lib/increase/models/card_payment.rb', line 11132 required :presentment_currency, String |
#purchase_details ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
11139 11140 11141 |
# File 'lib/increase/models/card_payment.rb', line 11139 required :purchase_details, -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>
The scheme fees associated with this card settlement.
11147 11148 |
# File 'lib/increase/models/card_payment.rb', line 11147 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardSettlement::SchemeFee] } |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardSettlement::Surcharge?
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
11156 |
# File 'lib/increase/models/card_payment.rb', line 11156 required :surcharge, -> { Increase::CardPayment::Element::CardSettlement::Surcharge }, nil?: true |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
11162 |
# File 'lib/increase/models/card_payment.rb', line 11162 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Type
A constant representing the object's type. For this resource it will always be
card_settlement.
11169 |
# File 'lib/increase/models/card_payment.rb', line 11169 required :type, enum: -> { Increase::CardPayment::Element::CardSettlement::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 11289
|
Instance Method Details
#to_hash ⇒ {
7823 |
# File 'sig/increase/models/card_payment.rbs', line 7823
def to_hash: -> {
|