Class: Increase::Models::CardPayment::Element::CardSettlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element#card_settlement

Defined Under Namespace

Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, presentment_amount:) ⇒ Object

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • amount (Integer)

    The surcharge amount in the minor unit of the transaction's settlement currency.

  • presentment_amount (Integer)

    The surcharge amount in the minor unit of the transaction's presentment currency.



# File 'lib/increase/models/card_payment.rb', line 11154

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11004
# File 'lib/increase/models/card_payment.rb', line 11004

required :amount, Integer

#card_authorizationString?

The Card Authorization that was created prior to this Card Settlement, if one exists.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11011
# File 'lib/increase/models/card_payment.rb', line 11011

required :card_authorization, String, nil?: true

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


11017
# File 'lib/increase/models/card_payment.rb', line 11017

required :card_payment_id, String

#cashbackIncrease::Models::CardPayment::Element::CardSettlement::Cashback?

Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::Cashback, nil)

Returns:



11024
# File 'lib/increase/models/card_payment.rb', line 11024

required :cashback, -> { Increase::CardPayment::Element::CardSettlement::Cashback }, nil?: true

#currencySymbol, Increase::Models::CardPayment::Element::CardSettlement::Currency

The ISO 4217 code for the transaction's settlement currency.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::currency)

Returns:



11031
# File 'lib/increase/models/card_payment.rb', line 11031

required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::Currency }

#idString

The Card Settlement identifier.

Parameters:

  • value (String)

Returns:

  • (String)


10997
# File 'lib/increase/models/card_payment.rb', line 10997

required :id, String

#interchangeIncrease::Models::CardPayment::Element::CardSettlement::Interchange?

Interchange assessed as a part of this transaction.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::Interchange, nil)

Returns:



11037
11038
11039
11040
11041
# File 'lib/increase/models/card_payment.rb', line 11037

required :interchange,
-> {
  Increase::CardPayment::Element::CardSettlement::Interchange
},
nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


11048
# File 'lib/increase/models/card_payment.rb', line 11048

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant's business.

Parameters:

  • value (String)

Returns:

  • (String)


11054
# File 'lib/increase/models/card_payment.rb', line 11054

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


11060
# File 'lib/increase/models/card_payment.rb', line 11060

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


11066
# File 'lib/increase/models/card_payment.rb', line 11066

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Parameters:

  • value (String)

Returns:

  • (String)


11072
# File 'lib/increase/models/card_payment.rb', line 11072

required :merchant_name, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is always a 5-digit ZIP code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11078
# File 'lib/increase/models/card_payment.rb', line 11078

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11084
# File 'lib/increase/models/card_payment.rb', line 11084

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::CardPayment::Element::CardSettlement::Network

The card network on which this transaction was processed.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::network)

Returns:



11090
# File 'lib/increase/models/card_payment.rb', line 11090

required :network, enum: -> { Increase::CardPayment::Element::CardSettlement::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers

Network-specific identifiers for this refund.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers)

Returns:



11096
# File 'lib/increase/models/card_payment.rb', line 11096

required :network_identifiers, -> { Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11102
# File 'lib/increase/models/card_payment.rb', line 11102

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11108
# File 'lib/increase/models/card_payment.rb', line 11108

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


11115
# File 'lib/increase/models/card_payment.rb', line 11115

required :presentment_currency, String

#purchase_detailsIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::PurchaseDetails, nil)

Returns:



11122
11123
11124
# File 'lib/increase/models/card_payment.rb', line 11122

required :purchase_details,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails },
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>

The scheme fees associated with this card settlement.

Parameters:

  • value (::Array[Increase::CardPayment::Element::CardSettlement::SchemeFee])

Returns:



11130
11131
# File 'lib/increase/models/card_payment.rb', line 11130

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardSettlement::SchemeFee] }

#surchargeIncrease::Models::CardPayment::Element::CardSettlement::Surcharge?

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • value (Increase::CardPayment::Element::CardSettlement::Surcharge, nil)

Returns:



11139
# File 'lib/increase/models/card_payment.rb', line 11139

required :surcharge, -> { Increase::CardPayment::Element::CardSettlement::Surcharge }, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


11145
# File 'lib/increase/models/card_payment.rb', line 11145

required :transaction_id, String

#typeSymbol, Increase::Models::CardPayment::Element::CardSettlement::Type

A constant representing the object's type. For this resource it will always be card_settlement.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::type_)

Returns:



11152
# File 'lib/increase/models/card_payment.rb', line 11152

required :type, enum: -> { Increase::CardPayment::Element::CardSettlement::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 11272

Instance Method Details

#to_hash{

Returns:

  • ({)


7818
# File 'sig/increase/models/card_payment.rbs', line 7818

def to_hash: -> {