Class: Increase::Models::CardPayment::Element::CardSettlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, presentment_amount:) ⇒ Object

Some parameter documentations has been truncated, see Surcharge for more details.

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • amount (Integer)

    The surcharge amount in the minor unit of the transaction’s settlement currency.

  • presentment_amount (Integer)

    The surcharge amount in the minor unit of the transaction’s presentment currency



# File 'lib/increase/models/card_payment.rb', line 10565

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


10415
# File 'lib/increase/models/card_payment.rb', line 10415

required :amount, Integer

#card_authorizationString?

The Card Authorization that was created prior to this Card Settlement, if one exists.

Returns:

  • (String, nil)


10422
# File 'lib/increase/models/card_payment.rb', line 10422

required :card_authorization, String, nil?: true

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Returns:

  • (String)


10428
# File 'lib/increase/models/card_payment.rb', line 10428

required :card_payment_id, String

#cashbackIncrease::Models::CardPayment::Element::CardSettlement::Cashback?

Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.



10435
# File 'lib/increase/models/card_payment.rb', line 10435

required :cashback, -> { Increase::CardPayment::Element::CardSettlement::Cashback }, nil?: true

#currencySymbol, Increase::Models::CardPayment::Element::CardSettlement::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.



10442
# File 'lib/increase/models/card_payment.rb', line 10442

required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::Currency }

#idString

The Card Settlement identifier.

Returns:

  • (String)


10408
# File 'lib/increase/models/card_payment.rb', line 10408

required :id, String

#interchangeIncrease::Models::CardPayment::Element::CardSettlement::Interchange?

Interchange assessed as a part of this transaction.



10448
10449
10450
10451
10452
# File 'lib/increase/models/card_payment.rb', line 10448

required :interchange,
-> {
  Increase::CardPayment::Element::CardSettlement::Interchange
},
nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


10459
# File 'lib/increase/models/card_payment.rb', line 10459

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant’s business.

Returns:

  • (String)


10465
# File 'lib/increase/models/card_payment.rb', line 10465

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Returns:

  • (String)


10471
# File 'lib/increase/models/card_payment.rb', line 10471

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


10477
# File 'lib/increase/models/card_payment.rb', line 10477

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Returns:

  • (String)


10483
# File 'lib/increase/models/card_payment.rb', line 10483

required :merchant_name, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.

Returns:

  • (String, nil)


10489
# File 'lib/increase/models/card_payment.rb', line 10489

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


10495
# File 'lib/increase/models/card_payment.rb', line 10495

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::CardPayment::Element::CardSettlement::Network

The card network on which this transaction was processed.



10501
# File 'lib/increase/models/card_payment.rb', line 10501

required :network, enum: -> { Increase::CardPayment::Element::CardSettlement::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers

Network-specific identifiers for this refund.



10507
# File 'lib/increase/models/card_payment.rb', line 10507

required :network_identifiers, -> { Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Transaction.

Returns:

  • (String, nil)


10513
# File 'lib/increase/models/card_payment.rb', line 10513

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount in the minor unit of the transaction’s presentment currency.

Returns:

  • (Integer)


10519
# File 'lib/increase/models/card_payment.rb', line 10519

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.

Returns:

  • (String)


10526
# File 'lib/increase/models/card_payment.rb', line 10526

required :presentment_currency, String

#purchase_detailsIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.



10533
10534
10535
# File 'lib/increase/models/card_payment.rb', line 10533

required :purchase_details,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails },
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>

The scheme fees associated with this card settlement.



10541
10542
# File 'lib/increase/models/card_payment.rb', line 10541

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardSettlement::SchemeFee] }

#surchargeIncrease::Models::CardPayment::Element::CardSettlement::Surcharge?

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).



10550
# File 'lib/increase/models/card_payment.rb', line 10550

required :surcharge, -> { Increase::CardPayment::Element::CardSettlement::Surcharge }, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Returns:

  • (String)


10556
# File 'lib/increase/models/card_payment.rb', line 10556

required :transaction_id, String

#typeSymbol, Increase::Models::CardPayment::Element::CardSettlement::Type

A constant representing the object’s type. For this resource it will always be ‘card_settlement`.



10563
# File 'lib/increase/models/card_payment.rb', line 10563

required :type, enum: -> { Increase::CardPayment::Element::CardSettlement::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 10660