Class: Increase::Models::CardPayment::Element::CardSettlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, presentment_amount:) ⇒ Object

Some parameter documentations has been truncated, see Surcharge for more details.

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • amount (Integer)

    The surcharge amount in the minor unit of the transaction’s settlement currency.

  • presentment_amount (Integer)

    The surcharge amount in the minor unit of the transaction’s presentment currency



# File 'lib/increase/models/card_payment.rb', line 10556

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


10406
# File 'lib/increase/models/card_payment.rb', line 10406

required :amount, Integer

#card_authorizationString?

The Card Authorization that was created prior to this Card Settlement, if one exists.

Returns:

  • (String, nil)


10413
# File 'lib/increase/models/card_payment.rb', line 10413

required :card_authorization, String, nil?: true

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Returns:

  • (String)


10419
# File 'lib/increase/models/card_payment.rb', line 10419

required :card_payment_id, String

#cashbackIncrease::Models::CardPayment::Element::CardSettlement::Cashback?

Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.



10426
# File 'lib/increase/models/card_payment.rb', line 10426

required :cashback, -> { Increase::CardPayment::Element::CardSettlement::Cashback }, nil?: true

#currencySymbol, Increase::Models::CardPayment::Element::CardSettlement::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.



10433
# File 'lib/increase/models/card_payment.rb', line 10433

required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::Currency }

#idString

The Card Settlement identifier.

Returns:

  • (String)


10399
# File 'lib/increase/models/card_payment.rb', line 10399

required :id, String

#interchangeIncrease::Models::CardPayment::Element::CardSettlement::Interchange?

Interchange assessed as a part of this transaction.



10439
10440
10441
10442
10443
# File 'lib/increase/models/card_payment.rb', line 10439

required :interchange,
-> {
  Increase::CardPayment::Element::CardSettlement::Interchange
},
nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


10450
# File 'lib/increase/models/card_payment.rb', line 10450

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant’s business.

Returns:

  • (String)


10456
# File 'lib/increase/models/card_payment.rb', line 10456

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Returns:

  • (String)


10462
# File 'lib/increase/models/card_payment.rb', line 10462

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


10468
# File 'lib/increase/models/card_payment.rb', line 10468

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Returns:

  • (String)


10474
# File 'lib/increase/models/card_payment.rb', line 10474

required :merchant_name, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.

Returns:

  • (String, nil)


10480
# File 'lib/increase/models/card_payment.rb', line 10480

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


10486
# File 'lib/increase/models/card_payment.rb', line 10486

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::CardPayment::Element::CardSettlement::Network

The card network on which this transaction was processed.



10492
# File 'lib/increase/models/card_payment.rb', line 10492

required :network, enum: -> { Increase::CardPayment::Element::CardSettlement::Network }

#network_identifiersIncrease::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers

Network-specific identifiers for this refund.



10498
# File 'lib/increase/models/card_payment.rb', line 10498

required :network_identifiers, -> { Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Transaction.

Returns:

  • (String, nil)


10504
# File 'lib/increase/models/card_payment.rb', line 10504

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount in the minor unit of the transaction’s presentment currency.

Returns:

  • (Integer)


10510
# File 'lib/increase/models/card_payment.rb', line 10510

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.

Returns:

  • (String)


10517
# File 'lib/increase/models/card_payment.rb', line 10517

required :presentment_currency, String

#purchase_detailsIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.



10524
10525
10526
# File 'lib/increase/models/card_payment.rb', line 10524

required :purchase_details,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails },
nil?: true

#scheme_feesArray<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>

The scheme fees associated with this card settlement.



10532
10533
# File 'lib/increase/models/card_payment.rb', line 10532

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardSettlement::SchemeFee] }

#surchargeIncrease::Models::CardPayment::Element::CardSettlement::Surcharge?

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).



10541
# File 'lib/increase/models/card_payment.rb', line 10541

required :surcharge, -> { Increase::CardPayment::Element::CardSettlement::Surcharge }, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Returns:

  • (String)


10547
# File 'lib/increase/models/card_payment.rb', line 10547

required :transaction_id, String

#typeSymbol, Increase::Models::CardPayment::Element::CardSettlement::Type

A constant representing the object’s type. For this resource it will always be ‘card_settlement`.



10554
# File 'lib/increase/models/card_payment.rb', line 10554

required :type, enum: -> { Increase::CardPayment::Element::CardSettlement::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 10651