Class: Increase::Models::CardPayment::Element::CardSettlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardSettlement
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction’s settlement currency.
-
#card_authorization ⇒ String?
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cashback ⇒ Increase::Models::CardPayment::Element::CardSettlement::Cashback?
Cashback earned on this transaction, if eligible.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.
-
#id ⇒ String
The Card Settlement identifier.
-
#interchange ⇒ Increase::Models::CardPayment::Element::CardSettlement::Interchange?
Interchange assessed as a part of this transaction.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant’s business.
-
#merchant_city ⇒ String
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_name ⇒ String
The name of the merchant.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Network
The card network on which this transaction was processed.
-
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers
Network-specific identifiers for this refund.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
-
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction’s presentment currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
-
#purchase_details ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>
The scheme fees associated with this card settlement.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardSettlement::Surcharge?
Surcharge amount details, if applicable.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, presentment_amount:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Surcharge for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, presentment_amount:) ⇒ Object
Some parameter documentations has been truncated, see Surcharge for more details.
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
|
|
# File 'lib/increase/models/card_payment.rb', line 10556
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.
10406 |
# File 'lib/increase/models/card_payment.rb', line 10406 required :amount, Integer |
#card_authorization ⇒ String?
The Card Authorization that was created prior to this Card Settlement, if one exists.
10413 |
# File 'lib/increase/models/card_payment.rb', line 10413 required :card_authorization, String, nil?: true |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
10419 |
# File 'lib/increase/models/card_payment.rb', line 10419 required :card_payment_id, String |
#cashback ⇒ Increase::Models::CardPayment::Element::CardSettlement::Cashback?
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
10426 |
# File 'lib/increase/models/card_payment.rb', line 10426 required :cashback, -> { Increase::CardPayment::Element::CardSettlement::Cashback }, nil?: true |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.
10433 |
# File 'lib/increase/models/card_payment.rb', line 10433 required :currency, enum: -> { Increase::CardPayment::Element::CardSettlement::Currency } |
#id ⇒ String
The Card Settlement identifier.
10399 |
# File 'lib/increase/models/card_payment.rb', line 10399 required :id, String |
#interchange ⇒ Increase::Models::CardPayment::Element::CardSettlement::Interchange?
Interchange assessed as a part of this transaction.
10439 10440 10441 10442 10443 |
# File 'lib/increase/models/card_payment.rb', line 10439 required :interchange, -> { Increase::CardPayment::Element::CardSettlement::Interchange }, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
10450 |
# File 'lib/increase/models/card_payment.rb', line 10450 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant’s business.
10456 |
# File 'lib/increase/models/card_payment.rb', line 10456 required :merchant_category_code, String |
#merchant_city ⇒ String
The city the merchant resides in.
10462 |
# File 'lib/increase/models/card_payment.rb', line 10462 required :merchant_city, String |
#merchant_country ⇒ String
The country the merchant resides in.
10468 |
# File 'lib/increase/models/card_payment.rb', line 10468 required :merchant_country, String |
#merchant_name ⇒ String
The name of the merchant.
10474 |
# File 'lib/increase/models/card_payment.rb', line 10474 required :merchant_name, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.
10480 |
# File 'lib/increase/models/card_payment.rb', line 10480 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
10486 |
# File 'lib/increase/models/card_payment.rb', line 10486 required :merchant_state, String, nil?: true |
#network ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Network
The card network on which this transaction was processed.
10492 |
# File 'lib/increase/models/card_payment.rb', line 10492 required :network, enum: -> { Increase::CardPayment::Element::CardSettlement::Network } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardSettlement::NetworkIdentifiers
Network-specific identifiers for this refund.
10498 |
# File 'lib/increase/models/card_payment.rb', line 10498 required :network_identifiers, -> { Increase::CardPayment::Element::CardSettlement::NetworkIdentifiers } |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
10504 |
# File 'lib/increase/models/card_payment.rb', line 10504 required :pending_transaction_id, String, nil?: true |
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction’s presentment currency.
10510 |
# File 'lib/increase/models/card_payment.rb', line 10510 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
10517 |
# File 'lib/increase/models/card_payment.rb', line 10517 required :presentment_currency, String |
#purchase_details ⇒ Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
10524 10525 10526 |
# File 'lib/increase/models/card_payment.rb', line 10524 required :purchase_details, -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardSettlement::SchemeFee>
The scheme fees associated with this card settlement.
10532 10533 |
# File 'lib/increase/models/card_payment.rb', line 10532 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardSettlement::SchemeFee] } |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardSettlement::Surcharge?
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
10541 |
# File 'lib/increase/models/card_payment.rb', line 10541 required :surcharge, -> { Increase::CardPayment::Element::CardSettlement::Surcharge }, nil?: true |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
10547 |
# File 'lib/increase/models/card_payment.rb', line 10547 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardSettlement::Type
A constant representing the object’s type. For this resource it will always be ‘card_settlement`.
10554 |
# File 'lib/increase/models/card_payment.rb', line 10554 required :type, enum: -> { Increase::CardPayment::Element::CardSettlement::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 10651
|