Class: Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb

Overview

See Also:

Defined Under Namespace

Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails for more details.

Additional details about the card purchase, such as tax and industry-specific fields.

Parameters:



# File 'lib/increase/models/card_payment.rb', line 10798

Instance Attribute Details

#car_rentalIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails::CarRental?

Fields specific to car rentals.



10730
10731
10732
# File 'lib/increase/models/card_payment.rb', line 10730

required :car_rental,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::CarRental },
nil?: true

#customer_reference_identifierString?

An identifier from the merchant for the customer or consumer.

Returns:

  • (String, nil)


10738
# File 'lib/increase/models/card_payment.rb', line 10738

required :customer_reference_identifier, String, nil?: true

#local_tax_amountInteger?

The state or provincial tax amount in minor units.

Returns:

  • (Integer, nil)


10744
# File 'lib/increase/models/card_payment.rb', line 10744

required :local_tax_amount, Integer, nil?: true

#local_tax_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.

Returns:

  • (String, nil)


10751
# File 'lib/increase/models/card_payment.rb', line 10751

required :local_tax_currency, String, nil?: true

#lodgingIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging?

Fields specific to lodging.



10757
10758
10759
# File 'lib/increase/models/card_payment.rb', line 10757

required :lodging,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging },
nil?: true

#national_tax_amountInteger?

The national tax amount in minor units.

Returns:

  • (Integer, nil)


10765
# File 'lib/increase/models/card_payment.rb', line 10765

required :national_tax_amount, Integer, nil?: true

#national_tax_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.

Returns:

  • (String, nil)


10772
# File 'lib/increase/models/card_payment.rb', line 10772

required :national_tax_currency, String, nil?: true

#purchase_identifierString?

An identifier from the merchant for the purchase to the issuer and cardholder.

Returns:

  • (String, nil)


10778
# File 'lib/increase/models/card_payment.rb', line 10778

required :purchase_identifier, String, nil?: true

#purchase_identifier_formatSymbol, ...

The format of the purchase identifier.



10784
10785
10786
10787
10788
# File 'lib/increase/models/card_payment.rb', line 10784

required :purchase_identifier_format,
enum: -> {
  Increase::CardPayment::Element::CardSettlement::PurchaseDetails::PurchaseIdentifierFormat
},
nil?: true

#travelIncrease::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Travel?

Fields specific to travel.



10794
10795
10796
# File 'lib/increase/models/card_payment.rb', line 10794

required :travel,
-> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Travel },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 11020