Class: Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs

Overview

See Also:

  • Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails#lodging

Defined Under Namespace

Modules: ExtraCharges, NoShowIndicator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging for more details.

Fields specific to lodging.

Parameters:

  • check_in_date (Date, nil)

    Date the customer checked in.

  • daily_room_rate_amount (Integer, nil)

    Daily rate being charged for the room.

  • daily_room_rate_currency (String, nil)

    The ISO 4217 code for the daily room r

  • extra_charges (Symbol, Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::ExtraCharges, nil)

    Additional charges (phone, late check-out, etc.) being billed.

  • folio_cash_advances_amount (Integer, nil)

    Folio cash advances for the room.

  • folio_cash_advances_currency (String, nil)

    The ISO 4217 code for the folio cash a

  • food_beverage_charges_amount (Integer, nil)

    Food and beverage charges for the room.

  • food_beverage_charges_currency (String, nil)

    The ISO 4217 code for the food and bev

  • no_show_indicator (Symbol, Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::NoShowIndicator, nil)

    Indicator that the cardholder is being billed for a reserved room that was not a

  • prepaid_expenses_amount (Integer, nil)

    Prepaid expenses being charged for the room.

  • prepaid_expenses_currency (String, nil)

    The ISO 4217 code for the prepaid expe

  • room_nights (Integer, nil)

    Number of nights the room was rented.

  • total_room_tax_amount (Integer, nil)

    Total room tax being charged.

  • total_room_tax_currency (String, nil)

    The ISO 4217 code for the total room t

  • total_tax_amount (Integer, nil)

    Total tax being charged for the room.

  • total_tax_currency (String, nil)

    The ISO 4217 code for the total tax as



# File 'lib/increase/models/card_payment.rb', line 11206

Instance Attribute Details

#check_in_dateDate?

Date the customer checked in.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


11099
# File 'lib/increase/models/card_payment.rb', line 11099

required :check_in_date, Date, nil?: true

#daily_room_rate_amountInteger?

Daily rate being charged for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11105
# File 'lib/increase/models/card_payment.rb', line 11105

required :daily_room_rate_amount, Integer, nil?: true

#daily_room_rate_currencyString?

The ISO 4217 code for the daily room rate.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11112
# File 'lib/increase/models/card_payment.rb', line 11112

required :daily_room_rate_currency, String, nil?: true

#extra_chargesSymbol, ...

Additional charges (phone, late check-out, etc.) being billed.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::extra_charges, nil)

Returns:



11118
11119
11120
11121
11122
# File 'lib/increase/models/card_payment.rb', line 11118

required :extra_charges,
enum: -> {
  Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::ExtraCharges
},
nil?: true

#folio_cash_advances_amountInteger?

Folio cash advances for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11128
# File 'lib/increase/models/card_payment.rb', line 11128

required :folio_cash_advances_amount, Integer, nil?: true

#folio_cash_advances_currencyString?

The ISO 4217 code for the folio cash advances.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11135
# File 'lib/increase/models/card_payment.rb', line 11135

required :folio_cash_advances_currency, String, nil?: true

#food_beverage_charges_amountInteger?

Food and beverage charges for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11141
# File 'lib/increase/models/card_payment.rb', line 11141

required :food_beverage_charges_amount, Integer, nil?: true

#food_beverage_charges_currencyString?

The ISO 4217 code for the food and beverage charges.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11148
# File 'lib/increase/models/card_payment.rb', line 11148

required :food_beverage_charges_currency, String, nil?: true

#no_show_indicatorSymbol, ...

Indicator that the cardholder is being billed for a reserved room that was not actually used.

Parameters:

  • value (Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::no_show_indicator, nil)

Returns:



11155
11156
11157
11158
11159
# File 'lib/increase/models/card_payment.rb', line 11155

required :no_show_indicator,
enum: -> {
  Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::NoShowIndicator
},
nil?: true

#prepaid_expenses_amountInteger?

Prepaid expenses being charged for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11165
# File 'lib/increase/models/card_payment.rb', line 11165

required :prepaid_expenses_amount, Integer, nil?: true

#prepaid_expenses_currencyString?

The ISO 4217 code for the prepaid expenses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11172
# File 'lib/increase/models/card_payment.rb', line 11172

required :prepaid_expenses_currency, String, nil?: true

#room_nightsInteger?

Number of nights the room was rented.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11178
# File 'lib/increase/models/card_payment.rb', line 11178

required :room_nights, Integer, nil?: true

#total_room_tax_amountInteger?

Total room tax being charged.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11184
# File 'lib/increase/models/card_payment.rb', line 11184

required :total_room_tax_amount, Integer, nil?: true

#total_room_tax_currencyString?

The ISO 4217 code for the total room tax.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11191
# File 'lib/increase/models/card_payment.rb', line 11191

required :total_room_tax_currency, String, nil?: true

#total_tax_amountInteger?

Total tax being charged for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


11197
# File 'lib/increase/models/card_payment.rb', line 11197

required :total_tax_amount, Integer, nil?: true

#total_tax_currencyString?

The ISO 4217 code for the total tax assessed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


11204
# File 'lib/increase/models/card_payment.rb', line 11204

required :total_tax_currency, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_payment.rb', line 11272

Instance Method Details

#to_hash{

Returns:

  • ({)


8245
# File 'sig/increase/models/card_payment.rbs', line 8245

def to_hash: -> {