Class: Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Modules: ExtraCharges, NoShowIndicator
Instance Attribute Summary collapse
-
#check_in_date ⇒ Date?
Date the customer checked in.
-
#daily_room_rate_amount ⇒ Integer?
Daily rate being charged for the room.
-
#daily_room_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily room rate.
-
#extra_charges ⇒ Symbol, ...
Additional charges (phone, late check-out, etc.) being billed.
-
#folio_cash_advances_amount ⇒ Integer?
Folio cash advances for the room.
-
#folio_cash_advances_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the folio cash advances.
-
#food_beverage_charges_amount ⇒ Integer?
Food and beverage charges for the room.
-
#food_beverage_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the food and beverage charges.
-
#no_show_indicator ⇒ Symbol, ...
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
#prepaid_expenses_amount ⇒ Integer?
Prepaid expenses being charged for the room.
-
#prepaid_expenses_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the prepaid expenses.
-
#room_nights ⇒ Integer?
Number of nights the room was rented.
-
#total_room_tax_amount ⇒ Integer?
Total room tax being charged.
-
#total_room_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total room tax.
-
#total_tax_amount ⇒ Integer?
Total tax being charged for the room.
-
#total_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total tax assessed.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Lodging for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging for more details.
Fields specific to lodging.
|
|
# File 'lib/increase/models/card_payment.rb', line 11138
|
Instance Attribute Details
#check_in_date ⇒ Date?
Date the customer checked in.
11031 |
# File 'lib/increase/models/card_payment.rb', line 11031 required :check_in_date, Date, nil?: true |
#daily_room_rate_amount ⇒ Integer?
Daily rate being charged for the room.
11037 |
# File 'lib/increase/models/card_payment.rb', line 11037 required :daily_room_rate_amount, Integer, nil?: true |
#daily_room_rate_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily room rate.
11044 |
# File 'lib/increase/models/card_payment.rb', line 11044 required :daily_room_rate_currency, String, nil?: true |
#extra_charges ⇒ Symbol, ...
Additional charges (phone, late check-out, etc.) being billed.
11050 11051 11052 11053 11054 |
# File 'lib/increase/models/card_payment.rb', line 11050 required :extra_charges, enum: -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::ExtraCharges }, nil?: true |
#folio_cash_advances_amount ⇒ Integer?
Folio cash advances for the room.
11060 |
# File 'lib/increase/models/card_payment.rb', line 11060 required :folio_cash_advances_amount, Integer, nil?: true |
#folio_cash_advances_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the folio cash advances.
11067 |
# File 'lib/increase/models/card_payment.rb', line 11067 required :folio_cash_advances_currency, String, nil?: true |
#food_beverage_charges_amount ⇒ Integer?
Food and beverage charges for the room.
11073 |
# File 'lib/increase/models/card_payment.rb', line 11073 required :food_beverage_charges_amount, Integer, nil?: true |
#food_beverage_charges_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the food and beverage charges.
11080 |
# File 'lib/increase/models/card_payment.rb', line 11080 required :food_beverage_charges_currency, String, nil?: true |
#no_show_indicator ⇒ Symbol, ...
Indicator that the cardholder is being billed for a reserved room that was not actually used.
11087 11088 11089 11090 11091 |
# File 'lib/increase/models/card_payment.rb', line 11087 required :no_show_indicator, enum: -> { Increase::CardPayment::Element::CardSettlement::PurchaseDetails::Lodging::NoShowIndicator }, nil?: true |
#prepaid_expenses_amount ⇒ Integer?
Prepaid expenses being charged for the room.
11097 |
# File 'lib/increase/models/card_payment.rb', line 11097 required :prepaid_expenses_amount, Integer, nil?: true |
#prepaid_expenses_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the prepaid expenses.
11104 |
# File 'lib/increase/models/card_payment.rb', line 11104 required :prepaid_expenses_currency, String, nil?: true |
#room_nights ⇒ Integer?
Number of nights the room was rented.
11110 |
# File 'lib/increase/models/card_payment.rb', line 11110 required :room_nights, Integer, nil?: true |
#total_room_tax_amount ⇒ Integer?
Total room tax being charged.
11116 |
# File 'lib/increase/models/card_payment.rb', line 11116 required :total_room_tax_amount, Integer, nil?: true |
#total_room_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total room tax.
11123 |
# File 'lib/increase/models/card_payment.rb', line 11123 required :total_room_tax_currency, String, nil?: true |
#total_tax_amount ⇒ Integer?
Total tax being charged for the room.
11129 |
# File 'lib/increase/models/card_payment.rb', line 11129 required :total_tax_amount, Integer, nil?: true |
#total_tax_currency ⇒ String?
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the total tax assessed.
11136 |
# File 'lib/increase/models/card_payment.rb', line 11136 required :total_tax_currency, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 11204
|