Class: Increase::Models::CardPayment::Element::CardValidation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardValidation
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
Defined Under Namespace
Modules: Actioner, Currency, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardValidation::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardValidation::Currency
The ISO 4217 code for the transaction's currency.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#id ⇒ String
The Card Validation identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::CardPayment::Element::CardValidation::NetworkDetails
Fields specific to the
network. -
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardValidation::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardValidation::SchemeFee>
The scheme fees associated with this card validation.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardValidation::Type
A constant representing the object's type.
-
#verification ⇒ Increase::Models::CardPayment::Element::CardValidation::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for a specific request or transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/card_payment.rb', line 12793
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::CardPayment::Element::CardValidation::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
12657 |
# File 'lib/increase/models/card_payment.rb', line 12657 required :actioner, enum: -> { Increase::CardPayment::Element::CardValidation::Actioner } |
#additional_amounts ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM
surcharges fees. These are usually a subset of the amount field and are used
to provide more detailed information about the transaction.
12665 |
# File 'lib/increase/models/card_payment.rb', line 12665 required :additional_amounts, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts } |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
12671 |
# File 'lib/increase/models/card_payment.rb', line 12671 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::CardPayment::Element::CardValidation::Currency
The ISO 4217 code for the transaction's currency.
12678 |
# File 'lib/increase/models/card_payment.rb', line 12678 required :currency, enum: -> { Increase::CardPayment::Element::CardValidation::Currency } |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
12685 |
# File 'lib/increase/models/card_payment.rb', line 12685 required :digital_wallet_token_id, String, nil?: true |
#id ⇒ String
The Card Validation identifier.
12650 |
# File 'lib/increase/models/card_payment.rb', line 12650 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
12692 |
# File 'lib/increase/models/card_payment.rb', line 12692 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
12699 |
# File 'lib/increase/models/card_payment.rb', line 12699 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
12705 |
# File 'lib/increase/models/card_payment.rb', line 12705 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
12711 |
# File 'lib/increase/models/card_payment.rb', line 12711 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
12717 |
# File 'lib/increase/models/card_payment.rb', line 12717 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
12724 |
# File 'lib/increase/models/card_payment.rb', line 12724 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
12730 |
# File 'lib/increase/models/card_payment.rb', line 12730 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::CardPayment::Element::CardValidation::NetworkDetails
Fields specific to the network.
12736 |
# File 'lib/increase/models/card_payment.rb', line 12736 required :network_details, -> { Increase::CardPayment::Element::CardValidation::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::CardPayment::Element::CardValidation::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
12742 |
# File 'lib/increase/models/card_payment.rb', line 12742 required :network_identifiers, -> { Increase::CardPayment::Element::CardValidation::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
12750 |
# File 'lib/increase/models/card_payment.rb', line 12750 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
12757 |
# File 'lib/increase/models/card_payment.rb', line 12757 required :physical_card_id, String, nil?: true |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
12764 |
# File 'lib/increase/models/card_payment.rb', line 12764 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::CardPayment::Element::CardValidation::SchemeFee>
The scheme fees associated with this card validation.
12770 12771 |
# File 'lib/increase/models/card_payment.rb', line 12770 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::CardPayment::Element::CardValidation::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
12778 |
# File 'lib/increase/models/card_payment.rb', line 12778 required :terminal_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::CardPayment::Element::CardValidation::Type
A constant representing the object's type. For this resource it will always be
inbound_card_validation.
12785 |
# File 'lib/increase/models/card_payment.rb', line 12785 required :type, enum: -> { Increase::CardPayment::Element::CardValidation::Type } |
#verification ⇒ Increase::Models::CardPayment::Element::CardValidation::Verification
Fields related to verification of cardholder-provided values.
12791 |
# File 'lib/increase/models/card_payment.rb', line 12791 required :verification, -> { Increase::CardPayment::Element::CardValidation::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/card_payment.rb', line 12889
|
Instance Method Details
#to_hash ⇒ {
9027 |
# File 'sig/increase/models/card_payment.rbs', line 9027
def to_hash: -> {
|