Class: Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts
- Defined in:
- lib/increase/models/card_payment.rb
Overview
Defined Under Namespace
Classes: Clinic, Dental, Original, Prescription, Surcharge, TotalCumulative, TotalHealthcare, Transit, Unknown, Vision
Instance Attribute Summary collapse
-
#clinic ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
-
#dental ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
-
#original ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Original?
The original pre-authorized amount.
-
#prescription ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
-
#surcharge ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
-
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
-
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
-
#transit ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
-
#unknown ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Unknown?
An unknown additional amount.
-
#vision ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
Instance Method Summary collapse
-
#initialize(amount:, currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Unknown for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:) ⇒ Object
Some parameter documentations has been truncated, see Unknown for more details.
An unknown additional amount.
|
|
# File 'lib/increase/models/card_payment.rb', line 12223
|
Instance Attribute Details
#clinic ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Clinic?
The part of this transaction amount that was for clinic-related services.
12143 12144 12145 |
# File 'lib/increase/models/card_payment.rb', line 12143 required :clinic, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Clinic }, nil?: true |
#dental ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Dental?
The part of this transaction amount that was for dental-related services.
12151 12152 12153 |
# File 'lib/increase/models/card_payment.rb', line 12151 required :dental, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Dental }, nil?: true |
#original ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Original?
The original pre-authorized amount.
12159 12160 12161 |
# File 'lib/increase/models/card_payment.rb', line 12159 required :original, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Original }, nil?: true |
#prescription ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Prescription?
The part of this transaction amount that was for healthcare prescriptions.
12167 12168 12169 |
# File 'lib/increase/models/card_payment.rb', line 12167 required :prescription, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Prescription }, nil?: true |
#surcharge ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Surcharge?
The surcharge amount charged for this transaction by the merchant.
12175 12176 12177 |
# File 'lib/increase/models/card_payment.rb', line 12175 required :surcharge, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Surcharge }, nil?: true |
#total_cumulative ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::TotalCumulative?
The total amount of a series of incremental authorizations, optionally provided.
12183 12184 12185 12186 12187 |
# File 'lib/increase/models/card_payment.rb', line 12183 required :total_cumulative, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::TotalCumulative }, nil?: true |
#total_healthcare ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::TotalHealthcare?
The total amount of healthcare-related additional amounts.
12193 12194 12195 12196 12197 |
# File 'lib/increase/models/card_payment.rb', line 12193 required :total_healthcare, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::TotalHealthcare }, nil?: true |
#transit ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Transit?
The part of this transaction amount that was for transit-related services.
12203 12204 12205 |
# File 'lib/increase/models/card_payment.rb', line 12203 required :transit, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Transit }, nil?: true |
#unknown ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Unknown?
An unknown additional amount.
12211 12212 12213 |
# File 'lib/increase/models/card_payment.rb', line 12211 required :unknown, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Unknown }, nil?: true |
#vision ⇒ Increase::Models::CardPayment::Element::CardValidation::AdditionalAmounts::Vision?
The part of this transaction amount that was for vision-related services.
12219 12220 12221 |
# File 'lib/increase/models/card_payment.rb', line 12219 required :vision, -> { Increase::CardPayment::Element::CardValidation::AdditionalAmounts::Vision }, nil?: true |