Module: Increase::Models::CardPayment::Element::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/card_payment.rb,
sig/increase/models/card_payment.rbs
Overview
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
Constant Summary collapse
- CARD_AUTHORIZATION =
Card Authorization: details will be under the
card_authorizationobject. :card_authorization- CARD_AUTHENTICATION =
Card Authentication: details will be under the
card_authenticationobject. :card_authentication- CARD_BALANCE_INQUIRY =
Card Balance Inquiry: details will be under the
card_balance_inquiryobject. :card_balance_inquiry- CARD_VALIDATION =
Inbound Card Validation: details will be under the
card_validationobject. :card_validation- CARD_DECLINE =
Card Decline: details will be under the
card_declineobject. :card_decline- CARD_REVERSAL =
Card Reversal: details will be under the
card_reversalobject. :card_reversal- CARD_AUTHORIZATION_EXPIRATION =
Card Authorization Expiration: details will be under the
card_authorization_expirationobject. :card_authorization_expiration- CARD_INCREMENT =
Card Increment: details will be under the
card_incrementobject. :card_increment- CARD_SETTLEMENT =
Card Settlement: details will be under the
card_settlementobject. :card_settlement- CARD_REFUND =
Card Refund: details will be under the
card_refundobject. :card_refund- CARD_FUEL_CONFIRMATION =
Card Fuel Confirmation: details will be under the
card_fuel_confirmationobject. :card_fuel_confirmation- CARD_FINANCIAL =
Card Financial: details will be under the
card_financialobject. :card_financial- OTHER =
Unknown card payment element.
:other
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CardPayment::Element::category]
202 |
# File 'sig/increase/models/card_payment.rbs', line 202
def self?.values: -> ::Array[Increase::Models::CardPayment::Element::category]
|