Class: Increase::Models::CardPushTransfer::PresentmentAmount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CardPushTransfer::PresentmentAmount
- Defined in:
- lib/increase/models/card_push_transfer.rb,
sig/increase/models/card_push_transfer.rbs
Overview
Defined Under Namespace
Modules: Currency
Instance Attribute Summary collapse
-
#currency ⇒ Symbol, Increase::Models::CardPushTransfer::PresentmentAmount::Currency
The ISO 4217 currency code.
-
#value ⇒ String
The amount value represented as a string containing a decimal number in major units (so e.g., "12.34" for $12.34).
Instance Method Summary collapse
-
#initialize(currency:, value:) ⇒ Object
constructor
The amount that was transferred.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, value:) ⇒ Object
The amount that was transferred. The receiving bank will have converted this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
|
|
# File 'lib/increase/models/card_push_transfer.rb', line 902
|
Instance Attribute Details
#currency ⇒ Symbol, Increase::Models::CardPushTransfer::PresentmentAmount::Currency
The ISO 4217 currency code.
893 |
# File 'lib/increase/models/card_push_transfer.rb', line 893 required :currency, enum: -> { Increase::CardPushTransfer::PresentmentAmount::Currency } |
#value ⇒ String
The amount value represented as a string containing a decimal number in major units (so e.g., "12.34" for $12.34).
900 |
# File 'lib/increase/models/card_push_transfer.rb', line 900 required :value, String |
Instance Method Details
#to_hash ⇒ {
706 |
# File 'sig/increase/models/card_push_transfer.rbs', line 706
def to_hash: -> {
|