Module: Increase::Models::CardPushTransferListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/card_push_transfer_list_params.rb,
sig/increase/models/card_push_transfer_list_params.rbs

Constant Summary collapse

PENDING_APPROVAL =

The transfer is pending approval.

Returns:

  • (:pending_approval)
:pending_approval
CANCELED =

The transfer has been canceled.

Returns:

  • (:canceled)
:canceled
PENDING_SUBMISSION =

The transfer is queued to be submitted to the card network.

Returns:

  • (:pending_submission)
:pending_submission
PENDING_REVIEWING =

The transfer is pending review by Increase.

Returns:

  • (:pending_reviewing)
:pending_reviewing
REQUIRES_ATTENTION =

The transfer requires attention from an Increase operator.

Returns:

  • (:requires_attention)
:requires_attention
SUBMITTED =

The transfer has been submitted and is pending a response from the card network.

Returns:

  • (:submitted)
:submitted
COMPLETE =

The transfer has been sent successfully and is complete.

Returns:

  • (:complete)
:complete
DECLINED =

The transfer was declined by the network or the recipient's bank.

Returns:

  • (:declined)
:declined

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/card_push_transfer_list_params.rb', line 153

Instance Method Details

#initialize(in_: nil) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::CardPushTransferListParams::Status for more details.

Parameters:



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/increase/models/card_push_transfer_list_params.rb', line 126

module In
  extend Increase::Internal::Type::Enum

  # The transfer is pending approval.
  PENDING_APPROVAL = :pending_approval

  # The transfer has been canceled.
  CANCELED = :canceled

  # The transfer is queued to be submitted to the card network.
  PENDING_SUBMISSION = :pending_submission

  # The transfer is pending review by Increase.
  PENDING_REVIEWING = :pending_reviewing

  # The transfer requires attention from an Increase operator.
  REQUIRES_ATTENTION = :requires_attention

  # The transfer has been submitted and is pending a response from the card network.
  SUBMITTED = :submitted

  # The transfer has been sent successfully and is complete.
  COMPLETE = :complete

  # The transfer was declined by the network or the recipient's bank.
  DECLINED = :declined

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::CardPushTransferListParams::Status::in_]

Returns:

  • (::Array[Increase::Models::CardPushTransferListParams::Status::in_])


158
# File 'sig/increase/models/card_push_transfer_list_params.rbs', line 158

def self?.values: -> ::Array[Increase::Models::CardPushTransferListParams::Status::in_]