Class: Increase::Models::CardUpdateParams::AuthorizationControls::MerchantCountry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/card_update_params.rb

Overview

See Also:

Defined Under Namespace

Classes: Allowed, Blocked

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:) ⇒ Object

Parameters:

  • country (String)

    The ISO 3166-1 alpha-2 country code.



# File 'lib/increase/models/card_update_params.rb', line 262

Instance Attribute Details

#allowedArray<Increase::Models::CardUpdateParams::AuthorizationControls::MerchantCountry::Allowed>?

The merchant countries that are allowed for authorizations on this card. Authorizations with merchant countries not in this list will be declined.



232
233
# File 'lib/increase/models/card_update_params.rb', line 232

optional :allowed,
-> { Increase::Internal::Type::ArrayOf[Increase::CardUpdateParams::AuthorizationControls::MerchantCountry::Allowed] }

#blockedArray<Increase::Models::CardUpdateParams::AuthorizationControls::MerchantCountry::Blocked>?

The merchant countries that are blocked for authorizations on this card. Authorizations with merchant countries in this list will be declined.



240
241
# File 'lib/increase/models/card_update_params.rb', line 240

optional :blocked,
-> { Increase::Internal::Type::ArrayOf[Increase::CardUpdateParams::AuthorizationControls::MerchantCountry::Blocked] }