Class: Increase::Models::CheckDeposit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckDeposit
- Defined in:
- lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs
Overview
Defined Under Namespace
Modules: Status, Type Classes: DepositAcceptance, DepositAdjustment, DepositRejection, DepositReturn, DepositSubmission, InboundFundsHold
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account the check was deposited into.
-
#amount ⇒ Integer
The deposited amount in USD cents.
-
#back_image_file_id ⇒ String?
The ID for the File containing the image of the back of the check.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the transfer was created.
-
#deposit_acceptance ⇒ Increase::Models::CheckDeposit::DepositAcceptance?
Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
#deposit_adjustments ⇒ Array<Increase::Models::CheckDeposit::DepositAdjustment>
If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments.
-
#deposit_rejection ⇒ Increase::Models::CheckDeposit::DepositRejection?
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
#deposit_return ⇒ Increase::Models::CheckDeposit::DepositReturn?
If your deposit is returned, this will contain details as to why it was returned.
-
#deposit_submission ⇒ Increase::Models::CheckDeposit::DepositSubmission?
After the check is parsed, it is submitted to the Check21 network for processing.
-
#description ⇒ String?
The description of the Check Deposit, for display purposes only.
-
#front_image_file_id ⇒ String
The ID for the File containing the image of the front of the check.
-
#id ⇒ String
The deposit's identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#inbound_funds_hold ⇒ Increase::Models::CheckDeposit::InboundFundsHold?
Increase will sometimes hold the funds for Check Deposits.
-
#inbound_mail_item_id ⇒ String?
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.
-
#lockbox_recipient_id ⇒ String?
If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it.
-
#status ⇒ Symbol, Increase::Models::CheckDeposit::Status
The status of the Check Deposit.
-
#transaction_id ⇒ String?
The ID for the Transaction created by the deposit.
-
#type ⇒ Symbol, Increase::Models::CheckDeposit::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(back_file_id:, front_file_id:, submitted_at:) ⇒ Object
constructor
After the check is parsed, it is submitted to the Check21 network for processing.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(back_file_id:, front_file_id:, submitted_at:) ⇒ Object
After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
|
|
# File 'lib/increase/models/check_deposit.rb', line 135
|
Instance Attribute Details
#account_id ⇒ String
The Account the check was deposited into.
17 |
# File 'lib/increase/models/check_deposit.rb', line 17 required :account_id, String |
#amount ⇒ Integer
The deposited amount in USD cents.
23 |
# File 'lib/increase/models/check_deposit.rb', line 23 required :amount, Integer |
#back_image_file_id ⇒ String?
The ID for the File containing the image of the back of the check.
29 |
# File 'lib/increase/models/check_deposit.rb', line 29 required :back_image_file_id, String, nil?: true |
#created_at ⇒ Time
The ISO 8601 date and time at which the transfer was created.
36 |
# File 'lib/increase/models/check_deposit.rb', line 36 required :created_at, Time |
#deposit_acceptance ⇒ Increase::Models::CheckDeposit::DepositAcceptance?
Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
43 |
# File 'lib/increase/models/check_deposit.rb', line 43 required :deposit_acceptance, -> { Increase::CheckDeposit::DepositAcceptance }, nil?: true |
#deposit_adjustments ⇒ Array<Increase::Models::CheckDeposit::DepositAdjustment>
If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments.
50 51 |
# File 'lib/increase/models/check_deposit.rb', line 50 required :deposit_adjustments, -> { Increase::Internal::Type::ArrayOf[Increase::CheckDeposit::DepositAdjustment] } |
#deposit_rejection ⇒ Increase::Models::CheckDeposit::DepositRejection?
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
58 |
# File 'lib/increase/models/check_deposit.rb', line 58 required :deposit_rejection, -> { Increase::CheckDeposit::DepositRejection }, nil?: true |
#deposit_return ⇒ Increase::Models::CheckDeposit::DepositReturn?
If your deposit is returned, this will contain details as to why it was returned.
65 |
# File 'lib/increase/models/check_deposit.rb', line 65 required :deposit_return, -> { Increase::CheckDeposit::DepositReturn }, nil?: true |
#deposit_submission ⇒ Increase::Models::CheckDeposit::DepositSubmission?
After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
72 |
# File 'lib/increase/models/check_deposit.rb', line 72 required :deposit_submission, -> { Increase::CheckDeposit::DepositSubmission }, nil?: true |
#description ⇒ String?
The description of the Check Deposit, for display purposes only.
78 |
# File 'lib/increase/models/check_deposit.rb', line 78 required :description, String, nil?: true |
#front_image_file_id ⇒ String
The ID for the File containing the image of the front of the check.
84 |
# File 'lib/increase/models/check_deposit.rb', line 84 required :front_image_file_id, String |
#id ⇒ String
The deposit's identifier.
11 |
# File 'lib/increase/models/check_deposit.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
92 |
# File 'lib/increase/models/check_deposit.rb', line 92 required :idempotency_key, String, nil?: true |
#inbound_funds_hold ⇒ Increase::Models::CheckDeposit::InboundFundsHold?
Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
99 |
# File 'lib/increase/models/check_deposit.rb', line 99 required :inbound_funds_hold, -> { Increase::CheckDeposit::InboundFundsHold }, nil?: true |
#inbound_mail_item_id ⇒ String?
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.
106 |
# File 'lib/increase/models/check_deposit.rb', line 106 required :inbound_mail_item_id, String, nil?: true |
#lockbox_recipient_id ⇒ String?
If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it.
114 |
# File 'lib/increase/models/check_deposit.rb', line 114 required :lockbox_recipient_id, String, nil?: true |
#status ⇒ Symbol, Increase::Models::CheckDeposit::Status
The status of the Check Deposit.
120 |
# File 'lib/increase/models/check_deposit.rb', line 120 required :status, enum: -> { Increase::CheckDeposit::Status } |
#transaction_id ⇒ String?
The ID for the Transaction created by the deposit.
126 |
# File 'lib/increase/models/check_deposit.rb', line 126 required :transaction_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::CheckDeposit::Type
A constant representing the object's type. For this resource it will always be
check_deposit.
133 |
# File 'lib/increase/models/check_deposit.rb', line 133 required :type, enum: -> { Increase::CheckDeposit::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_deposit.rb', line 290
|
Instance Method Details
#to_hash ⇒ {
87 |
# File 'sig/increase/models/check_deposit.rbs', line 87
def to_hash: -> {
|