Module: Increase::Models::CheckDeposit::DepositAdjustment::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/check_deposit.rb

Overview

The reason for the adjustment.

See Also:

Constant Summary collapse

ADJUSTED_AMOUNT =

The check was deposited with a different amount than what was written on the check.

:adjusted_amount
NON_CONFORMING_ITEM =

The recipient was not able to process the check. This usually happens for e.g., low quality images.

:non_conforming_item
:paid

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info