Class: Increase::Models::CheckDeposit::DepositSubmission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckDeposit::DepositSubmission
- Defined in:
- lib/increase/models/check_deposit.rb,
sig/increase/models/check_deposit.rbs
Overview
Instance Attribute Summary collapse
-
#back_file_id ⇒ String
The ID for the File containing the check back image that was submitted to the Check21 network.
-
#front_file_id ⇒ String
The ID for the File containing the check front image that was submitted to the Check21 network.
-
#submitted_at ⇒ Time
When the check deposit was submitted to the Check21 network for processing.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
500 |
# File 'sig/increase/models/check_deposit.rbs', line 500
def initialize: (
|
Instance Attribute Details
#back_file_id ⇒ String
The ID for the File containing the check back image that was submitted to the Check21 network.
612 |
# File 'lib/increase/models/check_deposit.rb', line 612 required :back_file_id, String |
#front_file_id ⇒ String
The ID for the File containing the check front image that was submitted to the Check21 network.
619 |
# File 'lib/increase/models/check_deposit.rb', line 619 required :front_file_id, String |
#submitted_at ⇒ Time
When the check deposit was submitted to the Check21 network for processing. During business days, this happens within a few hours of the check being accepted by Increase.
627 |
# File 'lib/increase/models/check_deposit.rb', line 627 required :submitted_at, Time |
Instance Method Details
#to_hash ⇒ {
506 |
# File 'sig/increase/models/check_deposit.rbs', line 506
def to_hash: -> {
|