Class: Increase::Models::CheckDeposit::DepositSubmission

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_deposit.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#back_file_idString

The ID for the File containing the check back image that was submitted to the Check21 network.

Returns:

  • (String)


611
# File 'lib/increase/models/check_deposit.rb', line 611

required :back_file_id, String

#front_file_idString

The ID for the File containing the check front image that was submitted to the Check21 network.

Returns:

  • (String)


618
# File 'lib/increase/models/check_deposit.rb', line 618

required :front_file_id, String

#submitted_atTime

When the check deposit was submitted to the Check21 network for processing. During business days, this happens within a few hours of the check being accepted by Increase.

Returns:

  • (Time)


626
# File 'lib/increase/models/check_deposit.rb', line 626

required :submitted_at, Time