Class: Increase::Models::CheckDeposit::InboundFundsHold
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckDeposit::InboundFundsHold
- Defined in:
- lib/increase/models/check_deposit.rb
Overview
Defined Under Namespace
Modules: Currency, Status, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The held amount in the minor unit of the account’s currency.
-
#automatically_releases_at ⇒ Time
When the hold will be released automatically.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the hold was created.
-
#currency ⇒ Symbol, Increase::Models::CheckDeposit::InboundFundsHold::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the hold’s currency.
-
#held_transaction_id ⇒ String?
The ID of the Transaction for which funds were held.
-
#pending_transaction_id ⇒ String?
The ID of the Pending Transaction representing the held funds.
-
#released_at ⇒ Time?
When the hold was released (if it has been released).
-
#status ⇒ Symbol, Increase::Models::CheckDeposit::InboundFundsHold::Status
The status of the hold.
-
#type ⇒ Symbol, Increase::Models::CheckDeposit::InboundFundsHold::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see InboundFundsHold for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CheckDeposit::InboundFundsHold for more details.
Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
|
|
# File 'lib/increase/models/check_deposit.rb', line 703
|
Instance Attribute Details
#amount ⇒ Integer
The held amount in the minor unit of the account’s currency. For dollars, for example, this is cents.
649 |
# File 'lib/increase/models/check_deposit.rb', line 649 required :amount, Integer |
#automatically_releases_at ⇒ Time
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
656 |
# File 'lib/increase/models/check_deposit.rb', line 656 required :automatically_releases_at, Time |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the hold was created.
663 |
# File 'lib/increase/models/check_deposit.rb', line 663 required :created_at, Time |
#currency ⇒ Symbol, Increase::Models::CheckDeposit::InboundFundsHold::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the hold’s currency.
670 |
# File 'lib/increase/models/check_deposit.rb', line 670 required :currency, enum: -> { Increase::CheckDeposit::InboundFundsHold::Currency } |
#held_transaction_id ⇒ String?
The ID of the Transaction for which funds were held.
676 |
# File 'lib/increase/models/check_deposit.rb', line 676 required :held_transaction_id, String, nil?: true |
#pending_transaction_id ⇒ String?
The ID of the Pending Transaction representing the held funds.
682 |
# File 'lib/increase/models/check_deposit.rb', line 682 required :pending_transaction_id, String, nil?: true |
#released_at ⇒ Time?
When the hold was released (if it has been released).
688 |
# File 'lib/increase/models/check_deposit.rb', line 688 required :released_at, Time, nil?: true |
#status ⇒ Symbol, Increase::Models::CheckDeposit::InboundFundsHold::Status
The status of the hold.
694 |
# File 'lib/increase/models/check_deposit.rb', line 694 required :status, enum: -> { Increase::CheckDeposit::InboundFundsHold::Status } |
#type ⇒ Symbol, Increase::Models::CheckDeposit::InboundFundsHold::Type
A constant representing the object’s type. For this resource it will always be ‘inbound_funds_hold`.
701 |
# File 'lib/increase/models/check_deposit.rb', line 701 required :type, enum: -> { Increase::CheckDeposit::InboundFundsHold::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_deposit.rb', line 738
|