Class: Increase::Models::CheckTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb

Overview

Defined Under Namespace

Modules: BalanceCheck, Currency, FulfillmentMethod, Status, Type Classes: Approval, Cancellation, CreatedBy, Mailing, PhysicalCheck, StopPaymentRequest, Submission, ThirdParty

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(recipient_name:) ⇒ Object

Details relating to the custom fulfillment you will perform. Will be present if and only if ‘fulfillment_method` is equal to `third_party`.

Parameters:

  • recipient_name (String, nil)

    The name that you will print on the check.



# File 'lib/increase/models/check_transfer.rb', line 176

Instance Attribute Details

#account_idString

The identifier of the Account from which funds will be transferred.

Returns:

  • (String)


17
# File 'lib/increase/models/check_transfer.rb', line 17

required :account_id, String

#account_numberString

The account number printed on the check.

Returns:

  • (String)


23
# File 'lib/increase/models/check_transfer.rb', line 23

required :account_number, String

#amountInteger

The transfer amount in USD cents.

Returns:

  • (Integer)


29
# File 'lib/increase/models/check_transfer.rb', line 29

required :amount, Integer

#approvalIncrease::Models::CheckTransfer::Approval?

If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.



36
# File 'lib/increase/models/check_transfer.rb', line 36

required :approval, -> { Increase::CheckTransfer::Approval }, nil?: true

#approved_inbound_check_deposit_idString?

If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.

Returns:

  • (String, nil)


43
# File 'lib/increase/models/check_transfer.rb', line 43

required :approved_inbound_check_deposit_id, String, nil?: true

#balance_checkSymbol, ...

How the account’s available balance should be checked.



49
# File 'lib/increase/models/check_transfer.rb', line 49

required :balance_check, enum: -> { Increase::CheckTransfer::BalanceCheck }, nil?: true

#cancellationIncrease::Models::CheckTransfer::Cancellation?

If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.



56
# File 'lib/increase/models/check_transfer.rb', line 56

required :cancellation, -> { Increase::CheckTransfer::Cancellation }, nil?: true

#check_numberString

The check number printed on the check.

Returns:

  • (String)


62
# File 'lib/increase/models/check_transfer.rb', line 62

required :check_number, String

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.

Returns:

  • (Time)


69
# File 'lib/increase/models/check_transfer.rb', line 69

required :created_at, Time

#created_byIncrease::Models::CheckTransfer::CreatedBy?

What object created the transfer, either via the API or the dashboard.



75
# File 'lib/increase/models/check_transfer.rb', line 75

required :created_by, -> { Increase::CheckTransfer::CreatedBy }, nil?: true

#currencySymbol, Increase::Models::CheckTransfer::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.



82
# File 'lib/increase/models/check_transfer.rb', line 82

required :currency, enum: -> { Increase::CheckTransfer::Currency }

#fulfillment_methodSymbol, Increase::Models::CheckTransfer::FulfillmentMethod

Whether Increase will print and mail the check or if you will do it yourself.



88
# File 'lib/increase/models/check_transfer.rb', line 88

required :fulfillment_method, enum: -> { Increase::CheckTransfer::FulfillmentMethod }

#idString

The Check transfer’s identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/check_transfer.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).

Returns:

  • (String, nil)


96
# File 'lib/increase/models/check_transfer.rb', line 96

required :idempotency_key, String, nil?: true

#mailingIncrease::Models::CheckTransfer::Mailing?

If the check has been mailed by Increase, this will contain details of the shipment.



103
# File 'lib/increase/models/check_transfer.rb', line 103

required :mailing, -> { Increase::CheckTransfer::Mailing }, nil?: true

#pending_transaction_idString?

The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer [requires approval](increase.com/documentation/transfer-approvals#transfer-approvals) by someone else in your organization.

Returns:

  • (String, nil)


112
# File 'lib/increase/models/check_transfer.rb', line 112

required :pending_transaction_id, String, nil?: true

#physical_checkIncrease::Models::CheckTransfer::PhysicalCheck?

Details relating to the physical check that Increase will print and mail. Will be present if and only if ‘fulfillment_method` is equal to `physical_check`.



119
# File 'lib/increase/models/check_transfer.rb', line 119

required :physical_check, -> { Increase::CheckTransfer::PhysicalCheck }, nil?: true

#routing_numberString

The routing number printed on the check.

Returns:

  • (String)


125
# File 'lib/increase/models/check_transfer.rb', line 125

required :routing_number, String

#source_account_number_idString?

The identifier of the Account Number from which to send the transfer and print on the check.

Returns:

  • (String, nil)


132
# File 'lib/increase/models/check_transfer.rb', line 132

required :source_account_number_id, String, nil?: true

#statusSymbol, Increase::Models::CheckTransfer::Status

The lifecycle status of the transfer.



138
# File 'lib/increase/models/check_transfer.rb', line 138

required :status, enum: -> { Increase::CheckTransfer::Status }

#stop_payment_requestIncrease::Models::CheckTransfer::StopPaymentRequest?

After a stop-payment is requested on the check, this will contain supplemental details.



145
# File 'lib/increase/models/check_transfer.rb', line 145

required :stop_payment_request, -> { Increase::CheckTransfer::StopPaymentRequest }, nil?: true

#submissionIncrease::Models::CheckTransfer::Submission?

After the transfer is submitted, this will contain supplemental details.



151
# File 'lib/increase/models/check_transfer.rb', line 151

required :submission, -> { Increase::CheckTransfer::Submission }, nil?: true

#third_partyIncrease::Models::CheckTransfer::ThirdParty?

Details relating to the custom fulfillment you will perform. Will be present if and only if ‘fulfillment_method` is equal to `third_party`.



158
# File 'lib/increase/models/check_transfer.rb', line 158

required :third_party, -> { Increase::CheckTransfer::ThirdParty }, nil?: true

#typeSymbol, Increase::Models::CheckTransfer::Type

A constant representing the object’s type. For this resource it will always be ‘check_transfer`.



165
# File 'lib/increase/models/check_transfer.rb', line 165

required :type, enum: -> { Increase::CheckTransfer::Type }

#valid_until_dateDate?

If set, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.

Returns:

  • (Date, nil)


174
# File 'lib/increase/models/check_transfer.rb', line 174

required :valid_until_date, Date, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/check_transfer.rb', line 273