Class: Increase::Models::CheckTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer
- Defined in:
- lib/increase/models/check_transfer.rb
Overview
Defined Under Namespace
Modules: BalanceCheck, Currency, FulfillmentMethod, Status, Type Classes: Approval, Cancellation, CreatedBy, Mailing, PhysicalCheck, StopPaymentRequest, Submission, ThirdParty
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier of the Account from which funds will be transferred.
-
#account_number ⇒ String
The account number printed on the check.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#approval ⇒ Increase::Models::CheckTransfer::Approval?
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
#approved_inbound_check_deposit_id ⇒ String?
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
#balance_check ⇒ Symbol, ...
How the account’s available balance should be checked.
-
#cancellation ⇒ Increase::Models::CheckTransfer::Cancellation?
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
#check_number ⇒ String
The check number printed on the check.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
-
#created_by ⇒ Increase::Models::CheckTransfer::CreatedBy?
What object created the transfer, either via the API or the dashboard.
-
#currency ⇒ Symbol, Increase::Models::CheckTransfer::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.
-
#fulfillment_method ⇒ Symbol, Increase::Models::CheckTransfer::FulfillmentMethod
Whether Increase will print and mail the check or if you will do it yourself.
-
#id ⇒ String
The Check transfer’s identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#mailing ⇒ Increase::Models::CheckTransfer::Mailing?
If the check has been mailed by Increase, this will contain details of the shipment.
-
#pending_transaction_id ⇒ String?
The ID for the pending transaction representing the transfer.
-
#physical_check ⇒ Increase::Models::CheckTransfer::PhysicalCheck?
Details relating to the physical check that Increase will print and mail.
-
#routing_number ⇒ String
The routing number printed on the check.
-
#source_account_number_id ⇒ String?
The identifier of the Account Number from which to send the transfer and print on the check.
-
#status ⇒ Symbol, Increase::Models::CheckTransfer::Status
The lifecycle status of the transfer.
-
#stop_payment_request ⇒ Increase::Models::CheckTransfer::StopPaymentRequest?
After a stop-payment is requested on the check, this will contain supplemental details.
-
#submission ⇒ Increase::Models::CheckTransfer::Submission?
After the transfer is submitted, this will contain supplemental details.
-
#third_party ⇒ Increase::Models::CheckTransfer::ThirdParty?
Details relating to the custom fulfillment you will perform.
-
#type ⇒ Symbol, Increase::Models::CheckTransfer::Type
A constant representing the object’s type.
-
#valid_until_date ⇒ Date?
If set, the check will be valid on or before this date.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(recipient_name:) ⇒ Object
constructor
Details relating to the custom fulfillment you will perform.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(recipient_name:) ⇒ Object
Details relating to the custom fulfillment you will perform. Will be present if and only if ‘fulfillment_method` is equal to `third_party`.
|
|
# File 'lib/increase/models/check_transfer.rb', line 176
|
Instance Attribute Details
#account_id ⇒ String
The identifier of the Account from which funds will be transferred.
17 |
# File 'lib/increase/models/check_transfer.rb', line 17 required :account_id, String |
#account_number ⇒ String
The account number printed on the check.
23 |
# File 'lib/increase/models/check_transfer.rb', line 23 required :account_number, String |
#amount ⇒ Integer
The transfer amount in USD cents.
29 |
# File 'lib/increase/models/check_transfer.rb', line 29 required :amount, Integer |
#approval ⇒ Increase::Models::CheckTransfer::Approval?
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
36 |
# File 'lib/increase/models/check_transfer.rb', line 36 required :approval, -> { Increase::CheckTransfer::Approval }, nil?: true |
#approved_inbound_check_deposit_id ⇒ String?
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
43 |
# File 'lib/increase/models/check_transfer.rb', line 43 required :approved_inbound_check_deposit_id, String, nil?: true |
#balance_check ⇒ Symbol, ...
How the account’s available balance should be checked.
49 |
# File 'lib/increase/models/check_transfer.rb', line 49 required :balance_check, enum: -> { Increase::CheckTransfer::BalanceCheck }, nil?: true |
#cancellation ⇒ Increase::Models::CheckTransfer::Cancellation?
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
56 |
# File 'lib/increase/models/check_transfer.rb', line 56 required :cancellation, -> { Increase::CheckTransfer::Cancellation }, nil?: true |
#check_number ⇒ String
The check number printed on the check.
62 |
# File 'lib/increase/models/check_transfer.rb', line 62 required :check_number, String |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
69 |
# File 'lib/increase/models/check_transfer.rb', line 69 required :created_at, Time |
#created_by ⇒ Increase::Models::CheckTransfer::CreatedBy?
What object created the transfer, either via the API or the dashboard.
75 |
# File 'lib/increase/models/check_transfer.rb', line 75 required :created_by, -> { Increase::CheckTransfer::CreatedBy }, nil?: true |
#currency ⇒ Symbol, Increase::Models::CheckTransfer::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the check’s currency.
82 |
# File 'lib/increase/models/check_transfer.rb', line 82 required :currency, enum: -> { Increase::CheckTransfer::Currency } |
#fulfillment_method ⇒ Symbol, Increase::Models::CheckTransfer::FulfillmentMethod
Whether Increase will print and mail the check or if you will do it yourself.
88 |
# File 'lib/increase/models/check_transfer.rb', line 88 required :fulfillment_method, enum: -> { Increase::CheckTransfer::FulfillmentMethod } |
#id ⇒ String
The Check transfer’s identifier.
11 |
# File 'lib/increase/models/check_transfer.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
96 |
# File 'lib/increase/models/check_transfer.rb', line 96 required :idempotency_key, String, nil?: true |
#mailing ⇒ Increase::Models::CheckTransfer::Mailing?
If the check has been mailed by Increase, this will contain details of the shipment.
103 |
# File 'lib/increase/models/check_transfer.rb', line 103 required :mailing, -> { Increase::CheckTransfer::Mailing }, nil?: true |
#pending_transaction_id ⇒ String?
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer [requires approval](increase.com/documentation/transfer-approvals#transfer-approvals) by someone else in your organization.
112 |
# File 'lib/increase/models/check_transfer.rb', line 112 required :pending_transaction_id, String, nil?: true |
#physical_check ⇒ Increase::Models::CheckTransfer::PhysicalCheck?
Details relating to the physical check that Increase will print and mail. Will be present if and only if ‘fulfillment_method` is equal to `physical_check`.
119 |
# File 'lib/increase/models/check_transfer.rb', line 119 required :physical_check, -> { Increase::CheckTransfer::PhysicalCheck }, nil?: true |
#routing_number ⇒ String
The routing number printed on the check.
125 |
# File 'lib/increase/models/check_transfer.rb', line 125 required :routing_number, String |
#source_account_number_id ⇒ String?
The identifier of the Account Number from which to send the transfer and print on the check.
132 |
# File 'lib/increase/models/check_transfer.rb', line 132 required :source_account_number_id, String, nil?: true |
#status ⇒ Symbol, Increase::Models::CheckTransfer::Status
The lifecycle status of the transfer.
138 |
# File 'lib/increase/models/check_transfer.rb', line 138 required :status, enum: -> { Increase::CheckTransfer::Status } |
#stop_payment_request ⇒ Increase::Models::CheckTransfer::StopPaymentRequest?
After a stop-payment is requested on the check, this will contain supplemental details.
145 |
# File 'lib/increase/models/check_transfer.rb', line 145 required :stop_payment_request, -> { Increase::CheckTransfer::StopPaymentRequest }, nil?: true |
#submission ⇒ Increase::Models::CheckTransfer::Submission?
After the transfer is submitted, this will contain supplemental details.
151 |
# File 'lib/increase/models/check_transfer.rb', line 151 required :submission, -> { Increase::CheckTransfer::Submission }, nil?: true |
#third_party ⇒ Increase::Models::CheckTransfer::ThirdParty?
Details relating to the custom fulfillment you will perform. Will be present if and only if ‘fulfillment_method` is equal to `third_party`.
158 |
# File 'lib/increase/models/check_transfer.rb', line 158 required :third_party, -> { Increase::CheckTransfer::ThirdParty }, nil?: true |
#type ⇒ Symbol, Increase::Models::CheckTransfer::Type
A constant representing the object’s type. For this resource it will always be ‘check_transfer`.
165 |
# File 'lib/increase/models/check_transfer.rb', line 165 required :type, enum: -> { Increase::CheckTransfer::Type } |
#valid_until_date ⇒ Date?
If set, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.
174 |
# File 'lib/increase/models/check_transfer.rb', line 174 required :valid_until_date, Date, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_transfer.rb', line 273
|