Module: Increase::Models::CheckTransfer::FulfillmentMethod
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Whether Increase will print and mail the check or if you will do it yourself.
Constant Summary collapse
- PHYSICAL_CHECK =
Increase will print and mail a physical check.
:physical_check- THIRD_PARTY =
Increase will not print a check; you are responsible for printing and mailing a check with the provided account number, routing number, check number, and amount.
:third_party
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CheckTransfer::fulfillment_method]
278 |
# File 'sig/increase/models/check_transfer.rbs', line 278
def self?.values: -> ::Array[Increase::Models::CheckTransfer::fulfillment_method]
|