Class: Increase::Models::CheckTransfer::PhysicalCheck

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb

Overview

See Also:

Defined Under Namespace

Modules: ShippingMethod Classes: MailingAddress, Payer, ReturnAddress, Signature, TrackingUpdate

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(image_file_id:, text:) ⇒ Object

The signature that will appear on the check.

Parameters:

  • image_file_id (String, nil)

    The ID of a File containing a PNG of the signature.

  • text (String, nil)

    The text that will appear as the signature on the check in cursive font.



# File 'lib/increase/models/check_transfer.rb', line 529

Instance Attribute Details

#attachment_file_idString?

The ID of the file for the check attachment.

Returns:

  • (String, nil)


461
# File 'lib/increase/models/check_transfer.rb', line 461

required :attachment_file_id, String, nil?: true

#check_voucher_image_file_idString?

The ID of the file for the check voucher image.

Returns:

  • (String, nil)


467
# File 'lib/increase/models/check_transfer.rb', line 467

required :check_voucher_image_file_id, String, nil?: true

#mailing_addressIncrease::Models::CheckTransfer::PhysicalCheck::MailingAddress

Details for where Increase will mail the check.



473
# File 'lib/increase/models/check_transfer.rb', line 473

required :mailing_address, -> { Increase::CheckTransfer::PhysicalCheck::MailingAddress }

#memoString?

The descriptor that will be printed on the memo field on the check.

Returns:

  • (String, nil)


479
# File 'lib/increase/models/check_transfer.rb', line 479

required :memo, String, nil?: true

#noteString?

The descriptor that will be printed on the letter included with the check.

Returns:

  • (String, nil)


485
# File 'lib/increase/models/check_transfer.rb', line 485

required :note, String, nil?: true

#payerArray<Increase::Models::CheckTransfer::PhysicalCheck::Payer>

The payer of the check. This will be printed on the top-left portion of the check and defaults to the return address if unspecified.



492
# File 'lib/increase/models/check_transfer.rb', line 492

required :payer, -> { Increase::Internal::Type::ArrayOf[Increase::CheckTransfer::PhysicalCheck::Payer] }

#recipient_nameString

The name that will be printed on the check.

Returns:

  • (String)


498
# File 'lib/increase/models/check_transfer.rb', line 498

required :recipient_name, String

#return_addressIncrease::Models::CheckTransfer::PhysicalCheck::ReturnAddress?

The return address to be printed on the check.



504
# File 'lib/increase/models/check_transfer.rb', line 504

required :return_address, -> { Increase::CheckTransfer::PhysicalCheck::ReturnAddress }, nil?: true

#shipping_methodSymbol, ...

The shipping method for the check.



510
511
512
513
514
# File 'lib/increase/models/check_transfer.rb', line 510

required :shipping_method,
enum: -> {
  Increase::CheckTransfer::PhysicalCheck::ShippingMethod
},
nil?: true

#signatureIncrease::Models::CheckTransfer::PhysicalCheck::Signature

The signature that will appear on the check.



520
# File 'lib/increase/models/check_transfer.rb', line 520

required :signature, -> { Increase::CheckTransfer::PhysicalCheck::Signature }

#tracking_updatesArray<Increase::Models::CheckTransfer::PhysicalCheck::TrackingUpdate>

Tracking updates relating to the physical check’s delivery.



526
527
# File 'lib/increase/models/check_transfer.rb', line 526

required :tracking_updates,
-> { Increase::Internal::Type::ArrayOf[Increase::CheckTransfer::PhysicalCheck::TrackingUpdate] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/check_transfer.rb', line 715