Class: Increase::Models::CheckTransfer::PhysicalCheck::MailingAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::PhysicalCheck::MailingAddress
- Defined in:
- lib/increase/models/check_transfer.rb,
sig/increase/models/check_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String?
The city of the check's destination.
-
#line1 ⇒ String?
The street address of the check's destination.
-
#line2 ⇒ String?
The second line of the address of the check's destination.
-
#name ⇒ String?
The name component of the check's mailing address.
-
#phone ⇒ String?
The phone number to be used in case of delivery issues at the check's mailing address.
-
#postal_code ⇒ String?
The postal code of the check's destination.
-
#state ⇒ String?
The state of the check's destination.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
388 |
# File 'sig/increase/models/check_transfer.rbs', line 388
def initialize: (
|
Instance Attribute Details
#city ⇒ String?
The city of the check's destination.
613 |
# File 'lib/increase/models/check_transfer.rb', line 613 required :city, String, nil?: true |
#line1 ⇒ String?
The street address of the check's destination.
619 |
# File 'lib/increase/models/check_transfer.rb', line 619 required :line1, String, nil?: true |
#line2 ⇒ String?
The second line of the address of the check's destination.
625 |
# File 'lib/increase/models/check_transfer.rb', line 625 required :line2, String, nil?: true |
#name ⇒ String?
The name component of the check's mailing address.
631 |
# File 'lib/increase/models/check_transfer.rb', line 631 required :name, String, nil?: true |
#phone ⇒ String?
The phone number to be used in case of delivery issues at the check's mailing address. Only used for FedEx overnight shipping.
638 |
# File 'lib/increase/models/check_transfer.rb', line 638 required :phone, String, nil?: true |
#postal_code ⇒ String?
The postal code of the check's destination.
644 |
# File 'lib/increase/models/check_transfer.rb', line 644 required :postal_code, String, nil?: true |
#state ⇒ String?
The state of the check's destination.
650 |
# File 'lib/increase/models/check_transfer.rb', line 650 required :state, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
398 |
# File 'sig/increase/models/check_transfer.rbs', line 398
def to_hash: -> {
|