Class: Increase::Models::CheckTransfer::PhysicalCheck::MailingAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#cityString?

The city of the check’s destination.

Returns:

  • (String, nil)


562
# File 'lib/increase/models/check_transfer.rb', line 562

required :city, String, nil?: true

#line1String?

The street address of the check’s destination.

Returns:

  • (String, nil)


568
# File 'lib/increase/models/check_transfer.rb', line 568

required :line1, String, nil?: true

#line2String?

The second line of the address of the check’s destination.

Returns:

  • (String, nil)


574
# File 'lib/increase/models/check_transfer.rb', line 574

required :line2, String, nil?: true

#nameString?

The name component of the check’s mailing address.

Returns:

  • (String, nil)


580
# File 'lib/increase/models/check_transfer.rb', line 580

required :name, String, nil?: true

#phoneString?

The phone number to be used in case of delivery issues at the check’s mailing address. Only used for FedEx overnight shipping.

Returns:

  • (String, nil)


587
# File 'lib/increase/models/check_transfer.rb', line 587

required :phone, String, nil?: true

#postal_codeString?

The postal code of the check’s destination.

Returns:

  • (String, nil)


593
# File 'lib/increase/models/check_transfer.rb', line 593

required :postal_code, String, nil?: true

#stateString?

The state of the check’s destination.

Returns:

  • (String, nil)


599
# File 'lib/increase/models/check_transfer.rb', line 599

required :state, String, nil?: true