Class: Increase::Models::CheckTransfer::Submission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransfer::Submission
- Defined in:
- lib/increase/models/check_transfer.rb
Overview
Defined Under Namespace
Classes: SubmittedAddress
Instance Attribute Summary collapse
-
#preview_file_id ⇒ String?
The ID of the file corresponding to an image of the check that was mailed, if available.
-
#submitted_address ⇒ Increase::Models::CheckTransfer::Submission::SubmittedAddress
The address we submitted to the printer.
-
#submitted_at ⇒ Time
When this check was submitted to our check printer.
-
#tracking_number ⇒ String?
The tracking number for the check shipment.
Instance Method Summary collapse
-
#initialize(preview_file_id:, submitted_address:, submitted_at:, tracking_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Submission for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(preview_file_id:, submitted_address:, submitted_at:, tracking_number:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::CheckTransfer::Submission for more details.
After the transfer is submitted, this will contain supplemental details.
|
|
# File 'lib/increase/models/check_transfer.rb', line 946
|
Instance Attribute Details
#preview_file_id ⇒ String?
The ID of the file corresponding to an image of the check that was mailed, if available.
925 |
# File 'lib/increase/models/check_transfer.rb', line 925 required :preview_file_id, String, nil?: true |
#submitted_address ⇒ Increase::Models::CheckTransfer::Submission::SubmittedAddress
The address we submitted to the printer. This is what is physically printed on the check.
932 |
# File 'lib/increase/models/check_transfer.rb', line 932 required :submitted_address, -> { Increase::CheckTransfer::Submission::SubmittedAddress } |
#submitted_at ⇒ Time
When this check was submitted to our check printer.
938 |
# File 'lib/increase/models/check_transfer.rb', line 938 required :submitted_at, Time |
#tracking_number ⇒ String?
The tracking number for the check shipment.
944 |
# File 'lib/increase/models/check_transfer.rb', line 944 required :tracking_number, String, nil?: true |