Module: Increase::Models::CheckTransferCreateParams::BalanceCheck
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs
Overview
How the account's available balance should be checked. If omitted, the default
behavior is balance_check: full.
Constant Summary collapse
- FULL =
The available balance of the account must be at least the amount of the check, and a Pending Transaction will be created for the full amount. This is the default behavior if
balance_checkis omitted. :full- NONE =
No balance check will performed when the check transfer is initiated. A zero-dollar Pending Transaction will be created. The balance will still be checked when the Inbound Check Deposit is created.
:none
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::CheckTransferCreateParams::balance_check]
113 |
# File 'sig/increase/models/check_transfer_create_params.rbs', line 113
def self?.values: -> ::Array[Increase::Models::CheckTransferCreateParams::balance_check]
|