Class: Increase::Models::CheckTransferCreateParams::PhysicalCheck

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs

Defined Under Namespace

Modules: ShippingMethod Classes: MailingAddress, Payer, ReturnAddress, Signature

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, line1:, name:, postal_code:, state:, line2: nil, phone: nil) ⇒ Object

The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.

Parameters:

  • city (String)

    The city of the return address.

  • line1 (String)

    The first line of the return address.

  • name (String)

    The name of the return address.

  • postal_code (String)

    The postal code of the return address.

  • state (String)

    The US state of the return address.

  • line2 (String) (defaults to: nil)

    The second line of the return address.

  • phone (String) (defaults to: nil)

    The phone number to associate with the shipper. The phone number is only used when shipping_method is fedex_overnight and will be supplied to FedEx to be used in case of delivery issues.



# File 'lib/increase/models/check_transfer_create_params.rb', line 232

Instance Attribute Details

#attachment_file_idString?

The ID of a File to be attached to the check. This must have purpose: check_attachment. For details on pricing and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .

Parameters:

  • (String)

Returns:

  • (String, nil)


186
# File 'lib/increase/models/check_transfer_create_params.rb', line 186

optional :attachment_file_id, String

#check_voucher_image_file_idString?

The ID of a File to be used as the check voucher image. This must have purpose: check_voucher_image. For details on pricing and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .

Parameters:

  • (String)

Returns:

  • (String, nil)


194
# File 'lib/increase/models/check_transfer_create_params.rb', line 194

optional :check_voucher_image_file_id, String

#mailing_addressIncrease::Models::CheckTransferCreateParams::PhysicalCheck::MailingAddress

Details for where Increase will mail the check.

Parameters:

  • value (Increase::CheckTransferCreateParams::PhysicalCheck::MailingAddress)

Returns:



157
# File 'lib/increase/models/check_transfer_create_params.rb', line 157

required :mailing_address, -> { Increase::CheckTransferCreateParams::PhysicalCheck::MailingAddress }

#memoString

The descriptor that will be printed on the memo field on the check.

Parameters:

  • value (String)

Returns:

  • (String)


163
# File 'lib/increase/models/check_transfer_create_params.rb', line 163

required :memo, String

#noteString?

The descriptor that will be printed on the letter included with the check.

Parameters:

  • (String)

Returns:

  • (String, nil)


200
# File 'lib/increase/models/check_transfer_create_params.rb', line 200

optional :note, String

#payerArray<Increase::Models::CheckTransferCreateParams::PhysicalCheck::Payer>

The payer of the check. This will be printed on the top-left portion of the check. This should be an array of up to 4 elements, each of which represents a line of the payer.

Parameters:

  • value (::Array[Increase::CheckTransferCreateParams::PhysicalCheck::Payer])

Returns:



171
172
# File 'lib/increase/models/check_transfer_create_params.rb', line 171

required :payer,
-> { Increase::Internal::Type::ArrayOf[Increase::CheckTransferCreateParams::PhysicalCheck::Payer] }

#recipient_nameString

The name that will be printed on the check in the 'To:' field.

Parameters:

  • value (String)

Returns:

  • (String)


178
# File 'lib/increase/models/check_transfer_create_params.rb', line 178

required :recipient_name, String

#return_addressIncrease::Models::CheckTransferCreateParams::PhysicalCheck::ReturnAddress?

The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.



208
# File 'lib/increase/models/check_transfer_create_params.rb', line 208

optional :return_address, -> { Increase::CheckTransferCreateParams::PhysicalCheck::ReturnAddress }

#return_address_nameString?

A custom name to print above the default return address. Cannot be provided together with return_address.

Parameters:

  • (String)

Returns:

  • (String, nil)


215
# File 'lib/increase/models/check_transfer_create_params.rb', line 215

optional :return_address_name, String

#shipping_methodSymbol, ...

How to ship the check. For details on pricing, timing, and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .



222
# File 'lib/increase/models/check_transfer_create_params.rb', line 222

optional :shipping_method, enum: -> { Increase::CheckTransferCreateParams::PhysicalCheck::ShippingMethod }

#signatureIncrease::Models::CheckTransferCreateParams::PhysicalCheck::Signature?

The signature that will appear on the check. If not provided, the check will be printed with 'No Signature Required'. At most one of text and image_file_id may be provided.



230
# File 'lib/increase/models/check_transfer_create_params.rb', line 230

optional :signature, -> { Increase::CheckTransferCreateParams::PhysicalCheck::Signature }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/check_transfer_create_params.rb', line 442

Instance Method Details

#to_hash{

Returns:

  • ({)


188
# File 'sig/increase/models/check_transfer_create_params.rbs', line 188

def to_hash: -> {