Class: Increase::Models::CheckTransferCreateParams::PhysicalCheck
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransferCreateParams::PhysicalCheck
- Defined in:
- lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs
Defined Under Namespace
Modules: ShippingMethod Classes: MailingAddress, Payer, ReturnAddress, Signature
Instance Attribute Summary collapse
-
#attachment_file_id ⇒ String?
The ID of a File to be attached to the check.
-
#check_voucher_image_file_id ⇒ String?
The ID of a File to be used as the check voucher image.
-
#mailing_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::MailingAddress
Details for where Increase will mail the check.
-
#memo ⇒ String
The descriptor that will be printed on the memo field on the check.
-
#note ⇒ String?
The descriptor that will be printed on the letter included with the check.
-
#payer ⇒ Array<Increase::Models::CheckTransferCreateParams::PhysicalCheck::Payer>
The payer of the check.
-
#recipient_name ⇒ String
The name that will be printed on the check in the 'To:' field.
-
#return_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::ReturnAddress?
The return address to be printed on the check.
-
#return_address_name ⇒ String?
A custom name to print above the default return address.
-
#shipping_method ⇒ Symbol, ...
How to ship the check.
-
#signature ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature?
The signature that will appear on the check.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, line1:, name:, postal_code:, state:, line2: nil, phone: nil) ⇒ Object
constructor
The return address to be printed on the check.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, line1:, name:, postal_code:, state:, line2: nil, phone: nil) ⇒ Object
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 232
|
Instance Attribute Details
#attachment_file_id ⇒ String?
The ID of a File to be attached to the check. This must have
purpose: check_attachment. For details on pricing and restrictions, see
https://increase.com/documentation/originating-checks#printing-checks .
186 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 186 optional :attachment_file_id, String |
#check_voucher_image_file_id ⇒ String?
The ID of a File to be used as the check voucher image. This must have
purpose: check_voucher_image. For details on pricing and restrictions, see
https://increase.com/documentation/originating-checks#printing-checks .
194 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 194 optional :check_voucher_image_file_id, String |
#mailing_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::MailingAddress
Details for where Increase will mail the check.
157 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 157 required :mailing_address, -> { Increase::CheckTransferCreateParams::PhysicalCheck::MailingAddress } |
#memo ⇒ String
The descriptor that will be printed on the memo field on the check.
163 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 163 required :memo, String |
#note ⇒ String?
The descriptor that will be printed on the letter included with the check.
200 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 200 optional :note, String |
#payer ⇒ Array<Increase::Models::CheckTransferCreateParams::PhysicalCheck::Payer>
The payer of the check. This will be printed on the top-left portion of the check. This should be an array of up to 4 elements, each of which represents a line of the payer.
171 172 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 171 required :payer, -> { Increase::Internal::Type::ArrayOf[Increase::CheckTransferCreateParams::PhysicalCheck::Payer] } |
#recipient_name ⇒ String
The name that will be printed on the check in the 'To:' field.
178 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 178 required :recipient_name, String |
#return_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::ReturnAddress?
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
208 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 208 optional :return_address, -> { Increase::CheckTransferCreateParams::PhysicalCheck::ReturnAddress } |
#return_address_name ⇒ String?
A custom name to print above the default return address. Cannot be provided
together with return_address.
215 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 215 optional :return_address_name, String |
#shipping_method ⇒ Symbol, ...
How to ship the check. For details on pricing, timing, and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
222 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 222 optional :shipping_method, enum: -> { Increase::CheckTransferCreateParams::PhysicalCheck::ShippingMethod } |
#signature ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature?
The signature that will appear on the check. If not provided, the check will be
printed with 'No Signature Required'. At most one of text and image_file_id
may be provided.
230 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 230 optional :signature, -> { Increase::CheckTransferCreateParams::PhysicalCheck::Signature } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 442
|
Instance Method Details
#to_hash ⇒ {
188 |
# File 'sig/increase/models/check_transfer_create_params.rbs', line 188
def to_hash: -> {
|