Class: Increase::Models::CheckTransferCreateParams::PhysicalCheck
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransferCreateParams::PhysicalCheck
- Defined in:
- lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs
Defined Under Namespace
Modules: ShippingMethod Classes: MailingAddress, Payer, ReturnAddress, Signature
Instance Attribute Summary collapse
-
#attachment_file_id ⇒ String?
The ID of a File to be attached to the check.
-
#check_voucher_image_file_id ⇒ String?
The ID of a File to be used as the check voucher image.
-
#mailing_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::MailingAddress
Details for where Increase will mail the check.
-
#memo ⇒ String
The descriptor that will be printed on the memo field on the check.
-
#note ⇒ String?
A few paragraphs of text printed on the letter included with the check.
-
#payer ⇒ Array<Increase::Models::CheckTransferCreateParams::PhysicalCheck::Payer>
The payer of the check.
-
#physical_check_batch_id ⇒ String?
The identifier of the Physical Check Batch to mail this check as a part of.
-
#recipient_name ⇒ String
The name that will be printed on the check in the 'To:' field.
-
#return_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::ReturnAddress?
Details for where the courier will return the check to if it is unable to be delivered.
-
#return_address_name ⇒ String?
A custom name to print above the default return address.
-
#shipping_method ⇒ Symbol, ...
How to ship the check.
-
#signature ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature?
The signature that will appear on the check.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, line1:, name:, postal_code:, state:, line2: nil, phone: nil) ⇒ Object
constructor
Details for where the courier will return the check to if it is unable to be delivered.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, line1:, name:, postal_code:, state:, line2: nil, phone: nil) ⇒ Object
Details for where the courier will return the check to if it is unable to be delivered. Defaults to an Increase-owned address that will mark checks as delivery failed and shred them.
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 241
|
Instance Attribute Details
#attachment_file_id ⇒ String?
The ID of a File to be attached to the check. This must have
purpose: check_attachment. For details on pricing and restrictions, see
https://increase.com/documentation/originating-checks#printing-checks .
187 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 187 optional :attachment_file_id, String |
#check_voucher_image_file_id ⇒ String?
The ID of a File to be used as the check voucher image. This must have
purpose: check_voucher_image. For details on pricing and restrictions, see
https://increase.com/documentation/originating-checks#printing-checks .
195 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 195 optional :check_voucher_image_file_id, String |
#mailing_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::MailingAddress
Details for where Increase will mail the check. When physical_check_batch_id
is set, the address must match the Physical Check Batch.
158 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 158 required :mailing_address, -> { Increase::CheckTransferCreateParams::PhysicalCheck::MailingAddress } |
#memo ⇒ String
The descriptor that will be printed on the memo field on the check.
164 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 164 required :memo, String |
#note ⇒ String?
A few paragraphs of text printed on the letter included with the check. It can contain at most 22 lines. Paragraphs will wrap at about 120 characters, but depending on your exact message, it might be slightly more or slightly less.
203 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 203 optional :note, String |
#payer ⇒ Array<Increase::Models::CheckTransferCreateParams::PhysicalCheck::Payer>
The payer of the check. This will be printed on the top-left portion of the check. This should be an array of up to 4 elements, each of which represents a line of the payer.
172 173 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 172 required :payer, -> { Increase::Internal::Type::ArrayOf[Increase::CheckTransferCreateParams::PhysicalCheck::Payer] } |
#physical_check_batch_id ⇒ String?
The identifier of the Physical Check Batch to mail this check as a part of.
209 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 209 optional :physical_check_batch_id, String |
#recipient_name ⇒ String
The name that will be printed on the check in the 'To:' field.
179 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 179 required :recipient_name, String |
#return_address ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::ReturnAddress?
Details for where the courier will return the check to if it is unable to be delivered. Defaults to an Increase-owned address that will mark checks as delivery failed and shred them.
217 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 217 optional :return_address, -> { Increase::CheckTransferCreateParams::PhysicalCheck::ReturnAddress } |
#return_address_name ⇒ String?
A custom name to print above the default return address. Cannot be provided
together with return_address.
224 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 224 optional :return_address_name, String |
#shipping_method ⇒ Symbol, ...
How to ship the check. For details on pricing, timing, and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
231 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 231 optional :shipping_method, enum: -> { Increase::CheckTransferCreateParams::PhysicalCheck::ShippingMethod } |
#signature ⇒ Increase::Models::CheckTransferCreateParams::PhysicalCheck::Signature?
The signature that will appear on the check. If not provided, the check will be
printed with 'No Signature Required'. At most one of text and image_file_id
may be provided.
239 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 239 optional :signature, -> { Increase::CheckTransferCreateParams::PhysicalCheck::Signature } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 459
|
Instance Method Details
#to_hash ⇒ {
194 |
# File 'sig/increase/models/check_transfer_create_params.rbs', line 194 def to_hash: -> { |