Class: Increase::Models::CheckTransferCreateParams::ThirdParty
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::CheckTransferCreateParams::ThirdParty
- Defined in:
- lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs
Instance Attribute Summary collapse
-
#recipient_name ⇒ String?
The pay-to name you will print on the check.
Instance Method Summary collapse
-
#initialize(recipient_name: nil) ⇒ ThirdParty
constructor
Details relating to the custom fulfillment you will perform.
- #to_hash ⇒ { recipient_name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(recipient_name: nil) ⇒ ThirdParty
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_method is equal to third_party. It must not be included if any
other fulfillment_method is provided.
|
|
# File 'lib/increase/models/check_transfer_create_params.rb', line 483
|
Instance Attribute Details
#recipient_name ⇒ String?
The pay-to name you will print on the check. If provided, this is used for Positive Pay. If this is omitted, Increase will be unable to validate the payer name when the check is deposited.
481 |
# File 'lib/increase/models/check_transfer_create_params.rb', line 481 optional :recipient_name, String |
Instance Method Details
#to_hash ⇒ { recipient_name: String }
356 |
# File 'sig/increase/models/check_transfer_create_params.rbs', line 356
def to_hash: -> { recipient_name: String }
|