Class: Increase::Models::CheckTransferCreateParams::ThirdParty

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/check_transfer_create_params.rb,
sig/increase/models/check_transfer_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(recipient_name: nil) ⇒ ThirdParty

Some parameter documentations has been truncated, see Increase::Models::CheckTransferCreateParams::ThirdParty for more details.

Details relating to the custom fulfillment you will perform. This is required if fulfillment_method is equal to third_party. It must not be included if any other fulfillment_method is provided.

Parameters:

  • recipient_name (String) (defaults to: nil)

    The pay-to name you will print on the check. If provided, this is used for [Posi

  • recipient_name: (String) (defaults to: nil)


# File 'lib/increase/models/check_transfer_create_params.rb', line 443

Instance Attribute Details

#recipient_nameString?

The pay-to name you will print on the check. If provided, this is used for Positive Pay. If this is omitted, Increase will be unable to validate the payer name when the check is deposited.

Parameters:

  • (String)

Returns:

  • (String, nil)


441
# File 'lib/increase/models/check_transfer_create_params.rb', line 441

optional :recipient_name, String

Instance Method Details

#to_hash{ recipient_name: String }

Returns:

  • ({ recipient_name: String })


353
# File 'sig/increase/models/check_transfer_create_params.rbs', line 353

def to_hash: -> { recipient_name: String }