Class: Increase::Models::DeclinedTransaction::Source::ACHDecline
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransaction::Source::ACHDecline
- Defined in:
- lib/increase/models/declined_transaction.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The declined amount in USD cents.
-
#id ⇒ String
The ACH Decline’s identifier.
-
#inbound_ach_transfer_id ⇒ String
The identifier of the Inbound ACH Transfer object associated with this decline.
-
#originator_company_descriptive_date ⇒ String?
The descriptive date of the transfer.
-
#originator_company_discretionary_data ⇒ String?
The additional information included with the transfer.
-
#originator_company_id ⇒ String
The identifier of the company that initiated the transfer.
-
#originator_company_name ⇒ String
The name of the company that initiated the transfer.
-
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Reason
Why the ACH transfer was declined.
-
#receiver_id_number ⇒ String?
The id of the receiver of the transfer.
-
#receiver_name ⇒ String?
The name of the receiver of the transfer.
-
#trace_number ⇒ String
The trace number of the transfer.
-
#type ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, amount:, inbound_ach_transfer_id:, originator_company_descriptive_date:, originator_company_discretionary_data:, originator_company_id:, originator_company_name:, reason:, receiver_id_number:, receiver_name:, trace_number:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ACHDecline for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, inbound_ach_transfer_id:, originator_company_descriptive_date:, originator_company_discretionary_data:, originator_company_id:, originator_company_name:, reason:, receiver_id_number:, receiver_name:, trace_number:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::DeclinedTransaction::Source::ACHDecline for more details.
An ACH Decline object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_decline`.
|
|
# File 'lib/increase/models/declined_transaction.rb', line 350
|
Instance Attribute Details
#amount ⇒ Integer
The declined amount in USD cents.
287 |
# File 'lib/increase/models/declined_transaction.rb', line 287 required :amount, Integer |
#id ⇒ String
The ACH Decline’s identifier.
281 |
# File 'lib/increase/models/declined_transaction.rb', line 281 required :id, String |
#inbound_ach_transfer_id ⇒ String
The identifier of the Inbound ACH Transfer object associated with this decline.
293 |
# File 'lib/increase/models/declined_transaction.rb', line 293 required :inbound_ach_transfer_id, String |
#originator_company_descriptive_date ⇒ String?
The descriptive date of the transfer.
299 |
# File 'lib/increase/models/declined_transaction.rb', line 299 required :originator_company_descriptive_date, String, nil?: true |
#originator_company_discretionary_data ⇒ String?
The additional information included with the transfer.
305 |
# File 'lib/increase/models/declined_transaction.rb', line 305 required :originator_company_discretionary_data, String, nil?: true |
#originator_company_id ⇒ String
The identifier of the company that initiated the transfer.
311 |
# File 'lib/increase/models/declined_transaction.rb', line 311 required :originator_company_id, String |
#originator_company_name ⇒ String
The name of the company that initiated the transfer.
317 |
# File 'lib/increase/models/declined_transaction.rb', line 317 required :originator_company_name, String |
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Reason
Why the ACH transfer was declined.
323 |
# File 'lib/increase/models/declined_transaction.rb', line 323 required :reason, enum: -> { Increase::DeclinedTransaction::Source::ACHDecline::Reason } |
#receiver_id_number ⇒ String?
The id of the receiver of the transfer.
329 |
# File 'lib/increase/models/declined_transaction.rb', line 329 required :receiver_id_number, String, nil?: true |
#receiver_name ⇒ String?
The name of the receiver of the transfer.
335 |
# File 'lib/increase/models/declined_transaction.rb', line 335 required :receiver_name, String, nil?: true |
#trace_number ⇒ String
The trace number of the transfer.
341 |
# File 'lib/increase/models/declined_transaction.rb', line 341 required :trace_number, String |
#type ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::ACHDecline::Type
A constant representing the object’s type. For this resource it will always be ‘ach_decline`.
348 |
# File 'lib/increase/models/declined_transaction.rb', line 348 required :type, enum: -> { Increase::DeclinedTransaction::Source::ACHDecline::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/declined_transaction.rb', line 440
|