Class: Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderName
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransaction::Source::CardDecline::Verification::CardholderName
- Defined in:
- lib/increase/models/declined_transaction.rb
Overview
Instance Attribute Summary collapse
-
#provided_first_name ⇒ String?
The first name provided for verification in the authorization request.
-
#provided_last_name ⇒ String?
The last name provided for verification in the authorization request.
-
#provided_middle_name ⇒ String?
The middle name provided for verification in the authorization request.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#provided_first_name ⇒ String?
The first name provided for verification in the authorization request.
1990 |
# File 'lib/increase/models/declined_transaction.rb', line 1990 required :provided_first_name, String, nil?: true |
#provided_last_name ⇒ String?
The last name provided for verification in the authorization request.
1996 |
# File 'lib/increase/models/declined_transaction.rb', line 1996 required :provided_last_name, String, nil?: true |
#provided_middle_name ⇒ String?
The middle name provided for verification in the authorization request.
2002 |
# File 'lib/increase/models/declined_transaction.rb', line 2002 required :provided_middle_name, String, nil?: true |