Module: Increase::Models::DeclinedTransaction::Source::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/declined_transaction.rb,
sig/increase/models/declined_transaction.rbs
Overview
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
Constant Summary collapse
- ACH_DECLINE =
ACH Decline: details will be under the
ach_declineobject. :ach_decline- CARD_DECLINE =
Card Decline: details will be under the
card_declineobject. :card_decline- CHECK_DECLINE =
Check Decline: details will be under the
check_declineobject. :check_decline- INBOUND_REAL_TIME_PAYMENTS_TRANSFER_DECLINE =
Inbound Real-Time Payments Transfer Decline: details will be under the
inbound_real_time_payments_transfer_declineobject. :inbound_real_time_payments_transfer_decline- INBOUND_FEDNOW_TRANSFER_DECLINE =
Inbound FedNow Transfer Decline: details will be under the
inbound_fednow_transfer_declineobject. :inbound_fednow_transfer_decline- WIRE_DECLINE =
Wire Decline: details will be under the
wire_declineobject. :wire_decline- CHECK_DEPOSIT_REJECTION =
Check Deposit Rejection: details will be under the
check_deposit_rejectionobject. :check_deposit_rejection- OTHER =
The Declined Transaction was made for an undocumented or deprecated reason.
:other
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::DeclinedTransaction::Source::category]
185 |
# File 'sig/increase/models/declined_transaction.rbs', line 185
def self?.values: -> ::Array[Increase::Models::DeclinedTransaction::Source::category]
|