Class: Increase::Models::DeclinedTransaction::Source::CheckDecline

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/declined_transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, auxiliary_on_us:, back_image_file_id:, check_transfer_id:, front_image_file_id:, inbound_check_deposit_id:, reason:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::DeclinedTransaction::Source::CheckDecline for more details.

A Check Decline object. This field will be present in the JSON response if and only if ‘category` is equal to `check_decline`.

Parameters:

  • amount (Integer)

    The declined amount in USD cents.

  • auxiliary_on_us (String, nil)

    A computer-readable number printed on the MICR line of business checks, usually

  • back_image_file_id (String, nil)

    The identifier of the API File object containing an image of the back of the dec

  • check_transfer_id (String, nil)

    The identifier of the Check Transfer object associated with this decline.

  • front_image_file_id (String, nil)

    The identifier of the API File object containing an image of the front of the de

  • inbound_check_deposit_id (String, nil)

    The identifier of the Inbound Check Deposit object associated with this decline.

  • reason (Symbol, Increase::Models::DeclinedTransaction::Source::CheckDecline::Reason)

    Why the check was declined.



# File 'lib/increase/models/declined_transaction.rb', line 2064

Instance Attribute Details

#amountInteger

The declined amount in USD cents.

Returns:

  • (Integer)


2022
# File 'lib/increase/models/declined_transaction.rb', line 2022

required :amount, Integer

#auxiliary_on_usString?

A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.

Returns:

  • (String, nil)


2030
# File 'lib/increase/models/declined_transaction.rb', line 2030

required :auxiliary_on_us, String, nil?: true

#back_image_file_idString?

The identifier of the API File object containing an image of the back of the declined check.

Returns:

  • (String, nil)


2037
# File 'lib/increase/models/declined_transaction.rb', line 2037

required :back_image_file_id, String, nil?: true

#check_transfer_idString?

The identifier of the Check Transfer object associated with this decline.

Returns:

  • (String, nil)


2043
# File 'lib/increase/models/declined_transaction.rb', line 2043

required :check_transfer_id, String, nil?: true

#front_image_file_idString?

The identifier of the API File object containing an image of the front of the declined check.

Returns:

  • (String, nil)


2050
# File 'lib/increase/models/declined_transaction.rb', line 2050

required :front_image_file_id, String, nil?: true

#inbound_check_deposit_idString?

The identifier of the Inbound Check Deposit object associated with this decline.

Returns:

  • (String, nil)


2056
# File 'lib/increase/models/declined_transaction.rb', line 2056

required :inbound_check_deposit_id, String, nil?: true

#reasonSymbol, Increase::Models::DeclinedTransaction::Source::CheckDecline::Reason

Why the check was declined.



2062
# File 'lib/increase/models/declined_transaction.rb', line 2062

required :reason, enum: -> { Increase::DeclinedTransaction::Source::CheckDecline::Reason }