Class: Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline
- Defined in:
- lib/increase/models/declined_transaction.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The declined amount in the minor unit of the destination account currency.
-
#creditor_name ⇒ String
The name the sender of the transfer specified as the recipient of the transfer.
-
#currency ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code of the declined transfer’s currency.
-
#debtor_account_number ⇒ String
The account number of the account that sent the transfer.
-
#debtor_name ⇒ String
The name provided by the sender of the transfer.
-
#debtor_routing_number ⇒ String
The routing number of the account that sent the transfer.
-
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline::Reason
Why the transfer was declined.
-
#transaction_identification ⇒ String
The Real-Time Payments network identification of the declined transfer.
-
#transfer_id ⇒ String
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
#unstructured_remittance_information ⇒ String?
Additional information included with the transfer.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, creditor_name:, currency:, debtor_account_number:, debtor_name:, debtor_routing_number:, reason:, transaction_identification:, transfer_id:, unstructured_remittance_information:) ⇒ Object
constructor
Some parameter documentations has been truncated, see InboundRealTimePaymentsTransferDecline for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, creditor_name:, currency:, debtor_account_number:, debtor_name:, debtor_routing_number:, reason:, transaction_identification:, transfer_id:, unstructured_remittance_information:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline for more details.
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_real_time_payments_transfer_decline`.
|
|
# File 'lib/increase/models/declined_transaction.rb', line 2391
|
Instance Attribute Details
#amount ⇒ Integer
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
2331 |
# File 'lib/increase/models/declined_transaction.rb', line 2331 required :amount, Integer |
#creditor_name ⇒ String
The name the sender of the transfer specified as the recipient of the transfer.
2337 |
# File 'lib/increase/models/declined_transaction.rb', line 2337 required :creditor_name, String |
#currency ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code of the declined transfer’s currency. This will always be “USD” for a Real-Time Payments transfer.
2345 2346 |
# File 'lib/increase/models/declined_transaction.rb', line 2345 required :currency, enum: -> { Increase::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline::Currency } |
#debtor_account_number ⇒ String
The account number of the account that sent the transfer.
2352 |
# File 'lib/increase/models/declined_transaction.rb', line 2352 required :debtor_account_number, String |
#debtor_name ⇒ String
The name provided by the sender of the transfer.
2358 |
# File 'lib/increase/models/declined_transaction.rb', line 2358 required :debtor_name, String |
#debtor_routing_number ⇒ String
The routing number of the account that sent the transfer.
2364 |
# File 'lib/increase/models/declined_transaction.rb', line 2364 required :debtor_routing_number, String |
#reason ⇒ Symbol, Increase::Models::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline::Reason
Why the transfer was declined.
2370 2371 |
# File 'lib/increase/models/declined_transaction.rb', line 2370 required :reason, enum: -> { Increase::DeclinedTransaction::Source::InboundRealTimePaymentsTransferDecline::Reason } |
#transaction_identification ⇒ String
The Real-Time Payments network identification of the declined transfer.
2377 |
# File 'lib/increase/models/declined_transaction.rb', line 2377 required :transaction_identification, String |
#transfer_id ⇒ String
The identifier of the Real-Time Payments Transfer that led to this Transaction.
2383 |
# File 'lib/increase/models/declined_transaction.rb', line 2383 required :transfer_id, String |
#unstructured_remittance_information ⇒ String?
Additional information included with the transfer.
2389 |
# File 'lib/increase/models/declined_transaction.rb', line 2389 required :unstructured_remittance_information, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/declined_transaction.rb', line 2431
|