Class: Increase::Models::DeclinedTransactionListParams::Category
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DeclinedTransactionListParams::Category
- Defined in:
- lib/increase/models/declined_transaction_list_params.rb,
sig/increase/models/declined_transaction_list_params.rbs
Defined Under Namespace
Modules: In
Instance Attribute Summary collapse
-
#in_ ⇒ Array<Symbol, Increase::Models::DeclinedTransactionListParams::Category::In>?
Return results whose value is in the provided list.
Instance Method Summary collapse
- #initialize(account_id: nil, category: nil, created_at: nil, cursor: nil, limit: nil, route_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id: nil, category: nil, created_at: nil, cursor: nil, limit: nil, route_id: nil, request_options: {}) ⇒ Object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/increase/models/declined_transaction_list_params.rb', line 62 class Category < Increase::Internal::Type::BaseModel # @!attribute in_ # Return results whose value is in the provided list. For GET requests, this # should be encoded as a comma-delimited string, such as `?in=one,two,three`. # # @return [Array<Symbol, Increase::Models::DeclinedTransactionListParams::Category::In>, nil] optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::DeclinedTransactionListParams::Category::In] }, api_name: :in # @!method initialize(in_: nil) # @param in_ [Array<Symbol, Increase::Models::DeclinedTransactionListParams::Category::In>] # Return results whose value is in the provided list. For GET requests, this # should be encoded as a comma-delimited string, such as `?in=one,two,three`. module In extend Increase::Internal::Type::Enum # ACH Decline: details will be under the `ach_decline` object. ACH_DECLINE = :ach_decline # Card Decline: details will be under the `card_decline` object. CARD_DECLINE = :card_decline # Check Decline: details will be under the `check_decline` object. CHECK_DECLINE = :check_decline # Inbound Real-Time Payments Transfer Decline: details will be under the `inbound_real_time_payments_transfer_decline` object. INBOUND_REAL_TIME_PAYMENTS_TRANSFER_DECLINE = :inbound_real_time_payments_transfer_decline # Inbound FedNow Transfer Decline: details will be under the `inbound_fednow_transfer_decline` object. INBOUND_FEDNOW_TRANSFER_DECLINE = :inbound_fednow_transfer_decline # Wire Decline: details will be under the `wire_decline` object. WIRE_DECLINE = :wire_decline # Check Deposit Rejection: details will be under the `check_deposit_rejection` object. CHECK_DEPOSIT_REJECTION = :check_deposit_rejection # The Declined Transaction was made for an undocumented or deprecated reason. OTHER = :other # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#in_ ⇒ Array<Symbol, Increase::Models::DeclinedTransactionListParams::Category::In>?
Return results whose value is in the provided list. For GET requests, this
should be encoded as a comma-delimited string, such as ?in=one,two,three.
68 69 70 71 72 |
# File 'lib/increase/models/declined_transaction_list_params.rb', line 68 optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::DeclinedTransactionListParams::Category::In] }, api_name: :in |
Instance Method Details
#to_hash ⇒ {
82 |
# File 'sig/increase/models/declined_transaction_list_params.rbs', line 82
def to_hash: -> {
|