Module: Increase::Models::DeclinedTransactionListParams::Category::In
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/declined_transaction_list_params.rb,
sig/increase/models/declined_transaction_list_params.rbs
Constant Summary collapse
- ACH_DECLINE =
ACH Decline: details will be under the
ach_declineobject. :ach_decline- CARD_DECLINE =
Card Decline: details will be under the
card_declineobject. :card_decline- CHECK_DECLINE =
Check Decline: details will be under the
check_declineobject. :check_decline- INBOUND_REAL_TIME_PAYMENTS_TRANSFER_DECLINE =
Inbound Real-Time Payments Transfer Decline: details will be under the
inbound_real_time_payments_transfer_declineobject. :inbound_real_time_payments_transfer_decline- INBOUND_FEDNOW_TRANSFER_DECLINE =
Inbound FedNow Transfer Decline: details will be under the
inbound_fednow_transfer_declineobject. :inbound_fednow_transfer_decline- WIRE_DECLINE =
Wire Decline: details will be under the
wire_declineobject. :wire_decline- CHECK_DEPOSIT_REJECTION =
Check Deposit Rejection: details will be under the
check_deposit_rejectionobject. :check_deposit_rejection- OTHER =
The Declined Transaction was made for an undocumented or deprecated reason.
:other
Instance Method Summary collapse
-
#initialize(in_: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::DeclinedTransactionListParams::Category for more details.
- #self?.values ⇒ ::Array[Increase::Models::DeclinedTransactionListParams::Category::in_]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(in_: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::DeclinedTransactionListParams::Category for more details.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/increase/models/declined_transaction_list_params.rb', line 81 module In extend Increase::Internal::Type::Enum # ACH Decline: details will be under the `ach_decline` object. ACH_DECLINE = :ach_decline # Card Decline: details will be under the `card_decline` object. CARD_DECLINE = :card_decline # Check Decline: details will be under the `check_decline` object. CHECK_DECLINE = :check_decline # Inbound Real-Time Payments Transfer Decline: details will be under the `inbound_real_time_payments_transfer_decline` object. INBOUND_REAL_TIME_PAYMENTS_TRANSFER_DECLINE = :inbound_real_time_payments_transfer_decline # Inbound FedNow Transfer Decline: details will be under the `inbound_fednow_transfer_decline` object. INBOUND_FEDNOW_TRANSFER_DECLINE = :inbound_fednow_transfer_decline # Wire Decline: details will be under the `wire_decline` object. WIRE_DECLINE = :wire_decline # Check Deposit Rejection: details will be under the `check_deposit_rejection` object. CHECK_DEPOSIT_REJECTION = :check_deposit_rejection # The Declined Transaction was made for an undocumented or deprecated reason. OTHER = :other # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[Increase::Models::DeclinedTransactionListParams::Category::in_]
123 |
# File 'sig/increase/models/declined_transaction_list_params.rbs', line 123
def self?.values: -> ::Array[Increase::Models::DeclinedTransactionListParams::Category::in_]
|