Class: Increase::Models::DigitalWalletToken
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DigitalWalletToken
- Defined in:
- lib/increase/models/digital_wallet_token.rb
Overview
Defined Under Namespace
Modules: Status, TokenRequestor, Type Classes: Cardholder, Device, DynamicPrimaryAccountNumber, Update
Instance Attribute Summary collapse
-
#card_id ⇒ String
The identifier for the Card this Digital Wallet Token belongs to.
-
#cardholder ⇒ Increase::Models::DigitalWalletToken::Cardholder
The cardholder information given when the Digital Wallet Token was created.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Digital Wallet Token was created.
-
#device ⇒ Increase::Models::DigitalWalletToken::Device
The device that was used to create the Digital Wallet Token.
-
#dynamic_primary_account_number ⇒ Increase::Models::DigitalWalletToken::DynamicPrimaryAccountNumber?
The redacted Dynamic Primary Account Number.
-
#id ⇒ String
The Digital Wallet Token identifier.
-
#status ⇒ Symbol, Increase::Models::DigitalWalletToken::Status
This indicates if payments can be made with the Digital Wallet Token.
-
#token_requestor ⇒ Symbol, Increase::Models::DigitalWalletToken::TokenRequestor
The digital wallet app being used.
-
#type ⇒ Symbol, Increase::Models::DigitalWalletToken::Type
A constant representing the object’s type.
-
#updates ⇒ Array<Increase::Models::DigitalWalletToken::Update>
Updates to the Digital Wallet Token.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(first6:, last4:) ⇒ Object
constructor
The redacted Dynamic Primary Account Number.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(first6:, last4:) ⇒ Object
The redacted Dynamic Primary Account Number.
|
|
# File 'lib/increase/models/digital_wallet_token.rb', line 71
|
Instance Attribute Details
#card_id ⇒ String
The identifier for the Card this Digital Wallet Token belongs to.
17 |
# File 'lib/increase/models/digital_wallet_token.rb', line 17 required :card_id, String |
#cardholder ⇒ Increase::Models::DigitalWalletToken::Cardholder
The cardholder information given when the Digital Wallet Token was created.
23 |
# File 'lib/increase/models/digital_wallet_token.rb', line 23 required :cardholder, -> { Increase::DigitalWalletToken::Cardholder } |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Digital Wallet Token was created.
30 |
# File 'lib/increase/models/digital_wallet_token.rb', line 30 required :created_at, Time |
#device ⇒ Increase::Models::DigitalWalletToken::Device
The device that was used to create the Digital Wallet Token.
36 |
# File 'lib/increase/models/digital_wallet_token.rb', line 36 required :device, -> { Increase::DigitalWalletToken::Device } |
#dynamic_primary_account_number ⇒ Increase::Models::DigitalWalletToken::DynamicPrimaryAccountNumber?
The redacted Dynamic Primary Account Number.
42 43 44 |
# File 'lib/increase/models/digital_wallet_token.rb', line 42 required :dynamic_primary_account_number, -> { Increase::DigitalWalletToken::DynamicPrimaryAccountNumber }, nil?: true |
#id ⇒ String
The Digital Wallet Token identifier.
11 |
# File 'lib/increase/models/digital_wallet_token.rb', line 11 required :id, String |
#status ⇒ Symbol, Increase::Models::DigitalWalletToken::Status
This indicates if payments can be made with the Digital Wallet Token.
50 |
# File 'lib/increase/models/digital_wallet_token.rb', line 50 required :status, enum: -> { Increase::DigitalWalletToken::Status } |
#token_requestor ⇒ Symbol, Increase::Models::DigitalWalletToken::TokenRequestor
The digital wallet app being used.
56 |
# File 'lib/increase/models/digital_wallet_token.rb', line 56 required :token_requestor, enum: -> { Increase::DigitalWalletToken::TokenRequestor } |
#type ⇒ Symbol, Increase::Models::DigitalWalletToken::Type
A constant representing the object’s type. For this resource it will always be ‘digital_wallet_token`.
63 |
# File 'lib/increase/models/digital_wallet_token.rb', line 63 required :type, enum: -> { Increase::DigitalWalletToken::Type } |
#updates ⇒ Array<Increase::Models::DigitalWalletToken::Update>
Updates to the Digital Wallet Token.
69 |
# File 'lib/increase/models/digital_wallet_token.rb', line 69 required :updates, -> { Increase::Internal::Type::ArrayOf[Increase::DigitalWalletToken::Update] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/digital_wallet_token.rb', line 183
|