Class: Increase::Models::DigitalWalletToken::Device
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::DigitalWalletToken::Device
- Defined in:
- lib/increase/models/digital_wallet_token.rb
Overview
Defined Under Namespace
Modules: DeviceType
Instance Attribute Summary collapse
-
#device_type ⇒ Symbol, ...
Device type.
-
#identifier ⇒ String?
ID assigned to the device by the digital wallet provider.
-
#ip_address ⇒ String?
IP address of the device.
-
#name ⇒ String?
Name of the device, for example “My Work Phone”.
Instance Method Summary collapse
-
#initialize(device_type:, identifier:, ip_address:, name:) ⇒ Object
constructor
The device that was used to create the Digital Wallet Token.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(device_type:, identifier:, ip_address:, name:) ⇒ Object
The device that was used to create the Digital Wallet Token.
|
|
# File 'lib/increase/models/digital_wallet_token.rb', line 139
|
Instance Attribute Details
#device_type ⇒ Symbol, ...
Device type.
119 |
# File 'lib/increase/models/digital_wallet_token.rb', line 119 required :device_type, enum: -> { Increase::DigitalWalletToken::Device::DeviceType }, nil?: true |
#identifier ⇒ String?
ID assigned to the device by the digital wallet provider.
125 |
# File 'lib/increase/models/digital_wallet_token.rb', line 125 required :identifier, String, nil?: true |
#ip_address ⇒ String?
IP address of the device.
131 |
# File 'lib/increase/models/digital_wallet_token.rb', line 131 required :ip_address, String, nil?: true |
#name ⇒ String?
Name of the device, for example “My Work Phone”.
137 |
# File 'lib/increase/models/digital_wallet_token.rb', line 137 required :name, String, nil?: true |