Class: Increase::Models::Entity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity
- Defined in:
- lib/increase/models/entity.rb
Overview
Defined Under Namespace
Modules: Status, Structure, Type Classes: Corporation, GovernmentAuthority, Joint, NaturalPerson, RiskRating, TermsAgreement, ThirdPartyVerification, Trust, Validation
Instance Attribute Summary collapse
-
#corporation ⇒ Increase::Models::Entity::Corporation?
Details of the corporation entity.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Entity was created.
-
#creating_entity_onboarding_session_id ⇒ String?
The identifier of the Entity Onboarding Session that was used to create this Entity, if any.
-
#description ⇒ String?
The entity’s description for display purposes.
-
#details_confirmed_at ⇒ Time?
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Entity’s details were most recently confirmed.
-
#government_authority ⇒ Increase::Models::Entity::GovernmentAuthority?
Details of the government authority entity.
-
#id ⇒ String
The entity’s identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#joint ⇒ Increase::Models::Entity::Joint?
Details of the joint entity.
-
#natural_person ⇒ Increase::Models::Entity::NaturalPerson?
Details of the natural person entity.
-
#risk_rating ⇒ Increase::Models::Entity::RiskRating?
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
#status ⇒ Symbol, Increase::Models::Entity::Status
The status of the entity.
-
#structure ⇒ Symbol, Increase::Models::Entity::Structure
The entity’s legal structure.
-
#supplemental_documents ⇒ Array<Increase::Models::EntitySupplementalDocument>
Additional documentation associated with the entity.
-
#terms_agreements ⇒ Array<Increase::Models::Entity::TermsAgreement>
The terms that the Entity agreed to.
-
#third_party_verification ⇒ Increase::Models::Entity::ThirdPartyVerification?
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
#trust ⇒ Increase::Models::Entity::Trust?
Details of the trust entity.
-
#type ⇒ Symbol, Increase::Models::Entity::Type
A constant representing the object’s type.
-
#validation ⇒ Increase::Models::Entity::Validation?
The validation results for the entity.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agreed_at:, ip_address:, terms_url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see TermsAgreement for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agreed_at:, ip_address:, terms_url:) ⇒ Object
Some parameter documentations has been truncated, see TermsAgreement for more details.
|
|
# File 'lib/increase/models/entity.rb', line 138
|
Instance Attribute Details
#corporation ⇒ Increase::Models::Entity::Corporation?
Details of the corporation entity. Will be present if ‘structure` is equal to `corporation`.
18 |
# File 'lib/increase/models/entity.rb', line 18 required :corporation, -> { Increase::Entity::Corporation }, nil?: true |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Entity was created.
25 |
# File 'lib/increase/models/entity.rb', line 25 required :created_at, Time |
#creating_entity_onboarding_session_id ⇒ String?
The identifier of the Entity Onboarding Session that was used to create this Entity, if any.
32 |
# File 'lib/increase/models/entity.rb', line 32 required :creating_entity_onboarding_session_id, String, nil?: true |
#description ⇒ String?
The entity’s description for display purposes.
38 |
# File 'lib/increase/models/entity.rb', line 38 required :description, String, nil?: true |
#details_confirmed_at ⇒ Time?
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Entity’s details were most recently confirmed.
45 |
# File 'lib/increase/models/entity.rb', line 45 required :details_confirmed_at, Time, nil?: true |
#government_authority ⇒ Increase::Models::Entity::GovernmentAuthority?
Details of the government authority entity. Will be present if ‘structure` is equal to `government_authority`.
52 |
# File 'lib/increase/models/entity.rb', line 52 required :government_authority, -> { Increase::Entity::GovernmentAuthority }, nil?: true |
#id ⇒ String
The entity’s identifier.
11 |
# File 'lib/increase/models/entity.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
60 |
# File 'lib/increase/models/entity.rb', line 60 required :idempotency_key, String, nil?: true |
#joint ⇒ Increase::Models::Entity::Joint?
Details of the joint entity. Will be present if ‘structure` is equal to `joint`.
66 |
# File 'lib/increase/models/entity.rb', line 66 required :joint, -> { Increase::Entity::Joint }, nil?: true |
#natural_person ⇒ Increase::Models::Entity::NaturalPerson?
Details of the natural person entity. Will be present if ‘structure` is equal to `natural_person`.
73 |
# File 'lib/increase/models/entity.rb', line 73 required :natural_person, -> { Increase::Entity::NaturalPerson }, nil?: true |
#risk_rating ⇒ Increase::Models::Entity::RiskRating?
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
80 |
# File 'lib/increase/models/entity.rb', line 80 required :risk_rating, -> { Increase::Entity::RiskRating }, nil?: true |
#status ⇒ Symbol, Increase::Models::Entity::Status
The status of the entity.
86 |
# File 'lib/increase/models/entity.rb', line 86 required :status, enum: -> { Increase::Entity::Status } |
#structure ⇒ Symbol, Increase::Models::Entity::Structure
The entity’s legal structure.
92 |
# File 'lib/increase/models/entity.rb', line 92 required :structure, enum: -> { Increase::Entity::Structure } |
#supplemental_documents ⇒ Array<Increase::Models::EntitySupplementalDocument>
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
100 101 |
# File 'lib/increase/models/entity.rb', line 100 required :supplemental_documents, -> { Increase::Internal::Type::ArrayOf[Increase::EntitySupplementalDocument] } |
#terms_agreements ⇒ Array<Increase::Models::Entity::TermsAgreement>
The terms that the Entity agreed to. Not all programs are required to submit this data.
108 |
# File 'lib/increase/models/entity.rb', line 108 required :terms_agreements, -> { Increase::Internal::Type::ArrayOf[Increase::Entity::TermsAgreement] } |
#third_party_verification ⇒ Increase::Models::Entity::ThirdPartyVerification?
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
116 |
# File 'lib/increase/models/entity.rb', line 116 required :third_party_verification, -> { Increase::Entity::ThirdPartyVerification }, nil?: true |
#trust ⇒ Increase::Models::Entity::Trust?
Details of the trust entity. Will be present if ‘structure` is equal to `trust`.
122 |
# File 'lib/increase/models/entity.rb', line 122 required :trust, -> { Increase::Entity::Trust }, nil?: true |
#type ⇒ Symbol, Increase::Models::Entity::Type
A constant representing the object’s type. For this resource it will always be ‘entity`.
129 |
# File 'lib/increase/models/entity.rb', line 129 required :type, enum: -> { Increase::Entity::Type } |
#validation ⇒ Increase::Models::Entity::Validation?
The validation results for the entity. Learn more about [validations](/documentation/entity-validation).
136 |
# File 'lib/increase/models/entity.rb', line 136 required :validation, -> { Increase::Entity::Validation }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity.rb', line 556
|