Class: Increase::Models::Entity::Corporation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity.rb,
sig/increase/models/entity.rbs

Overview

See Also:

  • Increase::Models::Entity#corporation

Defined Under Namespace

Modules: BeneficialOwnershipExemptionReason Classes: Address, BeneficialOwner, LegalIdentifier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The corporation's address.

Parameters:

  • city (String, nil)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address.

  • line2 (String, nil)

    The second line of the address.

  • state (String, nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String, nil)

    The ZIP or postal code of the address.



# File 'lib/increase/models/entity.rb', line 248

Instance Attribute Details

#addressIncrease::Models::Entity::Corporation::Address

The corporation's address.

Parameters:

  • value (Increase::Entity::Corporation::Address)

Returns:



190
# File 'lib/increase/models/entity.rb', line 190

required :address, -> { Increase::Entity::Corporation::Address }

#beneficial_ownersArray<Increase::Models::Entity::Corporation::BeneficialOwner>

The identifying details of anyone controlling or owning 25% or more of the corporation.

Parameters:

  • value (::Array[Increase::Entity::Corporation::BeneficialOwner])

Returns:



197
198
# File 'lib/increase/models/entity.rb', line 197

required :beneficial_owners,
-> { Increase::Internal::Type::ArrayOf[Increase::Entity::Corporation::BeneficialOwner] }

#beneficial_ownership_exemption_reasonSymbol, ...

If the entity is exempt from the requirement to submit beneficial owners, the justification for the exemption.

Parameters:

  • value (Increase::Models::Entity::Corporation::beneficial_ownership_exemption_reason, nil)

Returns:



205
206
207
# File 'lib/increase/models/entity.rb', line 205

required :beneficial_ownership_exemption_reason,
enum: -> { Increase::Entity::Corporation::BeneficialOwnershipExemptionReason },
nil?: true

#emailString?

An email address for the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


213
# File 'lib/increase/models/entity.rb', line 213

required :email, String, nil?: true

#incorporation_stateString?

The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


220
# File 'lib/increase/models/entity.rb', line 220

required :incorporation_state, String, nil?: true

#industry_codeString?

The numeric North American Industry Classification System (NAICS) code submitted for the corporation.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


227
# File 'lib/increase/models/entity.rb', line 227

required :industry_code, String, nil?: true

The legal identifier of the corporation, like an Employer Identification Number (EIN).

Parameters:

  • value (Increase::Entity::Corporation::LegalIdentifier, nil)

Returns:



234
# File 'lib/increase/models/entity.rb', line 234

required :legal_identifier, -> { Increase::Entity::Corporation::LegalIdentifier }, nil?: true

#nameString

The legal name of the corporation.

Parameters:

  • value (String)

Returns:

  • (String)


240
# File 'lib/increase/models/entity.rb', line 240

required :name, String

#websiteString?

The website of the corporation.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


246
# File 'lib/increase/models/entity.rb', line 246

required :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity.rb', line 530

Instance Method Details

#to_hash{

Returns:

  • ({)


153
# File 'sig/increase/models/entity.rbs', line 153

def to_hash: -> {