Class: Increase::Models::Entity::Corporation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity.rb

Overview

See Also:

Defined Under Namespace

Classes: Address, BeneficialOwner, LegalIdentifier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The corporation’s address.

Parameters:

  • city (String, nil)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address.

  • line2 (String, nil)

    The second line of the address.

  • state (String, nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String, nil)

    The ZIP or postal code of the address.



# File 'lib/increase/models/entity.rb', line 238

Instance Attribute Details

#addressIncrease::Models::Entity::Corporation::Address

The corporation’s address.



190
# File 'lib/increase/models/entity.rb', line 190

required :address, -> { Increase::Entity::Corporation::Address }

#beneficial_ownersArray<Increase::Models::Entity::Corporation::BeneficialOwner>

The identifying details of anyone controlling or owning 25% or more of the corporation.



197
198
# File 'lib/increase/models/entity.rb', line 197

required :beneficial_owners,
-> { Increase::Internal::Type::ArrayOf[Increase::Entity::Corporation::BeneficialOwner] }

#emailString?

An email address for the business.

Returns:

  • (String, nil)


204
# File 'lib/increase/models/entity.rb', line 204

required :email, String, nil?: true

#incorporation_stateString?

The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.

Returns:

  • (String, nil)


211
# File 'lib/increase/models/entity.rb', line 211

required :incorporation_state, String, nil?: true

#industry_codeString?

The numeric North American Industry Classification System (NAICS) code submitted for the corporation.

Returns:

  • (String, nil)


218
# File 'lib/increase/models/entity.rb', line 218

required :industry_code, String, nil?: true

The legal identifier of the corporation.



224
# File 'lib/increase/models/entity.rb', line 224

required :legal_identifier, -> { Increase::Entity::Corporation::LegalIdentifier }, nil?: true

#nameString

The legal name of the corporation.

Returns:

  • (String)


230
# File 'lib/increase/models/entity.rb', line 230

required :name, String

#websiteString?

The website of the corporation.

Returns:

  • (String, nil)


236
# File 'lib/increase/models/entity.rb', line 236

required :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity.rb', line 518