Class: Increase::Models::Entity::Corporation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Corporation
- Defined in:
- lib/increase/models/entity.rb
Overview
Defined Under Namespace
Classes: Address, BeneficialOwner, LegalIdentifier
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::Entity::Corporation::Address
The corporation’s address.
-
#beneficial_owners ⇒ Array<Increase::Models::Entity::Corporation::BeneficialOwner>
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
#email ⇒ String?
An email address for the business.
-
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.
-
#industry_code ⇒ String?
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
-
#legal_identifier ⇒ Increase::Models::Entity::Corporation::LegalIdentifier?
The legal identifier of the corporation.
-
#name ⇒ String
The legal name of the corporation.
-
#website ⇒ String?
The website of the corporation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The corporation’s address.
|
|
# File 'lib/increase/models/entity.rb', line 238
|
Instance Attribute Details
#address ⇒ Increase::Models::Entity::Corporation::Address
The corporation’s address.
190 |
# File 'lib/increase/models/entity.rb', line 190 required :address, -> { Increase::Entity::Corporation::Address } |
#beneficial_owners ⇒ Array<Increase::Models::Entity::Corporation::BeneficialOwner>
The identifying details of anyone controlling or owning 25% or more of the corporation.
197 198 |
# File 'lib/increase/models/entity.rb', line 197 required :beneficial_owners, -> { Increase::Internal::Type::ArrayOf[Increase::Entity::Corporation::BeneficialOwner] } |
#email ⇒ String?
An email address for the business.
204 |
# File 'lib/increase/models/entity.rb', line 204 required :email, String, nil?: true |
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.
211 |
# File 'lib/increase/models/entity.rb', line 211 required :incorporation_state, String, nil?: true |
#industry_code ⇒ String?
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
218 |
# File 'lib/increase/models/entity.rb', line 218 required :industry_code, String, nil?: true |
#legal_identifier ⇒ Increase::Models::Entity::Corporation::LegalIdentifier?
The legal identifier of the corporation.
224 |
# File 'lib/increase/models/entity.rb', line 224 required :legal_identifier, -> { Increase::Entity::Corporation::LegalIdentifier }, nil?: true |
#name ⇒ String
The legal name of the corporation.
230 |
# File 'lib/increase/models/entity.rb', line 230 required :name, String |
#website ⇒ String?
The website of the corporation.
236 |
# File 'lib/increase/models/entity.rb', line 236 required :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity.rb', line 518
|