Class: Increase::Models::Entity::Joint::Individual
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Joint::Individual
- Defined in:
- lib/increase/models/entity.rb
Defined Under Namespace
Classes: Address, Identification
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::Entity::Joint::Individual::Address
The person’s address.
-
#date_of_birth ⇒ Date
The person’s date of birth in YYYY-MM-DD format.
-
#identification ⇒ Increase::Models::Entity::Joint::Individual::Identification?
A means of verifying the person’s identity.
-
#name ⇒ String
The person’s legal name.
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The person’s address.
772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 |
# File 'lib/increase/models/entity.rb', line 772 class Individual < Increase::Internal::Type::BaseModel # @!attribute address # The person's address. # # @return [Increase::Models::Entity::Joint::Individual::Address] required :address, -> { Increase::Entity::Joint::Individual::Address } # @!attribute date_of_birth # The person's date of birth in YYYY-MM-DD format. # # @return [Date] required :date_of_birth, Date # @!attribute identification # A means of verifying the person's identity. # # @return [Increase::Models::Entity::Joint::Individual::Identification, nil] required :identification, -> { Increase::Entity::Joint::Individual::Identification }, nil?: true # @!attribute name # The person's legal name. # # @return [String] required :name, String # @!method initialize(address:, date_of_birth:, identification:, name:) # @param address [Increase::Models::Entity::Joint::Individual::Address] The person's address. # # @param date_of_birth [Date] The person's date of birth in YYYY-MM-DD format. # # @param identification [Increase::Models::Entity::Joint::Individual::Identification, nil] A means of verifying the person's identity. # # @param name [String] The person's legal name. # @see Increase::Models::Entity::Joint::Individual#address class Address < Increase::Internal::Type::BaseModel # @!attribute city # The city, district, town, or village of the address. # # @return [String, nil] required :city, String, nil?: true # @!attribute country # The two-letter ISO 3166-1 alpha-2 code for the country of the address. # # @return [String] required :country, String # @!attribute line1 # The first line of the address. # # @return [String] required :line1, String # @!attribute line2 # The second line of the address. # # @return [String, nil] required :line2, String, nil?: true # @!attribute state # The two-letter United States Postal Service (USPS) abbreviation for the US # state, province, or region of the address. # # @return [String, nil] required :state, String, nil?: true # @!attribute zip # The ZIP or postal code of the address. # # @return [String, nil] required :zip, String, nil?: true # @!method initialize(city:, country:, line1:, line2:, state:, zip:) # Some parameter documentations has been truncated, see # {Increase::Models::Entity::Joint::Individual::Address} for more details. # # The person's address. # # @param city [String, nil] The city, district, town, or village of the address. # # @param country [String] The two-letter ISO 3166-1 alpha-2 code for the country of the address. # # @param line1 [String] The first line of the address. # # @param line2 [String, nil] The second line of the address. # # @param state [String, nil] The two-letter United States Postal Service (USPS) abbreviation for the US state # # @param zip [String, nil] The ZIP or postal code of the address. end # @see Increase::Models::Entity::Joint::Individual#identification class Identification < Increase::Internal::Type::BaseModel # @!attribute method_ # A method that can be used to verify the individual's identity. # # @return [Symbol, Increase::Models::Entity::Joint::Individual::Identification::Method] required :method_, enum: -> { Increase::Entity::Joint::Individual::Identification::Method }, api_name: :method # @!attribute number_last4 # The last 4 digits of the identification number that can be used to verify the # individual's identity. # # @return [String] required :number_last4, String # @!method initialize(method_:, number_last4:) # Some parameter documentations has been truncated, see # {Increase::Models::Entity::Joint::Individual::Identification} for more details. # # A means of verifying the person's identity. # # @param method_ [Symbol, Increase::Models::Entity::Joint::Individual::Identification::Method] A method that can be used to verify the individual's identity. # # @param number_last4 [String] The last 4 digits of the identification number that can be used to verify the in # A method that can be used to verify the individual's identity. # # @see Increase::Models::Entity::Joint::Individual::Identification#method_ module Method extend Increase::Internal::Type::Enum # A social security number. SOCIAL_SECURITY_NUMBER = :social_security_number # An individual taxpayer identification number (ITIN). INDIVIDUAL_TAXPAYER_IDENTIFICATION_NUMBER = :individual_taxpayer_identification_number # A passport number. PASSPORT = :passport # A driver's license number. DRIVERS_LICENSE = :drivers_license # Another identifying document. OTHER = :other # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#address ⇒ Increase::Models::Entity::Joint::Individual::Address
The person’s address.
777 |
# File 'lib/increase/models/entity.rb', line 777 required :address, -> { Increase::Entity::Joint::Individual::Address } |
#date_of_birth ⇒ Date
The person’s date of birth in YYYY-MM-DD format.
783 |
# File 'lib/increase/models/entity.rb', line 783 required :date_of_birth, Date |
#identification ⇒ Increase::Models::Entity::Joint::Individual::Identification?
A means of verifying the person’s identity.
789 |
# File 'lib/increase/models/entity.rb', line 789 required :identification, -> { Increase::Entity::Joint::Individual::Identification }, nil?: true |
#name ⇒ String
The person’s legal name.
795 |
# File 'lib/increase/models/entity.rb', line 795 required :name, String |