Class: Increase::Models::Entity::SoleProprietorship
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::SoleProprietorship
- Defined in:
- lib/increase/models/entity.rb,
sig/increase/models/entity.rbs
Overview
Defined Under Namespace
Classes: Address, SoleProprietor
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::Entity::SoleProprietorship::Address
The sole proprietorship's address.
-
#doing_business_as_name ⇒ String?
The name under which the sole proprietorship does business.
-
#email ⇒ String?
An email address for the sole proprietorship.
-
#industry_code ⇒ String?
The numeric North American Industry Classification System (NAICS) code submitted for the sole proprietorship.
-
#sole_proprietor ⇒ Increase::Models::Entity::SoleProprietorship::SoleProprietor
The individual who operates the sole proprietorship.
-
#tax_identifier ⇒ String?
The Employer Identification Number (EIN) for the sole proprietorship.
-
#website ⇒ String?
The sole proprietorship's website.
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
constructor
The sole proprietorship's address.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object
The sole proprietorship's address.
|
|
# File 'lib/increase/models/entity.rb', line 1213
|
Instance Attribute Details
#address ⇒ Increase::Models::Entity::SoleProprietorship::Address
The sole proprietorship's address.
1174 |
# File 'lib/increase/models/entity.rb', line 1174 required :address, -> { Increase::Entity::SoleProprietorship::Address } |
#doing_business_as_name ⇒ String?
The name under which the sole proprietorship does business.
1180 |
# File 'lib/increase/models/entity.rb', line 1180 required :doing_business_as_name, String, nil?: true |
#email ⇒ String?
An email address for the sole proprietorship.
1186 |
# File 'lib/increase/models/entity.rb', line 1186 required :email, String, nil?: true |
#industry_code ⇒ String?
The numeric North American Industry Classification System (NAICS) code submitted for the sole proprietorship.
1193 |
# File 'lib/increase/models/entity.rb', line 1193 required :industry_code, String, nil?: true |
#sole_proprietor ⇒ Increase::Models::Entity::SoleProprietorship::SoleProprietor
The individual who operates the sole proprietorship.
1199 |
# File 'lib/increase/models/entity.rb', line 1199 required :sole_proprietor, -> { Increase::Entity::SoleProprietorship::SoleProprietor } |
#tax_identifier ⇒ String?
The Employer Identification Number (EIN) for the sole proprietorship.
1205 |
# File 'lib/increase/models/entity.rb', line 1205 required :tax_identifier, String, nil?: true |
#website ⇒ String?
The sole proprietorship's website.
1211 |
# File 'lib/increase/models/entity.rb', line 1211 required :website, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
902 |
# File 'sig/increase/models/entity.rbs', line 902
def to_hash: -> {
|