Class: Increase::Models::Entity::Trust

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity.rb

Overview

See Also:

Defined Under Namespace

Modules: Category Classes: Address, Grantor, Trustee

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2:, state:, zip:) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The trust’s address.

Parameters:

  • city (String, nil)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address.

  • line2 (String, nil)

    The second line of the address.

  • state (String, nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String, nil)

    The ZIP or postal code of the address.



# File 'lib/increase/models/entity.rb', line 1257

Instance Attribute Details

#addressIncrease::Models::Entity::Trust::Address

The trust’s address.



1212
# File 'lib/increase/models/entity.rb', line 1212

required :address, -> { Increase::Entity::Trust::Address }

#categorySymbol, Increase::Models::Entity::Trust::Category

Whether the trust is ‘revocable` or `irrevocable`.



1218
# File 'lib/increase/models/entity.rb', line 1218

required :category, enum: -> { Increase::Entity::Trust::Category }

#formation_document_file_idString?

The ID for the File containing the formation document of the trust.

Returns:

  • (String, nil)


1224
# File 'lib/increase/models/entity.rb', line 1224

required :formation_document_file_id, String, nil?: true

#formation_stateString?

The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.

Returns:

  • (String, nil)


1231
# File 'lib/increase/models/entity.rb', line 1231

required :formation_state, String, nil?: true

#grantorIncrease::Models::Entity::Trust::Grantor?

The grantor of the trust. Will be present if the ‘category` is `revocable`.



1237
# File 'lib/increase/models/entity.rb', line 1237

required :grantor, -> { Increase::Entity::Trust::Grantor }, nil?: true

#nameString

The trust’s name.

Returns:

  • (String)


1243
# File 'lib/increase/models/entity.rb', line 1243

required :name, String

#tax_identifierString?

The Employer Identification Number (EIN) of the trust itself.

Returns:

  • (String, nil)


1249
# File 'lib/increase/models/entity.rb', line 1249

required :tax_identifier, String, nil?: true

#trusteesArray<Increase::Models::Entity::Trust::Trustee>

The trustees of the trust.



1255
# File 'lib/increase/models/entity.rb', line 1255

required :trustees, -> { Increase::Internal::Type::ArrayOf[Increase::Entity::Trust::Trustee] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity.rb', line 1349