Class: Increase::Models::Entity::Validation::Issue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Entity::Validation::Issue
- Defined in:
- lib/increase/models/entity.rb
Defined Under Namespace
Modules: Category Classes: BeneficialOwnerAddress, BeneficialOwnerIdentity, EntityAddress, EntityTaxIdentifier
Instance Attribute Summary collapse
-
#beneficial_owner_address ⇒ Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress?
Details when the issue is with a beneficial owner’s address.
-
#beneficial_owner_identity ⇒ Increase::Models::Entity::Validation::Issue::BeneficialOwnerIdentity?
Details when the issue is with a beneficial owner’s identity verification.
-
#category ⇒ Symbol, Increase::Models::Entity::Validation::Issue::Category
The type of issue.
-
#entity_address ⇒ Increase::Models::Entity::Validation::Issue::EntityAddress?
Details when the issue is with the entity’s address.
-
#entity_tax_identifier ⇒ Increase::Models::Entity::Validation::Issue::EntityTaxIdentifier?
Details when the issue is with the entity’s tax ID.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(beneficial_owner_id:) ⇒ Object
constructor
Details when the issue is with a beneficial owner’s identity verification.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(beneficial_owner_id:) ⇒ Object
Details when the issue is with a beneficial owner’s identity verification.
1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 |
# File 'lib/increase/models/entity.rb', line 1768 class Issue < Increase::Internal::Type::BaseModel # @!attribute beneficial_owner_address # Details when the issue is with a beneficial owner's address. # # @return [Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress, nil] required :beneficial_owner_address, -> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress }, nil?: true # @!attribute beneficial_owner_identity # Details when the issue is with a beneficial owner's identity verification. # # @return [Increase::Models::Entity::Validation::Issue::BeneficialOwnerIdentity, nil] required :beneficial_owner_identity, -> { Increase::Entity::Validation::Issue::BeneficialOwnerIdentity }, nil?: true # @!attribute category # The type of issue. We may add additional possible values for this enum over # time; your application should be able to handle such additions gracefully. # # @return [Symbol, Increase::Models::Entity::Validation::Issue::Category] required :category, enum: -> { Increase::Entity::Validation::Issue::Category } # @!attribute entity_address # Details when the issue is with the entity's address. # # @return [Increase::Models::Entity::Validation::Issue::EntityAddress, nil] required :entity_address, -> { Increase::Entity::Validation::Issue::EntityAddress }, nil?: true # @!attribute entity_tax_identifier # Details when the issue is with the entity's tax ID. # # @return [Increase::Models::Entity::Validation::Issue::EntityTaxIdentifier, nil] required :entity_tax_identifier, -> { Increase::Entity::Validation::Issue::EntityTaxIdentifier }, nil?: true # @!method initialize(beneficial_owner_address:, beneficial_owner_identity:, category:, entity_address:, entity_tax_identifier:) # Some parameter documentations has been truncated, see # {Increase::Models::Entity::Validation::Issue} for more details. # # @param beneficial_owner_address [Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress, nil] Details when the issue is with a beneficial owner's address. # # @param beneficial_owner_identity [Increase::Models::Entity::Validation::Issue::BeneficialOwnerIdentity, nil] Details when the issue is with a beneficial owner's identity verification. # # @param category [Symbol, Increase::Models::Entity::Validation::Issue::Category] The type of issue. We may add additional possible values for this enum over time # # @param entity_address [Increase::Models::Entity::Validation::Issue::EntityAddress, nil] Details when the issue is with the entity's address. # # @param entity_tax_identifier [Increase::Models::Entity::Validation::Issue::EntityTaxIdentifier, nil] Details when the issue is with the entity's tax ID. # @see Increase::Models::Entity::Validation::Issue#beneficial_owner_address class BeneficialOwnerAddress < Increase::Internal::Type::BaseModel # @!attribute beneficial_owner_id # The ID of the beneficial owner. # # @return [String] required :beneficial_owner_id, String # @!attribute reason # The reason the address is invalid. # # @return [Symbol, Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress::Reason] required :reason, enum: -> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress::Reason } # @!method initialize(beneficial_owner_id:, reason:) # Details when the issue is with a beneficial owner's address. # # @param beneficial_owner_id [String] The ID of the beneficial owner. # # @param reason [Symbol, Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress::Reason] The reason the address is invalid. # The reason the address is invalid. # # @see Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress#reason module Reason extend Increase::Internal::Type::Enum # The address is a mailbox or other non-physical address. MAILBOX_ADDRESS = :mailbox_address # @!method self.values # @return [Array<Symbol>] end end # @see Increase::Models::Entity::Validation::Issue#beneficial_owner_identity class BeneficialOwnerIdentity < Increase::Internal::Type::BaseModel # @!attribute beneficial_owner_id # The ID of the beneficial owner. # # @return [String] required :beneficial_owner_id, String # @!method initialize(beneficial_owner_id:) # Details when the issue is with a beneficial owner's identity verification. # # @param beneficial_owner_id [String] The ID of the beneficial owner. end # The type of issue. We may add additional possible values for this enum over # time; your application should be able to handle such additions gracefully. # # @see Increase::Models::Entity::Validation::Issue#category module Category extend Increase::Internal::Type::Enum # The entity's tax identifier could not be validated. Update the tax ID with the [update an entity API](/documentation/api/entities#update-an-entity.corporation.legal_identifier). ENTITY_TAX_IDENTIFIER = :entity_tax_identifier # The entity's address could not be validated. Update the address with the [update an entity API](/documentation/api/entities#update-an-entity.corporation.address). ENTITY_ADDRESS = :entity_address # A beneficial owner's identity could not be verified. Update the identification with the [update a beneficial owner API](/documentation/api/beneficial-owners#update-a-beneficial-owner). BENEFICIAL_OWNER_IDENTITY = :beneficial_owner_identity # A beneficial owner's address could not be validated. Update the address with the [update a beneficial owner API](/documentation/api/beneficial-owners#update-a-beneficial-owner). BENEFICIAL_OWNER_ADDRESS = :beneficial_owner_address # @!method self.values # @return [Array<Symbol>] end # @see Increase::Models::Entity::Validation::Issue#entity_address class EntityAddress < Increase::Internal::Type::BaseModel # @!attribute reason # The reason the address is invalid. # # @return [Symbol, Increase::Models::Entity::Validation::Issue::EntityAddress::Reason] required :reason, enum: -> { Increase::Entity::Validation::Issue::EntityAddress::Reason } # @!method initialize(reason:) # Details when the issue is with the entity's address. # # @param reason [Symbol, Increase::Models::Entity::Validation::Issue::EntityAddress::Reason] The reason the address is invalid. # The reason the address is invalid. # # @see Increase::Models::Entity::Validation::Issue::EntityAddress#reason module Reason extend Increase::Internal::Type::Enum # The address is a mailbox or other non-physical address. MAILBOX_ADDRESS = :mailbox_address # @!method self.values # @return [Array<Symbol>] end end # @see Increase::Models::Entity::Validation::Issue#entity_tax_identifier class EntityTaxIdentifier < Increase::Internal::Type::BaseModel # @!method initialize # Details when the issue is with the entity's tax ID. end end |
Instance Attribute Details
#beneficial_owner_address ⇒ Increase::Models::Entity::Validation::Issue::BeneficialOwnerAddress?
Details when the issue is with a beneficial owner’s address.
1773 1774 1775 |
# File 'lib/increase/models/entity.rb', line 1773 required :beneficial_owner_address, -> { Increase::Entity::Validation::Issue::BeneficialOwnerAddress }, nil?: true |
#beneficial_owner_identity ⇒ Increase::Models::Entity::Validation::Issue::BeneficialOwnerIdentity?
Details when the issue is with a beneficial owner’s identity verification.
1781 1782 1783 |
# File 'lib/increase/models/entity.rb', line 1781 required :beneficial_owner_identity, -> { Increase::Entity::Validation::Issue::BeneficialOwnerIdentity }, nil?: true |
#category ⇒ Symbol, Increase::Models::Entity::Validation::Issue::Category
The type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
1790 |
# File 'lib/increase/models/entity.rb', line 1790 required :category, enum: -> { Increase::Entity::Validation::Issue::Category } |
#entity_address ⇒ Increase::Models::Entity::Validation::Issue::EntityAddress?
Details when the issue is with the entity’s address.
1796 |
# File 'lib/increase/models/entity.rb', line 1796 required :entity_address, -> { Increase::Entity::Validation::Issue::EntityAddress }, nil?: true |
#entity_tax_identifier ⇒ Increase::Models::Entity::Validation::Issue::EntityTaxIdentifier?
Details when the issue is with the entity’s tax ID.
1802 1803 1804 |
# File 'lib/increase/models/entity.rb', line 1802 required :entity_tax_identifier, -> { Increase::Entity::Validation::Issue::EntityTaxIdentifier }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity.rb', line 1850
|