Module: Increase::Models::Entity::Validation::Issue::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/entity.rb
Overview
The type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
Constant Summary collapse
- ENTITY_TAX_IDENTIFIER =
The entity’s tax identifier could not be validated. Update the tax ID with the [update an entity API](/documentation/api/entities#update-an-entity.corporation.legal_identifier).
:entity_tax_identifier- ENTITY_ADDRESS =
The entity’s address could not be validated. Update the address with the [update an entity API](/documentation/api/entities#update-an-entity.corporation.address).
:entity_address- BENEFICIAL_OWNER_IDENTITY =
A beneficial owner’s identity could not be verified. Update the identification with the [update a beneficial owner API](/documentation/api/beneficial-owners#update-a-beneficial-owner).
:beneficial_owner_identity- BENEFICIAL_OWNER_ADDRESS =
A beneficial owner’s address could not be validated. Update the address with the [update a beneficial owner API](/documentation/api/beneficial-owners#update-a-beneficial-owner).
:beneficial_owner_address
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info