Class: Increase::Models::EntityCreateParams::Corporation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb

Defined Under Namespace

Modules: BeneficialOwnershipExemptionReason Classes: Address, BeneficialOwner, LegalIdentifier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object

Some parameter documentations has been truncated, see Address for more details.

The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.

Parameters:

  • city (String)

    The city, district, town, or village of the address.

  • country (String)

    The two-letter ISO 3166-1 alpha-2 code for the country of the address.

  • line1 (String)

    The first line of the address. This is usually the street number and street.

  • line2 (String) (defaults to: nil)

    The second line of the address. This might be the floor or room number.

  • state (String) (defaults to: nil)

    The two-letter United States Postal Service (USPS) abbreviation for the US state

  • zip (String) (defaults to: nil)

    The ZIP or postal code of the address. Required in certain countries.



# File 'lib/increase/models/entity_create_params.rb', line 208

Instance Attribute Details

#addressIncrease::Models::EntityCreateParams::Corporation::Address

The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.



146
# File 'lib/increase/models/entity_create_params.rb', line 146

required :address, -> { Increase::EntityCreateParams::Corporation::Address }

#beneficial_ownersArray<Increase::Models::EntityCreateParams::Corporation::BeneficialOwner>

The identifying details of each person who owns 25% or more of the business and one control person, like the CEO, CFO, or other executive. You can submit between 1 and 5 people to this list.



154
155
# File 'lib/increase/models/entity_create_params.rb', line 154

required :beneficial_owners,
-> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::Corporation::BeneficialOwner] }

#beneficial_ownership_exemption_reasonSymbol, ...

If the entity is exempt from the requirement to submit beneficial owners, provide the justification. If a reason is provided, you do not need to submit a list of beneficial owners.



176
177
# File 'lib/increase/models/entity_create_params.rb', line 176

optional :beneficial_ownership_exemption_reason,
enum: -> { Increase::EntityCreateParams::Corporation::BeneficialOwnershipExemptionReason }

#emailString?

An email address for the business. Not every program requires an email for submitted Entities.

Returns:

  • (String, nil)


184
# File 'lib/increase/models/entity_create_params.rb', line 184

optional :email, String

#incorporation_stateString?

The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.

Returns:

  • (String, nil)


191
# File 'lib/increase/models/entity_create_params.rb', line 191

optional :incorporation_state, String

#industry_codeString?

The North American Industry Classification System (NAICS) code for the corporation’s primary line of business. This is a number, like ‘5132` for `Software Publishers`. A full list of classification codes is available [here](increase.com/documentation/data-dictionary#north-american-industry-classification-system-codes).

Returns:

  • (String, nil)


200
# File 'lib/increase/models/entity_create_params.rb', line 200

optional :industry_code, String

The legal identifier of the corporation. This is usually the Employer Identification Number (EIN).



162
# File 'lib/increase/models/entity_create_params.rb', line 162

required :legal_identifier, -> { Increase::EntityCreateParams::Corporation::LegalIdentifier }

#nameString

The legal name of the corporation.

Returns:

  • (String)


168
# File 'lib/increase/models/entity_create_params.rb', line 168

required :name, String

#websiteString?

The website of the corporation.

Returns:

  • (String, nil)


206
# File 'lib/increase/models/entity_create_params.rb', line 206

optional :website, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity_create_params.rb', line 663