Class: Increase::Models::EntityCreateParams::Corporation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Corporation
- Defined in:
- lib/increase/models/entity_create_params.rb
Defined Under Namespace
Modules: BeneficialOwnershipExemptionReason Classes: Address, BeneficialOwner, LegalIdentifier
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::EntityCreateParams::Corporation::Address
The entity’s physical address.
-
#beneficial_owners ⇒ Array<Increase::Models::EntityCreateParams::Corporation::BeneficialOwner>
The identifying details of each person who owns 25% or more of the business and one control person, like the CEO, CFO, or other executive.
-
#beneficial_ownership_exemption_reason ⇒ Symbol, ...
If the entity is exempt from the requirement to submit beneficial owners, provide the justification.
-
#email ⇒ String?
An email address for the business.
-
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.
-
#industry_code ⇒ String?
The North American Industry Classification System (NAICS) code for the corporation’s primary line of business.
-
#legal_identifier ⇒ Increase::Models::EntityCreateParams::Corporation::LegalIdentifier
The legal identifier of the corporation.
-
#name ⇒ String
The legal name of the corporation.
-
#website ⇒ String?
The website of the corporation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 208
|
Instance Attribute Details
#address ⇒ Increase::Models::EntityCreateParams::Corporation::Address
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
146 |
# File 'lib/increase/models/entity_create_params.rb', line 146 required :address, -> { Increase::EntityCreateParams::Corporation::Address } |
#beneficial_owners ⇒ Array<Increase::Models::EntityCreateParams::Corporation::BeneficialOwner>
The identifying details of each person who owns 25% or more of the business and one control person, like the CEO, CFO, or other executive. You can submit between 1 and 5 people to this list.
154 155 |
# File 'lib/increase/models/entity_create_params.rb', line 154 required :beneficial_owners, -> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::Corporation::BeneficialOwner] } |
#beneficial_ownership_exemption_reason ⇒ Symbol, ...
If the entity is exempt from the requirement to submit beneficial owners, provide the justification. If a reason is provided, you do not need to submit a list of beneficial owners.
176 177 |
# File 'lib/increase/models/entity_create_params.rb', line 176 optional :beneficial_ownership_exemption_reason, enum: -> { Increase::EntityCreateParams::Corporation::BeneficialOwnershipExemptionReason } |
#email ⇒ String?
An email address for the business. Not every program requires an email for submitted Entities.
184 |
# File 'lib/increase/models/entity_create_params.rb', line 184 optional :email, String |
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.
191 |
# File 'lib/increase/models/entity_create_params.rb', line 191 optional :incorporation_state, String |
#industry_code ⇒ String?
The North American Industry Classification System (NAICS) code for the corporation’s primary line of business. This is a number, like ‘5132` for `Software Publishers`. A full list of classification codes is available [here](increase.com/documentation/data-dictionary#north-american-industry-classification-system-codes).
200 |
# File 'lib/increase/models/entity_create_params.rb', line 200 optional :industry_code, String |
#legal_identifier ⇒ Increase::Models::EntityCreateParams::Corporation::LegalIdentifier
The legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
162 |
# File 'lib/increase/models/entity_create_params.rb', line 162 required :legal_identifier, -> { Increase::EntityCreateParams::Corporation::LegalIdentifier } |
#name ⇒ String
The legal name of the corporation.
168 |
# File 'lib/increase/models/entity_create_params.rb', line 168 required :name, String |
#website ⇒ String?
The website of the corporation.
206 |
# File 'lib/increase/models/entity_create_params.rb', line 206 optional :website, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity_create_params.rb', line 663
|