Class: Increase::Models::EntityCreateParams::Corporation::LegalIdentifier

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Overview

See Also:

  • Increase::Models::EntityCreateParams::Corporation#legal_identifier

Defined Under Namespace

Modules: Category

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(value:, category: nil) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::EntityCreateParams::Corporation::LegalIdentifier for more details.

The legal identifier of the corporation. This is usually the Employer Identification Number (EIN). This replaces the deprecated tax_identifier field.

Parameters:



# File 'lib/increase/models/entity_create_params.rb', line 694

Instance Attribute Details

#categorySymbol, ...

The category of the legal identifier. If not provided, the default is us_employer_identification_number.



692
# File 'lib/increase/models/entity_create_params.rb', line 692

optional :category, enum: -> { Increase::EntityCreateParams::Corporation::LegalIdentifier::Category }

#valueString

The legal identifier itself. For US Employer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.

Parameters:

  • value (String)

Returns:

  • (String)


685
# File 'lib/increase/models/entity_create_params.rb', line 685

required :value, String

Instance Method Details

#to_hash{

Returns:

  • ({)


578
# File 'sig/increase/models/entity_create_params.rbs', line 578

def to_hash: -> {