Class: Increase::Models::EntityCreateParams::GovernmentAuthority
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::GovernmentAuthority
- Defined in:
- lib/increase/models/entity_create_params.rb
Defined Under Namespace
Modules: Category Classes: Address, AuthorizedPerson
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::EntityCreateParams::GovernmentAuthority::Address
The entity’s physical address.
-
#authorized_persons ⇒ Array<Increase::Models::EntityCreateParams::GovernmentAuthority::AuthorizedPerson>
The identifying details of authorized officials acting on the entity’s behalf.
-
#category ⇒ Symbol, Increase::Models::EntityCreateParams::GovernmentAuthority::Category
The category of the government authority.
-
#name ⇒ String
The legal name of the government authority.
-
#tax_identifier ⇒ String
The Employer Identification Number (EIN) for the government authority.
-
#website ⇒ String?
A website for the government authority.
Instance Method Summary collapse
- #initialize(name:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:) ⇒ Object
|
|
# File 'lib/increase/models/entity_create_params.rb', line 783
|
Instance Attribute Details
#address ⇒ Increase::Models::EntityCreateParams::GovernmentAuthority::Address
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
748 |
# File 'lib/increase/models/entity_create_params.rb', line 748 required :address, -> { Increase::EntityCreateParams::GovernmentAuthority::Address } |
#authorized_persons ⇒ Array<Increase::Models::EntityCreateParams::GovernmentAuthority::AuthorizedPerson>
The identifying details of authorized officials acting on the entity’s behalf.
754 755 |
# File 'lib/increase/models/entity_create_params.rb', line 754 required :authorized_persons, -> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::GovernmentAuthority::AuthorizedPerson] } |
#category ⇒ Symbol, Increase::Models::EntityCreateParams::GovernmentAuthority::Category
The category of the government authority.
761 |
# File 'lib/increase/models/entity_create_params.rb', line 761 required :category, enum: -> { Increase::EntityCreateParams::GovernmentAuthority::Category } |
#name ⇒ String
The legal name of the government authority.
767 |
# File 'lib/increase/models/entity_create_params.rb', line 767 required :name, String |
#tax_identifier ⇒ String
The Employer Identification Number (EIN) for the government authority. Submit nine digits with no dashes or other separators.
774 |
# File 'lib/increase/models/entity_create_params.rb', line 774 required :tax_identifier, String |
#website ⇒ String?
A website for the government authority. Not every program requires a website for submitted Entities.
781 |
# File 'lib/increase/models/entity_create_params.rb', line 781 optional :website, String |