Class: Increase::Models::EntityCreateParams::Joint::Individual::Identification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs

Overview

See Also:

  • Increase::Models::EntityCreateParams::Joint::Individual#identification

Defined Under Namespace

Modules: Method Classes: DriversLicense, Other, Passport

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object

Information about the identification document provided. Required if method is equal to other.

Parameters:

  • country (String)

    The two-character ISO 3166-1 code representing the country that issued the document (e.g., US).

  • description (String)

    A description of the document submitted.

  • file_id (String)

    The identifier of the File containing the front of the document.

  • back_file_id (String) (defaults to: nil)

    The identifier of the File containing the back of the document. Not every document has a reverse side.

  • expiration_date (Date) (defaults to: nil)

    The document's expiration date in YYYY-MM-DD format.



# File 'lib/increase/models/entity_create_params.rb', line 1122

Instance Attribute Details

#drivers_licenseIncrease::Models::EntityCreateParams::Joint::Individual::Identification::DriversLicense?

Information about the United States driver's license used for identification. Required if method is equal to drivers_license.



1105
1106
# File 'lib/increase/models/entity_create_params.rb', line 1105

optional :drivers_license,
-> { Increase::EntityCreateParams::Joint::Individual::Identification::DriversLicense }

#method_Symbol, Increase::Models::EntityCreateParams::Joint::Individual::Identification::Method

A method that can be used to verify the individual's identity.

Parameters:

  • value (Increase::Models::EntityCreateParams::Joint::Individual::Identification::method_)

Returns:



1086
1087
1088
# File 'lib/increase/models/entity_create_params.rb', line 1086

required :method_,
enum: -> { Increase::EntityCreateParams::Joint::Individual::Identification::Method },
api_name: :method

#numberString

An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.

Parameters:

  • value (String)

Returns:

  • (String)


1098
# File 'lib/increase/models/entity_create_params.rb', line 1098

required :number, String

#otherIncrease::Models::EntityCreateParams::Joint::Individual::Identification::Other?

Information about the identification document provided. Required if method is equal to other.



1113
# File 'lib/increase/models/entity_create_params.rb', line 1113

optional :other, -> { Increase::EntityCreateParams::Joint::Individual::Identification::Other }

#passportIncrease::Models::EntityCreateParams::Joint::Individual::Identification::Passport?

Information about the passport used for identification. Required if method is equal to passport.



1120
# File 'lib/increase/models/entity_create_params.rb', line 1120

optional :passport, -> { Increase::EntityCreateParams::Joint::Individual::Identification::Passport }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity_create_params.rb', line 1168

Instance Method Details

#to_hash{

Returns:

  • ({)


885
# File 'sig/increase/models/entity_create_params.rbs', line 885

def to_hash: -> {