Class: Increase::Models::EntityCreateParams::SoleProprietorship
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::SoleProprietorship
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Defined Under Namespace
Classes: Address, SoleProprietor
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::EntityCreateParams::SoleProprietorship::Address
The sole proprietorship's business address.
-
#doing_business_as_name ⇒ String?
The name under which the sole proprietorship does business, if it is different from the name of the sole proprietor.
-
#email ⇒ String?
An email address for the sole proprietorship.
-
#industry_code ⇒ String?
The North American Industry Classification System (NAICS) code for the sole proprietorship's primary line of business.
-
#sole_proprietor ⇒ Increase::Models::EntityCreateParams::SoleProprietorship::SoleProprietor
The individual who operates the sole proprietorship.
-
#tax_identifier ⇒ String?
The United States Employer Identification Number (EIN) for the sole proprietorship, if the sole proprietor has one.
-
#website ⇒ String?
A website for the sole proprietorship.
Instance Method Summary collapse
-
#initialize(city:, line1:, state:, zip:, line2: nil) ⇒ Object
constructor
The sole proprietorship's business address.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, line1:, state:, zip:, line2: nil) ⇒ Object
The sole proprietorship's business address. Mail receiving locations like PO Boxes and PMB's are disallowed.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 1770
|
Instance Attribute Details
#address ⇒ Increase::Models::EntityCreateParams::SoleProprietorship::Address
The sole proprietorship's business address. Mail receiving locations like PO Boxes and PMB's are disallowed.
1724 |
# File 'lib/increase/models/entity_create_params.rb', line 1724 required :address, -> { Increase::EntityCreateParams::SoleProprietorship::Address } |
#doing_business_as_name ⇒ String?
The name under which the sole proprietorship does business, if it is different from the name of the sole proprietor.
1737 |
# File 'lib/increase/models/entity_create_params.rb', line 1737 optional :doing_business_as_name, String |
#email ⇒ String?
An email address for the sole proprietorship. Not every program requires an email for submitted Entities.
1744 |
# File 'lib/increase/models/entity_create_params.rb', line 1744 optional :email, String |
#industry_code ⇒ String?
The North American Industry Classification System (NAICS) code for the sole
proprietorship's primary line of business. This is a number, like 5132 for
Software Publishers. A full list of classification codes is available
here.
1753 |
# File 'lib/increase/models/entity_create_params.rb', line 1753 optional :industry_code, String |
#sole_proprietor ⇒ Increase::Models::EntityCreateParams::SoleProprietorship::SoleProprietor
The individual who operates the sole proprietorship.
1730 |
# File 'lib/increase/models/entity_create_params.rb', line 1730 required :sole_proprietor, -> { Increase::EntityCreateParams::SoleProprietorship::SoleProprietor } |
#tax_identifier ⇒ String?
The United States Employer Identification Number (EIN) for the sole proprietorship, if the sole proprietor has one. Submit nine digits with no dashes or other separators.
1761 |
# File 'lib/increase/models/entity_create_params.rb', line 1761 optional :tax_identifier, String |
#website ⇒ String?
A website for the sole proprietorship. Not every program requires a website for submitted Entities.
1768 |
# File 'lib/increase/models/entity_create_params.rb', line 1768 optional :website, String |
Instance Method Details
#to_hash ⇒ {
1380 |
# File 'sig/increase/models/entity_create_params.rbs', line 1380 def to_hash: -> { |