Class: Increase::Models::EntityCreateParams::SoleProprietorship::SoleProprietor::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::SoleProprietorship::SoleProprietor::Identification
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Overview
Defined Under Namespace
Modules: Method
Instance Attribute Summary collapse
-
#method_ ⇒ Symbol, Increase::Models::EntityCreateParams::SoleProprietorship::SoleProprietor::Identification::Method
A method that can be used to verify the individual's identity.
-
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number.
Instance Method Summary collapse
-
#initialize(method_:, number:) ⇒ Object
constructor
A means of verifying the person's identity.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(method_:, number:) ⇒ Object
A means of verifying the person's identity. Sole proprietors must be identified
with a social_security_number or an
individual_taxpayer_identification_number.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 1985
|
Instance Attribute Details
#method_ ⇒ Symbol, Increase::Models::EntityCreateParams::SoleProprietorship::SoleProprietor::Identification::Method
A method that can be used to verify the individual's identity.
Defaults to social_security_number.
1971 1972 1973 1974 1975 |
# File 'lib/increase/models/entity_create_params.rb', line 1971 required :method_, enum: -> { Increase::EntityCreateParams::SoleProprietorship::SoleProprietor::Identification::Method }, api_name: :method |
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number. Submit nine digits with no dashes or other separators.
1983 |
# File 'lib/increase/models/entity_create_params.rb', line 1983 required :number, String |
Instance Method Details
#to_hash ⇒ {
1524 |
# File 'sig/increase/models/entity_create_params.rbs', line 1524 def to_hash: -> { |