Class: Increase::Models::EntityCreateParams::Trust
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Trust
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Defined Under Namespace
Modules: Category Classes: Address, Grantor, Trustee
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::EntityCreateParams::Trust::Address
The trust's physical address.
-
#category ⇒ Symbol, Increase::Models::EntityCreateParams::Trust::Category
Whether the trust is
revocableorirrevocable. -
#formation_document_file_id ⇒ String?
The identifier of the File containing the formation document of the trust.
-
#formation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
#grantor ⇒ Increase::Models::EntityCreateParams::Trust::Grantor?
The grantor of the trust.
-
#name ⇒ String
The legal name of the trust.
-
#tax_identifier ⇒ String?
The Employer Identification Number (EIN) for the trust.
-
#trustees ⇒ Array<Increase::Models::EntityCreateParams::Trust::Trustee>
The trustees of the trust.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, expiration_date:, file_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Trustee::Individual::Identification::Passport for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, expiration_date:, file_id:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Passport for more details.
Information about the passport used for identification. Required if method is
equal to passport.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 1749
|
Instance Attribute Details
#address ⇒ Increase::Models::EntityCreateParams::Trust::Address
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
1701 |
# File 'lib/increase/models/entity_create_params.rb', line 1701 required :address, -> { Increase::EntityCreateParams::Trust::Address } |
#category ⇒ Symbol, Increase::Models::EntityCreateParams::Trust::Category
Whether the trust is revocable or irrevocable. Irrevocable trusts require
their own Employer Identification Number. Revocable trusts require information
about the individual grantor who created the trust.
1709 |
# File 'lib/increase/models/entity_create_params.rb', line 1709 required :category, enum: -> { Increase::EntityCreateParams::Trust::Category } |
#formation_document_file_id ⇒ String?
The identifier of the File containing the formation document of the trust.
1727 |
# File 'lib/increase/models/entity_create_params.rb', line 1727 optional :formation_document_file_id, String |
#formation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
1734 |
# File 'lib/increase/models/entity_create_params.rb', line 1734 optional :formation_state, String |
#grantor ⇒ Increase::Models::EntityCreateParams::Trust::Grantor?
The grantor of the trust. Required if category is equal to revocable.
1740 |
# File 'lib/increase/models/entity_create_params.rb', line 1740 optional :grantor, -> { Increase::EntityCreateParams::Trust::Grantor } |
#name ⇒ String
The legal name of the trust.
1715 |
# File 'lib/increase/models/entity_create_params.rb', line 1715 required :name, String |
#tax_identifier ⇒ String?
The Employer Identification Number (EIN) for the trust. Submit nine digits with
no dashes or other separators. Required if category is equal to irrevocable.
1747 |
# File 'lib/increase/models/entity_create_params.rb', line 1747 optional :tax_identifier, String |
#trustees ⇒ Array<Increase::Models::EntityCreateParams::Trust::Trustee>
The trustees of the trust.
1721 |
# File 'lib/increase/models/entity_create_params.rb', line 1721 required :trustees, -> { Increase::Internal::Type::ArrayOf[Increase::EntityCreateParams::Trust::Trustee] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity_create_params.rb', line 1837
|
Instance Method Details
#to_hash ⇒ {
1445 |
# File 'sig/increase/models/entity_create_params.rbs', line 1445
def to_hash: -> {
|