Class: Increase::Models::EntityCreateParams::Trust::Grantor::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Trust::Grantor::Identification
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Overview
Defined Under Namespace
Modules: Method Classes: DriversLicense, Other, Passport
Instance Attribute Summary collapse
-
#drivers_license ⇒ Increase::Models::EntityCreateParams::Trust::Grantor::Identification::DriversLicense?
Information about the United States driver's license used for identification.
-
#method_ ⇒ Symbol, Increase::Models::EntityCreateParams::Trust::Grantor::Identification::Method
A method that can be used to verify the individual's identity.
-
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number.
-
#other ⇒ Increase::Models::EntityCreateParams::Trust::Grantor::Identification::Other?
Information about the identification document provided.
-
#passport ⇒ Increase::Models::EntityCreateParams::Trust::Grantor::Identification::Passport?
Information about the passport used for identification.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
constructor
Information about the identification document provided.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
Information about the identification document provided. Required if method is
equal to other.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 2443
|
Instance Attribute Details
#drivers_license ⇒ Increase::Models::EntityCreateParams::Trust::Grantor::Identification::DriversLicense?
Information about the United States driver's license used for identification.
Required if method is equal to drivers_license.
2426 2427 |
# File 'lib/increase/models/entity_create_params.rb', line 2426 optional :drivers_license, -> { Increase::EntityCreateParams::Trust::Grantor::Identification::DriversLicense } |
#method_ ⇒ Symbol, Increase::Models::EntityCreateParams::Trust::Grantor::Identification::Method
A method that can be used to verify the individual's identity.
2407 2408 2409 |
# File 'lib/increase/models/entity_create_params.rb', line 2407 required :method_, enum: -> { Increase::EntityCreateParams::Trust::Grantor::Identification::Method }, api_name: :method |
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.
2419 |
# File 'lib/increase/models/entity_create_params.rb', line 2419 required :number, String |
#other ⇒ Increase::Models::EntityCreateParams::Trust::Grantor::Identification::Other?
Information about the identification document provided. Required if method is
equal to other.
2434 |
# File 'lib/increase/models/entity_create_params.rb', line 2434 optional :other, -> { Increase::EntityCreateParams::Trust::Grantor::Identification::Other } |
#passport ⇒ Increase::Models::EntityCreateParams::Trust::Grantor::Identification::Passport?
Information about the passport used for identification. Required if method is
equal to passport.
2441 |
# File 'lib/increase/models/entity_create_params.rb', line 2441 optional :passport, -> { Increase::EntityCreateParams::Trust::Grantor::Identification::Passport } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity_create_params.rb', line 2489
|
Instance Method Details
#to_hash ⇒ {
1934 |
# File 'sig/increase/models/entity_create_params.rbs', line 1934
def to_hash: -> {
|