Class: Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification
- Defined in:
- lib/increase/models/entity_create_params.rb,
sig/increase/models/entity_create_params.rbs
Overview
Defined Under Namespace
Modules: Method Classes: DriversLicense, Other, Passport
Instance Attribute Summary collapse
-
#drivers_license ⇒ Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::DriversLicense?
Information about the United States driver's license used for identification.
-
#method_ ⇒ Symbol, Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Method
A method that can be used to verify the individual's identity.
-
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number.
-
#other ⇒ Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Other?
Information about the identification document provided.
-
#passport ⇒ Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Passport?
Information about the passport used for identification.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
constructor
Information about the identification document provided.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object
Information about the identification document provided. Required if method is
equal to other.
|
|
# File 'lib/increase/models/entity_create_params.rb', line 2156
|
Instance Attribute Details
#drivers_license ⇒ Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::DriversLicense?
Information about the United States driver's license used for identification.
Required if method is equal to drivers_license.
2138 2139 |
# File 'lib/increase/models/entity_create_params.rb', line 2138 optional :drivers_license, -> { Increase::EntityCreateParams::Trust::Trustee::Individual::Identification::DriversLicense } |
#method_ ⇒ Symbol, Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Method
A method that can be used to verify the individual's identity.
Defaults to social_security_number.
2117 2118 2119 2120 2121 |
# File 'lib/increase/models/entity_create_params.rb', line 2117 required :method_, enum: -> { Increase::EntityCreateParams::Trust::Trustee::Individual::Identification::Method }, api_name: :method |
#number ⇒ String
An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.
2131 |
# File 'lib/increase/models/entity_create_params.rb', line 2131 required :number, String |
#other ⇒ Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Other?
Information about the identification document provided. Required if method is
equal to other.
2146 |
# File 'lib/increase/models/entity_create_params.rb', line 2146 optional :other, -> { Increase::EntityCreateParams::Trust::Trustee::Individual::Identification::Other } |
#passport ⇒ Increase::Models::EntityCreateParams::Trust::Trustee::Individual::Identification::Passport?
Information about the passport used for identification. Required if method is
equal to passport.
2153 2154 |
# File 'lib/increase/models/entity_create_params.rb', line 2153 optional :passport, -> { Increase::EntityCreateParams::Trust::Trustee::Individual::Identification::Passport } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity_create_params.rb', line 2206
|
Instance Method Details
#to_hash ⇒ {
1671 |
# File 'sig/increase/models/entity_create_params.rbs', line 1671
def to_hash: -> {
|