Class: Increase::Models::EntityOnboardingSession
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityOnboardingSession
- Defined in:
- lib/increase/models/entity_onboarding_session.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Entity Onboarding Session was created.
-
#entity_id ⇒ String?
The identifier of the Entity associated with this session, if one has been created or was provided when creating the session.
-
#expires_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Entity Onboarding Session will expire.
-
#id ⇒ String
The Entity Onboarding Session’s identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#program_id ⇒ String
The identifier of the Program the Entity will be onboarded to.
-
#redirect_url ⇒ String
The URL to redirect to after the onboarding session is complete.
-
#session_url ⇒ String?
The URL containing the onboarding form.
-
#status ⇒ Symbol, Increase::Models::EntityOnboardingSession::Status
The status of the onboarding session.
-
#type ⇒ Symbol, Increase::Models::EntityOnboardingSession::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, entity_id:, expires_at:, idempotency_key:, program_id:, redirect_url:, session_url:, status:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see EntityOnboardingSession for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, entity_id:, expires_at:, idempotency_key:, program_id:, redirect_url:, session_url:, status:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::EntityOnboardingSession for more details.
Entity Onboarding Sessions let your customers onboard themselves by completing Increase-hosted forms. Create a session and redirect your customer to the returned URL. When they’re done, they’ll be redirected back to your site. This API is used for [hosted onboarding](/documentation/hosted-onboarding).
|
|
# File 'lib/increase/models/entity_onboarding_session.rb', line 76
|
Instance Attribute Details
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Entity Onboarding Session was created.
18 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 18 required :created_at, Time |
#entity_id ⇒ String?
The identifier of the Entity associated with this session, if one has been created or was provided when creating the session.
25 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 25 required :entity_id, String, nil?: true |
#expires_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the Entity Onboarding Session will expire.
32 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 32 required :expires_at, Time |
#id ⇒ String
The Entity Onboarding Session’s identifier.
11 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
40 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 40 required :idempotency_key, String, nil?: true |
#program_id ⇒ String
The identifier of the Program the Entity will be onboarded to.
46 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 46 required :program_id, String |
#redirect_url ⇒ String
The URL to redirect to after the onboarding session is complete. Increase will include the query parameters ‘entity_onboarding_session_id` and `entity_id` when redirecting.
54 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 54 required :redirect_url, String |
#session_url ⇒ String?
The URL containing the onboarding form. You should share this link with your customer. Only present when the session is active.
61 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 61 required :session_url, String, nil?: true |
#status ⇒ Symbol, Increase::Models::EntityOnboardingSession::Status
The status of the onboarding session.
67 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 67 required :status, enum: -> { Increase::EntityOnboardingSession::Status } |
#type ⇒ Symbol, Increase::Models::EntityOnboardingSession::Type
A constant representing the object’s type. For this resource it will always be ‘entity_onboarding_session`.
74 |
# File 'lib/increase/models/entity_onboarding_session.rb', line 74 required :type, enum: -> { Increase::EntityOnboardingSession::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/entity_onboarding_session.rb', line 117
|