Class: Increase::Models::EntityUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/entity_update_params.rb

Overview

Defined Under Namespace

Classes: Corporation, GovernmentAuthority, NaturalPerson, RiskRating, ThirdPartyVerification, Trust

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, expiration_date:, file_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::EntityUpdateParams::NaturalPerson::Identification::Passport for more details.

Information about the passport used for identification. Required if ‘method` is equal to `passport`.

Parameters:

  • country (String)

    The two-character ISO 3166-1 code representing the country that issued the docum

  • expiration_date (Date)

    The passport’s expiration date in YYYY-MM-DD format.

  • file_id (String)

    The identifier of the File containing the passport.



# File 'lib/increase/models/entity_update_params.rb', line 309

Instance Attribute Details

#corporationIncrease::Models::EntityUpdateParams::Corporation?

Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.



21
# File 'lib/increase/models/entity_update_params.rb', line 21

optional :corporation, -> { Increase::EntityUpdateParams::Corporation }

#details_confirmed_atTime?

When your user last confirmed the Entity’s details. Depending on your program, you may be required to affirmatively confirm details with your users on an annual basis.

Returns:

  • (Time, nil)


29
# File 'lib/increase/models/entity_update_params.rb', line 29

optional :details_confirmed_at, Time

#entity_idString

The entity identifier.

Returns:

  • (String)


14
# File 'lib/increase/models/entity_update_params.rb', line 14

required :entity_id, String

#government_authorityIncrease::Models::EntityUpdateParams::GovernmentAuthority?

Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.



36
# File 'lib/increase/models/entity_update_params.rb', line 36

optional :government_authority, -> { Increase::EntityUpdateParams::GovernmentAuthority }

#natural_personIncrease::Models::EntityUpdateParams::NaturalPerson?

Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.



43
# File 'lib/increase/models/entity_update_params.rb', line 43

optional :natural_person, -> { Increase::EntityUpdateParams::NaturalPerson }

#risk_ratingIncrease::Models::EntityUpdateParams::RiskRating?

An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.



50
# File 'lib/increase/models/entity_update_params.rb', line 50

optional :risk_rating, -> { Increase::EntityUpdateParams::RiskRating }

#third_party_verificationIncrease::Models::EntityUpdateParams::ThirdPartyVerification?

If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.



58
# File 'lib/increase/models/entity_update_params.rb', line 58

optional :third_party_verification, -> { Increase::EntityUpdateParams::ThirdPartyVerification }

#trustIncrease::Models::EntityUpdateParams::Trust?

Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.



65
# File 'lib/increase/models/entity_update_params.rb', line 65

optional :trust, -> { Increase::EntityUpdateParams::Trust }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity_update_params.rb', line 245