Class: Increase::Models::EntityUpdateParams::Corporation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityUpdateParams::Corporation
- Defined in:
- lib/increase/models/entity_update_params.rb
Defined Under Namespace
Classes: Address, LegalIdentifier
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::EntityUpdateParams::Corporation::Address?
The entity’s physical address.
-
#email ⇒ String?
An email address for the business.
-
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.
-
#industry_code ⇒ String?
The North American Industry Classification System (NAICS) code for the corporation’s primary line of business.
-
#legal_identifier ⇒ Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier?
The legal identifier of the corporation.
-
#name ⇒ String?
The legal name of the corporation.
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/increase/models/entity_update_params.rb', line 89 class Corporation < Increase::Internal::Type::BaseModel # @!attribute address # The entity's physical address. Mail receiving locations like PO Boxes and PMB's # are disallowed. # # @return [Increase::Models::EntityUpdateParams::Corporation::Address, nil] optional :address, -> { Increase::EntityUpdateParams::Corporation::Address } # @!attribute email # An email address for the business. Not every program requires an email for # submitted Entities. # # @return [String, nil] optional :email, String # @!attribute incorporation_state # The two-letter United States Postal Service (USPS) abbreviation for the # corporation's state of incorporation. # # @return [String, nil] optional :incorporation_state, String # @!attribute industry_code # The North American Industry Classification System (NAICS) code for the # corporation's primary line of business. This is a number, like `5132` for # `Software Publishers`. A full list of classification codes is available # [here](https://increase.com/documentation/data-dictionary#north-american-industry-classification-system-codes). # # @return [String, nil] optional :industry_code, String # @!attribute legal_identifier # The legal identifier of the corporation. This is usually the Employer # Identification Number (EIN). # # @return [Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier, nil] optional :legal_identifier, -> { Increase::EntityUpdateParams::Corporation::LegalIdentifier } # @!attribute name # The legal name of the corporation. # # @return [String, nil] optional :name, String # @!method initialize(address: nil, email: nil, incorporation_state: nil, industry_code: nil, legal_identifier: nil, name: nil) # Some parameter documentations has been truncated, see # {Increase::Models::EntityUpdateParams::Corporation} for more details. # # Details of the corporation entity to update. If you specify this parameter and # the entity is not a corporation, the request will fail. # # @param address [Increase::Models::EntityUpdateParams::Corporation::Address] The entity's physical address. Mail receiving locations like PO Boxes and PMB's # # @param email [String] An email address for the business. Not every program requires an email for submi # # @param incorporation_state [String] The two-letter United States Postal Service (USPS) abbreviation for the corporat # # @param industry_code [String] The North American Industry Classification System (NAICS) code for the corporati # # @param legal_identifier [Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier] The legal identifier of the corporation. This is usually the Employer Identifica # # @param name [String] The legal name of the corporation. # @see Increase::Models::EntityUpdateParams::Corporation#address class Address < Increase::Internal::Type::BaseModel # @!attribute city # The city, district, town, or village of the address. # # @return [String] required :city, String # @!attribute country # The two-letter ISO 3166-1 alpha-2 code for the country of the address. # # @return [String] required :country, String # @!attribute line1 # The first line of the address. This is usually the street number and street. # # @return [String] required :line1, String # @!attribute line2 # The second line of the address. This might be the floor or room number. # # @return [String, nil] optional :line2, String # @!attribute state # The two-letter United States Postal Service (USPS) abbreviation for the US # state, province, or region of the address. Required in certain countries. # # @return [String, nil] optional :state, String # @!attribute zip # The ZIP or postal code of the address. Required in certain countries. # # @return [String, nil] optional :zip, String # @!method initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) # Some parameter documentations has been truncated, see # {Increase::Models::EntityUpdateParams::Corporation::Address} for more details. # # The entity's physical address. Mail receiving locations like PO Boxes and PMB's # are disallowed. # # @param city [String] The city, district, town, or village of the address. # # @param country [String] The two-letter ISO 3166-1 alpha-2 code for the country of the address. # # @param line1 [String] The first line of the address. This is usually the street number and street. # # @param line2 [String] The second line of the address. This might be the floor or room number. # # @param state [String] The two-letter United States Postal Service (USPS) abbreviation for the US state # # @param zip [String] The ZIP or postal code of the address. Required in certain countries. end # @see Increase::Models::EntityUpdateParams::Corporation#legal_identifier class LegalIdentifier < Increase::Internal::Type::BaseModel # @!attribute value # The identifier of the legal identifier. # # @return [String] required :value, String # @!attribute category # The category of the legal identifier. # # @return [Symbol, Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier::Category, nil] optional :category, enum: -> { Increase::EntityUpdateParams::Corporation::LegalIdentifier::Category } # @!method initialize(value:, category: nil) # The legal identifier of the corporation. This is usually the Employer # Identification Number (EIN). # # @param value [String] The identifier of the legal identifier. # # @param category [Symbol, Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier::Category] The category of the legal identifier. # The category of the legal identifier. # # @see Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier#category module Category extend Increase::Internal::Type::Enum # The Employer Identification Number (EIN) for the company. The EIN is a 9-digit number assigned by the IRS. US_EMPLOYER_IDENTIFICATION_NUMBER = :us_employer_identification_number # A legal identifier issued by a foreign government, like a tax identification number or registration number. OTHER = :other # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#address ⇒ Increase::Models::EntityUpdateParams::Corporation::Address?
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
95 |
# File 'lib/increase/models/entity_update_params.rb', line 95 optional :address, -> { Increase::EntityUpdateParams::Corporation::Address } |
#email ⇒ String?
An email address for the business. Not every program requires an email for submitted Entities.
102 |
# File 'lib/increase/models/entity_update_params.rb', line 102 optional :email, String |
#incorporation_state ⇒ String?
The two-letter United States Postal Service (USPS) abbreviation for the corporation’s state of incorporation.
109 |
# File 'lib/increase/models/entity_update_params.rb', line 109 optional :incorporation_state, String |
#industry_code ⇒ String?
The North American Industry Classification System (NAICS) code for the corporation’s primary line of business. This is a number, like ‘5132` for `Software Publishers`. A full list of classification codes is available [here](increase.com/documentation/data-dictionary#north-american-industry-classification-system-codes).
118 |
# File 'lib/increase/models/entity_update_params.rb', line 118 optional :industry_code, String |
#legal_identifier ⇒ Increase::Models::EntityUpdateParams::Corporation::LegalIdentifier?
The legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
125 |
# File 'lib/increase/models/entity_update_params.rb', line 125 optional :legal_identifier, -> { Increase::EntityUpdateParams::Corporation::LegalIdentifier } |
#name ⇒ String?
The legal name of the corporation.
131 |
# File 'lib/increase/models/entity_update_params.rb', line 131 optional :name, String |