Class: Increase::Models::EntityUpdateParams::NaturalPerson
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EntityUpdateParams::NaturalPerson
- Defined in:
- lib/increase/models/entity_update_params.rb
Defined Under Namespace
Classes: Address, Identification
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::EntityUpdateParams::NaturalPerson::Address?
The entity’s physical address.
-
#confirmed_no_us_tax_id ⇒ Boolean?
The identification method for an individual can only be a passport, driver’s license, or other document if you’ve confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
#identification ⇒ Increase::Models::EntityUpdateParams::NaturalPerson::Identification?
A means of verifying the person’s identity.
-
#name ⇒ String?
The legal name of the natural person.
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2: nil, state: nil, zip: nil) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
|
|
# File 'lib/increase/models/entity_update_params.rb', line 358
|
Instance Attribute Details
#address ⇒ Increase::Models::EntityUpdateParams::NaturalPerson::Address?
The entity’s physical address. Mail receiving locations like PO Boxes and PMB’s are disallowed.
335 |
# File 'lib/increase/models/entity_update_params.rb', line 335 optional :address, -> { Increase::EntityUpdateParams::NaturalPerson::Address } |
#confirmed_no_us_tax_id ⇒ Boolean?
The identification method for an individual can only be a passport, driver’s license, or other document if you’ve confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
344 |
# File 'lib/increase/models/entity_update_params.rb', line 344 optional :confirmed_no_us_tax_id, Increase::Internal::Type::Boolean |
#identification ⇒ Increase::Models::EntityUpdateParams::NaturalPerson::Identification?
A means of verifying the person’s identity.
350 |
# File 'lib/increase/models/entity_update_params.rb', line 350 optional :identification, -> { Increase::EntityUpdateParams::NaturalPerson::Identification } |
#name ⇒ String?
The legal name of the natural person.
356 |
# File 'lib/increase/models/entity_update_params.rb', line 356 optional :name, String |