Class: Increase::Models::EntityUpdateParams::NaturalPerson::Identification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/entity_update_params.rb,
sig/increase/models/entity_update_params.rbs

Overview

See Also:

  • Increase::Models::EntityUpdateParams::NaturalPerson#identification

Defined Under Namespace

Modules: Method Classes: DriversLicense, Other, Passport

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, description:, file_id:, back_file_id: nil, expiration_date: nil) ⇒ Object

Some parameter documentations has been truncated, see Other for more details.

Information about the identification document provided. Required if method is equal to other.

Parameters:

  • country (String)

    The two-character ISO 3166-1 code representing the country that issued the docum

  • description (String)

    A description of the document submitted.

  • file_id (String)

    The identifier of the File containing the front of the document.

  • back_file_id (String) (defaults to: nil)

    The identifier of the File containing the back of the document. Not every docume

  • expiration_date (Date) (defaults to: nil)

    The document's expiration date in YYYY-MM-DD format.



# File 'lib/increase/models/entity_update_params.rb', line 498

Instance Attribute Details

#drivers_licenseIncrease::Models::EntityUpdateParams::NaturalPerson::Identification::DriversLicense?

Information about the United States driver's license used for identification. Required if method is equal to drivers_license.



481
482
# File 'lib/increase/models/entity_update_params.rb', line 481

optional :drivers_license,
-> { Increase::EntityUpdateParams::NaturalPerson::Identification::DriversLicense }

#method_Symbol, Increase::Models::EntityUpdateParams::NaturalPerson::Identification::Method

A method that can be used to verify the individual's identity.

Parameters:

  • value (Increase::Models::EntityUpdateParams::NaturalPerson::Identification::method_)

Returns:



462
463
464
# File 'lib/increase/models/entity_update_params.rb', line 462

required :method_,
enum: -> { Increase::EntityUpdateParams::NaturalPerson::Identification::Method },
api_name: :method

#numberString

An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.

Parameters:

  • value (String)

Returns:

  • (String)


474
# File 'lib/increase/models/entity_update_params.rb', line 474

required :number, String

#otherIncrease::Models::EntityUpdateParams::NaturalPerson::Identification::Other?

Information about the identification document provided. Required if method is equal to other.



489
# File 'lib/increase/models/entity_update_params.rb', line 489

optional :other, -> { Increase::EntityUpdateParams::NaturalPerson::Identification::Other }

#passportIncrease::Models::EntityUpdateParams::NaturalPerson::Identification::Passport?

Information about the passport used for identification. Required if method is equal to passport.



496
# File 'lib/increase/models/entity_update_params.rb', line 496

optional :passport, -> { Increase::EntityUpdateParams::NaturalPerson::Identification::Passport }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/entity_update_params.rb', line 536

Instance Method Details

#to_hash{

Returns:

  • ({)


446
# File 'sig/increase/models/entity_update_params.rbs', line 446

def to_hash: -> {