Class: Increase::Models::EventSubscription

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/event_subscription.rb

Overview

Defined Under Namespace

Modules: Status, Type Classes: SelectedEventCategory

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#created_atTime

The time the event subscription was created.

Returns:

  • (Time)


17
# File 'lib/increase/models/event_subscription.rb', line 17

required :created_at, Time

#idString

The event subscription identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/event_subscription.rb', line 11

required :id, String

#idempotency_keyString?

The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).

Returns:

  • (String, nil)


25
# File 'lib/increase/models/event_subscription.rb', line 25

required :idempotency_key, String, nil?: true

#oauth_connection_idString?

If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.

Returns:

  • (String, nil)


32
# File 'lib/increase/models/event_subscription.rb', line 32

required :oauth_connection_id, String, nil?: true

#selected_event_categoriesArray<Increase::Models::EventSubscription::SelectedEventCategory>?

If specified, this subscription will only receive webhooks for Events with the specified ‘category`.



39
40
41
# File 'lib/increase/models/event_subscription.rb', line 39

required :selected_event_categories,
-> { Increase::Internal::Type::ArrayOf[Increase::EventSubscription::SelectedEventCategory] },
nil?: true

#statusSymbol, Increase::Models::EventSubscription::Status

This indicates if we’ll send notifications to this subscription.



47
# File 'lib/increase/models/event_subscription.rb', line 47

required :status, enum: -> { Increase::EventSubscription::Status }

#typeSymbol, Increase::Models::EventSubscription::Type

A constant representing the object’s type. For this resource it will always be ‘event_subscription`.



54
# File 'lib/increase/models/event_subscription.rb', line 54

required :type, enum: -> { Increase::EventSubscription::Type }

#urlString

The webhook url where we’ll send notifications.

Returns:

  • (String)


60
# File 'lib/increase/models/event_subscription.rb', line 60

required :url, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/event_subscription.rb', line 439