Class: Increase::Models::EventSubscriptionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::EventSubscriptionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/event_subscription_create_params.rb
Overview
Defined Under Namespace
Modules: Status Classes: SelectedEventCategory
Instance Attribute Summary collapse
-
#oauth_connection_id ⇒ String?
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
#selected_event_categories ⇒ Array<Increase::Models::EventSubscriptionCreateParams::SelectedEventCategory>?
If specified, this subscription will only receive webhooks for Events with the specified ‘category`.
-
#shared_secret ⇒ String?
The key that will be used to sign webhooks.
-
#status ⇒ Symbol, ...
The status of the event subscription.
-
#url ⇒ String
The URL you’d like us to send webhooks to.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#oauth_connection_id ⇒ String?
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
21 |
# File 'lib/increase/models/event_subscription_create_params.rb', line 21 optional :oauth_connection_id, String |
#selected_event_categories ⇒ Array<Increase::Models::EventSubscriptionCreateParams::SelectedEventCategory>?
If specified, this subscription will only receive webhooks for Events with the specified ‘category`. If specifying a Real-Time Decision event category, only one Event Category can be specified for the Event Subscription.
29 30 |
# File 'lib/increase/models/event_subscription_create_params.rb', line 29 optional :selected_event_categories, -> { Increase::Internal::Type::ArrayOf[Increase::EventSubscriptionCreateParams::SelectedEventCategory] } |
#shared_secret ⇒ String?
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
37 |
# File 'lib/increase/models/event_subscription_create_params.rb', line 37 optional :shared_secret, String |
#status ⇒ Symbol, ...
The status of the event subscription. Defaults to ‘active` if not specified.
43 |
# File 'lib/increase/models/event_subscription_create_params.rb', line 43 optional :status, enum: -> { Increase::EventSubscriptionCreateParams::Status } |
#url ⇒ String
The URL you’d like us to send webhooks to.
14 |
# File 'lib/increase/models/event_subscription_create_params.rb', line 14 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/event_subscription_create_params.rb', line 410
|