Class: Increase::Models::Export
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Export
- Defined in:
- lib/increase/models/export.rb
Overview
Defined Under Namespace
Modules: Category, Status, Type Classes: AccountStatementBai2, AccountStatementOfx, AccountVerificationLetter, BalanceCsv, BookkeepingAccountBalanceCsv, DailyAccountBalanceCsv, DashboardTableCsv, EntityCsv, FeeCsv, Form1099Int, Form1099Misc, FundingInstructions, Result, TransactionCsv, VendorCsv, VoidedCheck
Instance Attribute Summary collapse
-
#account_statement_bai2 ⇒ Increase::Models::Export::AccountStatementBai2?
Details of the account statement BAI2 export.
-
#account_statement_ofx ⇒ Increase::Models::Export::AccountStatementOfx?
Details of the account statement OFX export.
-
#account_verification_letter ⇒ Increase::Models::Export::AccountVerificationLetter?
Details of the account verification letter export.
-
#balance_csv ⇒ Increase::Models::Export::BalanceCsv?
Details of the balance CSV export.
-
#bookkeeping_account_balance_csv ⇒ Increase::Models::Export::BookkeepingAccountBalanceCsv?
Details of the bookkeeping account balance CSV export.
-
#category ⇒ Symbol, Increase::Models::Export::Category
The category of the Export.
-
#created_at ⇒ Time
The time the Export was created.
-
#daily_account_balance_csv ⇒ Increase::Models::Export::DailyAccountBalanceCsv?
Details of the daily account balance CSV export.
-
#dashboard_table_csv ⇒ Increase::Models::Export::DashboardTableCsv?
Details of the dashboard table CSV export.
-
#entity_csv ⇒ Increase::Models::Export::EntityCsv?
Details of the entity CSV export.
-
#fee_csv ⇒ Increase::Models::Export::FeeCsv?
Details of the fee CSV export.
-
#form_1099_int ⇒ Increase::Models::Export::Form1099Int?
Details of the Form 1099-INT export.
-
#form_1099_misc ⇒ Increase::Models::Export::Form1099Misc?
Details of the Form 1099-MISC export.
-
#funding_instructions ⇒ Increase::Models::Export::FundingInstructions?
Details of the funding instructions export.
-
#id ⇒ String
The Export identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#result ⇒ Increase::Models::Export::Result?
The result of the Export.
-
#status ⇒ Symbol, Increase::Models::Export::Status
The status of the Export.
-
#transaction_csv ⇒ Increase::Models::Export::TransactionCsv?
Details of the transaction CSV export.
-
#type ⇒ Symbol, Increase::Models::Export::Type
A constant representing the object’s type.
-
#vendor_csv ⇒ Increase::Models::Export::VendorCsv?
Details of the vendor CSV export.
-
#voided_check ⇒ Increase::Models::Export::VoidedCheck?
Details of the voided check export.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize ⇒ Object
constructor
Details of the vendor CSV export.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
Details of the vendor CSV export. This field will be present when the ‘category` is equal to `vendor_csv`.
|
|
# File 'lib/increase/models/export.rb', line 161
|
Instance Attribute Details
#account_statement_bai2 ⇒ Increase::Models::Export::AccountStatementBai2?
Details of the account statement BAI2 export. This field will be present when the ‘category` is equal to `account_statement_bai2`.
18 |
# File 'lib/increase/models/export.rb', line 18 required :account_statement_bai2, -> { Increase::Export::AccountStatementBai2 }, nil?: true |
#account_statement_ofx ⇒ Increase::Models::Export::AccountStatementOfx?
Details of the account statement OFX export. This field will be present when the ‘category` is equal to `account_statement_ofx`.
25 |
# File 'lib/increase/models/export.rb', line 25 required :account_statement_ofx, -> { Increase::Export::AccountStatementOfx }, nil?: true |
#account_verification_letter ⇒ Increase::Models::Export::AccountVerificationLetter?
Details of the account verification letter export. This field will be present when the ‘category` is equal to `account_verification_letter`.
32 |
# File 'lib/increase/models/export.rb', line 32 required :account_verification_letter, -> { Increase::Export::AccountVerificationLetter }, nil?: true |
#balance_csv ⇒ Increase::Models::Export::BalanceCsv?
Details of the balance CSV export. This field will be present when the ‘category` is equal to `balance_csv`.
39 |
# File 'lib/increase/models/export.rb', line 39 required :balance_csv, -> { Increase::Export::BalanceCsv }, nil?: true |
#bookkeeping_account_balance_csv ⇒ Increase::Models::Export::BookkeepingAccountBalanceCsv?
Details of the bookkeeping account balance CSV export. This field will be present when the ‘category` is equal to `bookkeeping_account_balance_csv`.
46 47 48 |
# File 'lib/increase/models/export.rb', line 46 required :bookkeeping_account_balance_csv, -> { Increase::Export::BookkeepingAccountBalanceCsv }, nil?: true |
#category ⇒ Symbol, Increase::Models::Export::Category
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
55 |
# File 'lib/increase/models/export.rb', line 55 required :category, enum: -> { Increase::Export::Category } |
#created_at ⇒ Time
The time the Export was created.
61 |
# File 'lib/increase/models/export.rb', line 61 required :created_at, Time |
#daily_account_balance_csv ⇒ Increase::Models::Export::DailyAccountBalanceCsv?
Details of the daily account balance CSV export. This field will be present when the ‘category` is equal to `daily_account_balance_csv`.
68 |
# File 'lib/increase/models/export.rb', line 68 required :daily_account_balance_csv, -> { Increase::Export::DailyAccountBalanceCsv }, nil?: true |
#dashboard_table_csv ⇒ Increase::Models::Export::DashboardTableCsv?
Details of the dashboard table CSV export. This field will be present when the ‘category` is equal to `dashboard_table_csv`.
75 |
# File 'lib/increase/models/export.rb', line 75 required :dashboard_table_csv, -> { Increase::Export::DashboardTableCsv }, nil?: true |
#entity_csv ⇒ Increase::Models::Export::EntityCsv?
Details of the entity CSV export. This field will be present when the ‘category` is equal to `entity_csv`.
82 |
# File 'lib/increase/models/export.rb', line 82 required :entity_csv, -> { Increase::Export::EntityCsv }, nil?: true |
#fee_csv ⇒ Increase::Models::Export::FeeCsv?
Details of the fee CSV export. This field will be present when the ‘category` is equal to `fee_csv`.
89 |
# File 'lib/increase/models/export.rb', line 89 required :fee_csv, -> { Increase::Export::FeeCsv }, nil?: true |
#form_1099_int ⇒ Increase::Models::Export::Form1099Int?
Details of the Form 1099-INT export. This field will be present when the ‘category` is equal to `form_1099_int`.
96 |
# File 'lib/increase/models/export.rb', line 96 required :form_1099_int, -> { Increase::Export::Form1099Int }, nil?: true |
#form_1099_misc ⇒ Increase::Models::Export::Form1099Misc?
Details of the Form 1099-MISC export. This field will be present when the ‘category` is equal to `form_1099_misc`.
103 |
# File 'lib/increase/models/export.rb', line 103 required :form_1099_misc, -> { Increase::Export::Form1099Misc }, nil?: true |
#funding_instructions ⇒ Increase::Models::Export::FundingInstructions?
Details of the funding instructions export. This field will be present when the ‘category` is equal to `funding_instructions`.
110 |
# File 'lib/increase/models/export.rb', line 110 required :funding_instructions, -> { Increase::Export::FundingInstructions }, nil?: true |
#id ⇒ String
The Export identifier.
11 |
# File 'lib/increase/models/export.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
118 |
# File 'lib/increase/models/export.rb', line 118 required :idempotency_key, String, nil?: true |
#result ⇒ Increase::Models::Export::Result?
The result of the Export. This will be present when the Export’s status transitions to ‘complete`.
125 |
# File 'lib/increase/models/export.rb', line 125 required :result, -> { Increase::Export::Result }, nil?: true |
#status ⇒ Symbol, Increase::Models::Export::Status
The status of the Export.
131 |
# File 'lib/increase/models/export.rb', line 131 required :status, enum: -> { Increase::Export::Status } |
#transaction_csv ⇒ Increase::Models::Export::TransactionCsv?
Details of the transaction CSV export. This field will be present when the ‘category` is equal to `transaction_csv`.
138 |
# File 'lib/increase/models/export.rb', line 138 required :transaction_csv, -> { Increase::Export::TransactionCsv }, nil?: true |
#type ⇒ Symbol, Increase::Models::Export::Type
A constant representing the object’s type. For this resource it will always be ‘export`.
145 |
# File 'lib/increase/models/export.rb', line 145 required :type, enum: -> { Increase::Export::Type } |
#vendor_csv ⇒ Increase::Models::Export::VendorCsv?
Details of the vendor CSV export. This field will be present when the ‘category` is equal to `vendor_csv`.
152 |
# File 'lib/increase/models/export.rb', line 152 required :vendor_csv, -> { Increase::Export::VendorCsv }, nil?: true |
#voided_check ⇒ Increase::Models::Export::VoidedCheck?
Details of the voided check export. This field will be present when the ‘category` is equal to `voided_check`.
159 |
# File 'lib/increase/models/export.rb', line 159 required :voided_check, -> { Increase::Export::VoidedCheck }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/export.rb', line 442
|