Module: Increase::Models::Export::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/export.rb
Overview
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
Constant Summary collapse
- ACCOUNT_STATEMENT_OFX =
Export an Open Financial Exchange (OFX) file of transactions and balances for a given time range and Account.
:account_statement_ofx- ACCOUNT_STATEMENT_BAI2 =
Export a BAI2 file of transactions and balances for a given date and optional Account.
:account_statement_bai2- TRANSACTION_CSV =
Export a CSV of all transactions for a given time range.
:transaction_csv- BALANCE_CSV =
Export a CSV of account balances for the dates in a given range.
:balance_csv- BOOKKEEPING_ACCOUNT_BALANCE_CSV =
Export a CSV of bookkeeping account balances for the dates in a given range.
:bookkeeping_account_balance_csv- ENTITY_CSV =
Export a CSV of entities with a given status.
:entity_csv- VENDOR_CSV =
Export a CSV of vendors added to the third-party risk management dashboard.
:vendor_csv- DASHBOARD_TABLE_CSV =
Certain dashboard tables are available as CSV exports. This export cannot be created via the API.
:dashboard_table_csv- ACCOUNT_VERIFICATION_LETTER =
A PDF of an account verification letter.
:account_verification_letter- FUNDING_INSTRUCTIONS =
A PDF of funding instructions.
:funding_instructions- FORM_1099_INT =
A PDF of an Internal Revenue Service Form 1099-INT.
:form_1099_int- FORM_1099_MISC =
A PDF of an Internal Revenue Service Form 1099-MISC.
:form_1099_misc- FEE_CSV =
Export a CSV of fees. The time range must not include any fees that are part of an open fee statement.
:fee_csv- VOIDED_CHECK =
A PDF of a voided check.
:voided_check- DAILY_ACCOUNT_BALANCE_CSV =
Export a CSV of daily account balances with starting and ending balances for a given date range.
:daily_account_balance_csv
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info