Module: Increase::Models::ExportListParams::Status::In

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/export_list_params.rb,
sig/increase/models/export_list_params.rbs

Constant Summary collapse

PENDING =

Increase is generating the export.

Returns:

  • (:pending)
:pending
COMPLETE =

The export has been successfully generated.

Returns:

  • (:complete)
:complete
FAILED =

The export failed to generate. Increase will reach out to you to resolve the issue.

Returns:

  • (:failed)
:failed

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/export_list_params.rb', line 235

Instance Method Details

#initialize(in_: nil) ⇒ Object

Parameters:

  • in_ (Array<Symbol, Increase::Models::ExportListParams::Status::In>) (defaults to: nil)

    Filter Exports for those with the specified status or statuses. For GET requests, this should be encoded as a comma-delimited string, such as ?in=one,two,three.



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/increase/models/export_list_params.rb', line 223

module In
  extend Increase::Internal::Type::Enum

  # Increase is generating the export.
  PENDING = :pending

  # The export has been successfully generated.
  COMPLETE = :complete

  # The export failed to generate. Increase will reach out to you to resolve the issue.
  FAILED = :failed

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Increase::Models::ExportListParams::Status::in_]

Returns:

  • (::Array[Increase::Models::ExportListParams::Status::in_])


245
# File 'sig/increase/models/export_list_params.rbs', line 245

def self?.values: -> ::Array[Increase::Models::ExportListParams::Status::in_]