Class: Increase::Models::ExternalAccountListParams::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::ExternalAccountListParams::Status
- Defined in:
- lib/increase/models/external_account_list_params.rb,
sig/increase/models/external_account_list_params.rbs
Defined Under Namespace
Modules: In
Instance Attribute Summary collapse
-
#in_ ⇒ Array<Symbol, Increase::Models::ExternalAccountListParams::Status::In>?
Filter External Accounts for those with the specified status or statuses.
Instance Method Summary collapse
- #initialize(cursor: nil, idempotency_key: nil, limit: nil, routing_number: nil, status: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor: nil, idempotency_key: nil, limit: nil, routing_number: nil, status: nil, request_options: {}) ⇒ Object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/increase/models/external_account_list_params.rb', line 62 class Status < Increase::Internal::Type::BaseModel # @!attribute in_ # Filter External Accounts for those with the specified status or statuses. For # GET requests, this should be encoded as a comma-delimited string, such as # `?in=one,two,three`. # # @return [Array<Symbol, Increase::Models::ExternalAccountListParams::Status::In>, nil] optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::ExternalAccountListParams::Status::In] }, api_name: :in # @!method initialize(in_: nil) # @param in_ [Array<Symbol, Increase::Models::ExternalAccountListParams::Status::In>] # Filter External Accounts for those with the specified status or statuses. For # GET requests, this should be encoded as a comma-delimited string, such as # `?in=one,two,three`. module In extend Increase::Internal::Type::Enum # The External Account is active. ACTIVE = :active # The External Account is archived and won't appear in the dashboard. ARCHIVED = :archived # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#in_ ⇒ Array<Symbol, Increase::Models::ExternalAccountListParams::Status::In>?
Filter External Accounts for those with the specified status or statuses. For
GET requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
69 70 71 72 73 |
# File 'lib/increase/models/external_account_list_params.rb', line 69 optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::ExternalAccountListParams::Status::In] }, api_name: :in |
Instance Method Details
#to_hash ⇒ {
73 |
# File 'sig/increase/models/external_account_list_params.rbs', line 73
def to_hash: -> {
|