Class: Increase::Models::FednowTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::FednowTransfer
- Defined in:
- lib/increase/models/fednow_transfer.rb
Overview
Defined Under Namespace
Modules: Currency, Status, Type Classes: Acknowledgement, CreatedBy, CreditorAddress, Rejection, Submission
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account from which the transfer was sent.
-
#account_number ⇒ String
The destination account number.
-
#acknowledgement ⇒ Increase::Models::FednowTransfer::Acknowledgement?
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
-
#created_by ⇒ Increase::Models::FednowTransfer::CreatedBy?
What object created the transfer, either via the API or the dashboard.
-
#creditor_address ⇒ Increase::Models::FednowTransfer::CreditorAddress?
The creditor’s address.
-
#creditor_name ⇒ String
The name of the transfer’s recipient.
-
#currency ⇒ Symbol, Increase::Models::FednowTransfer::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transfer’s currency.
-
#debtor_name ⇒ String
The name of the transfer’s sender.
-
#external_account_id ⇒ String?
The identifier of the External Account the transfer was made to, if any.
-
#id ⇒ String
The FedNow Transfer’s identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#pending_transaction_id ⇒ String?
The ID for the pending transaction representing the transfer.
-
#rejection ⇒ Increase::Models::FednowTransfer::Rejection?
If the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details.
-
#routing_number ⇒ String
The destination American Bankers’ Association (ABA) Routing Transit Number (RTN).
-
#source_account_number_id ⇒ String
The Account Number the recipient will see as having sent the transfer.
-
#status ⇒ Symbol, Increase::Models::FednowTransfer::Status
The lifecycle status of the transfer.
-
#submission ⇒ Increase::Models::FednowTransfer::Submission?
After the transfer is submitted to FedNow, this will contain supplemental details.
-
#transaction_id ⇒ String?
The Transaction funding the transfer once it is complete.
-
#type ⇒ Symbol, Increase::Models::FednowTransfer::Type
A constant representing the object’s type.
-
#unique_end_to_end_transaction_reference ⇒ String
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
-
#unstructured_remittance_information ⇒ String
Unstructured information that will show on the recipient’s bank statement.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(message_identification:, submitted_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Submission for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(message_identification:, submitted_at:) ⇒ Object
Some parameter documentations has been truncated, see Submission for more details.
After the transfer is submitted to FedNow, this will contain supplemental details.
|
|
# File 'lib/increase/models/fednow_transfer.rb', line 158
|
Instance Attribute Details
#account_id ⇒ String
The Account from which the transfer was sent.
17 |
# File 'lib/increase/models/fednow_transfer.rb', line 17 required :account_id, String |
#account_number ⇒ String
The destination account number.
23 |
# File 'lib/increase/models/fednow_transfer.rb', line 23 required :account_number, String |
#acknowledgement ⇒ Increase::Models::FednowTransfer::Acknowledgement?
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
30 |
# File 'lib/increase/models/fednow_transfer.rb', line 30 required :acknowledgement, -> { Increase::FednowTransfer::Acknowledgement }, nil?: true |
#amount ⇒ Integer
The transfer amount in USD cents.
36 |
# File 'lib/increase/models/fednow_transfer.rb', line 36 required :amount, Integer |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
43 |
# File 'lib/increase/models/fednow_transfer.rb', line 43 required :created_at, Time |
#created_by ⇒ Increase::Models::FednowTransfer::CreatedBy?
What object created the transfer, either via the API or the dashboard.
49 |
# File 'lib/increase/models/fednow_transfer.rb', line 49 required :created_by, -> { Increase::FednowTransfer::CreatedBy }, nil?: true |
#creditor_address ⇒ Increase::Models::FednowTransfer::CreditorAddress?
The creditor’s address.
55 |
# File 'lib/increase/models/fednow_transfer.rb', line 55 required :creditor_address, -> { Increase::FednowTransfer::CreditorAddress }, nil?: true |
#creditor_name ⇒ String
The name of the transfer’s recipient. This is set by the sender when creating the transfer.
62 |
# File 'lib/increase/models/fednow_transfer.rb', line 62 required :creditor_name, String |
#currency ⇒ Symbol, Increase::Models::FednowTransfer::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transfer’s currency. For FedNow transfers this is always equal to ‘USD`.
69 |
# File 'lib/increase/models/fednow_transfer.rb', line 69 required :currency, enum: -> { Increase::FednowTransfer::Currency } |
#debtor_name ⇒ String
The name of the transfer’s sender. If not provided, defaults to the name of the account’s entity.
76 |
# File 'lib/increase/models/fednow_transfer.rb', line 76 required :debtor_name, String |
#external_account_id ⇒ String?
The identifier of the External Account the transfer was made to, if any.
82 |
# File 'lib/increase/models/fednow_transfer.rb', line 82 required :external_account_id, String, nil?: true |
#id ⇒ String
The FedNow Transfer’s identifier.
11 |
# File 'lib/increase/models/fednow_transfer.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
90 |
# File 'lib/increase/models/fednow_transfer.rb', line 90 required :idempotency_key, String, nil?: true |
#pending_transaction_id ⇒ String?
The ID for the pending transaction representing the transfer.
96 |
# File 'lib/increase/models/fednow_transfer.rb', line 96 required :pending_transaction_id, String, nil?: true |
#rejection ⇒ Increase::Models::FednowTransfer::Rejection?
If the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details.
103 |
# File 'lib/increase/models/fednow_transfer.rb', line 103 required :rejection, -> { Increase::FednowTransfer::Rejection }, nil?: true |
#routing_number ⇒ String
The destination American Bankers’ Association (ABA) Routing Transit Number (RTN).
110 |
# File 'lib/increase/models/fednow_transfer.rb', line 110 required :routing_number, String |
#source_account_number_id ⇒ String
The Account Number the recipient will see as having sent the transfer.
116 |
# File 'lib/increase/models/fednow_transfer.rb', line 116 required :source_account_number_id, String |
#status ⇒ Symbol, Increase::Models::FednowTransfer::Status
The lifecycle status of the transfer.
122 |
# File 'lib/increase/models/fednow_transfer.rb', line 122 required :status, enum: -> { Increase::FednowTransfer::Status } |
#submission ⇒ Increase::Models::FednowTransfer::Submission?
After the transfer is submitted to FedNow, this will contain supplemental details.
129 |
# File 'lib/increase/models/fednow_transfer.rb', line 129 required :submission, -> { Increase::FednowTransfer::Submission }, nil?: true |
#transaction_id ⇒ String?
The Transaction funding the transfer once it is complete.
135 |
# File 'lib/increase/models/fednow_transfer.rb', line 135 required :transaction_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::FednowTransfer::Type
A constant representing the object’s type. For this resource it will always be ‘fednow_transfer`.
142 |
# File 'lib/increase/models/fednow_transfer.rb', line 142 required :type, enum: -> { Increase::FednowTransfer::Type } |
#unique_end_to_end_transaction_reference ⇒ String
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
150 |
# File 'lib/increase/models/fednow_transfer.rb', line 150 required :unique_end_to_end_transaction_reference, String |
#unstructured_remittance_information ⇒ String
Unstructured information that will show on the recipient’s bank statement.
156 |
# File 'lib/increase/models/fednow_transfer.rb', line 156 required :unstructured_remittance_information, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/fednow_transfer.rb', line 373
|