Module: Increase::Models::FednowTransfer::Rejection::RejectReasonCode

Extended by:
Internal::Type::Enum
Defined in:
lib/increase/models/fednow_transfer.rb,
sig/increase/models/fednow_transfer.rbs

Overview

The reason the transfer was rejected as provided by the recipient bank or the FedNow network.

See Also:

  • Increase::Models::FednowTransfer::Rejection#reject_reason_code

Constant Summary collapse

ACCOUNT_CLOSED =

The destination account is closed. Corresponds to the FedNow reason code AC04.

Returns:

  • (:account_closed)
:account_closed
ACCOUNT_BLOCKED =

The destination account is currently blocked from receiving transactions. Corresponds to the FedNow reason code AC06.

Returns:

  • (:account_blocked)
:account_blocked
INVALID_CREDITOR_ACCOUNT_TYPE =

The destination account is ineligible to receive FedNow transfers. Corresponds to the FedNow reason code AC14.

Returns:

  • (:invalid_creditor_account_type)
:invalid_creditor_account_type
INVALID_CREDITOR_ACCOUNT_NUMBER =

The destination account does not exist. Corresponds to the FedNow reason code AC03.

Returns:

  • (:invalid_creditor_account_number)
:invalid_creditor_account_number
INVALID_CREDITOR_FINANCIAL_INSTITUTION_IDENTIFIER =

The destination routing number is invalid. Corresponds to the FedNow reason code RC04.

Returns:

  • (:invalid_creditor_financial_institution_identifier)
:invalid_creditor_financial_institution_identifier
END_CUSTOMER_DECEASED =

The destination account holder is deceased. Corresponds to the FedNow reason code MD07.

Returns:

  • (:end_customer_deceased)
:end_customer_deceased
NARRATIVE =

The reason is provided as narrative information in the additional information field. Corresponds to the FedNow reason code NARR.

Returns:

  • (:narrative)
:narrative
TRANSACTION_FORBIDDEN =

FedNow transfers are not allowed to the destination account. Corresponds to the FedNow reason code AG01.

Returns:

  • (:transaction_forbidden)
:transaction_forbidden
TRANSACTION_TYPE_NOT_SUPPORTED =

FedNow transfers are not enabled for the destination account. Corresponds to the FedNow reason code AG03.

Returns:

  • (:transaction_type_not_supported)
:transaction_type_not_supported
AMOUNT_EXCEEDS_BANK_LIMITS =

The amount is higher than the recipient is authorized to send or receive. Corresponds to the FedNow reason code E990.

Returns:

  • (:amount_exceeds_bank_limits)
:amount_exceeds_bank_limits
INVALID_CREDITOR_ADDRESS =

The creditor's address is required, but missing or invalid. Corresponds to the FedNow reason code BE04.

Returns:

  • (:invalid_creditor_address)
:invalid_creditor_address
INVALID_DEBTOR_ADDRESS =

The debtor's address is required, but missing or invalid. Corresponds to the FedNow reason code BE07.

Returns:

  • (:invalid_debtor_address)
:invalid_debtor_address
TIMEOUT =

There was a timeout processing the transfer. Corresponds to the FedNow reason code E997.

Returns:

  • (:timeout)
:timeout
PROCESSING_ERROR =

The transfer was rejected due to an internal Increase issue. We have been notified.

Returns:

  • (:processing_error)
:processing_error
OTHER =

Some other error or issue has occurred.

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Increase::Models::FednowTransfer::Rejection::reject_reason_code]

Returns:

  • (::Array[Increase::Models::FednowTransfer::Rejection::reject_reason_code])


389
# File 'sig/increase/models/fednow_transfer.rbs', line 389

def self?.values: -> ::Array[Increase::Models::FednowTransfer::Rejection::reject_reason_code]