Class: Increase::Models::FednowTransfer::Return
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::FednowTransfer::Return
- Defined in:
- lib/increase/models/fednow_transfer.rb,
sig/increase/models/fednow_transfer.rbs
Defined Under Namespace
Modules: ReturnReasonCode
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The returned amount in USD cents.
-
#return_reason_additional_information ⇒ String?
Additional information about the return provided by the recipient's bank.
-
#return_reason_code ⇒ Symbol, Increase::Models::FednowTransfer::Return::ReturnReasonCode
The reason the transfer was returned as provided by the recipient's bank.
-
#transfer_id ⇒ String
The identifier of the FedNow Transfer that led to this Transaction.
Instance Method Summary collapse
-
#initialize(amount:, return_reason_additional_information:, return_reason_code:, transfer_id:) ⇒ Object
constructor
A FedNow Transfer Return is created when a FedNow Transfer sent from Increase is returned by the recipient's bank.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, return_reason_additional_information:, return_reason_code:, transfer_id:) ⇒ Object
A FedNow Transfer Return is created when a FedNow Transfer sent from Increase is returned by the recipient's bank.
|
|
# File 'lib/increase/models/fednow_transfer.rb', line 584
|
Instance Attribute Details
#amount ⇒ Integer
The returned amount in USD cents. This is always a positive number.
564 |
# File 'lib/increase/models/fednow_transfer.rb', line 564 required :amount, Integer |
#return_reason_additional_information ⇒ String?
Additional information about the return provided by the recipient's bank.
570 |
# File 'lib/increase/models/fednow_transfer.rb', line 570 required :return_reason_additional_information, String, nil?: true |
#return_reason_code ⇒ Symbol, Increase::Models::FednowTransfer::Return::ReturnReasonCode
The reason the transfer was returned as provided by the recipient's bank.
576 |
# File 'lib/increase/models/fednow_transfer.rb', line 576 required :return_reason_code, enum: -> { Increase::FednowTransfer::Return::ReturnReasonCode } |
#transfer_id ⇒ String
The identifier of the FedNow Transfer that led to this Transaction.
582 |
# File 'lib/increase/models/fednow_transfer.rb', line 582 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
422 |
# File 'sig/increase/models/fednow_transfer.rbs', line 422 def to_hash: -> { |