Class: Increase::Models::FednowTransferCreateParams::CreditorAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::FednowTransferCreateParams::CreditorAddress
- Defined in:
- lib/increase/models/fednow_transfer_create_params.rb,
sig/increase/models/fednow_transfer_create_params.rbs
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#line1 ⇒ String?
The first line of the address.
-
#postal_code ⇒ String
The postal code component of the address.
-
#state ⇒ String
The US state component of the address.
Instance Method Summary collapse
- #initialize(amount:, creditor_name:, debtor_name:, source_account_number_id:, unstructured_remittance_information:, account_number: nil, creditor_address: nil, debtor_address: nil, external_account_id: nil, require_approval: nil, routing_number: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, creditor_name:, debtor_name:, source_account_number_id:, unstructured_remittance_information:, account_number: nil, creditor_address: nil, debtor_address: nil, external_account_id: nil, require_approval: nil, routing_number: nil, request_options: {}) ⇒ Object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 108 class CreditorAddress < Increase::Internal::Type::BaseModel # @!attribute city # The city, district, town, or village of the address. # # @return [String] required :city, String # @!attribute postal_code # The postal code component of the address. # # @return [String] required :postal_code, String # @!attribute state # The US state component of the address. # # @return [String] required :state, String # @!attribute line1 # The first line of the address. This is usually the street number and street. # # @return [String, nil] optional :line1, String # @!method initialize(city:, postal_code:, state:, line1: nil) # The creditor's address. # # @param city [String] The city, district, town, or village of the address. # # @param postal_code [String] The postal code component of the address. # # @param state [String] The US state component of the address. # # @param line1 [String] The first line of the address. This is usually the street number and street. end |
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
113 |
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 113 required :city, String |
#line1 ⇒ String?
The first line of the address. This is usually the street number and street.
131 |
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 131 optional :line1, String |
#postal_code ⇒ String
The postal code component of the address.
119 |
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 119 required :postal_code, String |
#state ⇒ String
The US state component of the address.
125 |
# File 'lib/increase/models/fednow_transfer_create_params.rb', line 125 required :state, String |
Instance Method Details
#to_hash ⇒ {
112 |
# File 'sig/increase/models/fednow_transfer_create_params.rbs', line 112
def to_hash: -> {
|