Class: Increase::Models::Group
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Group
- Defined in:
- lib/increase/models/group.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Group was created.
-
#id ⇒ String
The Group identifier.
-
#type ⇒ Symbol, Increase::Models::Group::Type
A constant representing the object’s type.
Instance Method Summary collapse
-
#initialize(id:, created_at:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Group for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Group for more details.
Groups represent organizations using Increase. You can retrieve information about your own organization via the API. More commonly, OAuth platforms can retrieve information about the organizations that have granted them access. Learn more about OAuth [here](increase.com/documentation/oauth).
|
|
# File 'lib/increase/models/group.rb', line 27
|
Instance Attribute Details
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Group was created.
18 |
# File 'lib/increase/models/group.rb', line 18 required :created_at, Time |
#id ⇒ String
The Group identifier.
11 |
# File 'lib/increase/models/group.rb', line 11 required :id, String |
#type ⇒ Symbol, Increase::Models::Group::Type
A constant representing the object’s type. For this resource it will always be ‘group`.
25 |
# File 'lib/increase/models/group.rb', line 25 required :type, enum: -> { Increase::Group::Type } |