Class: Increase::Models::InboundACHTransfer::InternationalAddenda

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs

Overview

See Also:

  • Increase::Models::InboundACHTransfer#international_addenda

Defined Under Namespace

Modules: ForeignExchangeIndicator, ForeignExchangeReferenceIndicator, InternationalTransactionTypeCode, OriginatingDepositoryFinancialInstitutionIDQualifier, ReceivingDepositoryFinancialInstitutionIDQualifier

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(destination_country_code:, destination_currency_code:, foreign_exchange_indicator:, foreign_exchange_reference:, foreign_exchange_reference_indicator:, foreign_payment_amount:, foreign_trace_number:, international_transaction_type_code:, originating_currency_code:, originating_depository_financial_institution_branch_country:, originating_depository_financial_institution_id:, originating_depository_financial_institution_id_qualifier:, originating_depository_financial_institution_name:, originator_city:, originator_country:, originator_identification:, originator_name:, originator_postal_code:, originator_state_or_province:, originator_street_address:, payment_related_information:, payment_related_information2:, receiver_city:, receiver_country:, receiver_identification_number:, receiver_postal_code:, receiver_state_or_province:, receiver_street_address:, receiving_company_or_individual_name:, receiving_depository_financial_institution_country:, receiving_depository_financial_institution_id:, receiving_depository_financial_institution_id_qualifier:, receiving_depository_financial_institution_name:) ⇒ Object

If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.

Parameters:

  • destination_country_code (String)

    The ISO 3166, Alpha-2 country code of the destination country.

  • destination_currency_code (String)

    The ISO 4217 currency code for the destination bank account.

  • foreign_exchange_indicator (Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator)

    A description of how the foreign exchange rate was calculated.

  • foreign_exchange_reference (String, nil)

    Depending on the foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.

  • foreign_exchange_reference_indicator (Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeReferenceIndicator)

    An instruction of how to interpret the foreign_exchange_reference field for this Transaction.

  • foreign_payment_amount (Integer)

    The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.

  • foreign_trace_number (String, nil)

    A reference number in the foreign banking infrastructure.

  • international_transaction_type_code (Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::InternationalTransactionTypeCode)

    The type of transfer. Set by the originator.

  • originating_currency_code (String)

    The ISO 4217 currency code for the originating bank account.

  • originating_depository_financial_institution_branch_country (String)

    The ISO 3166, Alpha-2 country code of the originating branch country.

  • originating_depository_financial_institution_id (String)

    An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.

  • originating_depository_financial_institution_id_qualifier (Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::OriginatingDepositoryFinancialInstitutionIDQualifier)

    An instruction of how to interpret the originating_depository_financial_institution_id field for this Transaction.

  • originating_depository_financial_institution_name (String)

    The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.

  • originator_city (String)

    A portion of the originator address. This may be incomplete.

  • originator_country (String)

    A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.

  • originator_identification (String)

    An identifier for the originating company. This is generally stable across multiple ACH transfers.

  • originator_name (String)

    Either the name of the originator or an intermediary money transmitter.

  • originator_postal_code (String, nil)

    A portion of the originator address. This may be incomplete.

  • originator_state_or_province (String, nil)

    A portion of the originator address. This may be incomplete.

  • originator_street_address (String)

    A portion of the originator address. This may be incomplete.

  • payment_related_information (String, nil)

    A description field set by the originator.

  • payment_related_information2 (String, nil)

    A description field set by the originator.

  • receiver_city (String)

    A portion of the receiver address. This may be incomplete.

  • receiver_country (String)

    A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.

  • receiver_identification_number (String, nil)

    An identification number the originator uses for the receiver.

  • receiver_postal_code (String, nil)

    A portion of the receiver address. This may be incomplete.

  • receiver_state_or_province (String, nil)

    A portion of the receiver address. This may be incomplete.

  • receiver_street_address (String)

    A portion of the receiver address. This may be incomplete.

  • receiving_company_or_individual_name (String)

    The name of the receiver of the transfer. This is not verified by Increase.

  • receiving_depository_financial_institution_country (String)

    The ISO 3166, Alpha-2 country code of the receiving bank country.

  • receiving_depository_financial_institution_id (String)

    An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.

  • receiving_depository_financial_institution_id_qualifier (Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ReceivingDepositoryFinancialInstitutionIDQualifier)

    An instruction of how to interpret the receiving_depository_financial_institution_id field for this Transaction.

  • receiving_depository_financial_institution_name (String)

    The name of the receiving bank, as set by the sending financial institution.



# File 'lib/increase/models/inbound_ach_transfer.rb', line 681

Instance Attribute Details

#destination_country_codeString

The ISO 3166, Alpha-2 country code of the destination country.

Parameters:

  • value (String)

Returns:

  • (String)


463
# File 'lib/increase/models/inbound_ach_transfer.rb', line 463

required :destination_country_code, String

#destination_currency_codeString

The ISO 4217 currency code for the destination bank account.

Parameters:

  • value (String)

Returns:

  • (String)


470
# File 'lib/increase/models/inbound_ach_transfer.rb', line 470

required :destination_currency_code, String

#foreign_exchange_indicatorSymbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator

A description of how the foreign exchange rate was calculated.

Parameters:

  • value (Increase::Models::InboundACHTransfer::InternationalAddenda::foreign_exchange_indicator)

Returns:



476
477
# File 'lib/increase/models/inbound_ach_transfer.rb', line 476

required :foreign_exchange_indicator,
enum: -> { Increase::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator }

#foreign_exchange_referenceString?

Depending on the foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


484
# File 'lib/increase/models/inbound_ach_transfer.rb', line 484

required :foreign_exchange_reference, String, nil?: true

#foreign_exchange_reference_indicatorSymbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeReferenceIndicator

An instruction of how to interpret the foreign_exchange_reference field for this Transaction.

Parameters:

  • value (Increase::Models::InboundACHTransfer::InternationalAddenda::foreign_exchange_reference_indicator)

Returns:



491
492
# File 'lib/increase/models/inbound_ach_transfer.rb', line 491

required :foreign_exchange_reference_indicator,
enum: -> { Increase::InboundACHTransfer::InternationalAddenda::ForeignExchangeReferenceIndicator }

#foreign_payment_amountInteger

The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


499
# File 'lib/increase/models/inbound_ach_transfer.rb', line 499

required :foreign_payment_amount, Integer

#foreign_trace_numberString?

A reference number in the foreign banking infrastructure.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


505
# File 'lib/increase/models/inbound_ach_transfer.rb', line 505

required :foreign_trace_number, String, nil?: true

#international_transaction_type_codeSymbol, Increase::Models::InboundACHTransfer::InternationalAddenda::InternationalTransactionTypeCode

The type of transfer. Set by the originator.

Parameters:

  • value (Increase::Models::InboundACHTransfer::InternationalAddenda::international_transaction_type_code)

Returns:



511
512
# File 'lib/increase/models/inbound_ach_transfer.rb', line 511

required :international_transaction_type_code,
enum: -> { Increase::InboundACHTransfer::InternationalAddenda::InternationalTransactionTypeCode }

#originating_currency_codeString

The ISO 4217 currency code for the originating bank account.

Parameters:

  • value (String)

Returns:

  • (String)


519
# File 'lib/increase/models/inbound_ach_transfer.rb', line 519

required :originating_currency_code, String

#originating_depository_financial_institution_branch_countryString

The ISO 3166, Alpha-2 country code of the originating branch country.

Parameters:

  • value (String)

Returns:

  • (String)


526
# File 'lib/increase/models/inbound_ach_transfer.rb', line 526

required :originating_depository_financial_institution_branch_country, String

#originating_depository_financial_institution_idString

An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.

Parameters:

  • value (String)

Returns:

  • (String)


534
# File 'lib/increase/models/inbound_ach_transfer.rb', line 534

required :originating_depository_financial_institution_id, String

#originating_depository_financial_institution_id_qualifierSymbol, Increase::Models::InboundACHTransfer::InternationalAddenda::OriginatingDepositoryFinancialInstitutionIDQualifier

An instruction of how to interpret the originating_depository_financial_institution_id field for this Transaction.

Parameters:

  • value (Increase::Models::InboundACHTransfer::InternationalAddenda::originating_depository_financial_institution_id_qualifier)

Returns:



541
542
# File 'lib/increase/models/inbound_ach_transfer.rb', line 541

required :originating_depository_financial_institution_id_qualifier,
enum: -> { Increase::InboundACHTransfer::InternationalAddenda::OriginatingDepositoryFinancialInstitutionIDQualifier }

#originating_depository_financial_institution_nameString

The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.

Parameters:

  • value (String)

Returns:

  • (String)


549
# File 'lib/increase/models/inbound_ach_transfer.rb', line 549

required :originating_depository_financial_institution_name, String

#originator_cityString

A portion of the originator address. This may be incomplete.

Parameters:

  • value (String)

Returns:

  • (String)


555
# File 'lib/increase/models/inbound_ach_transfer.rb', line 555

required :originator_city, String

#originator_countryString

A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.

Parameters:

  • value (String)

Returns:

  • (String)


563
# File 'lib/increase/models/inbound_ach_transfer.rb', line 563

required :originator_country, String

#originator_identificationString

An identifier for the originating company. This is generally stable across multiple ACH transfers.

Parameters:

  • value (String)

Returns:

  • (String)


570
# File 'lib/increase/models/inbound_ach_transfer.rb', line 570

required :originator_identification, String

#originator_nameString

Either the name of the originator or an intermediary money transmitter.

Parameters:

  • value (String)

Returns:

  • (String)


576
# File 'lib/increase/models/inbound_ach_transfer.rb', line 576

required :originator_name, String

#originator_postal_codeString?

A portion of the originator address. This may be incomplete.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


582
# File 'lib/increase/models/inbound_ach_transfer.rb', line 582

required :originator_postal_code, String, nil?: true

#originator_state_or_provinceString?

A portion of the originator address. This may be incomplete.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


588
# File 'lib/increase/models/inbound_ach_transfer.rb', line 588

required :originator_state_or_province, String, nil?: true

#originator_street_addressString

A portion of the originator address. This may be incomplete.

Parameters:

  • value (String)

Returns:

  • (String)


594
# File 'lib/increase/models/inbound_ach_transfer.rb', line 594

required :originator_street_address, String

A description field set by the originator.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


600
# File 'lib/increase/models/inbound_ach_transfer.rb', line 600

required :payment_related_information, String, nil?: true

A description field set by the originator.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


606
# File 'lib/increase/models/inbound_ach_transfer.rb', line 606

required :payment_related_information2, String, nil?: true

#receiver_cityString

A portion of the receiver address. This may be incomplete.

Parameters:

  • value (String)

Returns:

  • (String)


612
# File 'lib/increase/models/inbound_ach_transfer.rb', line 612

required :receiver_city, String

#receiver_countryString

A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.

Parameters:

  • value (String)

Returns:

  • (String)


620
# File 'lib/increase/models/inbound_ach_transfer.rb', line 620

required :receiver_country, String

#receiver_identification_numberString?

An identification number the originator uses for the receiver.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


626
# File 'lib/increase/models/inbound_ach_transfer.rb', line 626

required :receiver_identification_number, String, nil?: true

#receiver_postal_codeString?

A portion of the receiver address. This may be incomplete.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


632
# File 'lib/increase/models/inbound_ach_transfer.rb', line 632

required :receiver_postal_code, String, nil?: true

#receiver_state_or_provinceString?

A portion of the receiver address. This may be incomplete.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


638
# File 'lib/increase/models/inbound_ach_transfer.rb', line 638

required :receiver_state_or_province, String, nil?: true

#receiver_street_addressString

A portion of the receiver address. This may be incomplete.

Parameters:

  • value (String)

Returns:

  • (String)


644
# File 'lib/increase/models/inbound_ach_transfer.rb', line 644

required :receiver_street_address, String

#receiving_company_or_individual_nameString

The name of the receiver of the transfer. This is not verified by Increase.

Parameters:

  • value (String)

Returns:

  • (String)


650
# File 'lib/increase/models/inbound_ach_transfer.rb', line 650

required :receiving_company_or_individual_name, String

#receiving_depository_financial_institution_countryString

The ISO 3166, Alpha-2 country code of the receiving bank country.

Parameters:

  • value (String)

Returns:

  • (String)


657
# File 'lib/increase/models/inbound_ach_transfer.rb', line 657

required :receiving_depository_financial_institution_country, String

#receiving_depository_financial_institution_idString

An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.

Parameters:

  • value (String)

Returns:

  • (String)


665
# File 'lib/increase/models/inbound_ach_transfer.rb', line 665

required :receiving_depository_financial_institution_id, String

#receiving_depository_financial_institution_id_qualifierSymbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ReceivingDepositoryFinancialInstitutionIDQualifier

An instruction of how to interpret the receiving_depository_financial_institution_id field for this Transaction.

Parameters:

  • value (Increase::Models::InboundACHTransfer::InternationalAddenda::receiving_depository_financial_institution_id_qualifier)

Returns:



672
673
# File 'lib/increase/models/inbound_ach_transfer.rb', line 672

required :receiving_depository_financial_institution_id_qualifier,
enum: -> { Increase::InboundACHTransfer::InternationalAddenda::ReceivingDepositoryFinancialInstitutionIDQualifier }

#receiving_depository_financial_institution_nameString

The name of the receiving bank, as set by the sending financial institution.

Parameters:

  • value (String)

Returns:

  • (String)


679
# File 'lib/increase/models/inbound_ach_transfer.rb', line 679

required :receiving_depository_financial_institution_name, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/inbound_ach_transfer.rb', line 808

Instance Method Details

#to_hash{

Returns:

  • ({)


478
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 478

def to_hash: -> {