Class: Increase::Models::InboundACHTransfer::InternationalAddenda
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundACHTransfer::InternationalAddenda
- Defined in:
- lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs
Overview
Defined Under Namespace
Modules: ForeignExchangeIndicator, ForeignExchangeReferenceIndicator, InternationalTransactionTypeCode, OriginatingDepositoryFinancialInstitutionIDQualifier, ReceivingDepositoryFinancialInstitutionIDQualifier
Instance Attribute Summary collapse
-
#destination_country_code ⇒ String
The ISO 3166, Alpha-2 country code of the destination country.
-
#destination_currency_code ⇒ String
The ISO 4217 currency code for the destination bank account.
-
#foreign_exchange_indicator ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator
A description of how the foreign exchange rate was calculated.
-
#foreign_exchange_reference ⇒ String?
Depending on the
foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate. -
#foreign_exchange_reference_indicator ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeReferenceIndicator
An instruction of how to interpret the
foreign_exchange_referencefield for this Transaction. -
#foreign_payment_amount ⇒ Integer
The amount in the minor unit of the foreign payment currency.
-
#foreign_trace_number ⇒ String?
A reference number in the foreign banking infrastructure.
-
#international_transaction_type_code ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::InternationalTransactionTypeCode
The type of transfer.
-
#originating_currency_code ⇒ String
The ISO 4217 currency code for the originating bank account.
-
#originating_depository_financial_institution_branch_country ⇒ String
The ISO 3166, Alpha-2 country code of the originating branch country.
-
#originating_depository_financial_institution_id ⇒ String
An identifier for the originating bank.
-
#originating_depository_financial_institution_id_qualifier ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::OriginatingDepositoryFinancialInstitutionIDQualifier
An instruction of how to interpret the
originating_depository_financial_institution_idfield for this Transaction. -
#originating_depository_financial_institution_name ⇒ String
The name of the originating bank.
-
#originator_city ⇒ String
A portion of the originator address.
-
#originator_country ⇒ String
A portion of the originator address.
-
#originator_identification ⇒ String
An identifier for the originating company.
-
#originator_name ⇒ String
Either the name of the originator or an intermediary money transmitter.
-
#originator_postal_code ⇒ String?
A portion of the originator address.
-
#originator_state_or_province ⇒ String?
A portion of the originator address.
-
#originator_street_address ⇒ String
A portion of the originator address.
-
#payment_related_information ⇒ String?
A description field set by the originator.
-
#payment_related_information2 ⇒ String?
A description field set by the originator.
-
#receiver_city ⇒ String
A portion of the receiver address.
-
#receiver_country ⇒ String
A portion of the receiver address.
-
#receiver_identification_number ⇒ String?
An identification number the originator uses for the receiver.
-
#receiver_postal_code ⇒ String?
A portion of the receiver address.
-
#receiver_state_or_province ⇒ String?
A portion of the receiver address.
-
#receiver_street_address ⇒ String
A portion of the receiver address.
-
#receiving_company_or_individual_name ⇒ String
The name of the receiver of the transfer.
-
#receiving_depository_financial_institution_country ⇒ String
The ISO 3166, Alpha-2 country code of the receiving bank country.
-
#receiving_depository_financial_institution_id ⇒ String
An identifier for the receiving bank.
-
#receiving_depository_financial_institution_id_qualifier ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ReceivingDepositoryFinancialInstitutionIDQualifier
An instruction of how to interpret the
receiving_depository_financial_institution_idfield for this Transaction. -
#receiving_depository_financial_institution_name ⇒ String
The name of the receiving bank, as set by the sending financial institution.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(destination_country_code:, destination_currency_code:, foreign_exchange_indicator:, foreign_exchange_reference:, foreign_exchange_reference_indicator:, foreign_payment_amount:, foreign_trace_number:, international_transaction_type_code:, originating_currency_code:, originating_depository_financial_institution_branch_country:, originating_depository_financial_institution_id:, originating_depository_financial_institution_id_qualifier:, originating_depository_financial_institution_name:, originator_city:, originator_country:, originator_identification:, originator_name:, originator_postal_code:, originator_state_or_province:, originator_street_address:, payment_related_information:, payment_related_information2:, receiver_city:, receiver_country:, receiver_identification_number:, receiver_postal_code:, receiver_state_or_province:, receiver_street_address:, receiving_company_or_individual_name:, receiving_depository_financial_institution_country:, receiving_depository_financial_institution_id:, receiving_depository_financial_institution_id_qualifier:, receiving_depository_financial_institution_name:) ⇒ Object
constructor
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(destination_country_code:, destination_currency_code:, foreign_exchange_indicator:, foreign_exchange_reference:, foreign_exchange_reference_indicator:, foreign_payment_amount:, foreign_trace_number:, international_transaction_type_code:, originating_currency_code:, originating_depository_financial_institution_branch_country:, originating_depository_financial_institution_id:, originating_depository_financial_institution_id_qualifier:, originating_depository_financial_institution_name:, originator_city:, originator_country:, originator_identification:, originator_name:, originator_postal_code:, originator_state_or_province:, originator_street_address:, payment_related_information:, payment_related_information2:, receiver_city:, receiver_country:, receiver_identification_number:, receiver_postal_code:, receiver_state_or_province:, receiver_street_address:, receiving_company_or_individual_name:, receiving_depository_financial_institution_country:, receiving_depository_financial_institution_id:, receiving_depository_financial_institution_id_qualifier:, receiving_depository_financial_institution_name:) ⇒ Object
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
|
|
# File 'lib/increase/models/inbound_ach_transfer.rb', line 681
|
Instance Attribute Details
#destination_country_code ⇒ String
The ISO 3166, Alpha-2 country code of the destination country.
463 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 463 required :destination_country_code, String |
#destination_currency_code ⇒ String
The ISO 4217 currency code for the destination bank account.
470 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 470 required :destination_currency_code, String |
#foreign_exchange_indicator ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator
A description of how the foreign exchange rate was calculated.
476 477 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 476 required :foreign_exchange_indicator, enum: -> { Increase::InboundACHTransfer::InternationalAddenda::ForeignExchangeIndicator } |
#foreign_exchange_reference ⇒ String?
Depending on the foreign_exchange_reference_indicator, an exchange rate or a
reference to a well-known rate.
484 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 484 required :foreign_exchange_reference, String, nil?: true |
#foreign_exchange_reference_indicator ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ForeignExchangeReferenceIndicator
An instruction of how to interpret the foreign_exchange_reference field for
this Transaction.
491 492 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 491 required :foreign_exchange_reference_indicator, enum: -> { Increase::InboundACHTransfer::InternationalAddenda::ForeignExchangeReferenceIndicator } |
#foreign_payment_amount ⇒ Integer
The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.
499 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 499 required :foreign_payment_amount, Integer |
#foreign_trace_number ⇒ String?
A reference number in the foreign banking infrastructure.
505 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 505 required :foreign_trace_number, String, nil?: true |
#international_transaction_type_code ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::InternationalTransactionTypeCode
The type of transfer. Set by the originator.
511 512 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 511 required :international_transaction_type_code, enum: -> { Increase::InboundACHTransfer::InternationalAddenda::InternationalTransactionTypeCode } |
#originating_currency_code ⇒ String
The ISO 4217 currency code for the originating bank account.
519 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 519 required :originating_currency_code, String |
#originating_depository_financial_institution_branch_country ⇒ String
The ISO 3166, Alpha-2 country code of the originating branch country.
526 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 526 required :originating_depository_financial_institution_branch_country, String |
#originating_depository_financial_institution_id ⇒ String
An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
534 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 534 required :originating_depository_financial_institution_id, String |
#originating_depository_financial_institution_id_qualifier ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::OriginatingDepositoryFinancialInstitutionIDQualifier
An instruction of how to interpret the
originating_depository_financial_institution_id field for this Transaction.
541 542 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 541 required :originating_depository_financial_institution_id_qualifier, enum: -> { Increase::InboundACHTransfer::InternationalAddenda::OriginatingDepositoryFinancialInstitutionIDQualifier } |
#originating_depository_financial_institution_name ⇒ String
The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.
549 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 549 required :originating_depository_financial_institution_name, String |
#originator_city ⇒ String
A portion of the originator address. This may be incomplete.
555 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 555 required :originator_city, String |
#originator_country ⇒ String
A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.
563 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 563 required :originator_country, String |
#originator_identification ⇒ String
An identifier for the originating company. This is generally stable across multiple ACH transfers.
570 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 570 required :originator_identification, String |
#originator_name ⇒ String
Either the name of the originator or an intermediary money transmitter.
576 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 576 required :originator_name, String |
#originator_postal_code ⇒ String?
A portion of the originator address. This may be incomplete.
582 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 582 required :originator_postal_code, String, nil?: true |
#originator_state_or_province ⇒ String?
A portion of the originator address. This may be incomplete.
588 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 588 required :originator_state_or_province, String, nil?: true |
#originator_street_address ⇒ String
A portion of the originator address. This may be incomplete.
594 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 594 required :originator_street_address, String |
#payment_related_information ⇒ String?
A description field set by the originator.
600 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 600 required :payment_related_information, String, nil?: true |
#payment_related_information2 ⇒ String?
A description field set by the originator.
606 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 606 required :payment_related_information2, String, nil?: true |
#receiver_city ⇒ String
A portion of the receiver address. This may be incomplete.
612 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 612 required :receiver_city, String |
#receiver_country ⇒ String
A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.
620 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 620 required :receiver_country, String |
#receiver_identification_number ⇒ String?
An identification number the originator uses for the receiver.
626 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 626 required :receiver_identification_number, String, nil?: true |
#receiver_postal_code ⇒ String?
A portion of the receiver address. This may be incomplete.
632 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 632 required :receiver_postal_code, String, nil?: true |
#receiver_state_or_province ⇒ String?
A portion of the receiver address. This may be incomplete.
638 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 638 required :receiver_state_or_province, String, nil?: true |
#receiver_street_address ⇒ String
A portion of the receiver address. This may be incomplete.
644 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 644 required :receiver_street_address, String |
#receiving_company_or_individual_name ⇒ String
The name of the receiver of the transfer. This is not verified by Increase.
650 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 650 required :receiving_company_or_individual_name, String |
#receiving_depository_financial_institution_country ⇒ String
The ISO 3166, Alpha-2 country code of the receiving bank country.
657 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 657 required :receiving_depository_financial_institution_country, String |
#receiving_depository_financial_institution_id ⇒ String
An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
665 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 665 required :receiving_depository_financial_institution_id, String |
#receiving_depository_financial_institution_id_qualifier ⇒ Symbol, Increase::Models::InboundACHTransfer::InternationalAddenda::ReceivingDepositoryFinancialInstitutionIDQualifier
An instruction of how to interpret the
receiving_depository_financial_institution_id field for this Transaction.
672 673 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 672 required :receiving_depository_financial_institution_id_qualifier, enum: -> { Increase::InboundACHTransfer::InternationalAddenda::ReceivingDepositoryFinancialInstitutionIDQualifier } |
#receiving_depository_financial_institution_name ⇒ String
The name of the receiving bank, as set by the sending financial institution.
679 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 679 required :receiving_depository_financial_institution_name, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/inbound_ach_transfer.rb', line 808
|
Instance Method Details
#to_hash ⇒ {
478 |
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 478
def to_hash: -> {
|