Class: Increase::Models::InboundACHTransfer::NotificationOfChange
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundACHTransfer::NotificationOfChange
- Defined in:
- lib/increase/models/inbound_ach_transfer.rb,
sig/increase/models/inbound_ach_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#updated_account_number ⇒ String?
The new account number provided in the notification of change.
-
#updated_routing_number ⇒ String?
The new routing number provided in the notification of change.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
683 |
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 683
def initialize: (
|
Instance Attribute Details
#updated_account_number ⇒ String?
The new account number provided in the notification of change.
886 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 886 required :updated_account_number, String, nil?: true |
#updated_routing_number ⇒ String?
The new routing number provided in the notification of change.
892 |
# File 'lib/increase/models/inbound_ach_transfer.rb', line 892 required :updated_routing_number, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
688 |
# File 'sig/increase/models/inbound_ach_transfer.rbs', line 688
def to_hash: -> {
|