Module: Increase::Models::InboundCheckDeposit::Adjustment::Reason
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/inbound_check_deposit.rb
Overview
The reason for the adjustment.
Constant Summary collapse
- LATE_RETURN =
The return was initiated too late and the receiving institution has responded with a Late Return Claim.
:late_return- WRONG_PAYEE_CREDIT =
The check was deposited to the wrong payee and the depositing institution has reimbursed the funds with a Wrong Payee Credit.
:wrong_payee_credit
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info