Class: Increase::Models::InboundMailItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundMailItem
- Defined in:
- lib/increase/models/inbound_mail_item.rb,
sig/increase/models/inbound_mail_item.rbs
Overview
Defined Under Namespace
Modules: RejectionReason, Status, Type Classes: Check
Instance Attribute Summary collapse
-
#checks ⇒ Array<Increase::Models::InboundMailItem::Check>
The checks in the mail item.
-
#created_at ⇒ Time
The ISO 8601 time at which the Inbound Mail Item was created.
-
#file_id ⇒ String
The identifier for the File containing the scanned contents of the mail item.
-
#id ⇒ String
The Inbound Mail Item identifier.
-
#lockbox_address_id ⇒ String
The identifier for the Lockbox Address that received this mail item.
-
#lockbox_recipient_id ⇒ String?
The identifier for the Lockbox Recipient that received this mail item.
-
#recipient_name ⇒ String?
The recipient name as written on the mail item.
-
#rejection_reason ⇒ Symbol, ...
If the mail item has been rejected, why it was rejected.
-
#status ⇒ Symbol, Increase::Models::InboundMailItem::Status
If the mail item has been processed.
-
#type ⇒ Symbol, Increase::Models::InboundMailItem::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
38 |
# File 'sig/increase/models/inbound_mail_item.rbs', line 38
def initialize: (
|
Instance Attribute Details
#checks ⇒ Array<Increase::Models::InboundMailItem::Check>
The checks in the mail item.
17 |
# File 'lib/increase/models/inbound_mail_item.rb', line 17 required :checks, -> { Increase::Internal::Type::ArrayOf[Increase::InboundMailItem::Check] } |
#created_at ⇒ Time
The ISO 8601 time at which the Inbound Mail Item was created.
24 |
# File 'lib/increase/models/inbound_mail_item.rb', line 24 required :created_at, Time |
#file_id ⇒ String
The identifier for the File containing the scanned contents of the mail item.
30 |
# File 'lib/increase/models/inbound_mail_item.rb', line 30 required :file_id, String |
#id ⇒ String
The Inbound Mail Item identifier.
11 |
# File 'lib/increase/models/inbound_mail_item.rb', line 11 required :id, String |
#lockbox_address_id ⇒ String
The identifier for the Lockbox Address that received this mail item.
36 |
# File 'lib/increase/models/inbound_mail_item.rb', line 36 required :lockbox_address_id, String |
#lockbox_recipient_id ⇒ String?
The identifier for the Lockbox Recipient that received this mail item. For mail items that could not be routed to a Lockbox Recipient, this will be null.
43 |
# File 'lib/increase/models/inbound_mail_item.rb', line 43 required :lockbox_recipient_id, String, nil?: true |
#recipient_name ⇒ String?
The recipient name as written on the mail item.
49 |
# File 'lib/increase/models/inbound_mail_item.rb', line 49 required :recipient_name, String, nil?: true |
#rejection_reason ⇒ Symbol, ...
If the mail item has been rejected, why it was rejected.
55 |
# File 'lib/increase/models/inbound_mail_item.rb', line 55 required :rejection_reason, enum: -> { Increase::InboundMailItem::RejectionReason }, nil?: true |
#status ⇒ Symbol, Increase::Models::InboundMailItem::Status
If the mail item has been processed.
61 |
# File 'lib/increase/models/inbound_mail_item.rb', line 61 required :status, enum: -> { Increase::InboundMailItem::Status } |
#type ⇒ Symbol, Increase::Models::InboundMailItem::Type
A constant representing the object's type. For this resource it will always be
inbound_mail_item.
68 |
# File 'lib/increase/models/inbound_mail_item.rb', line 68 required :type, enum: -> { Increase::InboundMailItem::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/inbound_mail_item.rb', line 158
|
Instance Method Details
#to_hash ⇒ {
51 |
# File 'sig/increase/models/inbound_mail_item.rbs', line 51
def to_hash: -> {
|