Class: Increase::Models::InboundWireDrawdownRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_wire_drawdown_request.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, creditor_account_number:, creditor_address_line1:, creditor_address_line2:, creditor_address_line3:, creditor_name:, creditor_routing_number:, currency:, debtor_address_line1:, debtor_address_line2:, debtor_address_line3:, debtor_name:, end_to_end_identification:, input_message_accountability_data:, instruction_identification:, recipient_account_number_id:, type:, unique_end_to_end_transaction_reference:, unstructured_remittance_information:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::InboundWireDrawdownRequest for more details.

Inbound wire drawdown requests are requests from someone else to send them a wire. For more information, see our [Wire Drawdown Requests documentation](/documentation/wire-drawdown-requests).

Parameters:

  • id (String)

    The Wire drawdown request identifier.

  • amount (Integer)

    The amount being requested in cents.

  • created_at (Time)

    The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which th

  • creditor_account_number (String)

    The creditor’s account number.

  • creditor_address_line1 (String, nil)

    A free-form address field set by the sender.

  • creditor_address_line2 (String, nil)

    A free-form address field set by the sender.

  • creditor_address_line3 (String, nil)

    A free-form address field set by the sender.

  • creditor_name (String, nil)

    A name set by the sender.

  • creditor_routing_number (String)

    The creditor’s routing number.

  • currency (String)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the amount being

  • debtor_address_line1 (String, nil)

    A free-form address field set by the sender.

  • debtor_address_line2 (String, nil)

    A free-form address field set by the sender.

  • debtor_address_line3 (String, nil)

    A free-form address field set by the sender.

  • debtor_name (String, nil)

    A name set by the sender.

  • end_to_end_identification (String, nil)

    A free-form reference string set by the sender, to help identify the drawdown re

  • input_message_accountability_data (String, nil)

    A unique identifier available to the originating and receiving banks, commonly a

  • instruction_identification (String, nil)

    The sending bank’s identifier for the drawdown request.

  • recipient_account_number_id (String)

    The Account Number from which the recipient of this request is being requested t

  • type (Symbol, Increase::Models::InboundWireDrawdownRequest::Type)

    A constant representing the object’s type. For this resource it will always be ‘

  • unique_end_to_end_transaction_reference (String, nil)

    The Unique End-to-end Transaction Reference ([UETR](www.swift.com/paymen

  • unstructured_remittance_information (String, nil)

    A free-form message set by the sender.



# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 142

Instance Attribute Details

#amountInteger

The amount being requested in cents.

Returns:

  • (Integer)


17
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 17

required :amount, Integer

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the inbound wire drawdown request was created.

Returns:

  • (Time)


24
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 24

required :created_at, Time

#creditor_account_numberString

The creditor’s account number.

Returns:

  • (String)


30
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 30

required :creditor_account_number, String

#creditor_address_line1String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


36
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 36

required :creditor_address_line1, String, nil?: true

#creditor_address_line2String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


42
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 42

required :creditor_address_line2, String, nil?: true

#creditor_address_line3String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


48
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 48

required :creditor_address_line3, String, nil?: true

#creditor_nameString?

A name set by the sender.

Returns:

  • (String, nil)


54
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 54

required :creditor_name, String, nil?: true

#creditor_routing_numberString

The creditor’s routing number.

Returns:

  • (String)


60
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 60

required :creditor_routing_number, String

#currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the amount being requested. Will always be “USD”.

Returns:

  • (String)


67
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 67

required :currency, String

#debtor_address_line1String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


73
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 73

required :debtor_address_line1, String, nil?: true

#debtor_address_line2String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


79
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 79

required :debtor_address_line2, String, nil?: true

#debtor_address_line3String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


85
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 85

required :debtor_address_line3, String, nil?: true

#debtor_nameString?

A name set by the sender.

Returns:

  • (String, nil)


91
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 91

required :debtor_name, String, nil?: true

#end_to_end_identificationString?

A free-form reference string set by the sender, to help identify the drawdown request.

Returns:

  • (String, nil)


98
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 98

required :end_to_end_identification, String, nil?: true

#idString

The Wire drawdown request identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 11

required :id, String

#input_message_accountability_dataString?

A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.

Returns:

  • (String, nil)


106
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 106

required :input_message_accountability_data, String, nil?: true

#instruction_identificationString?

The sending bank’s identifier for the drawdown request.

Returns:

  • (String, nil)


112
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 112

required :instruction_identification, String, nil?: true

#recipient_account_number_idString

The Account Number from which the recipient of this request is being requested to send funds.

Returns:

  • (String)


119
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 119

required :recipient_account_number_id, String

#typeSymbol, Increase::Models::InboundWireDrawdownRequest::Type

A constant representing the object’s type. For this resource it will always be ‘inbound_wire_drawdown_request`.



126
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 126

required :type, enum: -> { Increase::InboundWireDrawdownRequest::Type }

#unique_end_to_end_transaction_referenceString?

The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the drawdown request.

Returns:

  • (String, nil)


134
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 134

required :unique_end_to_end_transaction_reference, String, nil?: true

#unstructured_remittance_informationString?

A free-form message set by the sender.

Returns:

  • (String, nil)


140
# File 'lib/increase/models/inbound_wire_drawdown_request.rb', line 140

required :unstructured_remittance_information, String, nil?: true