Class: Increase::Models::InboundWireTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/inbound_wire_transfer.rb

Overview

Defined Under Namespace

Modules: Status, Type Classes: Acceptance, Reversal

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accepted_at:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see Acceptance for more details.

If the transfer is accepted, this will contain details of the acceptance.

Parameters:

  • accepted_at (Time)

    The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which th

  • transaction_id (String)

    The identifier of the transaction for the accepted transfer.



# File 'lib/increase/models/inbound_wire_transfer.rb', line 164

Instance Attribute Details

#acceptanceIncrease::Models::InboundWireTransfer::Acceptance?

If the transfer is accepted, this will contain details of the acceptance.



17
# File 'lib/increase/models/inbound_wire_transfer.rb', line 17

required :acceptance, -> { Increase::InboundWireTransfer::Acceptance }, nil?: true

#account_idString

The Account to which the transfer belongs.

Returns:

  • (String)


23
# File 'lib/increase/models/inbound_wire_transfer.rb', line 23

required :account_id, String

#account_number_idString

The identifier of the Account Number to which this transfer was sent.

Returns:

  • (String)


29
# File 'lib/increase/models/inbound_wire_transfer.rb', line 29

required :account_number_id, String

#amountInteger

The amount in USD cents.

Returns:

  • (Integer)


35
# File 'lib/increase/models/inbound_wire_transfer.rb', line 35

required :amount, Integer

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the inbound wire transfer was created.

Returns:

  • (Time)


42
# File 'lib/increase/models/inbound_wire_transfer.rb', line 42

required :created_at, Time

#creditor_address_line1String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


48
# File 'lib/increase/models/inbound_wire_transfer.rb', line 48

required :creditor_address_line1, String, nil?: true

#creditor_address_line2String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


54
# File 'lib/increase/models/inbound_wire_transfer.rb', line 54

required :creditor_address_line2, String, nil?: true

#creditor_address_line3String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


60
# File 'lib/increase/models/inbound_wire_transfer.rb', line 60

required :creditor_address_line3, String, nil?: true

#creditor_nameString?

A name set by the sender.

Returns:

  • (String, nil)


66
# File 'lib/increase/models/inbound_wire_transfer.rb', line 66

required :creditor_name, String, nil?: true

#debtor_address_line1String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


72
# File 'lib/increase/models/inbound_wire_transfer.rb', line 72

required :debtor_address_line1, String, nil?: true

#debtor_address_line2String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


78
# File 'lib/increase/models/inbound_wire_transfer.rb', line 78

required :debtor_address_line2, String, nil?: true

#debtor_address_line3String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


84
# File 'lib/increase/models/inbound_wire_transfer.rb', line 84

required :debtor_address_line3, String, nil?: true

#debtor_nameString?

A name set by the sender.

Returns:

  • (String, nil)


90
# File 'lib/increase/models/inbound_wire_transfer.rb', line 90

required :debtor_name, String, nil?: true

#descriptionString

An Increase-constructed description of the transfer.

Returns:

  • (String)


96
# File 'lib/increase/models/inbound_wire_transfer.rb', line 96

required :description, String

#end_to_end_identificationString?

A free-form reference string set by the sender, to help identify the transfer.

Returns:

  • (String, nil)


102
# File 'lib/increase/models/inbound_wire_transfer.rb', line 102

required :end_to_end_identification, String, nil?: true

#idString

The inbound wire transfer’s identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/inbound_wire_transfer.rb', line 11

required :id, String

#input_message_accountability_dataString?

A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.

Returns:

  • (String, nil)


110
# File 'lib/increase/models/inbound_wire_transfer.rb', line 110

required :input_message_accountability_data, String, nil?: true

#instructing_agent_routing_numberString?

The American Banking Association (ABA) routing number of the bank that sent the wire.

Returns:

  • (String, nil)


117
# File 'lib/increase/models/inbound_wire_transfer.rb', line 117

required :instructing_agent_routing_number, String, nil?: true

#instruction_identificationString?

The sending bank’s identifier for the wire transfer.

Returns:

  • (String, nil)


123
# File 'lib/increase/models/inbound_wire_transfer.rb', line 123

required :instruction_identification, String, nil?: true

#reversalIncrease::Models::InboundWireTransfer::Reversal?

If the transfer is reversed, this will contain details of the reversal.



129
# File 'lib/increase/models/inbound_wire_transfer.rb', line 129

required :reversal, -> { Increase::InboundWireTransfer::Reversal }, nil?: true

#statusSymbol, Increase::Models::InboundWireTransfer::Status

The status of the transfer.



135
# File 'lib/increase/models/inbound_wire_transfer.rb', line 135

required :status, enum: -> { Increase::InboundWireTransfer::Status }

#typeSymbol, Increase::Models::InboundWireTransfer::Type

A constant representing the object’s type. For this resource it will always be ‘inbound_wire_transfer`.



142
# File 'lib/increase/models/inbound_wire_transfer.rb', line 142

required :type, enum: -> { Increase::InboundWireTransfer::Type }

#unique_end_to_end_transaction_referenceString?

The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.

Returns:

  • (String, nil)


150
# File 'lib/increase/models/inbound_wire_transfer.rb', line 150

required :unique_end_to_end_transaction_reference, String, nil?: true

#unstructured_remittance_informationString?

A free-form message set by the sender.

Returns:

  • (String, nil)


156
# File 'lib/increase/models/inbound_wire_transfer.rb', line 156

required :unstructured_remittance_information, String, nil?: true

#wire_drawdown_request_idString?

The wire drawdown request the inbound wire transfer is fulfilling.

Returns:

  • (String, nil)


162
# File 'lib/increase/models/inbound_wire_transfer.rb', line 162

required :wire_drawdown_request_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/inbound_wire_transfer.rb', line 287