Class: Increase::Models::InboundWireTransfer::Reversal
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::InboundWireTransfer::Reversal
- Defined in:
- lib/increase/models/inbound_wire_transfer.rb
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#reason ⇒ Symbol, Increase::Models::InboundWireTransfer::Reversal::Reason
The reason for the reversal.
-
#reversed_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was reversed.
Instance Method Summary collapse
-
#initialize(reason:, reversed_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reversal for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reason:, reversed_at:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::InboundWireTransfer::Reversal for more details.
If the transfer is reversed, this will contain details of the reversal.
|
|
# File 'lib/increase/models/inbound_wire_transfer.rb', line 262
|
Instance Attribute Details
#reason ⇒ Symbol, Increase::Models::InboundWireTransfer::Reversal::Reason
The reason for the reversal.
253 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 253 required :reason, enum: -> { Increase::InboundWireTransfer::Reversal::Reason } |
#reversed_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was reversed.
260 |
# File 'lib/increase/models/inbound_wire_transfer.rb', line 260 required :reversed_at, Time |