Class: Increase::Models::IntrafiBalance::Balance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::IntrafiBalance::Balance
- Defined in:
- lib/increase/models/intrafi_balance.rb
Defined Under Namespace
Classes: BankLocation
Instance Attribute Summary collapse
-
#balance ⇒ Integer
The balance, in minor units of ‘currency`, held with this bank.
-
#bank ⇒ String
The name of the bank holding these funds.
-
#bank_location ⇒ Increase::Models::IntrafiBalance::Balance::BankLocation?
The primary location of the bank.
-
#fdic_certificate_number ⇒ String
The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank.
Instance Method Summary collapse
-
#initialize(balance:, bank:, bank_location:, fdic_certificate_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Balance for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance:, bank:, bank_location:, fdic_certificate_number:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::IntrafiBalance::Balance for more details.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/increase/models/intrafi_balance.rb', line 59 class Balance < Increase::Internal::Type::BaseModel # @!attribute balance # The balance, in minor units of `currency`, held with this bank. # # @return [Integer] required :balance, Integer # @!attribute bank # The name of the bank holding these funds. # # @return [String] required :bank, String # @!attribute bank_location # The primary location of the bank. # # @return [Increase::Models::IntrafiBalance::Balance::BankLocation, nil] required :bank_location, -> { Increase::IntrafiBalance::Balance::BankLocation }, nil?: true # @!attribute fdic_certificate_number # The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank. # Because many banks have the same or similar names, this can be used to uniquely # identify the institution. # # @return [String] required :fdic_certificate_number, String # @!method initialize(balance:, bank:, bank_location:, fdic_certificate_number:) # Some parameter documentations has been truncated, see # {Increase::Models::IntrafiBalance::Balance} for more details. # # @param balance [Integer] The balance, in minor units of `currency`, held with this bank. # # @param bank [String] The name of the bank holding these funds. # # @param bank_location [Increase::Models::IntrafiBalance::Balance::BankLocation, nil] The primary location of the bank. # # @param fdic_certificate_number [String] The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank. # @see Increase::Models::IntrafiBalance::Balance#bank_location class BankLocation < Increase::Internal::Type::BaseModel # @!attribute city # The bank's city. # # @return [String] required :city, String # @!attribute state # The bank's state. # # @return [String] required :state, String # @!method initialize(city:, state:) # The primary location of the bank. # # @param city [String] The bank's city. # # @param state [String] The bank's state. end end |
Instance Attribute Details
#balance ⇒ Integer
The balance, in minor units of ‘currency`, held with this bank.
64 |
# File 'lib/increase/models/intrafi_balance.rb', line 64 required :balance, Integer |
#bank ⇒ String
The name of the bank holding these funds.
70 |
# File 'lib/increase/models/intrafi_balance.rb', line 70 required :bank, String |
#bank_location ⇒ Increase::Models::IntrafiBalance::Balance::BankLocation?
The primary location of the bank.
76 |
# File 'lib/increase/models/intrafi_balance.rb', line 76 required :bank_location, -> { Increase::IntrafiBalance::Balance::BankLocation }, nil?: true |
#fdic_certificate_number ⇒ String
The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank. Because many banks have the same or similar names, this can be used to uniquely identify the institution.
84 |
# File 'lib/increase/models/intrafi_balance.rb', line 84 required :fdic_certificate_number, String |