Class: Increase::Models::LockboxAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::LockboxAddress
- Defined in:
- lib/increase/models/lockbox_address.rb
Overview
Defined Under Namespace
Modules: Status, Type Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::LockboxAddress::Address?
The mailing address for the Lockbox Address.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Lockbox Address was created.
-
#description ⇒ String?
The description you choose for the Lockbox Address.
-
#id ⇒ String
The Lockbox Address identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#status ⇒ Symbol, Increase::Models::LockboxAddress::Status
The status of the Lockbox Address.
-
#type ⇒ Symbol, Increase::Models::LockboxAddress::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, line1:, line2:, postal_code:, state:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, line1:, line2:, postal_code:, state:) ⇒ Object
Some parameter documentations has been truncated, see Address for more details.
The mailing address for the Lockbox Address. It will be present after Increase generates it.
|
|
# File 'lib/increase/models/lockbox_address.rb', line 54
|
Instance Attribute Details
#address ⇒ Increase::Models::LockboxAddress::Address?
The mailing address for the Lockbox Address. It will be present after Increase generates it.
18 |
# File 'lib/increase/models/lockbox_address.rb', line 18 required :address, -> { Increase::LockboxAddress::Address }, nil?: true |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Lockbox Address was created.
25 |
# File 'lib/increase/models/lockbox_address.rb', line 25 required :created_at, Time |
#description ⇒ String?
The description you choose for the Lockbox Address.
31 |
# File 'lib/increase/models/lockbox_address.rb', line 31 required :description, String, nil?: true |
#id ⇒ String
The Lockbox Address identifier.
11 |
# File 'lib/increase/models/lockbox_address.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
39 |
# File 'lib/increase/models/lockbox_address.rb', line 39 required :idempotency_key, String, nil?: true |
#status ⇒ Symbol, Increase::Models::LockboxAddress::Status
The status of the Lockbox Address.
45 |
# File 'lib/increase/models/lockbox_address.rb', line 45 required :status, enum: -> { Increase::LockboxAddress::Status } |
#type ⇒ Symbol, Increase::Models::LockboxAddress::Type
A constant representing the object’s type. For this resource it will always be ‘lockbox_address`.
52 |
# File 'lib/increase/models/lockbox_address.rb', line 52 required :type, enum: -> { Increase::LockboxAddress::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/lockbox_address.rb', line 144
|