Class: Increase::Models::LockboxRecipient
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::LockboxRecipient
- Defined in:
- lib/increase/models/lockbox_recipient.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier for the Account that checks sent to this Lockbox Recipient will be deposited into.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Lockbox Recipient was created.
-
#description ⇒ String?
The description of the Lockbox Recipient.
-
#id ⇒ String
The Lockbox Recipient identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#lockbox_address_id ⇒ String
The identifier for the Lockbox Address where this Lockbox Recipient may receive physical mail.
-
#mail_stop_code ⇒ String
The mail stop code uniquely identifying this Lockbox Recipient at its Lockbox Address.
-
#recipient_name ⇒ String?
The name of the Lockbox Recipient.
-
#status ⇒ Symbol, ...
The status of the Lockbox Recipient.
-
#type ⇒ Symbol, Increase::Models::LockboxRecipient::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, account_id:, created_at:, description:, idempotency_key:, lockbox_address_id:, mail_stop_code:, recipient_name:, status:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see LockboxRecipient for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, created_at:, description:, idempotency_key:, lockbox_address_id:, mail_stop_code:, recipient_name:, status:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::LockboxRecipient for more details.
Lockbox Recipients represent an inbox at a Lockbox Address. Checks received for a Lockbox Recipient are deposited into its associated Account.
|
|
# File 'lib/increase/models/lockbox_recipient.rb', line 75
|
Instance Attribute Details
#account_id ⇒ String
The identifier for the Account that checks sent to this Lockbox Recipient will be deposited into.
18 |
# File 'lib/increase/models/lockbox_recipient.rb', line 18 required :account_id, String |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Lockbox Recipient was created.
25 |
# File 'lib/increase/models/lockbox_recipient.rb', line 25 required :created_at, Time |
#description ⇒ String?
The description of the Lockbox Recipient.
31 |
# File 'lib/increase/models/lockbox_recipient.rb', line 31 required :description, String, nil?: true |
#id ⇒ String
The Lockbox Recipient identifier.
11 |
# File 'lib/increase/models/lockbox_recipient.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
39 |
# File 'lib/increase/models/lockbox_recipient.rb', line 39 required :idempotency_key, String, nil?: true |
#lockbox_address_id ⇒ String
The identifier for the Lockbox Address where this Lockbox Recipient may receive physical mail.
46 |
# File 'lib/increase/models/lockbox_recipient.rb', line 46 required :lockbox_address_id, String |
#mail_stop_code ⇒ String
The mail stop code uniquely identifying this Lockbox Recipient at its Lockbox Address. It should be included in the mailing address intended for this Lockbox Recipient.
54 |
# File 'lib/increase/models/lockbox_recipient.rb', line 54 required :mail_stop_code, String |
#recipient_name ⇒ String?
The name of the Lockbox Recipient.
60 |
# File 'lib/increase/models/lockbox_recipient.rb', line 60 required :recipient_name, String, nil?: true |
#status ⇒ Symbol, ...
The status of the Lockbox Recipient.
66 |
# File 'lib/increase/models/lockbox_recipient.rb', line 66 required :status, enum: -> { Increase::LockboxRecipient::Status }, nil?: true |
#type ⇒ Symbol, Increase::Models::LockboxRecipient::Type
A constant representing the object’s type. For this resource it will always be ‘lockbox_recipient`.
73 |
# File 'lib/increase/models/lockbox_recipient.rb', line 73 required :type, enum: -> { Increase::LockboxRecipient::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/lockbox_recipient.rb', line 117
|