Class: Increase::Models::OAuthConnectionListParams::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::OAuthConnectionListParams::Status
- Defined in:
- lib/increase/models/oauth_connection_list_params.rb,
sig/increase/models/oauth_connection_list_params.rbs
Defined Under Namespace
Modules: In
Instance Attribute Summary collapse
-
#in_ ⇒ Array<Symbol, Increase::Models::OAuthConnectionListParams::Status::In>?
Filter to OAuth Connections by their status.
Instance Method Summary collapse
-
#initialize(cursor: nil, limit: nil, oauth_application_id: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Increase::Models::OAuthConnectionListParams for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor: nil, limit: nil, oauth_application_id: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::OAuthConnectionListParams for more details.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/increase/models/oauth_connection_list_params.rb', line 49 class Status < Increase::Internal::Type::BaseModel # @!attribute in_ # Filter to OAuth Connections by their status. By default, return only the # `active` ones. For GET requests, this should be encoded as a comma-delimited # string, such as `?in=one,two,three`. # # @return [Array<Symbol, Increase::Models::OAuthConnectionListParams::Status::In>, nil] optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::OAuthConnectionListParams::Status::In] }, api_name: :in # @!method initialize(in_: nil) # Some parameter documentations has been truncated, see # {Increase::Models::OAuthConnectionListParams::Status} for more details. # # @param in_ [Array<Symbol, Increase::Models::OAuthConnectionListParams::Status::In>] Filter to OAuth Connections by their status. By default, return only the `active module In extend Increase::Internal::Type::Enum # The OAuth connection is active. ACTIVE = :active # The OAuth connection is permanently deactivated. INACTIVE = :inactive # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#in_ ⇒ Array<Symbol, Increase::Models::OAuthConnectionListParams::Status::In>?
Filter to OAuth Connections by their status. By default, return only the
active ones. For GET requests, this should be encoded as a comma-delimited
string, such as ?in=one,two,three.
56 57 58 59 60 |
# File 'lib/increase/models/oauth_connection_list_params.rb', line 56 optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::OAuthConnectionListParams::Status::In] }, api_name: :in |
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/increase/models/oauth_connection_list_params.rbs', line 66
def to_hash: -> {
|