Class: Increase::Models::OAuthToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/oauth_token.rb,
sig/increase/models/oauth_token.rbs

Overview

See Also:

  • Increase::Resources::OAuthTokens#create

Defined Under Namespace

Modules: TokenType, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token:, group_id:, token_type:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::OAuthToken for more details.

A token that is returned to your application when a user completes the OAuth flow and may be used to authenticate requests. Learn more about OAuth here.

Parameters:

  • access_token (String)

    You may use this token in place of an API key to make OAuth requests on a user's

  • group_id (String)

    The Group's identifier. A Group is the top-level organization in Increase.

  • token_type (Symbol, Increase::Models::OAuthToken::TokenType)

    The type of OAuth token.

  • type (Symbol, Increase::Models::OAuthToken::Type)

    A constant representing the object's type. For this resource it will always be `



# File 'lib/increase/models/oauth_token.rb', line 33

Instance Attribute Details

#access_tokenString

You may use this token in place of an API key to make OAuth requests on a user's behalf.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/increase/models/oauth_token.rb', line 12

required :access_token, String

#group_idString

The Group's identifier. A Group is the top-level organization in Increase.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/increase/models/oauth_token.rb', line 18

required :group_id, String

#token_typeSymbol, Increase::Models::OAuthToken::TokenType

The type of OAuth token.

Parameters:

  • value (Increase::Models::OAuthToken::token_type)

Returns:



24
# File 'lib/increase/models/oauth_token.rb', line 24

required :token_type, enum: -> { Increase::OAuthToken::TokenType }

#typeSymbol, Increase::Models::OAuthToken::Type

A constant representing the object's type. For this resource it will always be oauth_token.

Parameters:

  • value (Increase::Models::OAuthToken::type_)

Returns:



31
# File 'lib/increase/models/oauth_token.rb', line 31

required :type, enum: -> { Increase::OAuthToken::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/oauth_token.rb', line 57

Instance Method Details

#to_hash{

Returns:

  • ({)


27
# File 'sig/increase/models/oauth_token.rbs', line 27

def to_hash: -> {