Class: Increase::Models::PendingTransaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb

Overview

Defined Under Namespace

Modules: Currency, RouteType, Status, Type Classes: Source

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, amount:, message_to_recipient:, routing_number:, transfer_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::WireTransferInstruction for more details.

A Wire Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `wire_transfer_instruction`.

Parameters:

  • account_number (String)

    The account number for the destination account.

  • amount (Integer)

    The transfer amount in USD cents.

  • message_to_recipient (String)

    The message that will show on the recipient’s bank statement.

  • routing_number (String)

    The American Bankers’ Association (ABA) Routing Transit Number (RTN) for the des

  • transfer_id (String)

    The identifier of the Wire Transfer that led to this Pending Transaction.



# File 'lib/increase/models/pending_transaction.rb', line 102

Instance Attribute Details

#account_idString

The identifier for the account this Pending Transaction belongs to.

Returns:

  • (String)


17
# File 'lib/increase/models/pending_transaction.rb', line 17

required :account_id, String

#amountInteger

The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents. This amount does not change after the Pending Transaction is created. If a card authorization settles for a different amount, the settled amount is available on the resulting Transaction and on the Card Payment’s ‘state.settled_amount`.

Returns:

  • (Integer)


27
# File 'lib/increase/models/pending_transaction.rb', line 27

required :amount, Integer

#completed_atTime?

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date on which the Pending Transaction was completed.

Returns:

  • (Time, nil)


34
# File 'lib/increase/models/pending_transaction.rb', line 34

required :completed_at, Time, nil?: true

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date on which the Pending Transaction occurred.

Returns:

  • (Time)


41
# File 'lib/increase/models/pending_transaction.rb', line 41

required :created_at, Time

#currencySymbol, Increase::Models::PendingTransaction::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the Pending Transaction’s currency. This will match the currency on the Pending Transaction’s Account.



49
# File 'lib/increase/models/pending_transaction.rb', line 49

required :currency, enum: -> { Increase::PendingTransaction::Currency }

#descriptionString

For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.

Returns:

  • (String)


57
# File 'lib/increase/models/pending_transaction.rb', line 57

required :description, String

#held_amountInteger

The amount that this Pending Transaction decrements the available balance of its Account. This is usually the same as ‘amount`, but will differ if the amount is positive.

Returns:

  • (Integer)


65
# File 'lib/increase/models/pending_transaction.rb', line 65

required :held_amount, Integer

#idString

The Pending Transaction identifier.

Returns:

  • (String)


11
# File 'lib/increase/models/pending_transaction.rb', line 11

required :id, String

#route_idString?

The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.

Returns:

  • (String, nil)


72
# File 'lib/increase/models/pending_transaction.rb', line 72

required :route_id, String, nil?: true

#route_typeSymbol, ...

The type of the route this Pending Transaction came through.



78
# File 'lib/increase/models/pending_transaction.rb', line 78

required :route_type, enum: -> { Increase::PendingTransaction::RouteType }, nil?: true

#sourceIncrease::Models::PendingTransaction::Source

This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant’s industry and location.



86
# File 'lib/increase/models/pending_transaction.rb', line 86

required :source, -> { Increase::PendingTransaction::Source }

#statusSymbol, Increase::Models::PendingTransaction::Status

Whether the Pending Transaction has been confirmed and has an associated Transaction.



93
# File 'lib/increase/models/pending_transaction.rb', line 93

required :status, enum: -> { Increase::PendingTransaction::Status }

#typeSymbol, Increase::Models::PendingTransaction::Type

A constant representing the object’s type. For this resource it will always be ‘pending_transaction`.



100
# File 'lib/increase/models/pending_transaction.rb', line 100

required :type, enum: -> { Increase::PendingTransaction::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/pending_transaction.rb', line 148