Class: Increase::Models::PendingTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction
- Defined in:
- lib/increase/models/pending_transaction.rb
Overview
Defined Under Namespace
Modules: Currency, RouteType, Status, Type Classes: Source
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier for the account this Pending Transaction belongs to.
-
#amount ⇒ Integer
The Pending Transaction amount in the minor unit of its currency.
-
#completed_at ⇒ Time?
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date on which the Pending Transaction was completed.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date on which the Pending Transaction occurred.
-
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the Pending Transaction’s currency.
-
#description ⇒ String
For a Pending Transaction related to a transfer, this is the description you provide.
-
#held_amount ⇒ Integer
The amount that this Pending Transaction decrements the available balance of its Account.
-
#id ⇒ String
The Pending Transaction identifier.
-
#route_id ⇒ String?
The identifier for the route this Pending Transaction came through.
-
#route_type ⇒ Symbol, ...
The type of the route this Pending Transaction came through.
-
#source ⇒ Increase::Models::PendingTransaction::Source
This is an object giving more details on the network-level event that caused the Pending Transaction.
-
#status ⇒ Symbol, Increase::Models::PendingTransaction::Status
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
#type ⇒ Symbol, Increase::Models::PendingTransaction::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_number:, amount:, message_to_recipient:, routing_number:, transfer_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Source::WireTransferInstruction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number:, amount:, message_to_recipient:, routing_number:, transfer_id:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::WireTransferInstruction for more details.
A Wire Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `wire_transfer_instruction`.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 102
|
Instance Attribute Details
#account_id ⇒ String
The identifier for the account this Pending Transaction belongs to.
17 |
# File 'lib/increase/models/pending_transaction.rb', line 17 required :account_id, String |
#amount ⇒ Integer
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents. This amount does not change after the Pending Transaction is created. If a card authorization settles for a different amount, the settled amount is available on the resulting Transaction and on the Card Payment’s ‘state.settled_amount`.
27 |
# File 'lib/increase/models/pending_transaction.rb', line 27 required :amount, Integer |
#completed_at ⇒ Time?
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date on which the Pending Transaction was completed.
34 |
# File 'lib/increase/models/pending_transaction.rb', line 34 required :completed_at, Time, nil?: true |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date on which the Pending Transaction occurred.
41 |
# File 'lib/increase/models/pending_transaction.rb', line 41 required :created_at, Time |
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the Pending Transaction’s currency. This will match the currency on the Pending Transaction’s Account.
49 |
# File 'lib/increase/models/pending_transaction.rb', line 49 required :currency, enum: -> { Increase::PendingTransaction::Currency } |
#description ⇒ String
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
57 |
# File 'lib/increase/models/pending_transaction.rb', line 57 required :description, String |
#held_amount ⇒ Integer
The amount that this Pending Transaction decrements the available balance of its Account. This is usually the same as ‘amount`, but will differ if the amount is positive.
65 |
# File 'lib/increase/models/pending_transaction.rb', line 65 required :held_amount, Integer |
#id ⇒ String
The Pending Transaction identifier.
11 |
# File 'lib/increase/models/pending_transaction.rb', line 11 required :id, String |
#route_id ⇒ String?
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
72 |
# File 'lib/increase/models/pending_transaction.rb', line 72 required :route_id, String, nil?: true |
#route_type ⇒ Symbol, ...
The type of the route this Pending Transaction came through.
78 |
# File 'lib/increase/models/pending_transaction.rb', line 78 required :route_type, enum: -> { Increase::PendingTransaction::RouteType }, nil?: true |
#source ⇒ Increase::Models::PendingTransaction::Source
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant’s industry and location.
86 |
# File 'lib/increase/models/pending_transaction.rb', line 86 required :source, -> { Increase::PendingTransaction::Source } |
#status ⇒ Symbol, Increase::Models::PendingTransaction::Status
Whether the Pending Transaction has been confirmed and has an associated Transaction.
93 |
# File 'lib/increase/models/pending_transaction.rb', line 93 required :status, enum: -> { Increase::PendingTransaction::Status } |
#type ⇒ Symbol, Increase::Models::PendingTransaction::Type
A constant representing the object’s type. For this resource it will always be ‘pending_transaction`.
100 |
# File 'lib/increase/models/pending_transaction.rb', line 100 required :type, enum: -> { Increase::PendingTransaction::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 148
|