Class: Increase::Models::PendingTransaction::Source
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source
- Defined in:
- lib/increase/models/pending_transaction.rb
Overview
Defined Under Namespace
Modules: Category Classes: ACHTransferInstruction, AccountTransferInstruction, BlockchainOfframpTransfer, BlockchainOnrampTransferInstruction, CardAuthorization, CardPushTransferInstruction, CheckDepositInstruction, CheckTransferInstruction, FednowTransferInstruction, InboundFundsHold, InboundWireTransferReversal, Other, RealTimePaymentsTransferInstruction, SwiftTransferInstruction, WireTransferInstruction
Instance Attribute Summary collapse
-
#account_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::AccountTransferInstruction?
An Account Transfer Instruction object.
-
#ach_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::ACHTransferInstruction?
An ACH Transfer Instruction object.
-
#blockchain_offramp_transfer ⇒ Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer?
A Blockchain Off-Ramp Transfer object.
-
#blockchain_onramp_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::BlockchainOnrampTransferInstruction?
A Blockchain On-Ramp Transfer Instruction object.
-
#card_authorization ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization?
A Card Authorization object.
-
#card_push_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::CardPushTransferInstruction?
A Card Push Transfer Instruction object.
-
#category ⇒ Symbol, Increase::Models::PendingTransaction::Source::Category
The type of the resource.
-
#check_deposit_instruction ⇒ Increase::Models::PendingTransaction::Source::CheckDepositInstruction?
A Check Deposit Instruction object.
-
#check_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::CheckTransferInstruction?
A Check Transfer Instruction object.
-
#fednow_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::FednowTransferInstruction?
A FedNow Transfer Instruction object.
-
#inbound_funds_hold ⇒ Increase::Models::PendingTransaction::Source::InboundFundsHold?
An Inbound Funds Hold object.
-
#inbound_wire_transfer_reversal ⇒ Increase::Models::PendingTransaction::Source::InboundWireTransferReversal?
An Inbound Wire Transfer Reversal object.
-
#other ⇒ Increase::Models::PendingTransaction::Source::Other?
If the category of this Transaction source is equal to ‘other`, this field will contain an empty object, otherwise it will contain null.
-
#real_time_payments_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::RealTimePaymentsTransferInstruction?
A Real-Time Payments Transfer Instruction object.
-
#swift_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::SwiftTransferInstruction?
A Swift Transfer Instruction object.
-
#user_initiated_hold ⇒ Hash{Symbol=>Object}?
An User Initiated Hold object.
-
#wire_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::WireTransferInstruction?
A Wire Transfer Instruction object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transfer_id:) ⇒ Object
constructor
A Swift Transfer Instruction object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transfer_id:) ⇒ Object
A Swift Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_instruction`.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 334
|
Instance Attribute Details
#account_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::AccountTransferInstruction?
An Account Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `account_transfer_instruction`.
182 183 184 |
# File 'lib/increase/models/pending_transaction.rb', line 182 optional :account_transfer_instruction, -> { Increase::PendingTransaction::Source::AccountTransferInstruction }, nil?: true |
#ach_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::ACHTransferInstruction?
An ACH Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_instruction`.
191 192 193 |
# File 'lib/increase/models/pending_transaction.rb', line 191 optional :ach_transfer_instruction, -> { Increase::PendingTransaction::Source::ACHTransferInstruction }, nil?: true |
#blockchain_offramp_transfer ⇒ Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer?
A Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_offramp_transfer`. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They’re automatically created when funds land in a Blockchain Address.
202 203 204 |
# File 'lib/increase/models/pending_transaction.rb', line 202 optional :blockchain_offramp_transfer, -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer }, nil?: true |
#blockchain_onramp_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::BlockchainOnrampTransferInstruction?
A Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_onramp_transfer_instruction`.
212 213 214 |
# File 'lib/increase/models/pending_transaction.rb', line 212 optional :blockchain_onramp_transfer_instruction, -> { Increase::PendingTransaction::Source::BlockchainOnrampTransferInstruction }, nil?: true |
#card_authorization ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization?
A Card Authorization object. This field will be present in the JSON response if and only if ‘category` is equal to `card_authorization`. Card Authorizations are temporary holds placed on a customer’s funds with the intent to later clear a transaction.
223 224 225 226 227 |
# File 'lib/increase/models/pending_transaction.rb', line 223 optional :card_authorization, -> { Increase::PendingTransaction::Source::CardAuthorization }, nil?: true |
#card_push_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::CardPushTransferInstruction?
A Card Push Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `card_push_transfer_instruction`.
234 235 236 |
# File 'lib/increase/models/pending_transaction.rb', line 234 optional :card_push_transfer_instruction, -> { Increase::PendingTransaction::Source::CardPushTransferInstruction }, nil?: true |
#category ⇒ Symbol, Increase::Models::PendingTransaction::Source::Category
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
175 |
# File 'lib/increase/models/pending_transaction.rb', line 175 required :category, enum: -> { Increase::PendingTransaction::Source::Category } |
#check_deposit_instruction ⇒ Increase::Models::PendingTransaction::Source::CheckDepositInstruction?
A Check Deposit Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_instruction`.
243 244 245 |
# File 'lib/increase/models/pending_transaction.rb', line 243 optional :check_deposit_instruction, -> { Increase::PendingTransaction::Source::CheckDepositInstruction }, nil?: true |
#check_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::CheckTransferInstruction?
A Check Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `check_transfer_instruction`.
252 253 254 |
# File 'lib/increase/models/pending_transaction.rb', line 252 optional :check_transfer_instruction, -> { Increase::PendingTransaction::Source::CheckTransferInstruction }, nil?: true |
#fednow_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::FednowTransferInstruction?
A FedNow Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `fednow_transfer_instruction`.
261 262 263 |
# File 'lib/increase/models/pending_transaction.rb', line 261 optional :fednow_transfer_instruction, -> { Increase::PendingTransaction::Source::FednowTransferInstruction }, nil?: true |
#inbound_funds_hold ⇒ Increase::Models::PendingTransaction::Source::InboundFundsHold?
An Inbound Funds Hold object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_funds_hold`. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
272 273 274 275 276 |
# File 'lib/increase/models/pending_transaction.rb', line 272 optional :inbound_funds_hold, -> { Increase::PendingTransaction::Source::InboundFundsHold }, nil?: true |
#inbound_wire_transfer_reversal ⇒ Increase::Models::PendingTransaction::Source::InboundWireTransferReversal?
An Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_transfer_reversal`. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.
285 286 287 |
# File 'lib/increase/models/pending_transaction.rb', line 285 optional :inbound_wire_transfer_reversal, -> { Increase::PendingTransaction::Source::InboundWireTransferReversal }, nil?: true |
#other ⇒ Increase::Models::PendingTransaction::Source::Other?
If the category of this Transaction source is equal to ‘other`, this field will contain an empty object, otherwise it will contain null.
294 |
# File 'lib/increase/models/pending_transaction.rb', line 294 optional :other, -> { Increase::PendingTransaction::Source::Other }, nil?: true |
#real_time_payments_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::RealTimePaymentsTransferInstruction?
A Real-Time Payments Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `real_time_payments_transfer_instruction`.
302 303 304 |
# File 'lib/increase/models/pending_transaction.rb', line 302 optional :real_time_payments_transfer_instruction, -> { Increase::PendingTransaction::Source::RealTimePaymentsTransferInstruction }, nil?: true |
#swift_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::SwiftTransferInstruction?
A Swift Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_instruction`.
311 312 313 |
# File 'lib/increase/models/pending_transaction.rb', line 311 optional :swift_transfer_instruction, -> { Increase::PendingTransaction::Source::SwiftTransferInstruction }, nil?: true |
#user_initiated_hold ⇒ Hash{Symbol=>Object}?
An User Initiated Hold object. This field will be present in the JSON response if and only if ‘category` is equal to `user_initiated_hold`. Created when a user initiates a hold on funds in their account.
321 322 323 |
# File 'lib/increase/models/pending_transaction.rb', line 321 optional :user_initiated_hold, Increase::Internal::Type::HashOf[Increase::Internal::Type::Unknown], nil?: true |
#wire_transfer_instruction ⇒ Increase::Models::PendingTransaction::Source::WireTransferInstruction?
A Wire Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `wire_transfer_instruction`.
330 331 332 |
# File 'lib/increase/models/pending_transaction.rb', line 330 optional :wire_transfer_instruction, -> { Increase::PendingTransaction::Source::WireTransferInstruction }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 431
|