Class: Increase::Models::PendingTransaction::Source

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Category Classes: ACHTransferInstruction, AccountTransferInstruction, BlockchainOfframpTransferInstruction, BlockchainOnrampTransferInstruction, CardAuthorization, CardPushTransferInstruction, CheckDepositInstruction, CheckTransferInstruction, FednowTransferInstruction, InboundFundsHold, InboundWireTransferReversal, Other, RealTimePaymentsTransferInstruction, SwiftTransferInstruction, WireTransferInstruction

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transfer_id:) ⇒ Object

A Swift Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_instruction`.

Parameters:

  • transfer_id (String)

    The identifier of the Swift Transfer that led to this Pending Transaction.



# File 'lib/increase/models/pending_transaction.rb', line 333

Instance Attribute Details

#account_transfer_instructionIncrease::Models::PendingTransaction::Source::AccountTransferInstruction?

An Account Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `account_transfer_instruction`.



182
183
184
# File 'lib/increase/models/pending_transaction.rb', line 182

optional :account_transfer_instruction,
-> { Increase::PendingTransaction::Source::AccountTransferInstruction },
nil?: true

#ach_transfer_instructionIncrease::Models::PendingTransaction::Source::ACHTransferInstruction?

An ACH Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_instruction`.



191
192
193
# File 'lib/increase/models/pending_transaction.rb', line 191

optional :ach_transfer_instruction,
-> { Increase::PendingTransaction::Source::ACHTransferInstruction },
nil?: true

#blockchain_offramp_transfer_instructionIncrease::Models::PendingTransaction::Source::BlockchainOfframpTransferInstruction?

A Blockchain Off-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_offramp_transfer_instruction`.



201
202
203
# File 'lib/increase/models/pending_transaction.rb', line 201

optional :blockchain_offramp_transfer_instruction,
-> { Increase::PendingTransaction::Source::BlockchainOfframpTransferInstruction },
nil?: true

#blockchain_onramp_transfer_instructionIncrease::Models::PendingTransaction::Source::BlockchainOnrampTransferInstruction?

A Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_onramp_transfer_instruction`.



211
212
213
# File 'lib/increase/models/pending_transaction.rb', line 211

optional :blockchain_onramp_transfer_instruction,
-> { Increase::PendingTransaction::Source::BlockchainOnrampTransferInstruction },
nil?: true

#card_authorizationIncrease::Models::PendingTransaction::Source::CardAuthorization?

A Card Authorization object. This field will be present in the JSON response if and only if ‘category` is equal to `card_authorization`. Card Authorizations are temporary holds placed on a customer’s funds with the intent to later clear a transaction.



222
223
224
225
226
# File 'lib/increase/models/pending_transaction.rb', line 222

optional :card_authorization,
-> {
  Increase::PendingTransaction::Source::CardAuthorization
},
nil?: true

#card_push_transfer_instructionIncrease::Models::PendingTransaction::Source::CardPushTransferInstruction?

A Card Push Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `card_push_transfer_instruction`.



233
234
235
# File 'lib/increase/models/pending_transaction.rb', line 233

optional :card_push_transfer_instruction,
-> { Increase::PendingTransaction::Source::CardPushTransferInstruction },
nil?: true

#categorySymbol, Increase::Models::PendingTransaction::Source::Category

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.



175
# File 'lib/increase/models/pending_transaction.rb', line 175

required :category, enum: -> { Increase::PendingTransaction::Source::Category }

#check_deposit_instructionIncrease::Models::PendingTransaction::Source::CheckDepositInstruction?

A Check Deposit Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_instruction`.



242
243
244
# File 'lib/increase/models/pending_transaction.rb', line 242

optional :check_deposit_instruction,
-> { Increase::PendingTransaction::Source::CheckDepositInstruction },
nil?: true

#check_transfer_instructionIncrease::Models::PendingTransaction::Source::CheckTransferInstruction?

A Check Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `check_transfer_instruction`.



251
252
253
# File 'lib/increase/models/pending_transaction.rb', line 251

optional :check_transfer_instruction,
-> { Increase::PendingTransaction::Source::CheckTransferInstruction },
nil?: true

#fednow_transfer_instructionIncrease::Models::PendingTransaction::Source::FednowTransferInstruction?

A FedNow Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `fednow_transfer_instruction`.



260
261
262
# File 'lib/increase/models/pending_transaction.rb', line 260

optional :fednow_transfer_instruction,
-> { Increase::PendingTransaction::Source::FednowTransferInstruction },
nil?: true

#inbound_funds_holdIncrease::Models::PendingTransaction::Source::InboundFundsHold?

An Inbound Funds Hold object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_funds_hold`. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.



271
272
273
274
275
# File 'lib/increase/models/pending_transaction.rb', line 271

optional :inbound_funds_hold,
-> {
  Increase::PendingTransaction::Source::InboundFundsHold
},
nil?: true

#inbound_wire_transfer_reversalIncrease::Models::PendingTransaction::Source::InboundWireTransferReversal?

An Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_transfer_reversal`. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.



284
285
286
# File 'lib/increase/models/pending_transaction.rb', line 284

optional :inbound_wire_transfer_reversal,
-> { Increase::PendingTransaction::Source::InboundWireTransferReversal },
nil?: true

#otherIncrease::Models::PendingTransaction::Source::Other?

If the category of this Transaction source is equal to ‘other`, this field will contain an empty object, otherwise it will contain null.



293
# File 'lib/increase/models/pending_transaction.rb', line 293

optional :other, -> { Increase::PendingTransaction::Source::Other }, nil?: true

#real_time_payments_transfer_instructionIncrease::Models::PendingTransaction::Source::RealTimePaymentsTransferInstruction?

A Real-Time Payments Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `real_time_payments_transfer_instruction`.



301
302
303
# File 'lib/increase/models/pending_transaction.rb', line 301

optional :real_time_payments_transfer_instruction,
-> { Increase::PendingTransaction::Source::RealTimePaymentsTransferInstruction },
nil?: true

#swift_transfer_instructionIncrease::Models::PendingTransaction::Source::SwiftTransferInstruction?

A Swift Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_instruction`.



310
311
312
# File 'lib/increase/models/pending_transaction.rb', line 310

optional :swift_transfer_instruction,
-> { Increase::PendingTransaction::Source::SwiftTransferInstruction },
nil?: true

#user_initiated_holdHash{Symbol=>Object}?

An User Initiated Hold object. This field will be present in the JSON response if and only if ‘category` is equal to `user_initiated_hold`. Created when a user initiates a hold on funds in their account.

Returns:

  • (Hash{Symbol=>Object}, nil)


320
321
322
# File 'lib/increase/models/pending_transaction.rb', line 320

optional :user_initiated_hold,
Increase::Internal::Type::HashOf[Increase::Internal::Type::Unknown],
nil?: true

#wire_transfer_instructionIncrease::Models::PendingTransaction::Source::WireTransferInstruction?

A Wire Transfer Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `wire_transfer_instruction`.



329
330
331
# File 'lib/increase/models/pending_transaction.rb', line 329

optional :wire_transfer_instruction,
-> { Increase::PendingTransaction::Source::WireTransferInstruction },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/pending_transaction.rb', line 430