Class: Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb

Overview

Defined Under Namespace

Modules: Status, Token, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, token:, amount:, created_at:, destination_account_id:, initiating_transaction_hash:, source_blockchain_address_id:, status:, transaction_id:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer for more details.

A Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_offramp_transfer`. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They’re automatically created when funds land in a Blockchain Address.

Parameters:



# File 'lib/increase/models/pending_transaction.rb', line 574

Instance Attribute Details

#amountInteger

The transfer amount in USD cents.

Returns:

  • (Integer)


528
# File 'lib/increase/models/pending_transaction.rb', line 528

required :amount, Integer

#created_atTime

The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.

Returns:

  • (Time)


535
# File 'lib/increase/models/pending_transaction.rb', line 535

required :created_at, Time

#destination_account_idString

The Account the funds were transferred into.

Returns:

  • (String)


541
# File 'lib/increase/models/pending_transaction.rb', line 541

required :destination_account_id, String

#idString

The Blockchain Off-Ramp Transfer’s identifier.

Returns:

  • (String)


516
# File 'lib/increase/models/pending_transaction.rb', line 516

required :id, String

#initiating_transaction_hashString

The transaction hash of the blockchain transaction that initiated this transfer.

Returns:

  • (String)


547
# File 'lib/increase/models/pending_transaction.rb', line 547

required :initiating_transaction_hash, String

#source_blockchain_address_idString

The Blockchain Address from which the transfer originated.

Returns:

  • (String)


553
# File 'lib/increase/models/pending_transaction.rb', line 553

required :source_blockchain_address_id, String

#statusSymbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Status

The lifecycle status of the transfer.



559
# File 'lib/increase/models/pending_transaction.rb', line 559

required :status, enum: -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer::Status }

#tokenSymbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Token

The token that was received.



522
# File 'lib/increase/models/pending_transaction.rb', line 522

required :token, enum: -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer::Token }

#transaction_idString?

The Transaction crediting the Account once the transfer is settled.

Returns:

  • (String, nil)


565
# File 'lib/increase/models/pending_transaction.rb', line 565

required :transaction_id, String, nil?: true

#typeSymbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Type

A constant representing the object’s type. For this resource it will always be ‘blockchain_offramp_transfer`.



572
# File 'lib/increase/models/pending_transaction.rb', line 572

required :type, enum: -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/pending_transaction.rb', line 613