Class: Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer
- Defined in:
- lib/increase/models/pending_transaction.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
-
#destination_account_id ⇒ String
The Account the funds were transferred into.
-
#id ⇒ String
The Blockchain Off-Ramp Transfer’s identifier.
-
#initiating_transaction_hash ⇒ String
The transaction hash of the blockchain transaction that initiated this transfer.
-
#source_blockchain_address_id ⇒ String
The Blockchain Address from which the transfer originated.
-
#status ⇒ Symbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Status
The lifecycle status of the transfer.
-
#token ⇒ Symbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Token
The token that was received.
-
#transaction_id ⇒ String?
The Transaction crediting the Account once the transfer is settled.
-
#type ⇒ Symbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, token:, amount:, created_at:, destination_account_id:, initiating_transaction_hash:, source_blockchain_address_id:, status:, transaction_id:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BlockchainOfframpTransfer for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, token:, amount:, created_at:, destination_account_id:, initiating_transaction_hash:, source_blockchain_address_id:, status:, transaction_id:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer for more details.
A Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_offramp_transfer`. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They’re automatically created when funds land in a Blockchain Address.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 574
|
Instance Attribute Details
#amount ⇒ Integer
The transfer amount in USD cents.
528 |
# File 'lib/increase/models/pending_transaction.rb', line 528 required :amount, Integer |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
535 |
# File 'lib/increase/models/pending_transaction.rb', line 535 required :created_at, Time |
#destination_account_id ⇒ String
The Account the funds were transferred into.
541 |
# File 'lib/increase/models/pending_transaction.rb', line 541 required :destination_account_id, String |
#id ⇒ String
The Blockchain Off-Ramp Transfer’s identifier.
516 |
# File 'lib/increase/models/pending_transaction.rb', line 516 required :id, String |
#initiating_transaction_hash ⇒ String
The transaction hash of the blockchain transaction that initiated this transfer.
547 |
# File 'lib/increase/models/pending_transaction.rb', line 547 required :initiating_transaction_hash, String |
#source_blockchain_address_id ⇒ String
The Blockchain Address from which the transfer originated.
553 |
# File 'lib/increase/models/pending_transaction.rb', line 553 required :source_blockchain_address_id, String |
#status ⇒ Symbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Status
The lifecycle status of the transfer.
559 |
# File 'lib/increase/models/pending_transaction.rb', line 559 required :status, enum: -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer::Status } |
#token ⇒ Symbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Token
The token that was received.
522 |
# File 'lib/increase/models/pending_transaction.rb', line 522 required :token, enum: -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer::Token } |
#transaction_id ⇒ String?
The Transaction crediting the Account once the transfer is settled.
565 |
# File 'lib/increase/models/pending_transaction.rb', line 565 required :transaction_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::PendingTransaction::Source::BlockchainOfframpTransfer::Type
A constant representing the object’s type. For this resource it will always be ‘blockchain_offramp_transfer`.
572 |
# File 'lib/increase/models/pending_transaction.rb', line 572 required :type, enum: -> { Increase::PendingTransaction::Source::BlockchainOfframpTransfer::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 613
|