Class: Increase::Models::PendingTransaction::Source::CardAuthorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::CardAuthorization
- Defined in:
- lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs
Overview
Defined Under Namespace
Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, Healthcare, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The pending amount in the minor unit of the transaction's currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Currency
The ISO 4217 code for the transaction's currency.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#expires_at ⇒ Time
The ISO 8601 when this authorization will expire and the pending transaction will be released.
-
#healthcare ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::Healthcare?
The healthcare-related fields for this authorization.
-
#id ⇒ String
The Card Authorization identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkDetails
Fields specific to the
network. -
#network_identifiers ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#original_card_payment_id ⇒ String?
The ID of the Card Payment containing the original authorization or card validation this transaction references.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#processing_category ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#scheme_fees ⇒ Array<Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee>
The scheme fees associated with this card authorization.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#type ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Type
A constant representing the object's type.
-
#verification ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for a specific request or transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 973
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Actioner
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
768 |
# File 'lib/increase/models/pending_transaction.rb', line 768 required :actioner, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::Actioner } |
#additional_amounts ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM
surcharges fees. These are usually a subset of the amount field and are used
to provide more detailed information about the transaction.
776 777 |
# File 'lib/increase/models/pending_transaction.rb', line 776 required :additional_amounts, -> { Increase::PendingTransaction::Source::CardAuthorization::AdditionalAmounts } |
#amount ⇒ Integer
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
784 |
# File 'lib/increase/models/pending_transaction.rb', line 784 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
790 |
# File 'lib/increase/models/pending_transaction.rb', line 790 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Currency
The ISO 4217 code for the transaction's currency.
797 |
# File 'lib/increase/models/pending_transaction.rb', line 797 required :currency, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::Currency } |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
804 |
# File 'lib/increase/models/pending_transaction.rb', line 804 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
811 |
# File 'lib/increase/models/pending_transaction.rb', line 811 required :direction, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::Direction } |
#expires_at ⇒ Time
The ISO 8601 when this authorization will expire and the pending transaction will be released.
818 |
# File 'lib/increase/models/pending_transaction.rb', line 818 required :expires_at, Time |
#healthcare ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::Healthcare?
The healthcare-related fields for this authorization. Only present for specific programs.
825 826 827 |
# File 'lib/increase/models/pending_transaction.rb', line 825 required :healthcare, -> { Increase::PendingTransaction::Source::CardAuthorization::Healthcare }, nil?: true |
#id ⇒ String
The Card Authorization identifier.
761 |
# File 'lib/increase/models/pending_transaction.rb', line 761 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
834 |
# File 'lib/increase/models/pending_transaction.rb', line 834 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
841 |
# File 'lib/increase/models/pending_transaction.rb', line 841 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
847 |
# File 'lib/increase/models/pending_transaction.rb', line 847 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
853 |
# File 'lib/increase/models/pending_transaction.rb', line 853 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
859 |
# File 'lib/increase/models/pending_transaction.rb', line 859 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
866 |
# File 'lib/increase/models/pending_transaction.rb', line 866 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
872 |
# File 'lib/increase/models/pending_transaction.rb', line 872 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkDetails
Fields specific to the network.
878 |
# File 'lib/increase/models/pending_transaction.rb', line 878 required :network_details, -> { Increase::PendingTransaction::Source::CardAuthorization::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
884 885 |
# File 'lib/increase/models/pending_transaction.rb', line 884 required :network_identifiers, -> { Increase::PendingTransaction::Source::CardAuthorization::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
893 |
# File 'lib/increase/models/pending_transaction.rb', line 893 required :network_risk_score, Integer, nil?: true |
#original_card_payment_id ⇒ String?
The ID of the Card Payment containing the original authorization or card validation this transaction references. For a merchant-initiated transaction, this is the Card Payment from when the card was first stored, which is typically where the CVV2 was verified. The reference this is derived from is supplied by the merchant or their acquirer, so it is not guaranteed to be present.
903 |
# File 'lib/increase/models/pending_transaction.rb', line 903 required :original_card_payment_id, String, nil?: true |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
909 |
# File 'lib/increase/models/pending_transaction.rb', line 909 required :pending_transaction_id, String, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
916 |
# File 'lib/increase/models/pending_transaction.rb', line 916 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction's presentment currency.
922 |
# File 'lib/increase/models/pending_transaction.rb', line 922 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
929 |
# File 'lib/increase/models/pending_transaction.rb', line 929 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
936 937 |
# File 'lib/increase/models/pending_transaction.rb', line 936 required :processing_category, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::ProcessingCategory } |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
944 |
# File 'lib/increase/models/pending_transaction.rb', line 944 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee>
The scheme fees associated with this card authorization.
950 951 |
# File 'lib/increase/models/pending_transaction.rb', line 950 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::PendingTransaction::Source::CardAuthorization::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
958 |
# File 'lib/increase/models/pending_transaction.rb', line 958 required :terminal_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::Type
A constant representing the object's type. For this resource it will always be
card_authorization.
965 |
# File 'lib/increase/models/pending_transaction.rb', line 965 required :type, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::Type } |
#verification ⇒ Increase::Models::PendingTransaction::Source::CardAuthorization::Verification
Fields related to verification of cardholder-provided values.
971 |
# File 'lib/increase/models/pending_transaction.rb', line 971 required :verification, -> { Increase::PendingTransaction::Source::CardAuthorization::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 1106
|
Instance Method Details
#to_hash ⇒ {
581 |
# File 'sig/increase/models/pending_transaction.rbs', line 581
def to_hash: -> {
|