Class: Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa
- Defined in:
- lib/increase/models/pending_transaction.rb
Overview
Defined Under Namespace
Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability
Instance Attribute Summary collapse
-
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer’s payment credential.
-
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder’s primary account number and card expiration date.
-
#stand_in_processing_reason ⇒ Symbol, ...
Only present when ‘actioner: network`.
-
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Visa for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa for more details.
Fields specific to the ‘visa` network.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 1420
|
Instance Attribute Details
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer’s payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
1378 1379 1380 1381 1382 |
# File 'lib/increase/models/pending_transaction.rb', line 1378 required :electronic_commerce_indicator, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa::ElectronicCommerceIndicator }, nil?: true |
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder’s primary account number and card expiration date.
1389 1390 1391 1392 1393 |
# File 'lib/increase/models/pending_transaction.rb', line 1389 required :point_of_service_entry_mode, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa::PointOfServiceEntryMode }, nil?: true |
#stand_in_processing_reason ⇒ Symbol, ...
Only present when ‘actioner: network`. Describes why a card authorization was approved or declined by Visa through stand-in processing.
1400 1401 1402 1403 1404 |
# File 'lib/increase/models/pending_transaction.rb', line 1400 required :stand_in_processing_reason, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa::StandInProcessingReason }, nil?: true |
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
1414 1415 1416 1417 1418 |
# File 'lib/increase/models/pending_transaction.rb', line 1414 required :terminal_entry_capability, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::NetworkDetails::Visa::TerminalEntryCapability }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 1468
|