Class: Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee
- Defined in:
- lib/increase/models/pending_transaction.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ String
The fee amount given as a string containing a decimal number.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the fee was created.
-
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fee reimbursement.
-
#fee_type ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::FeeType
The type of fee being assessed.
-
#fixed_component ⇒ String?
The fixed component of the fee, if applicable, given in major units of the fee amount.
-
#variable_rate ⇒ String?
The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, created_at:, currency:, fee_type:, fixed_component:, variable_rate:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SchemeFee for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, created_at:, currency:, fee_type:, fixed_component:, variable_rate:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee for more details.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 1721
|
Instance Attribute Details
#amount ⇒ String
The fee amount given as a string containing a decimal number.
1683 |
# File 'lib/increase/models/pending_transaction.rb', line 1683 required :amount, String |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the fee was created.
1690 |
# File 'lib/increase/models/pending_transaction.rb', line 1690 required :created_at, Time |
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fee reimbursement.
1697 1698 |
# File 'lib/increase/models/pending_transaction.rb', line 1697 required :currency, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::SchemeFee::Currency } |
#fee_type ⇒ Symbol, Increase::Models::PendingTransaction::Source::CardAuthorization::SchemeFee::FeeType
The type of fee being assessed.
1704 1705 |
# File 'lib/increase/models/pending_transaction.rb', line 1704 required :fee_type, enum: -> { Increase::PendingTransaction::Source::CardAuthorization::SchemeFee::FeeType } |
#fixed_component ⇒ String?
The fixed component of the fee, if applicable, given in major units of the fee amount.
1712 |
# File 'lib/increase/models/pending_transaction.rb', line 1712 required :fixed_component, String, nil?: true |
#variable_rate ⇒ String?
The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).
1719 |
# File 'lib/increase/models/pending_transaction.rb', line 1719 required :variable_rate, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 1748
|