Module: Increase::Models::PendingTransaction::Source::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs
Overview
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
Constant Summary collapse
- ACCOUNT_TRANSFER_INSTRUCTION =
Account Transfer Instruction: details will be under the
account_transfer_instructionobject. :account_transfer_instruction- ACH_TRANSFER_INSTRUCTION =
ACH Transfer Instruction: details will be under the
ach_transfer_instructionobject. :ach_transfer_instruction- CARD_AUTHORIZATION =
Card Authorization: details will be under the
card_authorizationobject. :card_authorization- CHECK_DEPOSIT_INSTRUCTION =
Check Deposit Instruction: details will be under the
check_deposit_instructionobject. :check_deposit_instruction- CHECK_TRANSFER_INSTRUCTION =
Check Transfer Instruction: details will be under the
check_transfer_instructionobject. :check_transfer_instruction- FEDNOW_TRANSFER_INSTRUCTION =
FedNow Transfer Instruction: details will be under the
fednow_transfer_instructionobject. :fednow_transfer_instruction- INBOUND_FUNDS_HOLD =
Inbound Funds Hold: details will be under the
inbound_funds_holdobject. :inbound_funds_hold- USER_INITIATED_HOLD =
User Initiated Hold: details will be under the
user_initiated_holdobject. :user_initiated_hold- REAL_TIME_PAYMENTS_TRANSFER_INSTRUCTION =
Real-Time Payments Transfer Instruction: details will be under the
real_time_payments_transfer_instructionobject. :real_time_payments_transfer_instruction- WIRE_TRANSFER_INSTRUCTION =
Wire Transfer Instruction: details will be under the
wire_transfer_instructionobject. :wire_transfer_instruction- INBOUND_WIRE_TRANSFER_REVERSAL =
Inbound Wire Transfer Reversal: details will be under the
inbound_wire_transfer_reversalobject. :inbound_wire_transfer_reversal- SWIFT_TRANSFER_INSTRUCTION =
Swift Transfer Instruction: details will be under the
swift_transfer_instructionobject. :swift_transfer_instruction- CARD_PUSH_TRANSFER_INSTRUCTION =
Card Push Transfer Instruction: details will be under the
card_push_transfer_instructionobject. :card_push_transfer_instruction- BLOCKCHAIN_ONRAMP_TRANSFER_INSTRUCTION =
Blockchain On-Ramp Transfer Instruction: details will be under the
blockchain_onramp_transfer_instructionobject. :blockchain_onramp_transfer_instruction- BLOCKCHAIN_OFFRAMP_TRANSFER =
Blockchain Off-Ramp Transfer: details will be under the
blockchain_offramp_transferobject. :blockchain_offramp_transfer- OTHER =
The Pending Transaction was made for an undocumented or deprecated reason.
:other
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::PendingTransaction::Source::category]
272 |
# File 'sig/increase/models/pending_transaction.rbs', line 272
def self?.values: -> ::Array[Increase::Models::PendingTransaction::Source::category]
|