Class: Increase::Models::PendingTransaction::Source::CheckDepositInstruction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs

Overview

See Also:

  • Increase::Models::PendingTransaction::Source#check_deposit_instruction

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, back_image_file_id:, check_deposit_id:, currency:, front_image_file_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::CheckDepositInstruction for more details.

A Check Deposit Instruction object. This field will be present in the JSON response if and only if category is equal to check_deposit_instruction.

Parameters:

  • amount (Integer)

    The pending amount in USD cents.

  • back_image_file_id (String, nil)

    The identifier of the File containing the image of the back of the check that wa

  • check_deposit_id (String, nil)

    The identifier of the Check Deposit.

  • currency (Symbol, Increase::Models::PendingTransaction::Source::CheckDepositInstruction::Currency)

    The ISO 4217 code for the transaction'

  • front_image_file_id (String)

    The identifier of the File containing the image of the front of the check that w



# File 'lib/increase/models/pending_transaction.rb', line 2282

Instance Attribute Details

#amountInteger

The pending amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


2253
# File 'lib/increase/models/pending_transaction.rb', line 2253

required :amount, Integer

#back_image_file_idString?

The identifier of the File containing the image of the back of the check that was deposited.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2260
# File 'lib/increase/models/pending_transaction.rb', line 2260

required :back_image_file_id, String, nil?: true

#check_deposit_idString?

The identifier of the Check Deposit.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2266
# File 'lib/increase/models/pending_transaction.rb', line 2266

required :check_deposit_id, String, nil?: true

#currencySymbol, Increase::Models::PendingTransaction::Source::CheckDepositInstruction::Currency

The ISO 4217 code for the transaction's currency.

Parameters:

  • value (Increase::Models::PendingTransaction::Source::CheckDepositInstruction::currency)

Returns:



2273
# File 'lib/increase/models/pending_transaction.rb', line 2273

required :currency, enum: -> { Increase::PendingTransaction::Source::CheckDepositInstruction::Currency }

#front_image_file_idString

The identifier of the File containing the image of the front of the check that was deposited.

Parameters:

  • value (String)

Returns:

  • (String)


2280
# File 'lib/increase/models/pending_transaction.rb', line 2280

required :front_image_file_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


1584
# File 'sig/increase/models/pending_transaction.rbs', line 1584

def to_hash: -> {