Class: Increase::Models::PendingTransaction::Source::CheckDepositInstruction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/pending_transaction.rb

Overview

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, back_image_file_id:, check_deposit_id:, currency:, front_image_file_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::CheckDepositInstruction for more details.

A Check Deposit Instruction object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_instruction`.

Parameters:



# File 'lib/increase/models/pending_transaction.rb', line 2113

Instance Attribute Details

#amountInteger

The pending amount in USD cents.

Returns:

  • (Integer)


2084
# File 'lib/increase/models/pending_transaction.rb', line 2084

required :amount, Integer

#back_image_file_idString?

The identifier of the File containing the image of the back of the check that was deposited.

Returns:

  • (String, nil)


2091
# File 'lib/increase/models/pending_transaction.rb', line 2091

required :back_image_file_id, String, nil?: true

#check_deposit_idString?

The identifier of the Check Deposit.

Returns:

  • (String, nil)


2097
# File 'lib/increase/models/pending_transaction.rb', line 2097

required :check_deposit_id, String, nil?: true

#currencySymbol, Increase::Models::PendingTransaction::Source::CheckDepositInstruction::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s currency.



2104
# File 'lib/increase/models/pending_transaction.rb', line 2104

required :currency, enum: -> { Increase::PendingTransaction::Source::CheckDepositInstruction::Currency }

#front_image_file_idString

The identifier of the File containing the image of the front of the check that was deposited.

Returns:

  • (String)


2111
# File 'lib/increase/models/pending_transaction.rb', line 2111

required :front_image_file_id, String