Class: Increase::Models::PendingTransaction::Source::InboundFundsHold
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PendingTransaction::Source::InboundFundsHold
- Defined in:
- lib/increase/models/pending_transaction.rb
Overview
Defined Under Namespace
Modules: Currency, Status, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The held amount in the minor unit of the account’s currency.
-
#automatically_releases_at ⇒ Time
When the hold will be released automatically.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the hold was created.
-
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the hold’s currency.
-
#held_transaction_id ⇒ String?
The ID of the Transaction for which funds were held.
-
#pending_transaction_id ⇒ String?
The ID of the Pending Transaction representing the held funds.
-
#released_at ⇒ Time?
When the hold was released (if it has been released).
-
#status ⇒ Symbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Status
The status of the hold.
-
#type ⇒ Symbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see InboundFundsHold for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, automatically_releases_at:, created_at:, currency:, held_transaction_id:, pending_transaction_id:, released_at:, status:, type:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransaction::Source::InboundFundsHold for more details.
An Inbound Funds Hold object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_funds_hold`. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
|
|
# File 'lib/increase/models/pending_transaction.rb', line 2272
|
Instance Attribute Details
#amount ⇒ Integer
The held amount in the minor unit of the account’s currency. For dollars, for example, this is cents.
2218 |
# File 'lib/increase/models/pending_transaction.rb', line 2218 required :amount, Integer |
#automatically_releases_at ⇒ Time
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
2225 |
# File 'lib/increase/models/pending_transaction.rb', line 2225 required :automatically_releases_at, Time |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the hold was created.
2232 |
# File 'lib/increase/models/pending_transaction.rb', line 2232 required :created_at, Time |
#currency ⇒ Symbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the hold’s currency.
2239 |
# File 'lib/increase/models/pending_transaction.rb', line 2239 required :currency, enum: -> { Increase::PendingTransaction::Source::InboundFundsHold::Currency } |
#held_transaction_id ⇒ String?
The ID of the Transaction for which funds were held.
2245 |
# File 'lib/increase/models/pending_transaction.rb', line 2245 required :held_transaction_id, String, nil?: true |
#pending_transaction_id ⇒ String?
The ID of the Pending Transaction representing the held funds.
2251 |
# File 'lib/increase/models/pending_transaction.rb', line 2251 required :pending_transaction_id, String, nil?: true |
#released_at ⇒ Time?
When the hold was released (if it has been released).
2257 |
# File 'lib/increase/models/pending_transaction.rb', line 2257 required :released_at, Time, nil?: true |
#status ⇒ Symbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Status
The status of the hold.
2263 |
# File 'lib/increase/models/pending_transaction.rb', line 2263 required :status, enum: -> { Increase::PendingTransaction::Source::InboundFundsHold::Status } |
#type ⇒ Symbol, Increase::Models::PendingTransaction::Source::InboundFundsHold::Type
A constant representing the object’s type. For this resource it will always be ‘inbound_funds_hold`.
2270 |
# File 'lib/increase/models/pending_transaction.rb', line 2270 required :type, enum: -> { Increase::PendingTransaction::Source::InboundFundsHold::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction.rb', line 2310
|