Module: Increase::Models::PendingTransaction::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/pending_transaction.rb,
sig/increase/models/pending_transaction.rbs
Overview
Whether the Pending Transaction has been confirmed and has an associated Transaction.
Constant Summary collapse
- PENDING =
The Pending Transaction is still awaiting confirmation.
:pending- COMPLETE =
The Pending Transaction is confirmed. An associated Transaction exists for this object. The Pending Transaction will no longer count against your balance and can generally be hidden from UIs, etc. The Pending Transaction's
amountis not updated if the associated Transaction settles for a different amount. :complete
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::PendingTransaction::status]
1835 |
# File 'sig/increase/models/pending_transaction.rbs', line 1835
def self?.values: -> ::Array[Increase::Models::PendingTransaction::status]
|