Module: Increase::Models::PendingTransactionListParams::Status::In
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/pending_transaction_list_params.rb
Constant Summary collapse
- PENDING =
The Pending Transaction is still awaiting confirmation.
:pending- COMPLETE =
The Pending Transaction is confirmed. An associated Transaction exists for this object. The Pending Transaction will no longer count against your balance and can generally be hidden from UIs, etc.
:complete
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(in_: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransactionListParams::Status for more details.
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/pending_transaction_list_params.rb', line 215
|
Instance Method Details
#initialize(in_: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::PendingTransactionListParams::Status for more details.
206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/increase/models/pending_transaction_list_params.rb', line 206 module In extend Increase::Internal::Type::Enum # The Pending Transaction is still awaiting confirmation. PENDING = :pending # The Pending Transaction is confirmed. An associated Transaction exists for this object. The Pending Transaction will no longer count against your balance and can generally be hidden from UIs, etc. COMPLETE = :complete # @!method self.values # @return [Array<Symbol>] end |