Class: Increase::Models::PhysicalCard::Shipment::Tracking
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PhysicalCard::Shipment::Tracking
- Defined in:
- lib/increase/models/physical_card.rb,
sig/increase/models/physical_card.rbs
Overview
Defined Under Namespace
Classes: Update
Instance Attribute Summary collapse
-
#number ⇒ String?
The tracking number.
-
#return_number ⇒ String?
For returned shipments, the tracking number of the return shipment.
-
#return_reason ⇒ String?
For returned shipments, this describes why the package was returned.
-
#shipped_at ⇒ Time
The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier.
-
#updates ⇒ Array<Increase::Models::PhysicalCard::Shipment::Tracking::Update>
Tracking updates relating to the physical card's delivery.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
257 |
# File 'sig/increase/models/physical_card.rbs', line 257
def initialize: (
|
Instance Attribute Details
#number ⇒ String?
The tracking number. Not available for USPS shipments.
319 |
# File 'lib/increase/models/physical_card.rb', line 319 required :number, String, nil?: true |
#return_number ⇒ String?
For returned shipments, the tracking number of the return shipment.
325 |
# File 'lib/increase/models/physical_card.rb', line 325 required :return_number, String, nil?: true |
#return_reason ⇒ String?
For returned shipments, this describes why the package was returned.
331 |
# File 'lib/increase/models/physical_card.rb', line 331 required :return_reason, String, nil?: true |
#shipped_at ⇒ Time
The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier.
339 |
# File 'lib/increase/models/physical_card.rb', line 339 required :shipped_at, Time |
#updates ⇒ Array<Increase::Models::PhysicalCard::Shipment::Tracking::Update>
Tracking updates relating to the physical card's delivery.
345 346 |
# File 'lib/increase/models/physical_card.rb', line 345 required :updates, -> { Increase::Internal::Type::ArrayOf[Increase::PhysicalCard::Shipment::Tracking::Update] } |
Instance Method Details
#to_hash ⇒ {
265 |
# File 'sig/increase/models/physical_card.rbs', line 265
def to_hash: -> {
|