Class: Increase::Models::PhysicalCardCreateParams::Cardholder

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/physical_card_create_params.rb,
sig/increase/models/physical_card_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(card_id:, cardholder:, shipment:, physical_card_profile_id: nil, request_options: {}) ⇒ Cardholder

Returns a new instance of Cardholder.

Parameters:

  • card_id (String)

    The underlying card representing this physical card.

  • cardholder (Increase::Models::PhysicalCardCreateParams::Cardholder)

    Details about the cardholder, as it will appear on the physical card. The combined first name and last name cannot exceed 25 characters.

  • shipment (Increase::Models::PhysicalCardCreateParams::Shipment)

    The details used to ship this physical card.

  • physical_card_profile_id (String) (defaults to: nil)

    The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})
  • first_name: (String)
  • last_name: (String)


52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/increase/models/physical_card_create_params.rb', line 52

class Cardholder < Increase::Internal::Type::BaseModel
  # @!attribute first_name
  #   The cardholder's first name.
  #
  #   @return [String]
  required :first_name, String

  # @!attribute last_name
  #   The cardholder's last name.
  #
  #   @return [String]
  required :last_name, String

  # @!method initialize(first_name:, last_name:)
  #   Details about the cardholder, as it will appear on the physical card. The
  #   combined first name and last name cannot exceed 25 characters.
  #
  #   @param first_name [String] The cardholder's first name.
  #
  #   @param last_name [String] The cardholder's last name.
end

Instance Attribute Details

#first_nameString

The cardholder's first name.

Parameters:

  • value (String)

Returns:

  • (String)


57
# File 'lib/increase/models/physical_card_create_params.rb', line 57

required :first_name, String

#last_nameString

The cardholder's last name.

Parameters:

  • value (String)

Returns:

  • (String)


63
# File 'lib/increase/models/physical_card_create_params.rb', line 63

required :last_name, String

Instance Method Details

#to_hash{ first_name: String, last_name: String }

Returns:

  • ({ first_name: String, last_name: String })


51
# File 'sig/increase/models/physical_card_create_params.rbs', line 51

def to_hash: -> { first_name: String, last_name: String }