Class: Increase::Models::PhysicalCardProfileListParams::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::PhysicalCardProfileListParams::Status
- Defined in:
- lib/increase/models/physical_card_profile_list_params.rb,
sig/increase/models/physical_card_profile_list_params.rbs
Defined Under Namespace
Modules: In
Instance Attribute Summary collapse
-
#in_ ⇒ Array<Symbol, Increase::Models::PhysicalCardProfileListParams::Status::In>?
Filter Physical Card Profiles for those with the specified statuses.
Instance Method Summary collapse
- #initialize(cursor: nil, idempotency_key: nil, limit: nil, status: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor: nil, idempotency_key: nil, limit: nil, status: nil, request_options: {}) ⇒ Object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/increase/models/physical_card_profile_list_params.rb', line 54 class Status < Increase::Internal::Type::BaseModel # @!attribute in_ # Filter Physical Card Profiles for those with the specified statuses. For GET # requests, this should be encoded as a comma-delimited string, such as # `?in=one,two,three`. # # @return [Array<Symbol, Increase::Models::PhysicalCardProfileListParams::Status::In>, nil] optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::PhysicalCardProfileListParams::Status::In] }, api_name: :in # @!method initialize(in_: nil) # @param in_ [Array<Symbol, Increase::Models::PhysicalCardProfileListParams::Status::In>] # Filter Physical Card Profiles for those with the specified statuses. For GET # requests, this should be encoded as a comma-delimited string, such as # `?in=one,two,three`. module In extend Increase::Internal::Type::Enum # The Card Profile has not yet been processed by Increase. PENDING_CREATING = :pending_creating # The card profile is awaiting review by Increase. PENDING_REVIEWING = :pending_reviewing # There is an issue with the Physical Card Profile preventing it from use. REJECTED = :rejected # The card profile is awaiting submission to the fulfillment provider. PENDING_SUBMITTING = :pending_submitting # The Physical Card Profile has been submitted to the fulfillment provider and is ready to use. ACTIVE = :active # The Physical Card Profile has been archived. ARCHIVED = :archived # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#in_ ⇒ Array<Symbol, Increase::Models::PhysicalCardProfileListParams::Status::In>?
Filter Physical Card Profiles for those with the specified statuses. For GET
requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
61 62 63 64 65 |
# File 'lib/increase/models/physical_card_profile_list_params.rb', line 61 optional :in_, -> { Increase::Internal::Type::ArrayOf[enum: Increase::PhysicalCardProfileListParams::Status::In] }, api_name: :in |
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/increase/models/physical_card_profile_list_params.rbs', line 66
def to_hash: -> {
|