Class: Increase::Models::Program
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Program
- Defined in:
- lib/increase/models/program.rb
Overview
Defined Under Namespace
Modules: Bank, Type Classes: Lending
Instance Attribute Summary collapse
-
#bank ⇒ Symbol, Increase::Models::Program::Bank
The Bank the Program is with.
-
#billing_account_id ⇒ String?
The Program billing account.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Program was created.
-
#default_digital_card_profile_id ⇒ String?
The default configuration for digital cards attached to this Program.
-
#id ⇒ String
The Program identifier.
-
#interest_rate ⇒ String
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number.
-
#lending ⇒ Increase::Models::Program::Lending?
The lending details for the program.
-
#name ⇒ String
The name of the Program.
-
#type ⇒ Symbol, Increase::Models::Program::Type
A constant representing the object’s type.
-
#updated_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Program was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(maximum_extendable_credit:) ⇒ Object
constructor
The lending details for the program.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(maximum_extendable_credit:) ⇒ Object
The lending details for the program.
|
|
# File 'lib/increase/models/program.rb', line 72
|
Instance Attribute Details
#bank ⇒ Symbol, Increase::Models::Program::Bank
The Bank the Program is with.
17 |
# File 'lib/increase/models/program.rb', line 17 required :bank, enum: -> { Increase::Program::Bank } |
#billing_account_id ⇒ String?
The Program billing account.
23 |
# File 'lib/increase/models/program.rb', line 23 required :billing_account_id, String, nil?: true |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Program was created.
30 |
# File 'lib/increase/models/program.rb', line 30 required :created_at, Time |
#default_digital_card_profile_id ⇒ String?
The default configuration for digital cards attached to this Program.
36 |
# File 'lib/increase/models/program.rb', line 36 required :default_digital_card_profile_id, String, nil?: true |
#id ⇒ String
The Program identifier.
11 |
# File 'lib/increase/models/program.rb', line 11 required :id, String |
#interest_rate ⇒ String
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as “0.01”.
44 |
# File 'lib/increase/models/program.rb', line 44 required :interest_rate, String |
#lending ⇒ Increase::Models::Program::Lending?
The lending details for the program.
50 |
# File 'lib/increase/models/program.rb', line 50 required :lending, -> { Increase::Program::Lending }, nil?: true |
#name ⇒ String
The name of the Program.
56 |
# File 'lib/increase/models/program.rb', line 56 required :name, String |
#type ⇒ Symbol, Increase::Models::Program::Type
A constant representing the object’s type. For this resource it will always be program.
63 |
# File 'lib/increase/models/program.rb', line 63 required :type, enum: -> { Increase::Program::Type } |
#updated_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) time at which the Program was last updated.
70 |
# File 'lib/increase/models/program.rb', line 70 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/program.rb', line 116
|