Class: Increase::Models::RealTimeDecision::CardAuthenticationChallenge

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb

Overview

Defined Under Namespace

Modules: Result

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, card_id:, card_payment_id:, one_time_code:, result:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::RealTimeDecision::CardAuthenticationChallenge for more details.

Fields related to a 3DS authentication attempt.

Parameters:

  • account_id (String)

    The identifier of the Account the card belongs to.

  • card_id (String)

    The identifier of the Card that is being tokenized.

  • card_payment_id (String)

    The identifier of the Card Payment this authentication challenge attempt belongs

  • one_time_code (String)

    The one-time code delivered to the cardholder.

  • result (Symbol, Increase::Models::RealTimeDecision::CardAuthenticationChallenge::Result, nil)

    Whether or not the challenge was delivered to the cardholder.



# File 'lib/increase/models/real_time_decision.rb', line 880

Instance Attribute Details

#account_idString

The identifier of the Account the card belongs to.

Returns:

  • (String)


849
# File 'lib/increase/models/real_time_decision.rb', line 849

required :account_id, String

#card_idString

The identifier of the Card that is being tokenized.

Returns:

  • (String)


855
# File 'lib/increase/models/real_time_decision.rb', line 855

required :card_id, String

#card_payment_idString

The identifier of the Card Payment this authentication challenge attempt belongs to.

Returns:

  • (String)


862
# File 'lib/increase/models/real_time_decision.rb', line 862

required :card_payment_id, String

#one_time_codeString

The one-time code delivered to the cardholder.

Returns:

  • (String)


868
# File 'lib/increase/models/real_time_decision.rb', line 868

required :one_time_code, String

#resultSymbol, ...

Whether or not the challenge was delivered to the cardholder.



874
875
876
877
878
# File 'lib/increase/models/real_time_decision.rb', line 874

required :result,
enum: -> {
  Increase::RealTimeDecision::CardAuthenticationChallenge::Result
},
nil?: true