Class: Increase::Models::RealTimeDecision::CardAuthorization
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::CardAuthorization
- Defined in:
- lib/increase/models/real_time_decision.rb
Overview
Defined Under Namespace
Modules: Decision, Direction, PartialApprovalCapability, ProcessingCategory Classes: AdditionalAmounts, Approval, Decline, NetworkDetails, NetworkIdentifiers, RequestDetails, Verification
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier of the Account the authorization will debit.
-
#additional_amounts ⇒ Increase::Models::RealTimeDecision::CardAuthorization::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#approval ⇒ Increase::Models::RealTimeDecision::CardAuthorization::Approval?
Present if and only if ‘decision` is `approve`.
-
#card_id ⇒ String
The identifier of the Card that is being authorized.
-
#decision ⇒ Symbol, ...
Whether or not the authorization was approved.
-
#decline ⇒ Increase::Models::RealTimeDecision::CardAuthorization::Decline?
Present if and only if ‘decision` is `decline`.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::RealTimeDecision::CardAuthorization::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::RealTimeDecision::CardAuthorization::NetworkDetails
Fields specific to the ‘network`.
-
#network_identifiers ⇒ Increase::Models::RealTimeDecision::CardAuthorization::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#partial_approval_capability ⇒ Symbol, Increase::Models::RealTimeDecision::CardAuthorization::PartialApprovalCapability
Whether or not the authorization supports partial approvals.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the currency the user sees at the time of purchase.
-
#processing_category ⇒ Symbol, Increase::Models::RealTimeDecision::CardAuthorization::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#request_details ⇒ Increase::Models::RealTimeDecision::CardAuthorization::RequestDetails
Fields specific to the type of request, such as an incremental authorization.
-
#settlement_amount ⇒ Integer
The amount of the attempted authorization in the currency it will be settled in.
-
#settlement_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the currency the transaction will be settled in.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#upcoming_card_payment_id ⇒ String
The identifier of the Card Payment this authorization will belong to.
-
#verification ⇒ Increase::Models::RealTimeDecision::CardAuthorization::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize ⇒ Object
constructor
Fields specific to the category ‘initial_authorization`.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
Fields specific to the category ‘initial_authorization`.
|
|
# File 'lib/increase/models/real_time_decision.rb', line 1112
|
Instance Attribute Details
#account_id ⇒ String
The identifier of the Account the authorization will debit.
920 |
# File 'lib/increase/models/real_time_decision.rb', line 920 required :account_id, String |
#additional_amounts ⇒ Increase::Models::RealTimeDecision::CardAuthorization::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.
928 |
# File 'lib/increase/models/real_time_decision.rb', line 928 required :additional_amounts, -> { Increase::RealTimeDecision::CardAuthorization::AdditionalAmounts } |
#approval ⇒ Increase::Models::RealTimeDecision::CardAuthorization::Approval?
Present if and only if ‘decision` is `approve`. Contains information related to the approval of the authorization.
935 |
# File 'lib/increase/models/real_time_decision.rb', line 935 required :approval, -> { Increase::RealTimeDecision::CardAuthorization::Approval }, nil?: true |
#card_id ⇒ String
The identifier of the Card that is being authorized.
941 |
# File 'lib/increase/models/real_time_decision.rb', line 941 required :card_id, String |
#decision ⇒ Symbol, ...
Whether or not the authorization was approved.
947 |
# File 'lib/increase/models/real_time_decision.rb', line 947 required :decision, enum: -> { Increase::RealTimeDecision::CardAuthorization::Decision }, nil?: true |
#decline ⇒ Increase::Models::RealTimeDecision::CardAuthorization::Decline?
Present if and only if ‘decision` is `decline`. Contains information related to the reason the authorization was declined.
954 |
# File 'lib/increase/models/real_time_decision.rb', line 954 required :decline, -> { Increase::RealTimeDecision::CardAuthorization::Decline }, nil?: true |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
961 |
# File 'lib/increase/models/real_time_decision.rb', line 961 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::RealTimeDecision::CardAuthorization::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
968 |
# File 'lib/increase/models/real_time_decision.rb', line 968 required :direction, enum: -> { Increase::RealTimeDecision::CardAuthorization::Direction } |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
975 |
# File 'lib/increase/models/real_time_decision.rb', line 975 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
982 |
# File 'lib/increase/models/real_time_decision.rb', line 982 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
988 |
# File 'lib/increase/models/real_time_decision.rb', line 988 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
994 |
# File 'lib/increase/models/real_time_decision.rb', line 994 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
1000 |
# File 'lib/increase/models/real_time_decision.rb', line 1000 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
1007 |
# File 'lib/increase/models/real_time_decision.rb', line 1007 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
1013 |
# File 'lib/increase/models/real_time_decision.rb', line 1013 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::RealTimeDecision::CardAuthorization::NetworkDetails
Fields specific to the ‘network`.
1019 |
# File 'lib/increase/models/real_time_decision.rb', line 1019 required :network_details, -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::RealTimeDecision::CardAuthorization::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
1025 |
# File 'lib/increase/models/real_time_decision.rb', line 1025 required :network_identifiers, -> { Increase::RealTimeDecision::CardAuthorization::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
1033 |
# File 'lib/increase/models/real_time_decision.rb', line 1033 required :network_risk_score, Integer, nil?: true |
#partial_approval_capability ⇒ Symbol, Increase::Models::RealTimeDecision::CardAuthorization::PartialApprovalCapability
Whether or not the authorization supports partial approvals.
1039 1040 |
# File 'lib/increase/models/real_time_decision.rb', line 1039 required :partial_approval_capability, enum: -> { Increase::RealTimeDecision::CardAuthorization::PartialApprovalCapability } |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
1047 |
# File 'lib/increase/models/real_time_decision.rb', line 1047 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.
1055 |
# File 'lib/increase/models/real_time_decision.rb', line 1055 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the currency the user sees at the time of purchase.
1062 |
# File 'lib/increase/models/real_time_decision.rb', line 1062 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::RealTimeDecision::CardAuthorization::ProcessingCategory
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
1069 1070 |
# File 'lib/increase/models/real_time_decision.rb', line 1069 required :processing_category, enum: -> { Increase::RealTimeDecision::CardAuthorization::ProcessingCategory } |
#request_details ⇒ Increase::Models::RealTimeDecision::CardAuthorization::RequestDetails
Fields specific to the type of request, such as an incremental authorization.
1076 |
# File 'lib/increase/models/real_time_decision.rb', line 1076 required :request_details, -> { Increase::RealTimeDecision::CardAuthorization::RequestDetails } |
#settlement_amount ⇒ Integer
The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.
1083 |
# File 'lib/increase/models/real_time_decision.rb', line 1083 required :settlement_amount, Integer |
#settlement_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the currency the transaction will be settled in.
1090 |
# File 'lib/increase/models/real_time_decision.rb', line 1090 required :settlement_currency, String |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
1097 |
# File 'lib/increase/models/real_time_decision.rb', line 1097 required :terminal_id, String, nil?: true |
#upcoming_card_payment_id ⇒ String
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
1104 |
# File 'lib/increase/models/real_time_decision.rb', line 1104 required :upcoming_card_payment_id, String |
#verification ⇒ Increase::Models::RealTimeDecision::CardAuthorization::Verification
Fields related to verification of cardholder-provided values.
1110 |
# File 'lib/increase/models/real_time_decision.rb', line 1110 required :verification, -> { Increase::RealTimeDecision::CardAuthorization::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_decision.rb', line 1610
|