Class: Increase::Models::RealTimeDecision::CardAuthorization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb

Overview

Defined Under Namespace

Modules: Decision, Direction, PartialApprovalCapability, ProcessingCategory Classes: AdditionalAmounts, Approval, Decline, NetworkDetails, NetworkIdentifiers, RequestDetails, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Fields specific to the category ‘initial_authorization`.



# File 'lib/increase/models/real_time_decision.rb', line 1112

Instance Attribute Details

#account_idString

The identifier of the Account the authorization will debit.

Returns:

  • (String)


920
# File 'lib/increase/models/real_time_decision.rb', line 920

required :account_id, String

#additional_amountsIncrease::Models::RealTimeDecision::CardAuthorization::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.



928
# File 'lib/increase/models/real_time_decision.rb', line 928

required :additional_amounts, -> { Increase::RealTimeDecision::CardAuthorization::AdditionalAmounts }

#approvalIncrease::Models::RealTimeDecision::CardAuthorization::Approval?

Present if and only if ‘decision` is `approve`. Contains information related to the approval of the authorization.



935
# File 'lib/increase/models/real_time_decision.rb', line 935

required :approval, -> { Increase::RealTimeDecision::CardAuthorization::Approval }, nil?: true

#card_idString

The identifier of the Card that is being authorized.

Returns:

  • (String)


941
# File 'lib/increase/models/real_time_decision.rb', line 941

required :card_id, String

#decisionSymbol, ...

Whether or not the authorization was approved.



947
# File 'lib/increase/models/real_time_decision.rb', line 947

required :decision, enum: -> { Increase::RealTimeDecision::CardAuthorization::Decision }, nil?: true

#declineIncrease::Models::RealTimeDecision::CardAuthorization::Decline?

Present if and only if ‘decision` is `decline`. Contains information related to the reason the authorization was declined.



954
# File 'lib/increase/models/real_time_decision.rb', line 954

required :decline, -> { Increase::RealTimeDecision::CardAuthorization::Decline }, nil?: true

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Returns:

  • (String, nil)


961
# File 'lib/increase/models/real_time_decision.rb', line 961

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::RealTimeDecision::CardAuthorization::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.



968
# File 'lib/increase/models/real_time_decision.rb', line 968

required :direction, enum: -> { Increase::RealTimeDecision::CardAuthorization::Direction }

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


975
# File 'lib/increase/models/real_time_decision.rb', line 975

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Returns:

  • (String)


982
# File 'lib/increase/models/real_time_decision.rb', line 982

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Returns:

  • (String, nil)


988
# File 'lib/increase/models/real_time_decision.rb', line 988

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


994
# File 'lib/increase/models/real_time_decision.rb', line 994

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Returns:

  • (String)


1000
# File 'lib/increase/models/real_time_decision.rb', line 1000

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Returns:

  • (String, nil)


1007
# File 'lib/increase/models/real_time_decision.rb', line 1007

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


1013
# File 'lib/increase/models/real_time_decision.rb', line 1013

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::RealTimeDecision::CardAuthorization::NetworkDetails

Fields specific to the ‘network`.



1019
# File 'lib/increase/models/real_time_decision.rb', line 1019

required :network_details, -> { Increase::RealTimeDecision::CardAuthorization::NetworkDetails }

#network_identifiersIncrease::Models::RealTimeDecision::CardAuthorization::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.



1025
# File 'lib/increase/models/real_time_decision.rb', line 1025

required :network_identifiers, -> { Increase::RealTimeDecision::CardAuthorization::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Returns:

  • (Integer, nil)


1033
# File 'lib/increase/models/real_time_decision.rb', line 1033

required :network_risk_score, Integer, nil?: true

#partial_approval_capabilitySymbol, Increase::Models::RealTimeDecision::CardAuthorization::PartialApprovalCapability

Whether or not the authorization supports partial approvals.



1039
1040
# File 'lib/increase/models/real_time_decision.rb', line 1039

required :partial_approval_capability,
enum: -> { Increase::RealTimeDecision::CardAuthorization::PartialApprovalCapability }

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Returns:

  • (String, nil)


1047
# File 'lib/increase/models/real_time_decision.rb', line 1047

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


1055
# File 'lib/increase/models/real_time_decision.rb', line 1055

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the currency the user sees at the time of purchase.

Returns:

  • (String)


1062
# File 'lib/increase/models/real_time_decision.rb', line 1062

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::RealTimeDecision::CardAuthorization::ProcessingCategory

The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.



1069
1070
# File 'lib/increase/models/real_time_decision.rb', line 1069

required :processing_category,
enum: -> { Increase::RealTimeDecision::CardAuthorization::ProcessingCategory }

#request_detailsIncrease::Models::RealTimeDecision::CardAuthorization::RequestDetails

Fields specific to the type of request, such as an incremental authorization.



1076
# File 'lib/increase/models/real_time_decision.rb', line 1076

required :request_details, -> { Increase::RealTimeDecision::CardAuthorization::RequestDetails }

#settlement_amountInteger

The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.

Returns:

  • (Integer)


1083
# File 'lib/increase/models/real_time_decision.rb', line 1083

required :settlement_amount, Integer

#settlement_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the currency the transaction will be settled in.

Returns:

  • (String)


1090
# File 'lib/increase/models/real_time_decision.rb', line 1090

required :settlement_currency, String

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Returns:

  • (String, nil)


1097
# File 'lib/increase/models/real_time_decision.rb', line 1097

required :terminal_id, String, nil?: true

#upcoming_card_payment_idString

The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.

Returns:

  • (String)


1104
# File 'lib/increase/models/real_time_decision.rb', line 1104

required :upcoming_card_payment_id, String

#verificationIncrease::Models::RealTimeDecision::CardAuthorization::Verification

Fields related to verification of cardholder-provided values.



1110
# File 'lib/increase/models/real_time_decision.rb', line 1110

required :verification, -> { Increase::RealTimeDecision::CardAuthorization::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 1610