Class: Increase::Models::RealTimeDecision::CardAuthorization::Approval
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::CardAuthorization::Approval
- Defined in:
- lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs
Overview
Instance Attribute Summary collapse
-
#partial_amount ⇒ Integer?
If the authorization was partially approved, this field contains the approved amount in the minor unit of the settlement currency.
Instance Method Summary collapse
-
#initialize ⇒ Approval
constructor
A new instance of Approval.
- #to_hash ⇒ { partial_amount: Integer? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Approval
Returns a new instance of Approval.
1057 |
# File 'sig/increase/models/real_time_decision.rbs', line 1057
def initialize: (partial_amount: Integer?) -> void
|
Instance Attribute Details
#partial_amount ⇒ Integer?
If the authorization was partially approved, this field contains the approved amount in the minor unit of the settlement currency.
1594 |
# File 'lib/increase/models/real_time_decision.rb', line 1594 required :partial_amount, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ { partial_amount: Integer? }
1059 |
# File 'sig/increase/models/real_time_decision.rbs', line 1059
def to_hash: -> { partial_amount: Integer? }
|