Class: Increase::Models::RealTimeDecision::CardAuthorization::NetworkDetails::Visa

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb

Overview

See Also:

Defined Under Namespace

Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::RealTimeDecision::CardAuthorization::NetworkDetails::Visa for more details.

Fields specific to the ‘visa` network.

Parameters:



# File 'lib/increase/models/real_time_decision.rb', line 1783

Instance Attribute Details

#electronic_commerce_indicatorSymbol, ...

For electronic commerce transactions, this identifies the level of security used in obtaining the customer’s payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.



1741
1742
1743
1744
1745
# File 'lib/increase/models/real_time_decision.rb', line 1741

required :electronic_commerce_indicator,
enum: -> {
  Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::ElectronicCommerceIndicator
},
nil?: true

#point_of_service_entry_modeSymbol, ...

The method used to enter the cardholder’s primary account number and card expiration date.



1752
1753
1754
1755
1756
# File 'lib/increase/models/real_time_decision.rb', line 1752

required :point_of_service_entry_mode,
enum: -> {
  Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::PointOfServiceEntryMode
},
nil?: true

#stand_in_processing_reasonSymbol, ...

Only present when ‘actioner: network`. Describes why a card authorization was approved or declined by Visa through stand-in processing.



1763
1764
1765
1766
1767
# File 'lib/increase/models/real_time_decision.rb', line 1763

required :stand_in_processing_reason,
enum: -> {
  Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::StandInProcessingReason
},
nil?: true

#terminal_entry_capabilitySymbol, ...

The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.



1777
1778
1779
1780
1781
# File 'lib/increase/models/real_time_decision.rb', line 1777

required :terminal_entry_capability,
enum: -> {
  Increase::RealTimeDecision::CardAuthorization::NetworkDetails::Visa::TerminalEntryCapability
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 1831