Class: Increase::Models::RealTimeDecision::CardBalanceInquiry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/real_time_decision.rb,
sig/increase/models/real_time_decision.rbs

Overview

See Also:

  • Increase::Models::RealTimeDecision#card_balance_inquiry

Defined Under Namespace

Modules: Decision Classes: AdditionalAmounts, Approval, NetworkDetails, NetworkIdentifiers, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/real_time_decision.rb', line 2654

Instance Attribute Details

#account_idString

The identifier of the Account the authorization will debit.

Parameters:

  • value (String)

Returns:

  • (String)


2526
# File 'lib/increase/models/real_time_decision.rb', line 2526

required :account_id, String

#additional_amountsIncrease::Models::RealTimeDecision::CardBalanceInquiry::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

  • value (Increase::RealTimeDecision::CardBalanceInquiry::AdditionalAmounts)

Returns:



2534
# File 'lib/increase/models/real_time_decision.rb', line 2534

required :additional_amounts, -> { Increase::RealTimeDecision::CardBalanceInquiry::AdditionalAmounts }

#approvalIncrease::Models::RealTimeDecision::CardBalanceInquiry::Approval?

Present if and only if decision is approve. Contains information related to the approval of the balance inquiry.

Parameters:

  • value (Increase::RealTimeDecision::CardBalanceInquiry::Approval, nil)

Returns:



2541
# File 'lib/increase/models/real_time_decision.rb', line 2541

required :approval, -> { Increase::RealTimeDecision::CardBalanceInquiry::Approval }, nil?: true

#card_idString

The identifier of the Card that is being authorized.

Parameters:

  • value (String)

Returns:

  • (String)


2547
# File 'lib/increase/models/real_time_decision.rb', line 2547

required :card_id, String

#decisionSymbol, ...

Whether or not the authorization was approved.

Parameters:

  • value (Increase::Models::RealTimeDecision::CardBalanceInquiry::decision, nil)

Returns:



2553
# File 'lib/increase/models/real_time_decision.rb', line 2553

required :decision, enum: -> { Increase::RealTimeDecision::CardBalanceInquiry::Decision }, nil?: true

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2560
# File 'lib/increase/models/real_time_decision.rb', line 2560

required :digital_wallet_token_id, String, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


2567
# File 'lib/increase/models/real_time_decision.rb', line 2567

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


2574
# File 'lib/increase/models/real_time_decision.rb', line 2574

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2580
# File 'lib/increase/models/real_time_decision.rb', line 2580

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


2586
# File 'lib/increase/models/real_time_decision.rb', line 2586

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


2592
# File 'lib/increase/models/real_time_decision.rb', line 2592

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2599
# File 'lib/increase/models/real_time_decision.rb', line 2599

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2605
# File 'lib/increase/models/real_time_decision.rb', line 2605

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails

Fields specific to the network.

Parameters:

  • value (Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails)

Returns:



2611
# File 'lib/increase/models/real_time_decision.rb', line 2611

required :network_details, -> { Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails }

#network_identifiersIncrease::Models::RealTimeDecision::CardBalanceInquiry::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::RealTimeDecision::CardBalanceInquiry::NetworkIdentifiers)

Returns:



2617
# File 'lib/increase/models/real_time_decision.rb', line 2617

required :network_identifiers, -> { Increase::RealTimeDecision::CardBalanceInquiry::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


2625
# File 'lib/increase/models/real_time_decision.rb', line 2625

required :network_risk_score, Integer, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2632
# File 'lib/increase/models/real_time_decision.rb', line 2632

required :physical_card_id, String, nil?: true

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2639
# File 'lib/increase/models/real_time_decision.rb', line 2639

required :terminal_id, String, nil?: true

#upcoming_card_payment_idString

The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.

Parameters:

  • value (String)

Returns:

  • (String)


2646
# File 'lib/increase/models/real_time_decision.rb', line 2646

required :upcoming_card_payment_id, String

#verificationIncrease::Models::RealTimeDecision::CardBalanceInquiry::Verification

Fields related to verification of cardholder-provided values.

Parameters:

  • value (Increase::RealTimeDecision::CardBalanceInquiry::Verification)

Returns:



2652
# File 'lib/increase/models/real_time_decision.rb', line 2652

required :verification, -> { Increase::RealTimeDecision::CardBalanceInquiry::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/real_time_decision.rb', line 3171

Instance Method Details

#to_hash{

Returns:

  • ({)


1831
# File 'sig/increase/models/real_time_decision.rbs', line 1831

def to_hash: -> {