Class: Increase::Models::RealTimeDecision::CardBalanceInquiry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecision::CardBalanceInquiry
- Defined in:
- lib/increase/models/real_time_decision.rb
Overview
Defined Under Namespace
Modules: Decision Classes: AdditionalAmounts, Approval, NetworkDetails, NetworkIdentifiers, Verification
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier of the Account the authorization will debit.
-
#additional_amounts ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#approval ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::Approval?
Present if and only if ‘decision` is `approve`.
-
#card_id ⇒ String
The identifier of the Card that is being authorized.
-
#decision ⇒ Symbol, ...
Whether or not the authorization was approved.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails
Fields specific to the ‘network`.
-
#network_identifiers ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#upcoming_card_payment_id ⇒ String
The identifier of the Card Payment this authorization will belong to.
-
#verification ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/real_time_decision.rb', line 2469
|
Instance Attribute Details
#account_id ⇒ String
The identifier of the Account the authorization will debit.
2341 |
# File 'lib/increase/models/real_time_decision.rb', line 2341 required :account_id, String |
#additional_amounts ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.
2349 |
# File 'lib/increase/models/real_time_decision.rb', line 2349 required :additional_amounts, -> { Increase::RealTimeDecision::CardBalanceInquiry::AdditionalAmounts } |
#approval ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::Approval?
Present if and only if ‘decision` is `approve`. Contains information related to the approval of the balance inquiry.
2356 |
# File 'lib/increase/models/real_time_decision.rb', line 2356 required :approval, -> { Increase::RealTimeDecision::CardBalanceInquiry::Approval }, nil?: true |
#card_id ⇒ String
The identifier of the Card that is being authorized.
2362 |
# File 'lib/increase/models/real_time_decision.rb', line 2362 required :card_id, String |
#decision ⇒ Symbol, ...
Whether or not the authorization was approved.
2368 |
# File 'lib/increase/models/real_time_decision.rb', line 2368 required :decision, enum: -> { Increase::RealTimeDecision::CardBalanceInquiry::Decision }, nil?: true |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
2375 |
# File 'lib/increase/models/real_time_decision.rb', line 2375 required :digital_wallet_token_id, String, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
2382 |
# File 'lib/increase/models/real_time_decision.rb', line 2382 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
2389 |
# File 'lib/increase/models/real_time_decision.rb', line 2389 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
2395 |
# File 'lib/increase/models/real_time_decision.rb', line 2395 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
2401 |
# File 'lib/increase/models/real_time_decision.rb', line 2401 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
2407 |
# File 'lib/increase/models/real_time_decision.rb', line 2407 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
2414 |
# File 'lib/increase/models/real_time_decision.rb', line 2414 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
2420 |
# File 'lib/increase/models/real_time_decision.rb', line 2420 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkDetails
Fields specific to the ‘network`.
2426 |
# File 'lib/increase/models/real_time_decision.rb', line 2426 required :network_details, -> { Increase::RealTimeDecision::CardBalanceInquiry::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
2432 |
# File 'lib/increase/models/real_time_decision.rb', line 2432 required :network_identifiers, -> { Increase::RealTimeDecision::CardBalanceInquiry::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
2440 |
# File 'lib/increase/models/real_time_decision.rb', line 2440 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
2447 |
# File 'lib/increase/models/real_time_decision.rb', line 2447 required :physical_card_id, String, nil?: true |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
2454 |
# File 'lib/increase/models/real_time_decision.rb', line 2454 required :terminal_id, String, nil?: true |
#upcoming_card_payment_id ⇒ String
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
2461 |
# File 'lib/increase/models/real_time_decision.rb', line 2461 required :upcoming_card_payment_id, String |
#verification ⇒ Increase::Models::RealTimeDecision::CardBalanceInquiry::Verification
Fields related to verification of cardholder-provided values.
2467 |
# File 'lib/increase/models/real_time_decision.rb', line 2467 required :verification, -> { Increase::RealTimeDecision::CardBalanceInquiry::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_decision.rb', line 2949
|