Class: Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Approval
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Approval
- Defined in:
- lib/increase/models/real_time_decision_action_params.rb
Overview
Defined Under Namespace
Classes: CardholderAddressVerificationResult
Instance Attribute Summary collapse
-
#cardholder_address_verification_result ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Approval::CardholderAddressVerificationResult?
Your decisions on whether or not each provided address component is a match.
-
#partial_amount ⇒ Integer?
If the transaction supports partial approvals (‘partial_approval_capability: supported`) the `partial_amount` can be provided in the transaction’s settlement currency to approve a lower amount than was requested.
Instance Method Summary collapse
-
#initialize(cardholder_address_verification_result: nil, partial_amount: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Approval for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cardholder_address_verification_result: nil, partial_amount: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Approval for more details.
If your application approves the authorization, this contains metadata about your decision to approve. Your response here is advisory to the acquiring bank. The bank may choose to reverse the authorization if you approve the transaction but indicate the address does not match.
|
|
# File 'lib/increase/models/real_time_decision_action_params.rb', line 262
|
Instance Attribute Details
#cardholder_address_verification_result ⇒ Increase::Models::RealTimeDecisionActionParams::CardAuthorization::Approval::CardholderAddressVerificationResult?
Your decisions on whether or not each provided address component is a match. Your response here is evaluated against the customer’s provided ‘postal_code` and `line1`, and an appropriate network response is generated. For more information, see our [Address Verification System Codes and Overrides](increase.com/documentation/address-verification-system-codes-and-overrides) guide.
250 251 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 250 optional :cardholder_address_verification_result, -> { Increase::RealTimeDecisionActionParams::CardAuthorization::Approval::CardholderAddressVerificationResult } |
#partial_amount ⇒ Integer?
If the transaction supports partial approvals (‘partial_approval_capability: supported`) the `partial_amount` can be provided in the transaction’s settlement currency to approve a lower amount than was requested.
260 |
# File 'lib/increase/models/real_time_decision_action_params.rb', line 260 optional :partial_amount, Integer |