Class: Increase::Models::RealTimePaymentsTransferCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::RealTimePaymentsTransferCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/real_time_payments_transfer_create_params.rb
Overview
Instance Attribute Summary collapse
-
#account_number ⇒ String?
The destination account number.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#creditor_name ⇒ String
The name of the transfer’s recipient.
-
#debtor_name ⇒ String?
The name of the transfer’s sender.
-
#external_account_id ⇒ String?
The ID of an External Account to initiate a transfer to.
-
#require_approval ⇒ Boolean?
Whether the transfer requires explicit approval via the dashboard or API.
-
#routing_number ⇒ String?
The destination American Bankers’ Association (ABA) Routing Transit Number (RTN).
-
#source_account_number_id ⇒ String
The identifier of the Account Number from which to send the transfer.
-
#ultimate_creditor_name ⇒ String?
The name of the ultimate recipient of the transfer.
-
#ultimate_debtor_name ⇒ String?
The name of the ultimate sender of the transfer.
-
#unstructured_remittance_information ⇒ String
Unstructured information that will show on the recipient’s bank statement.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, creditor_name:, source_account_number_id:, unstructured_remittance_information:, account_number: nil, debtor_name: nil, external_account_id: nil, require_approval: nil, routing_number: nil, ultimate_creditor_name: nil, ultimate_debtor_name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RealTimePaymentsTransferCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, creditor_name:, source_account_number_id:, unstructured_remittance_information:, account_number: nil, debtor_name: nil, external_account_id: nil, require_approval: nil, routing_number: nil, ultimate_creditor_name: nil, ultimate_debtor_name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::RealTimePaymentsTransferCreateParams for more details.
|
|
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 82
|
Instance Attribute Details
#account_number ⇒ String?
The destination account number.
39 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 39 optional :account_number, String |
#amount ⇒ Integer
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
15 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 15 required :amount, Integer |
#creditor_name ⇒ String
The name of the transfer’s recipient.
21 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 21 required :creditor_name, String |
#debtor_name ⇒ String?
The name of the transfer’s sender. If not provided, defaults to the name of the account’s entity.
46 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 46 optional :debtor_name, String |
#external_account_id ⇒ String?
The ID of an External Account to initiate a transfer to. If this parameter is provided, ‘account_number` and `routing_number` must be absent.
53 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 53 optional :external_account_id, String |
#require_approval ⇒ Boolean?
Whether the transfer requires explicit approval via the dashboard or API.
59 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 59 optional :require_approval, Increase::Internal::Type::Boolean |
#routing_number ⇒ String?
The destination American Bankers’ Association (ABA) Routing Transit Number (RTN).
66 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 66 optional :routing_number, String |
#source_account_number_id ⇒ String
The identifier of the Account Number from which to send the transfer.
27 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 27 required :source_account_number_id, String |
#ultimate_creditor_name ⇒ String?
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
73 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 73 optional :ultimate_creditor_name, String |
#ultimate_debtor_name ⇒ String?
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
80 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 80 optional :ultimate_debtor_name, String |
#unstructured_remittance_information ⇒ String
Unstructured information that will show on the recipient’s bank statement.
33 |
# File 'lib/increase/models/real_time_payments_transfer_create_params.rb', line 33 required :unstructured_remittance_information, String |