Module: Increase::Models::RealTimePaymentsTransferListParams::Status::In
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/real_time_payments_transfer_list_params.rb,
sig/increase/models/real_time_payments_transfer_list_params.rbs
Constant Summary collapse
- PENDING_APPROVAL =
The transfer is pending approval.
:pending_approval- CANCELED =
The transfer has been canceled.
:canceled- PENDING_SUBMISSION =
The transfer is queued to be submitted to Real-Time Payments.
:pending_submission- PENDING_REVIEWING =
The transfer is pending review by Increase.
:pending_reviewing- REQUIRES_ATTENTION =
The transfer requires attention from an Increase operator.
:requires_attention- REJECTED =
The transfer was rejected by the network or the recipient's bank.
:rejected- SUBMITTED =
The transfer has been submitted and is pending a response from Real-Time Payments.
:submitted- COMPLETE =
The transfer has been sent successfully and is complete.
:complete
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(in_: nil) ⇒ Object
- #self?.values ⇒ ::Array[Increase::Models::RealTimePaymentsTransferListParams::Status::in_]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 172
|
Instance Method Details
#initialize(in_: nil) ⇒ Object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/increase/models/real_time_payments_transfer_list_params.rb', line 145 module In extend Increase::Internal::Type::Enum # The transfer is pending approval. PENDING_APPROVAL = :pending_approval # The transfer has been canceled. CANCELED = :canceled # The transfer is queued to be submitted to Real-Time Payments. PENDING_SUBMISSION = :pending_submission # The transfer is pending review by Increase. PENDING_REVIEWING = :pending_reviewing # The transfer requires attention from an Increase operator. REQUIRES_ATTENTION = :requires_attention # The transfer was rejected by the network or the recipient's bank. REJECTED = :rejected # The transfer has been submitted and is pending a response from Real-Time Payments. SUBMITTED = :submitted # The transfer has been sent successfully and is complete. COMPLETE = :complete # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[Increase::Models::RealTimePaymentsTransferListParams::Status::in_]
165 |
# File 'sig/increase/models/real_time_payments_transfer_list_params.rbs', line 165
def self?.values: -> ::Array[Increase::Models::RealTimePaymentsTransferListParams::Status::in_]
|