Class: Increase::Models::Simulations::ACHTransferCreateNotificationOfChangeParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::ACHTransferCreateNotificationOfChangeParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb
Overview
Defined Under Namespace
Modules: CorrectedAccountFunding
Instance Attribute Summary collapse
-
#ach_transfer_id ⇒ String
The identifier of the ACH Transfer you wish to create a notification of change for.
-
#corrected_account_funding ⇒ Symbol, ...
The corrected account funding type.
-
#corrected_account_number ⇒ String?
The corrected account number.
-
#corrected_individual_id ⇒ String?
The corrected individual identifier.
-
#corrected_routing_number ⇒ String?
The corrected routing number.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(ach_transfer_id:, corrected_account_funding: nil, corrected_account_number: nil, corrected_individual_id: nil, corrected_routing_number: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ACHTransferCreateNotificationOfChangeParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ach_transfer_id:, corrected_account_funding: nil, corrected_account_number: nil, corrected_individual_id: nil, corrected_routing_number: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Simulations::ACHTransferCreateNotificationOfChangeParams for more details.
|
|
# File 'lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb', line 43
|
Instance Attribute Details
#ach_transfer_id ⇒ String
The identifier of the ACH Transfer you wish to create a notification of change for.
16 |
# File 'lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb', line 16 required :ach_transfer_id, String |
#corrected_account_funding ⇒ Symbol, ...
The corrected account funding type.
22 23 |
# File 'lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb', line 22 optional :corrected_account_funding, enum: -> { Increase::Simulations::ACHTransferCreateNotificationOfChangeParams::CorrectedAccountFunding } |
#corrected_account_number ⇒ String?
The corrected account number.
29 |
# File 'lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb', line 29 optional :corrected_account_number, String |
#corrected_individual_id ⇒ String?
The corrected individual identifier.
35 |
# File 'lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb', line 35 optional :corrected_individual_id, String |
#corrected_routing_number ⇒ String?
The corrected routing number.
41 |
# File 'lib/increase/models/simulations/ach_transfer_create_notification_of_change_params.rb', line 41 optional :corrected_routing_number, String |