Class: Increase::Models::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa
- Defined in:
- lib/increase/models/simulations/card_authorization_create_params.rb
Overview
Defined Under Namespace
Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability
Instance Attribute Summary collapse
-
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer’s payment credential.
-
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder’s primary account number and card expiration date.
-
#stand_in_processing_reason ⇒ Symbol, ...
The reason code for the stand-in processing.
-
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(electronic_commerce_indicator: nil, point_of_service_entry_mode: nil, stand_in_processing_reason: nil, terminal_entry_capability: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Visa for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(electronic_commerce_indicator: nil, point_of_service_entry_mode: nil, stand_in_processing_reason: nil, terminal_entry_capability: nil) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa for more details.
Fields specific to the Visa network.
|
|
# File 'lib/increase/models/simulations/card_authorization_create_params.rb', line 285
|
Instance Attribute Details
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer’s payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
256 257 |
# File 'lib/increase/models/simulations/card_authorization_create_params.rb', line 256 optional :electronic_commerce_indicator, enum: -> { Increase::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa::ElectronicCommerceIndicator } |
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder’s primary account number and card expiration date.
264 265 |
# File 'lib/increase/models/simulations/card_authorization_create_params.rb', line 264 optional :point_of_service_entry_mode, enum: -> { Increase::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa::PointOfServiceEntryMode } |
#stand_in_processing_reason ⇒ Symbol, ...
The reason code for the stand-in processing.
271 272 |
# File 'lib/increase/models/simulations/card_authorization_create_params.rb', line 271 optional :stand_in_processing_reason, enum: -> { Increase::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa::StandInProcessingReason } |
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
282 283 |
# File 'lib/increase/models/simulations/card_authorization_create_params.rb', line 282 optional :terminal_entry_capability, enum: -> { Increase::Simulations::CardAuthorizationCreateParams::NetworkDetails::Visa::TerminalEntryCapability } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/simulations/card_authorization_create_params.rb', line 333
|