Class: Increase::Models::Simulations::CardBalanceInquiryCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/simulations/card_balance_inquiry_create_params.rb

Overview

Defined Under Namespace

Modules: DeclineReason Classes: NetworkDetails

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(balance: nil, card_id: nil, decline_reason: nil, digital_wallet_token_id: nil, event_subscription_id: nil, merchant_acceptor_id: nil, merchant_category_code: nil, merchant_city: nil, merchant_country: nil, merchant_descriptor: nil, merchant_state: nil, network_details: nil, network_risk_score: nil, physical_card_id: nil, terminal_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Simulations::CardBalanceInquiryCreateParams for more details.

Parameters:

  • balance (Integer) (defaults to: nil)

    The balance amount in cents. The account balance will be used if not provided.

  • card_id (String) (defaults to: nil)

    The identifier of the Card to be authorized.

  • decline_reason (Symbol, Increase::Models::Simulations::CardBalanceInquiryCreateParams::DeclineReason) (defaults to: nil)

    Forces a card decline with a specific reason. No real time decision will be sent

  • digital_wallet_token_id (String) (defaults to: nil)

    The identifier of the Digital Wallet Token to be authorized.

  • event_subscription_id (String) (defaults to: nil)

    The identifier of the Event Subscription to use. If provided, will override the

  • merchant_acceptor_id (String) (defaults to: nil)

    The merchant identifier (commonly abbreviated as MID) of the merchant the card i

  • merchant_category_code (String) (defaults to: nil)

    The Merchant Category Code (commonly abbreviated as MCC) of the merchant the car

  • merchant_city (String) (defaults to: nil)

    The city the merchant resides in.

  • merchant_country (String) (defaults to: nil)

    The country the merchant resides in.

  • merchant_descriptor (String) (defaults to: nil)

    The merchant descriptor of the merchant the card is transacting with.

  • merchant_state (String) (defaults to: nil)

    The state the merchant resides in.

  • network_details (Increase::Models::Simulations::CardBalanceInquiryCreateParams::NetworkDetails) (defaults to: nil)

    Fields specific to a given card network.

  • network_risk_score (Integer) (defaults to: nil)

    The risk score generated by the card network. For Visa this is the Visa Advanced

  • physical_card_id (String) (defaults to: nil)

    The identifier of the Physical Card to be authorized.

  • terminal_id (String) (defaults to: nil)

    The terminal identifier (commonly abbreviated as TID) of the terminal the card i

  • request_options (Increase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 110

Instance Attribute Details

#balanceInteger?

The balance amount in cents. The account balance will be used if not provided.

Returns:

  • (Integer, nil)


15
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 15

optional :balance, Integer

#card_idString?

The identifier of the Card to be authorized.

Returns:

  • (String, nil)


21
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 21

optional :card_id, String

#decline_reasonSymbol, ...

Forces a card decline with a specific reason. No real time decision will be sent.



28
29
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 28

optional :decline_reason,
enum: -> { Increase::Simulations::CardBalanceInquiryCreateParams::DeclineReason }

#digital_wallet_token_idString?

The identifier of the Digital Wallet Token to be authorized.

Returns:

  • (String, nil)


35
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 35

optional :digital_wallet_token_id, String

#event_subscription_idString?

The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.

Returns:

  • (String, nil)


44
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 44

optional :event_subscription_id, String

#merchant_acceptor_idString?

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String, nil)


51
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 51

optional :merchant_acceptor_id, String

#merchant_category_codeString?

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Returns:

  • (String, nil)


58
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 58

optional :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Returns:

  • (String, nil)


64
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 64

optional :merchant_city, String

#merchant_countryString?

The country the merchant resides in.

Returns:

  • (String, nil)


70
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 70

optional :merchant_country, String

#merchant_descriptorString?

The merchant descriptor of the merchant the card is transacting with.

Returns:

  • (String, nil)


76
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 76

optional :merchant_descriptor, String

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


82
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 82

optional :merchant_state, String

#network_detailsIncrease::Models::Simulations::CardBalanceInquiryCreateParams::NetworkDetails?

Fields specific to a given card network.



88
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 88

optional :network_details, -> { Increase::Simulations::CardBalanceInquiryCreateParams::NetworkDetails }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.

Returns:

  • (Integer, nil)


95
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 95

optional :network_risk_score, Integer

#physical_card_idString?

The identifier of the Physical Card to be authorized.

Returns:

  • (String, nil)


101
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 101

optional :physical_card_id, String

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Returns:

  • (String, nil)


108
# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 108

optional :terminal_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/simulations/card_balance_inquiry_create_params.rb', line 215