Class: Increase::Models::Simulations::CheckDepositAdjustmentParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::CheckDepositAdjustmentParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/check_deposit_adjustment_params.rb
Overview
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The adjustment amount in the minor unit of the Check Deposit’s currency (e.g., cents).
-
#check_deposit_id ⇒ String
The identifier of the Check Deposit you wish to adjust.
-
#reason ⇒ Symbol, ...
The reason for the adjustment.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(check_deposit_id:, amount: nil, reason: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CheckDepositAdjustmentParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(check_deposit_id:, amount: nil, reason: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Simulations::CheckDepositAdjustmentParams for more details.
|
|
# File 'lib/increase/models/simulations/check_deposit_adjustment_params.rb', line 33
|
Instance Attribute Details
#amount ⇒ Integer?
The adjustment amount in the minor unit of the Check Deposit’s currency (e.g., cents). A negative amount means that the funds are being clawed back by the other bank and is a debit to your account. Defaults to the negative of the Check Deposit amount.
24 |
# File 'lib/increase/models/simulations/check_deposit_adjustment_params.rb', line 24 optional :amount, Integer |
#check_deposit_id ⇒ String
The identifier of the Check Deposit you wish to adjust.
15 |
# File 'lib/increase/models/simulations/check_deposit_adjustment_params.rb', line 15 required :check_deposit_id, String |
#reason ⇒ Symbol, ...
The reason for the adjustment. Defaults to ‘non_conforming_item`, which is often used for a low quality image that the recipient wasn’t able to handle.
31 |
# File 'lib/increase/models/simulations/check_deposit_adjustment_params.rb', line 31 optional :reason, enum: -> { Increase::Simulations::CheckDepositAdjustmentParams::Reason } |