Class: Increase::Models::Simulations::CheckDepositSubmitParams::Scan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/simulations/check_deposit_submit_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, routing_number:, auxiliary_on_us: nil) ⇒ Object

If set, the simulation will use these values for the check’s scanned MICR data.

Parameters:

  • account_number (String)

    The account number to be returned in the check deposit’s scan data.

  • routing_number (String)

    The routing number to be returned in the check deposit’s scan data.

  • auxiliary_on_us (String) (defaults to: nil)

    The auxiliary on-us data to be returned in the check deposit’s scan data.



30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 30

class Scan < Increase::Internal::Type::BaseModel
  # @!attribute account_number
  #   The account number to be returned in the check deposit's scan data.
  #
  #   @return [String]
  required :account_number, String

  # @!attribute routing_number
  #   The routing number to be returned in the check deposit's scan data.
  #
  #   @return [String]
  required :routing_number, String

  # @!attribute auxiliary_on_us
  #   The auxiliary on-us data to be returned in the check deposit's scan data.
  #
  #   @return [String, nil]
  optional :auxiliary_on_us, String

  # @!method initialize(account_number:, routing_number:, auxiliary_on_us: nil)
  #   If set, the simulation will use these values for the check's scanned MICR data.
  #
  #   @param account_number [String] The account number to be returned in the check deposit's scan data.
  #
  #   @param routing_number [String] The routing number to be returned in the check deposit's scan data.
  #
  #   @param auxiliary_on_us [String] The auxiliary on-us data to be returned in the check deposit's scan data.
end

Instance Attribute Details

#account_numberString

The account number to be returned in the check deposit’s scan data.

Returns:

  • (String)


35
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 35

required :account_number, String

#auxiliary_on_usString?

The auxiliary on-us data to be returned in the check deposit’s scan data.

Returns:

  • (String, nil)


47
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 47

optional :auxiliary_on_us, String

#routing_numberString

The routing number to be returned in the check deposit’s scan data.

Returns:

  • (String)


41
# File 'lib/increase/models/simulations/check_deposit_submit_params.rb', line 41

required :routing_number, String