Class: Increase::Models::Simulations::EntityUpdateValidationParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Simulations::EntityUpdateValidationParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/simulations/entity_update_validation_params.rb
Overview
Defined Under Namespace
Classes: Issue
Instance Attribute Summary collapse
-
#entity_id ⇒ String
The identifier of the Entity whose validation status to update.
-
#issues ⇒ Array<Increase::Models::Simulations::EntityUpdateValidationParams::Issue>
The validation issues to attach.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#entity_id ⇒ String
The identifier of the Entity whose validation status to update.
15 |
# File 'lib/increase/models/simulations/entity_update_validation_params.rb', line 15 required :entity_id, String |
#issues ⇒ Array<Increase::Models::Simulations::EntityUpdateValidationParams::Issue>
The validation issues to attach. If no issues are provided, the validation status will be set to ‘valid`.
22 23 |
# File 'lib/increase/models/simulations/entity_update_validation_params.rb', line 22 required :issues, -> { Increase::Internal::Type::ArrayOf[Increase::Simulations::EntityUpdateValidationParams::Issue] } |