Class: Increase::Models::Simulations::InboundCheckDepositAdjustmentParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb

Overview

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inbound_check_deposit_id:, amount: nil, reason: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Simulations::InboundCheckDepositAdjustmentParams for more details.

Parameters:



# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 30

Instance Attribute Details

#amountInteger?

The adjustment amount in cents. Defaults to the amount of the Inbound Check Deposit.

Returns:

  • (Integer, nil)


22
# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 22

optional :amount, Integer

#inbound_check_deposit_idString

The identifier of the Inbound Check Deposit to adjust.

Returns:

  • (String)


15
# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 15

required :inbound_check_deposit_id, String

#reasonSymbol, ...

The reason for the adjustment. Defaults to ‘wrong_payee_credit`.



28
# File 'lib/increase/models/simulations/inbound_check_deposit_adjustment_params.rb', line 28

optional :reason, enum: -> { Increase::Simulations::InboundCheckDepositAdjustmentParams::Reason }