Class: Increase::Models::SwiftTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::SwiftTransfer
- Defined in:
- lib/increase/models/swift_transfer.rb
Overview
Defined Under Namespace
Modules: InstructedCurrency, Status, Type Classes: CreatedBy, CreditorAddress, DebtorAddress
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account to which the transfer belongs.
-
#account_number ⇒ String
The creditor’s account number.
-
#amount ⇒ Integer
The transfer amount in USD cents.
-
#bank_identification_code ⇒ String
The bank identification code (BIC) of the creditor.
-
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
-
#created_by ⇒ Increase::Models::SwiftTransfer::CreatedBy
What object created the transfer, either via the API or the dashboard.
-
#creditor_address ⇒ Increase::Models::SwiftTransfer::CreditorAddress
The creditor’s address.
-
#creditor_name ⇒ String
The creditor’s name.
-
#debtor_address ⇒ Increase::Models::SwiftTransfer::DebtorAddress
The debtor’s address.
-
#debtor_name ⇒ String
The debtor’s name.
-
#id ⇒ String
The Swift transfer’s identifier.
-
#idempotency_key ⇒ String?
The idempotency key you chose for this object.
-
#instructed_amount ⇒ Integer
The amount that was instructed to be transferred in minor units of the ‘instructed_currency`.
-
#instructed_currency ⇒ Symbol, Increase::Models::SwiftTransfer::InstructedCurrency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) currency code of the instructed amount.
-
#pending_transaction_id ⇒ String?
The ID for the pending transaction representing the transfer.
-
#routing_number ⇒ String?
The creditor’s bank account routing or transit number.
-
#source_account_number_id ⇒ String
The Account Number included in the transfer as the debtor’s account number.
-
#status ⇒ Symbol, Increase::Models::SwiftTransfer::Status
The lifecycle status of the transfer.
-
#transaction_id ⇒ String?
The ID for the transaction funding the transfer.
-
#type ⇒ Symbol, Increase::Models::SwiftTransfer::Type
A constant representing the object’s type.
-
#unique_end_to_end_transaction_reference ⇒ String
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) for the transfer.
-
#unstructured_remittance_information ⇒ String
The unstructured remittance information that was included with the transfer.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2:, postal_code:, state:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DebtorAddress for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2:, postal_code:, state:) ⇒ Object
Some parameter documentations has been truncated, see DebtorAddress for more details.
The debtor’s address.
|
|
# File 'lib/increase/models/swift_transfer.rb', line 149
|
Instance Attribute Details
#account_id ⇒ String
The Account to which the transfer belongs.
17 |
# File 'lib/increase/models/swift_transfer.rb', line 17 required :account_id, String |
#account_number ⇒ String
The creditor’s account number.
23 |
# File 'lib/increase/models/swift_transfer.rb', line 23 required :account_number, String |
#amount ⇒ Integer
The transfer amount in USD cents.
29 |
# File 'lib/increase/models/swift_transfer.rb', line 29 required :amount, Integer |
#bank_identification_code ⇒ String
The bank identification code (BIC) of the creditor.
35 |
# File 'lib/increase/models/swift_transfer.rb', line 35 required :bank_identification_code, String |
#created_at ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time at which the transfer was created.
42 |
# File 'lib/increase/models/swift_transfer.rb', line 42 required :created_at, Time |
#created_by ⇒ Increase::Models::SwiftTransfer::CreatedBy
What object created the transfer, either via the API or the dashboard.
48 |
# File 'lib/increase/models/swift_transfer.rb', line 48 required :created_by, -> { Increase::SwiftTransfer::CreatedBy } |
#creditor_address ⇒ Increase::Models::SwiftTransfer::CreditorAddress
The creditor’s address.
54 |
# File 'lib/increase/models/swift_transfer.rb', line 54 required :creditor_address, -> { Increase::SwiftTransfer::CreditorAddress } |
#creditor_name ⇒ String
The creditor’s name.
60 |
# File 'lib/increase/models/swift_transfer.rb', line 60 required :creditor_name, String |
#debtor_address ⇒ Increase::Models::SwiftTransfer::DebtorAddress
The debtor’s address.
66 |
# File 'lib/increase/models/swift_transfer.rb', line 66 required :debtor_address, -> { Increase::SwiftTransfer::DebtorAddress } |
#debtor_name ⇒ String
The debtor’s name.
72 |
# File 'lib/increase/models/swift_transfer.rb', line 72 required :debtor_name, String |
#id ⇒ String
The Swift transfer’s identifier.
11 |
# File 'lib/increase/models/swift_transfer.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about [idempotency](increase.com/documentation/idempotency-keys).
80 |
# File 'lib/increase/models/swift_transfer.rb', line 80 required :idempotency_key, String, nil?: true |
#instructed_amount ⇒ Integer
The amount that was instructed to be transferred in minor units of the ‘instructed_currency`.
87 |
# File 'lib/increase/models/swift_transfer.rb', line 87 required :instructed_amount, Integer |
#instructed_currency ⇒ Symbol, Increase::Models::SwiftTransfer::InstructedCurrency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) currency code of the instructed amount.
94 |
# File 'lib/increase/models/swift_transfer.rb', line 94 required :instructed_currency, enum: -> { Increase::SwiftTransfer::InstructedCurrency } |
#pending_transaction_id ⇒ String?
The ID for the pending transaction representing the transfer.
100 |
# File 'lib/increase/models/swift_transfer.rb', line 100 required :pending_transaction_id, String, nil?: true |
#routing_number ⇒ String?
The creditor’s bank account routing or transit number. Required in certain countries.
107 |
# File 'lib/increase/models/swift_transfer.rb', line 107 required :routing_number, String, nil?: true |
#source_account_number_id ⇒ String
The Account Number included in the transfer as the debtor’s account number.
113 |
# File 'lib/increase/models/swift_transfer.rb', line 113 required :source_account_number_id, String |
#status ⇒ Symbol, Increase::Models::SwiftTransfer::Status
The lifecycle status of the transfer.
119 |
# File 'lib/increase/models/swift_transfer.rb', line 119 required :status, enum: -> { Increase::SwiftTransfer::Status } |
#transaction_id ⇒ String?
The ID for the transaction funding the transfer. This will be populated after the transfer is initiated.
126 |
# File 'lib/increase/models/swift_transfer.rb', line 126 required :transaction_id, String, nil?: true |
#type ⇒ Symbol, Increase::Models::SwiftTransfer::Type
A constant representing the object’s type. For this resource it will always be ‘swift_transfer`.
133 |
# File 'lib/increase/models/swift_transfer.rb', line 133 required :type, enum: -> { Increase::SwiftTransfer::Type } |
#unique_end_to_end_transaction_reference ⇒ String
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) for the transfer.
141 |
# File 'lib/increase/models/swift_transfer.rb', line 141 required :unique_end_to_end_transaction_reference, String |
#unstructured_remittance_information ⇒ String
The unstructured remittance information that was included with the transfer.
147 |
# File 'lib/increase/models/swift_transfer.rb', line 147 required :unstructured_remittance_information, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/swift_transfer.rb', line 426
|