Class: Increase::Models::SwiftTransferCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::SwiftTransferCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/increase/models/swift_transfer_create_params.rb
Overview
Defined Under Namespace
Modules: InstructedCurrency Classes: CreditorAddress, DebtorAddress
Instance Attribute Summary collapse
-
#account_id ⇒ String
The identifier for the account that will send the transfer.
-
#account_number ⇒ String
The creditor’s account number.
-
#bank_identification_code ⇒ String
The bank identification code (BIC) of the creditor.
-
#creditor_address ⇒ Increase::Models::SwiftTransferCreateParams::CreditorAddress
The creditor’s address.
-
#creditor_name ⇒ String
The creditor’s name.
-
#debtor_address ⇒ Increase::Models::SwiftTransferCreateParams::DebtorAddress
The debtor’s address.
-
#debtor_name ⇒ String
The debtor’s name.
-
#instructed_amount ⇒ Integer
The amount, in minor units of ‘instructed_currency`, to send to the creditor.
-
#instructed_currency ⇒ Symbol, Increase::Models::SwiftTransferCreateParams::InstructedCurrency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) currency code of the instructed amount.
-
#require_approval ⇒ Boolean?
Whether the transfer requires explicit approval via the dashboard or API.
-
#routing_number ⇒ String?
The creditor’s bank account routing or transit number.
-
#source_account_number_id ⇒ String
The Account Number to include in the transfer as the debtor’s account number.
-
#unstructured_remittance_information ⇒ String
Unstructured remittance information to include in the transfer.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DebtorAddress for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil) ⇒ Object
Some parameter documentations has been truncated, see DebtorAddress for more details.
The debtor’s address.
|
|
# File 'lib/increase/models/swift_transfer_create_params.rb', line 163
|
Instance Attribute Details
#account_id ⇒ String
The identifier for the account that will send the transfer.
14 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 14 required :account_id, String |
#account_number ⇒ String
The creditor’s account number.
20 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 20 required :account_number, String |
#bank_identification_code ⇒ String
The bank identification code (BIC) of the creditor. If it ends with the three-character branch code, this must be 11 characters long. Otherwise this must be 8 characters and the branch code will be assumed to be ‘XXX`.
28 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 28 required :bank_identification_code, String |
#creditor_address ⇒ Increase::Models::SwiftTransferCreateParams::CreditorAddress
The creditor’s address.
34 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 34 required :creditor_address, -> { Increase::SwiftTransferCreateParams::CreditorAddress } |
#creditor_name ⇒ String
The creditor’s name.
40 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 40 required :creditor_name, String |
#debtor_address ⇒ Increase::Models::SwiftTransferCreateParams::DebtorAddress
The debtor’s address.
46 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 46 required :debtor_address, -> { Increase::SwiftTransferCreateParams::DebtorAddress } |
#debtor_name ⇒ String
The debtor’s name.
52 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 52 required :debtor_name, String |
#instructed_amount ⇒ Integer
The amount, in minor units of ‘instructed_currency`, to send to the creditor.
58 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 58 required :instructed_amount, Integer |
#instructed_currency ⇒ Symbol, Increase::Models::SwiftTransferCreateParams::InstructedCurrency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) currency code of the instructed amount.
65 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 65 required :instructed_currency, enum: -> { Increase::SwiftTransferCreateParams::InstructedCurrency } |
#require_approval ⇒ Boolean?
Whether the transfer requires explicit approval via the dashboard or API.
83 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 83 optional :require_approval, Increase::Internal::Type::Boolean |
#routing_number ⇒ String?
The creditor’s bank account routing or transit number. Required in certain countries.
90 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 90 optional :routing_number, String |
#source_account_number_id ⇒ String
The Account Number to include in the transfer as the debtor’s account number.
71 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 71 required :source_account_number_id, String |
#unstructured_remittance_information ⇒ String
Unstructured remittance information to include in the transfer.
77 |
# File 'lib/increase/models/swift_transfer_create_params.rb', line 77 required :unstructured_remittance_information, String |