Class: Increase::Models::Transaction::Source
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: Category Classes: ACHTransferIntention, ACHTransferRejection, ACHTransferReturn, AccountRevenuePayment, AccountTransferIntention, BlockchainOfframpTransferSettlement, BlockchainOnrampTransferIntention, CardDisputeAcceptance, CardDisputeFinancial, CardDisputeLoss, CardFinancial, CardPushTransferAcceptance, CardRefund, CardRevenuePayment, CardSettlement, CashbackPayment, CheckDepositAcceptance, CheckDepositReturn, CheckTransferDeposit, FednowTransferAcknowledgement, FeePayment, InboundACHTransfer, InboundACHTransferReturnIntention, InboundCheckAdjustment, InboundCheckDepositReturnIntention, InboundFednowTransferConfirmation, InboundRealTimePaymentsTransferConfirmation, InboundWireReversal, InboundWireTransfer, InboundWireTransferReversal, InterestPayment, InternalSource, Other, RealTimePaymentsTransferAcknowledgement, SampleFunds, SwiftTransferIntention, SwiftTransferReturn, WireTransferIntention
Instance Attribute Summary collapse
-
#account_revenue_payment ⇒ Increase::Models::Transaction::Source::AccountRevenuePayment?
An Account Revenue Payment object.
-
#account_transfer_intention ⇒ Increase::Models::Transaction::Source::AccountTransferIntention?
An Account Transfer Intention object.
-
#ach_transfer_intention ⇒ Increase::Models::Transaction::Source::ACHTransferIntention?
An ACH Transfer Intention object.
-
#ach_transfer_rejection ⇒ Increase::Models::Transaction::Source::ACHTransferRejection?
An ACH Transfer Rejection object.
-
#ach_transfer_return ⇒ Increase::Models::Transaction::Source::ACHTransferReturn?
An ACH Transfer Return object.
-
#blockchain_offramp_transfer_settlement ⇒ Increase::Models::Transaction::Source::BlockchainOfframpTransferSettlement?
A Blockchain Off-Ramp Transfer Settlement object.
-
#blockchain_onramp_transfer_intention ⇒ Increase::Models::Transaction::Source::BlockchainOnrampTransferIntention?
A Blockchain On-Ramp Transfer Intention object.
-
#card_dispute_acceptance ⇒ Increase::Models::Transaction::Source::CardDisputeAcceptance?
A Legacy Card Dispute Acceptance object.
-
#card_dispute_financial ⇒ Increase::Models::Transaction::Source::CardDisputeFinancial?
A Card Dispute Financial object.
-
#card_dispute_loss ⇒ Increase::Models::Transaction::Source::CardDisputeLoss?
A Legacy Card Dispute Loss object.
-
#card_financial ⇒ Increase::Models::Transaction::Source::CardFinancial?
A Card Financial object.
-
#card_push_transfer_acceptance ⇒ Increase::Models::Transaction::Source::CardPushTransferAcceptance?
A Card Push Transfer Acceptance object.
-
#card_refund ⇒ Increase::Models::Transaction::Source::CardRefund?
A Card Refund object.
-
#card_revenue_payment ⇒ Increase::Models::Transaction::Source::CardRevenuePayment?
A Card Revenue Payment object.
-
#card_settlement ⇒ Increase::Models::Transaction::Source::CardSettlement?
A Card Settlement object.
-
#cashback_payment ⇒ Increase::Models::Transaction::Source::CashbackPayment?
A Cashback Payment object.
-
#category ⇒ Symbol, Increase::Models::Transaction::Source::Category
The type of the resource.
-
#check_deposit_acceptance ⇒ Increase::Models::Transaction::Source::CheckDepositAcceptance?
A Check Deposit Acceptance object.
-
#check_deposit_return ⇒ Increase::Models::Transaction::Source::CheckDepositReturn?
A Check Deposit Return object.
-
#check_transfer_deposit ⇒ Increase::Models::Transaction::Source::CheckTransferDeposit?
A Check Transfer Deposit object.
-
#fednow_transfer_acknowledgement ⇒ Increase::Models::Transaction::Source::FednowTransferAcknowledgement?
A FedNow Transfer Acknowledgement object.
-
#fee_payment ⇒ Increase::Models::Transaction::Source::FeePayment?
A Fee Payment object.
-
#inbound_ach_transfer ⇒ Increase::Models::Transaction::Source::InboundACHTransfer?
An Inbound ACH Transfer Intention object.
-
#inbound_ach_transfer_return_intention ⇒ Increase::Models::Transaction::Source::InboundACHTransferReturnIntention?
An Inbound ACH Transfer Return Intention object.
-
#inbound_check_adjustment ⇒ Increase::Models::Transaction::Source::InboundCheckAdjustment?
An Inbound Check Adjustment object.
-
#inbound_check_deposit_return_intention ⇒ Increase::Models::Transaction::Source::InboundCheckDepositReturnIntention?
An Inbound Check Deposit Return Intention object.
-
#inbound_fednow_transfer_confirmation ⇒ Increase::Models::Transaction::Source::InboundFednowTransferConfirmation?
An Inbound FedNow Transfer Confirmation object.
-
#inbound_real_time_payments_transfer_confirmation ⇒ Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation?
An Inbound Real-Time Payments Transfer Confirmation object.
-
#inbound_wire_reversal ⇒ Increase::Models::Transaction::Source::InboundWireReversal?
An Inbound Wire Reversal object.
-
#inbound_wire_transfer ⇒ Increase::Models::Transaction::Source::InboundWireTransfer?
An Inbound Wire Transfer Intention object.
-
#inbound_wire_transfer_reversal ⇒ Increase::Models::Transaction::Source::InboundWireTransferReversal?
An Inbound Wire Transfer Reversal Intention object.
-
#interest_payment ⇒ Increase::Models::Transaction::Source::InterestPayment?
An Interest Payment object.
-
#internal_source ⇒ Increase::Models::Transaction::Source::InternalSource?
An Internal Source object.
-
#other ⇒ Increase::Models::Transaction::Source::Other?
If the category of this Transaction source is equal to ‘other`, this field will contain an empty object, otherwise it will contain null.
-
#real_time_payments_transfer_acknowledgement ⇒ Increase::Models::Transaction::Source::RealTimePaymentsTransferAcknowledgement?
A Real-Time Payments Transfer Acknowledgement object.
-
#sample_funds ⇒ Increase::Models::Transaction::Source::SampleFunds?
A Sample Funds object.
-
#swift_transfer_intention ⇒ Increase::Models::Transaction::Source::SwiftTransferIntention?
A Swift Transfer Intention object.
-
#swift_transfer_return ⇒ Increase::Models::Transaction::Source::SwiftTransferReturn?
A Swift Transfer Return object.
-
#wire_transfer_intention ⇒ Increase::Models::Transaction::Source::WireTransferIntention?
A Wire Transfer Intention object.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(transfer_id:) ⇒ Object
constructor
A Swift Transfer Return object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(transfer_id:) ⇒ Object
A Swift Transfer Return object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_return`. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.
|
|
# File 'lib/increase/models/transaction.rb', line 549
|
Instance Attribute Details
#account_revenue_payment ⇒ Increase::Models::Transaction::Source::AccountRevenuePayment?
An Account Revenue Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `account_revenue_payment`. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.
156 157 158 159 160 |
# File 'lib/increase/models/transaction.rb', line 156 optional :account_revenue_payment, -> { Increase::Transaction::Source::AccountRevenuePayment }, nil?: true |
#account_transfer_intention ⇒ Increase::Models::Transaction::Source::AccountTransferIntention?
An Account Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `account_transfer_intention`. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
169 170 171 |
# File 'lib/increase/models/transaction.rb', line 169 optional :account_transfer_intention, -> { Increase::Transaction::Source::AccountTransferIntention }, nil?: true |
#ach_transfer_intention ⇒ Increase::Models::Transaction::Source::ACHTransferIntention?
An ACH Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_intention`. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
180 181 182 183 184 |
# File 'lib/increase/models/transaction.rb', line 180 optional :ach_transfer_intention, -> { Increase::Transaction::Source::ACHTransferIntention }, nil?: true |
#ach_transfer_rejection ⇒ Increase::Models::Transaction::Source::ACHTransferRejection?
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_rejection`. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
193 194 195 196 197 |
# File 'lib/increase/models/transaction.rb', line 193 optional :ach_transfer_rejection, -> { Increase::Transaction::Source::ACHTransferRejection }, nil?: true |
#ach_transfer_return ⇒ Increase::Models::Transaction::Source::ACHTransferReturn?
An ACH Transfer Return object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_return`. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later. The return appears as a new posted Transaction; no Pending Transaction is created.
209 |
# File 'lib/increase/models/transaction.rb', line 209 optional :ach_transfer_return, -> { Increase::Transaction::Source::ACHTransferReturn }, nil?: true |
#blockchain_offramp_transfer_settlement ⇒ Increase::Models::Transaction::Source::BlockchainOfframpTransferSettlement?
A Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_offramp_transfer_settlement`.
217 218 219 |
# File 'lib/increase/models/transaction.rb', line 217 optional :blockchain_offramp_transfer_settlement, -> { Increase::Transaction::Source::BlockchainOfframpTransferSettlement }, nil?: true |
#blockchain_onramp_transfer_intention ⇒ Increase::Models::Transaction::Source::BlockchainOnrampTransferIntention?
A Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_onramp_transfer_intention`.
227 228 229 |
# File 'lib/increase/models/transaction.rb', line 227 optional :blockchain_onramp_transfer_intention, -> { Increase::Transaction::Source::BlockchainOnrampTransferIntention }, nil?: true |
#card_dispute_acceptance ⇒ Increase::Models::Transaction::Source::CardDisputeAcceptance?
A Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `card_dispute_acceptance`. Contains the details of a successful Card Dispute.
237 238 239 240 241 |
# File 'lib/increase/models/transaction.rb', line 237 optional :card_dispute_acceptance, -> { Increase::Transaction::Source::CardDisputeAcceptance }, nil?: true |
#card_dispute_financial ⇒ Increase::Models::Transaction::Source::CardDisputeFinancial?
A Card Dispute Financial object. This field will be present in the JSON response if and only if ‘category` is equal to `card_dispute_financial`. Financial event related to a Card Dispute.
249 250 251 252 253 |
# File 'lib/increase/models/transaction.rb', line 249 optional :card_dispute_financial, -> { Increase::Transaction::Source::CardDisputeFinancial }, nil?: true |
#card_dispute_loss ⇒ Increase::Models::Transaction::Source::CardDisputeLoss?
A Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if ‘category` is equal to `card_dispute_loss`. Contains the details of a lost Card Dispute.
261 |
# File 'lib/increase/models/transaction.rb', line 261 optional :card_dispute_loss, -> { Increase::Transaction::Source::CardDisputeLoss }, nil?: true |
#card_financial ⇒ Increase::Models::Transaction::Source::CardFinancial?
A Card Financial object. This field will be present in the JSON response if and only if ‘category` is equal to `card_financial`. Card Financials are card transactions that have cleared and settled. Unlike a Card Settlement, which clears a previous authorization, a Card Financial is authorized and cleared in a single message.
271 |
# File 'lib/increase/models/transaction.rb', line 271 optional :card_financial, -> { Increase::Transaction::Source::CardFinancial }, nil?: true |
#card_push_transfer_acceptance ⇒ Increase::Models::Transaction::Source::CardPushTransferAcceptance?
A Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `card_push_transfer_acceptance`. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.
280 281 282 |
# File 'lib/increase/models/transaction.rb', line 280 optional :card_push_transfer_acceptance, -> { Increase::Transaction::Source::CardPushTransferAcceptance }, nil?: true |
#card_refund ⇒ Increase::Models::Transaction::Source::CardRefund?
A Card Refund object. This field will be present in the JSON response if and only if ‘category` is equal to `card_refund`. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.
292 |
# File 'lib/increase/models/transaction.rb', line 292 optional :card_refund, -> { Increase::Transaction::Source::CardRefund }, nil?: true |
#card_revenue_payment ⇒ Increase::Models::Transaction::Source::CardRevenuePayment?
A Card Revenue Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `card_revenue_payment`. Card Revenue Payments reflect earnings from fees on card transactions.
300 |
# File 'lib/increase/models/transaction.rb', line 300 optional :card_revenue_payment, -> { Increase::Transaction::Source::CardRevenuePayment }, nil?: true |
#card_settlement ⇒ Increase::Models::Transaction::Source::CardSettlement?
A Card Settlement object. This field will be present in the JSON response if and only if ‘category` is equal to `card_settlement`. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
310 |
# File 'lib/increase/models/transaction.rb', line 310 optional :card_settlement, -> { Increase::Transaction::Source::CardSettlement }, nil?: true |
#cashback_payment ⇒ Increase::Models::Transaction::Source::CashbackPayment?
A Cashback Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `cashback_payment`. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month’s transactions.
319 |
# File 'lib/increase/models/transaction.rb', line 319 optional :cashback_payment, -> { Increase::Transaction::Source::CashbackPayment }, nil?: true |
#category ⇒ Symbol, Increase::Models::Transaction::Source::Category
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
147 |
# File 'lib/increase/models/transaction.rb', line 147 required :category, enum: -> { Increase::Transaction::Source::Category } |
#check_deposit_acceptance ⇒ Increase::Models::Transaction::Source::CheckDepositAcceptance?
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_acceptance`. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
329 330 331 |
# File 'lib/increase/models/transaction.rb', line 329 optional :check_deposit_acceptance, -> { Increase::Transaction::Source::CheckDepositAcceptance }, nil?: true |
#check_deposit_return ⇒ Increase::Models::Transaction::Source::CheckDepositReturn?
A Check Deposit Return object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_return`. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
342 |
# File 'lib/increase/models/transaction.rb', line 342 optional :check_deposit_return, -> { Increase::Transaction::Source::CheckDepositReturn }, nil?: true |
#check_transfer_deposit ⇒ Increase::Models::Transaction::Source::CheckTransferDeposit?
A Check Transfer Deposit object. This field will be present in the JSON response if and only if ‘category` is equal to `check_transfer_deposit`. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
351 352 353 354 355 |
# File 'lib/increase/models/transaction.rb', line 351 optional :check_transfer_deposit, -> { Increase::Transaction::Source::CheckTransferDeposit }, nil?: true |
#fednow_transfer_acknowledgement ⇒ Increase::Models::Transaction::Source::FednowTransferAcknowledgement?
A FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if ‘category` is equal to `fednow_transfer_acknowledgement`. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.
364 365 366 |
# File 'lib/increase/models/transaction.rb', line 364 optional :fednow_transfer_acknowledgement, -> { Increase::Transaction::Source::FednowTransferAcknowledgement }, nil?: true |
#fee_payment ⇒ Increase::Models::Transaction::Source::FeePayment?
A Fee Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `fee_payment`. A Fee Payment represents a payment made to Increase.
374 |
# File 'lib/increase/models/transaction.rb', line 374 optional :fee_payment, -> { Increase::Transaction::Source::FeePayment }, nil?: true |
#inbound_ach_transfer ⇒ Increase::Models::Transaction::Source::InboundACHTransfer?
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_ach_transfer`. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
383 |
# File 'lib/increase/models/transaction.rb', line 383 optional :inbound_ach_transfer, -> { Increase::Transaction::Source::InboundACHTransfer }, nil?: true |
#inbound_ach_transfer_return_intention ⇒ Increase::Models::Transaction::Source::InboundACHTransferReturnIntention?
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_ach_transfer_return_intention`. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
393 394 395 |
# File 'lib/increase/models/transaction.rb', line 393 optional :inbound_ach_transfer_return_intention, -> { Increase::Transaction::Source::InboundACHTransferReturnIntention }, nil?: true |
#inbound_check_adjustment ⇒ Increase::Models::Transaction::Source::InboundCheckAdjustment?
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_check_adjustment`. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
404 405 406 |
# File 'lib/increase/models/transaction.rb', line 404 optional :inbound_check_adjustment, -> { Increase::Transaction::Source::InboundCheckAdjustment }, nil?: true |
#inbound_check_deposit_return_intention ⇒ Increase::Models::Transaction::Source::InboundCheckDepositReturnIntention?
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_check_deposit_return_intention`. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
416 417 418 |
# File 'lib/increase/models/transaction.rb', line 416 optional :inbound_check_deposit_return_intention, -> { Increase::Transaction::Source::InboundCheckDepositReturnIntention }, nil?: true |
#inbound_fednow_transfer_confirmation ⇒ Increase::Models::Transaction::Source::InboundFednowTransferConfirmation?
An Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_fednow_transfer_confirmation`. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.
428 429 430 |
# File 'lib/increase/models/transaction.rb', line 428 optional :inbound_fednow_transfer_confirmation, -> { Increase::Transaction::Source::InboundFednowTransferConfirmation }, nil?: true |
#inbound_real_time_payments_transfer_confirmation ⇒ Increase::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation?
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_real_time_payments_transfer_confirmation`. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
440 441 442 |
# File 'lib/increase/models/transaction.rb', line 440 optional :inbound_real_time_payments_transfer_confirmation, -> { Increase::Transaction::Source::InboundRealTimePaymentsTransferConfirmation }, nil?: true |
#inbound_wire_reversal ⇒ Increase::Models::Transaction::Source::InboundWireReversal?
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_reversal`. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
452 |
# File 'lib/increase/models/transaction.rb', line 452 optional :inbound_wire_reversal, -> { Increase::Transaction::Source::InboundWireReversal }, nil?: true |
#inbound_wire_transfer ⇒ Increase::Models::Transaction::Source::InboundWireTransfer?
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_transfer`. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
461 |
# File 'lib/increase/models/transaction.rb', line 461 optional :inbound_wire_transfer, -> { Increase::Transaction::Source::InboundWireTransfer }, nil?: true |
#inbound_wire_transfer_reversal ⇒ Increase::Models::Transaction::Source::InboundWireTransferReversal?
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_transfer_reversal`. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
471 472 473 |
# File 'lib/increase/models/transaction.rb', line 471 optional :inbound_wire_transfer_reversal, -> { Increase::Transaction::Source::InboundWireTransferReversal }, nil?: true |
#interest_payment ⇒ Increase::Models::Transaction::Source::InterestPayment?
An Interest Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `interest_payment`. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
482 |
# File 'lib/increase/models/transaction.rb', line 482 optional :interest_payment, -> { Increase::Transaction::Source::InterestPayment }, nil?: true |
#internal_source ⇒ Increase::Models::Transaction::Source::InternalSource?
An Internal Source object. This field will be present in the JSON response if and only if ‘category` is equal to `internal_source`. A transaction between the user and Increase. See the `reason` attribute for more information.
490 |
# File 'lib/increase/models/transaction.rb', line 490 optional :internal_source, -> { Increase::Transaction::Source::InternalSource }, nil?: true |
#other ⇒ Increase::Models::Transaction::Source::Other?
If the category of this Transaction source is equal to ‘other`, this field will contain an empty object, otherwise it will contain null.
497 |
# File 'lib/increase/models/transaction.rb', line 497 optional :other, -> { Increase::Transaction::Source::Other }, nil?: true |
#real_time_payments_transfer_acknowledgement ⇒ Increase::Models::Transaction::Source::RealTimePaymentsTransferAcknowledgement?
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if ‘category` is equal to `real_time_payments_transfer_acknowledgement`. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
507 508 509 |
# File 'lib/increase/models/transaction.rb', line 507 optional :real_time_payments_transfer_acknowledgement, -> { Increase::Transaction::Source::RealTimePaymentsTransferAcknowledgement }, nil?: true |
#sample_funds ⇒ Increase::Models::Transaction::Source::SampleFunds?
A Sample Funds object. This field will be present in the JSON response if and only if ‘category` is equal to `sample_funds`. Sample funds for testing purposes.
517 |
# File 'lib/increase/models/transaction.rb', line 517 optional :sample_funds, -> { Increase::Transaction::Source::SampleFunds }, nil?: true |
#swift_transfer_intention ⇒ Increase::Models::Transaction::Source::SwiftTransferIntention?
A Swift Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_intention`. A Swift Transfer initiated via Increase.
525 526 527 |
# File 'lib/increase/models/transaction.rb', line 525 optional :swift_transfer_intention, -> { Increase::Transaction::Source::SwiftTransferIntention }, nil?: true |
#swift_transfer_return ⇒ Increase::Models::Transaction::Source::SwiftTransferReturn?
A Swift Transfer Return object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_return`. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.
535 |
# File 'lib/increase/models/transaction.rb', line 535 optional :swift_transfer_return, -> { Increase::Transaction::Source::SwiftTransferReturn }, nil?: true |
#wire_transfer_intention ⇒ Increase::Models::Transaction::Source::WireTransferIntention?
A Wire Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `wire_transfer_intention`. A Wire Transfer initiated via Increase and sent to a different bank.
543 544 545 546 547 |
# File 'lib/increase/models/transaction.rb', line 543 optional :wire_transfer_intention, -> { Increase::Transaction::Source::WireTransferIntention }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 757
|