Class: Increase::Models::Transaction::Source

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Category Classes: ACHTransferIntention, ACHTransferRejection, ACHTransferReturn, AccountRevenuePayment, AccountTransferIntention, BlockchainOfframpTransferSettlement, BlockchainOnrampTransferIntention, CardDisputeAcceptance, CardDisputeFinancial, CardDisputeLoss, CardFinancial, CardPushTransferAcceptance, CardRefund, CardRevenuePayment, CardSettlement, CashbackPayment, CheckDepositAcceptance, CheckDepositReturn, CheckTransferDeposit, FednowTransferAcknowledgement, FeePayment, InboundACHTransfer, InboundACHTransferReturnIntention, InboundCheckAdjustment, InboundCheckDepositReturnIntention, InboundFednowTransferConfirmation, InboundRealTimePaymentsTransferConfirmation, InboundWireReversal, InboundWireTransfer, InboundWireTransferReversal, InterestPayment, InternalSource, Other, RealTimePaymentsTransferAcknowledgement, SampleFunds, SwiftTransferIntention, SwiftTransferReturn, WireTransferIntention

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(transfer_id:) ⇒ Object

A Swift Transfer Return object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_return`. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.

Parameters:

  • transfer_id (String)

    The identifier of the Swift Transfer that led to this Transaction.



# File 'lib/increase/models/transaction.rb', line 546

Instance Attribute Details

#account_revenue_paymentIncrease::Models::Transaction::Source::AccountRevenuePayment?

An Account Revenue Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `account_revenue_payment`. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.



156
157
158
159
160
# File 'lib/increase/models/transaction.rb', line 156

optional :account_revenue_payment,
-> {
  Increase::Transaction::Source::AccountRevenuePayment
},
nil?: true

#account_transfer_intentionIncrease::Models::Transaction::Source::AccountTransferIntention?

An Account Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `account_transfer_intention`. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.



169
170
171
# File 'lib/increase/models/transaction.rb', line 169

optional :account_transfer_intention,
-> { Increase::Transaction::Source::AccountTransferIntention },
nil?: true

#ach_transfer_intentionIncrease::Models::Transaction::Source::ACHTransferIntention?

An ACH Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_intention`. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.



180
181
182
183
184
# File 'lib/increase/models/transaction.rb', line 180

optional :ach_transfer_intention,
-> {
  Increase::Transaction::Source::ACHTransferIntention
},
nil?: true

#ach_transfer_rejectionIncrease::Models::Transaction::Source::ACHTransferRejection?

An ACH Transfer Rejection object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_rejection`. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.



193
194
195
196
197
# File 'lib/increase/models/transaction.rb', line 193

optional :ach_transfer_rejection,
-> {
  Increase::Transaction::Source::ACHTransferRejection
},
nil?: true

#ach_transfer_returnIncrease::Models::Transaction::Source::ACHTransferReturn?

An ACH Transfer Return object. This field will be present in the JSON response if and only if ‘category` is equal to `ach_transfer_return`. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.



208
# File 'lib/increase/models/transaction.rb', line 208

optional :ach_transfer_return, -> { Increase::Transaction::Source::ACHTransferReturn }, nil?: true

#blockchain_offramp_transfer_settlementIncrease::Models::Transaction::Source::BlockchainOfframpTransferSettlement?

A Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_offramp_transfer_settlement`.



216
217
218
# File 'lib/increase/models/transaction.rb', line 216

optional :blockchain_offramp_transfer_settlement,
-> { Increase::Transaction::Source::BlockchainOfframpTransferSettlement },
nil?: true

#blockchain_onramp_transfer_intentionIncrease::Models::Transaction::Source::BlockchainOnrampTransferIntention?

A Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `blockchain_onramp_transfer_intention`.



226
227
228
# File 'lib/increase/models/transaction.rb', line 226

optional :blockchain_onramp_transfer_intention,
-> { Increase::Transaction::Source::BlockchainOnrampTransferIntention },
nil?: true

#card_dispute_acceptanceIncrease::Models::Transaction::Source::CardDisputeAcceptance?

A Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `card_dispute_acceptance`. Contains the details of a successful Card Dispute.



236
237
238
239
240
# File 'lib/increase/models/transaction.rb', line 236

optional :card_dispute_acceptance,
-> {
  Increase::Transaction::Source::CardDisputeAcceptance
},
nil?: true

#card_dispute_financialIncrease::Models::Transaction::Source::CardDisputeFinancial?

A Card Dispute Financial object. This field will be present in the JSON response if and only if ‘category` is equal to `card_dispute_financial`. Financial event related to a Card Dispute.



248
249
250
251
252
# File 'lib/increase/models/transaction.rb', line 248

optional :card_dispute_financial,
-> {
  Increase::Transaction::Source::CardDisputeFinancial
},
nil?: true

#card_dispute_lossIncrease::Models::Transaction::Source::CardDisputeLoss?

A Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if ‘category` is equal to `card_dispute_loss`. Contains the details of a lost Card Dispute.



260
# File 'lib/increase/models/transaction.rb', line 260

optional :card_dispute_loss, -> { Increase::Transaction::Source::CardDisputeLoss }, nil?: true

#card_financialIncrease::Models::Transaction::Source::CardFinancial?

A Card Financial object. This field will be present in the JSON response if and only if ‘category` is equal to `card_financial`. Card Financials are temporary holds placed on a customer’s funds with the intent to later clear a transaction.



268
# File 'lib/increase/models/transaction.rb', line 268

optional :card_financial, -> { Increase::Transaction::Source::CardFinancial }, nil?: true

#card_push_transfer_acceptanceIncrease::Models::Transaction::Source::CardPushTransferAcceptance?

A Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `card_push_transfer_acceptance`. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.



277
278
279
# File 'lib/increase/models/transaction.rb', line 277

optional :card_push_transfer_acceptance,
-> { Increase::Transaction::Source::CardPushTransferAcceptance },
nil?: true

#card_refundIncrease::Models::Transaction::Source::CardRefund?

A Card Refund object. This field will be present in the JSON response if and only if ‘category` is equal to `card_refund`. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.



289
# File 'lib/increase/models/transaction.rb', line 289

optional :card_refund, -> { Increase::Transaction::Source::CardRefund }, nil?: true

#card_revenue_paymentIncrease::Models::Transaction::Source::CardRevenuePayment?

A Card Revenue Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `card_revenue_payment`. Card Revenue Payments reflect earnings from fees on card transactions.



297
# File 'lib/increase/models/transaction.rb', line 297

optional :card_revenue_payment, -> { Increase::Transaction::Source::CardRevenuePayment }, nil?: true

#card_settlementIncrease::Models::Transaction::Source::CardSettlement?

A Card Settlement object. This field will be present in the JSON response if and only if ‘category` is equal to `card_settlement`. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.



307
# File 'lib/increase/models/transaction.rb', line 307

optional :card_settlement, -> { Increase::Transaction::Source::CardSettlement }, nil?: true

#cashback_paymentIncrease::Models::Transaction::Source::CashbackPayment?

A Cashback Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `cashback_payment`. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month’s transactions.



316
# File 'lib/increase/models/transaction.rb', line 316

optional :cashback_payment, -> { Increase::Transaction::Source::CashbackPayment }, nil?: true

#categorySymbol, Increase::Models::Transaction::Source::Category

The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.



147
# File 'lib/increase/models/transaction.rb', line 147

required :category, enum: -> { Increase::Transaction::Source::Category }

#check_deposit_acceptanceIncrease::Models::Transaction::Source::CheckDepositAcceptance?

A Check Deposit Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_acceptance`. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.



326
327
328
# File 'lib/increase/models/transaction.rb', line 326

optional :check_deposit_acceptance,
-> { Increase::Transaction::Source::CheckDepositAcceptance },
nil?: true

#check_deposit_returnIncrease::Models::Transaction::Source::CheckDepositReturn?

A Check Deposit Return object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_return`. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.



339
# File 'lib/increase/models/transaction.rb', line 339

optional :check_deposit_return, -> { Increase::Transaction::Source::CheckDepositReturn }, nil?: true

#check_transfer_depositIncrease::Models::Transaction::Source::CheckTransferDeposit?

A Check Transfer Deposit object. This field will be present in the JSON response if and only if ‘category` is equal to `check_transfer_deposit`. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.



348
349
350
351
352
# File 'lib/increase/models/transaction.rb', line 348

optional :check_transfer_deposit,
-> {
  Increase::Transaction::Source::CheckTransferDeposit
},
nil?: true

#fednow_transfer_acknowledgementIncrease::Models::Transaction::Source::FednowTransferAcknowledgement?

A FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if ‘category` is equal to `fednow_transfer_acknowledgement`. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.



361
362
363
# File 'lib/increase/models/transaction.rb', line 361

optional :fednow_transfer_acknowledgement,
-> { Increase::Transaction::Source::FednowTransferAcknowledgement },
nil?: true

#fee_paymentIncrease::Models::Transaction::Source::FeePayment?

A Fee Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `fee_payment`. A Fee Payment represents a payment made to Increase.



371
# File 'lib/increase/models/transaction.rb', line 371

optional :fee_payment, -> { Increase::Transaction::Source::FeePayment }, nil?: true

#inbound_ach_transferIncrease::Models::Transaction::Source::InboundACHTransfer?

An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_ach_transfer`. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.



380
# File 'lib/increase/models/transaction.rb', line 380

optional :inbound_ach_transfer, -> { Increase::Transaction::Source::InboundACHTransfer }, nil?: true

#inbound_ach_transfer_return_intentionIncrease::Models::Transaction::Source::InboundACHTransferReturnIntention?

An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_ach_transfer_return_intention`. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.



390
391
392
# File 'lib/increase/models/transaction.rb', line 390

optional :inbound_ach_transfer_return_intention,
-> { Increase::Transaction::Source::InboundACHTransferReturnIntention },
nil?: true

#inbound_check_adjustmentIncrease::Models::Transaction::Source::InboundCheckAdjustment?

An Inbound Check Adjustment object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_check_adjustment`. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.



401
402
403
# File 'lib/increase/models/transaction.rb', line 401

optional :inbound_check_adjustment,
-> { Increase::Transaction::Source::InboundCheckAdjustment },
nil?: true

#inbound_check_deposit_return_intentionIncrease::Models::Transaction::Source::InboundCheckDepositReturnIntention?

An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_check_deposit_return_intention`. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.



413
414
415
# File 'lib/increase/models/transaction.rb', line 413

optional :inbound_check_deposit_return_intention,
-> { Increase::Transaction::Source::InboundCheckDepositReturnIntention },
nil?: true

#inbound_fednow_transfer_confirmationIncrease::Models::Transaction::Source::InboundFednowTransferConfirmation?

An Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_fednow_transfer_confirmation`. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.



425
426
427
# File 'lib/increase/models/transaction.rb', line 425

optional :inbound_fednow_transfer_confirmation,
-> { Increase::Transaction::Source::InboundFednowTransferConfirmation },
nil?: true

#inbound_real_time_payments_transfer_confirmationIncrease::Models::Transaction::Source::InboundRealTimePaymentsTransferConfirmation?

An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_real_time_payments_transfer_confirmation`. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.



437
438
439
# File 'lib/increase/models/transaction.rb', line 437

optional :inbound_real_time_payments_transfer_confirmation,
-> { Increase::Transaction::Source::InboundRealTimePaymentsTransferConfirmation },
nil?: true

#inbound_wire_reversalIncrease::Models::Transaction::Source::InboundWireReversal?

An Inbound Wire Reversal object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_reversal`. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.



449
# File 'lib/increase/models/transaction.rb', line 449

optional :inbound_wire_reversal, -> { Increase::Transaction::Source::InboundWireReversal }, nil?: true

#inbound_wire_transferIncrease::Models::Transaction::Source::InboundWireTransfer?

An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_transfer`. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.



458
# File 'lib/increase/models/transaction.rb', line 458

optional :inbound_wire_transfer, -> { Increase::Transaction::Source::InboundWireTransfer }, nil?: true

#inbound_wire_transfer_reversalIncrease::Models::Transaction::Source::InboundWireTransferReversal?

An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_wire_transfer_reversal`. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.



468
469
470
# File 'lib/increase/models/transaction.rb', line 468

optional :inbound_wire_transfer_reversal,
-> { Increase::Transaction::Source::InboundWireTransferReversal },
nil?: true

#interest_paymentIncrease::Models::Transaction::Source::InterestPayment?

An Interest Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `interest_payment`. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.



479
# File 'lib/increase/models/transaction.rb', line 479

optional :interest_payment, -> { Increase::Transaction::Source::InterestPayment }, nil?: true

#internal_sourceIncrease::Models::Transaction::Source::InternalSource?

An Internal Source object. This field will be present in the JSON response if and only if ‘category` is equal to `internal_source`. A transaction between the user and Increase. See the `reason` attribute for more information.



487
# File 'lib/increase/models/transaction.rb', line 487

optional :internal_source, -> { Increase::Transaction::Source::InternalSource }, nil?: true

#otherIncrease::Models::Transaction::Source::Other?

If the category of this Transaction source is equal to ‘other`, this field will contain an empty object, otherwise it will contain null.



494
# File 'lib/increase/models/transaction.rb', line 494

optional :other, -> { Increase::Transaction::Source::Other }, nil?: true

#real_time_payments_transfer_acknowledgementIncrease::Models::Transaction::Source::RealTimePaymentsTransferAcknowledgement?

A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if ‘category` is equal to `real_time_payments_transfer_acknowledgement`. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.



504
505
506
# File 'lib/increase/models/transaction.rb', line 504

optional :real_time_payments_transfer_acknowledgement,
-> { Increase::Transaction::Source::RealTimePaymentsTransferAcknowledgement },
nil?: true

#sample_fundsIncrease::Models::Transaction::Source::SampleFunds?

A Sample Funds object. This field will be present in the JSON response if and only if ‘category` is equal to `sample_funds`. Sample funds for testing purposes.



514
# File 'lib/increase/models/transaction.rb', line 514

optional :sample_funds, -> { Increase::Transaction::Source::SampleFunds }, nil?: true

#swift_transfer_intentionIncrease::Models::Transaction::Source::SwiftTransferIntention?

A Swift Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_intention`. A Swift Transfer initiated via Increase.



522
523
524
# File 'lib/increase/models/transaction.rb', line 522

optional :swift_transfer_intention,
-> { Increase::Transaction::Source::SwiftTransferIntention },
nil?: true

#swift_transfer_returnIncrease::Models::Transaction::Source::SwiftTransferReturn?

A Swift Transfer Return object. This field will be present in the JSON response if and only if ‘category` is equal to `swift_transfer_return`. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.



532
# File 'lib/increase/models/transaction.rb', line 532

optional :swift_transfer_return, -> { Increase::Transaction::Source::SwiftTransferReturn }, nil?: true

#wire_transfer_intentionIncrease::Models::Transaction::Source::WireTransferIntention?

A Wire Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `wire_transfer_intention`. A Wire Transfer initiated via Increase and sent to a different bank.



540
541
542
543
544
# File 'lib/increase/models/transaction.rb', line 540

optional :wire_transfer_intention,
-> {
  Increase::Transaction::Source::WireTransferIntention
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 754