Class: Increase::Models::Transaction::Source::ACHTransferIntention
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::ACHTransferIntention
- Defined in:
- lib/increase/models/transaction.rb
Overview
Instance Attribute Summary collapse
-
#account_number ⇒ String
The account number for the destination account.
-
#amount ⇒ Integer
The amount in the minor unit of the transaction’s currency.
-
#routing_number ⇒ String
The American Bankers’ Association (ABA) Routing Transit Number (RTN) for the destination account.
-
#statement_descriptor ⇒ String
A description set when the ACH Transfer was created.
-
#transfer_id ⇒ String
The identifier of the ACH Transfer that led to this Transaction.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#account_number ⇒ String
The account number for the destination account.
874 |
# File 'lib/increase/models/transaction.rb', line 874 required :account_number, String |
#amount ⇒ Integer
The amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
881 |
# File 'lib/increase/models/transaction.rb', line 881 required :amount, Integer |
#routing_number ⇒ String
The American Bankers’ Association (ABA) Routing Transit Number (RTN) for the destination account.
888 |
# File 'lib/increase/models/transaction.rb', line 888 required :routing_number, String |
#statement_descriptor ⇒ String
A description set when the ACH Transfer was created.
894 |
# File 'lib/increase/models/transaction.rb', line 894 required :statement_descriptor, String |
#transfer_id ⇒ String
The identifier of the ACH Transfer that led to this Transaction.
900 |
# File 'lib/increase/models/transaction.rb', line 900 required :transfer_id, String |