Class: Increase::Models::Transaction::Source::ACHTransferReturn
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::ACHTransferReturn
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: ReturnReasonCode
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The ISO 8601 date and time at which the transfer was created.
-
#raw_return_reason_code ⇒ String
The three character ACH return code, in the range R01 to R85.
-
#return_reason_code ⇒ Symbol, Increase::Models::Transaction::Source::ACHTransferReturn::ReturnReasonCode
Why the ACH Transfer was returned.
-
#trace_number ⇒ String
A 15 digit number that was generated by the bank that initiated the return.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this return.
-
#transfer_id ⇒ String
The identifier of the ACH Transfer associated with this return.
Instance Method Summary collapse
-
#initialize(created_at:, raw_return_reason_code:, return_reason_code:, trace_number:, transaction_id:, transfer_id:) ⇒ Object
constructor
An ACH Transfer Return object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, raw_return_reason_code:, return_reason_code:, trace_number:, transaction_id:, transfer_id:) ⇒ Object
An ACH Transfer Return object. This field will be present in the JSON response
if and only if category is equal to ach_transfer_return. An ACH Transfer
Return is created when an ACH Transfer is returned by the receiving bank. It
offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within
the first two business days after the transfer is initiated, but can occur much
later. The return appears as a new posted Transaction; no Pending Transaction is
created.
|
|
# File 'lib/increase/models/transaction.rb', line 1158
|
Instance Attribute Details
#created_at ⇒ Time
The ISO 8601 date and time at which the transfer was created.
1120 |
# File 'lib/increase/models/transaction.rb', line 1120 required :created_at, Time |
#raw_return_reason_code ⇒ String
The three character ACH return code, in the range R01 to R85.
1126 |
# File 'lib/increase/models/transaction.rb', line 1126 required :raw_return_reason_code, String |
#return_reason_code ⇒ Symbol, Increase::Models::Transaction::Source::ACHTransferReturn::ReturnReasonCode
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
1133 1134 |
# File 'lib/increase/models/transaction.rb', line 1133 required :return_reason_code, enum: -> { Increase::Transaction::Source::ACHTransferReturn::ReturnReasonCode } |
#trace_number ⇒ String
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
1143 |
# File 'lib/increase/models/transaction.rb', line 1143 required :trace_number, String |
#transaction_id ⇒ String
The identifier of the Transaction associated with this return.
1149 |
# File 'lib/increase/models/transaction.rb', line 1149 required :transaction_id, String |
#transfer_id ⇒ String
The identifier of the ACH Transfer associated with this return. This matches the
original Transaction's source.ach_transfer_intention.transfer_id.
1156 |
# File 'lib/increase/models/transaction.rb', line 1156 required :transfer_id, String |
Instance Method Details
#to_hash ⇒ {
617 |
# File 'sig/increase/models/transaction.rbs', line 617
def to_hash: -> {
|