Class: Increase::Models::Transaction::Source::AccountRevenuePayment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::AccountRevenuePayment
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#accrued_on_account_id ⇒ String
The account on which the account revenue was accrued.
-
#period_end ⇒ Time
The end of the period for which this transaction paid account revenue.
-
#period_start ⇒ Time
The start of the period for which this transaction paid account revenue.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
472 |
# File 'sig/increase/models/transaction.rbs', line 472
def initialize: (
|
Instance Attribute Details
#accrued_on_account_id ⇒ String
The account on which the account revenue was accrued.
767 |
# File 'lib/increase/models/transaction.rb', line 767 required :accrued_on_account_id, String |
#period_end ⇒ Time
The end of the period for which this transaction paid account revenue.
773 |
# File 'lib/increase/models/transaction.rb', line 773 required :period_end, Time |
#period_start ⇒ Time
The start of the period for which this transaction paid account revenue.
779 |
# File 'lib/increase/models/transaction.rb', line 779 required :period_start, Time |
Instance Method Details
#to_hash ⇒ {
478 |
# File 'sig/increase/models/transaction.rbs', line 478
def to_hash: -> {
|