Class: Increase::Models::Transaction::Source::CardDisputeFinancial
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardDisputeFinancial
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: Network Classes: Visa
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount of the financial event.
-
#network ⇒ Symbol, Increase::Models::Transaction::Source::CardDisputeFinancial::Network
The network that the Card Dispute is associated with.
-
#transaction_id ⇒ String
The identifier of the Transaction that was created to credit or debit the disputed funds to or from your account.
-
#visa ⇒ Increase::Models::Transaction::Source::CardDisputeFinancial::Visa?
Information for events related to card dispute for card payments processed over Visa's network.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, network:, transaction_id:, visa:) ⇒ Object
constructor
A Card Dispute Financial object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, network:, transaction_id:, visa:) ⇒ Object
A Card Dispute Financial object. This field will be present in the JSON response
if and only if category is equal to card_dispute_financial. Financial event
related to a Card Dispute.
|
|
# File 'lib/increase/models/transaction.rb', line 1524
|
Instance Attribute Details
#amount ⇒ Integer
The amount of the financial event.
1501 |
# File 'lib/increase/models/transaction.rb', line 1501 required :amount, Integer |
#network ⇒ Symbol, Increase::Models::Transaction::Source::CardDisputeFinancial::Network
The network that the Card Dispute is associated with.
1507 |
# File 'lib/increase/models/transaction.rb', line 1507 required :network, enum: -> { Increase::Transaction::Source::CardDisputeFinancial::Network } |
#transaction_id ⇒ String
The identifier of the Transaction that was created to credit or debit the disputed funds to or from your account.
1514 |
# File 'lib/increase/models/transaction.rb', line 1514 required :transaction_id, String |
#visa ⇒ Increase::Models::Transaction::Source::CardDisputeFinancial::Visa?
Information for events related to card dispute for card payments processed over
Visa's network. This field will be present in the JSON response if and only if
network is equal to visa.
1522 |
# File 'lib/increase/models/transaction.rb', line 1522 required :visa, -> { Increase::Transaction::Source::CardDisputeFinancial::Visa }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 1555
|
Instance Method Details
#to_hash ⇒ {
990 |
# File 'sig/increase/models/transaction.rbs', line 990
def to_hash: -> {
|