Class: Increase::Models::Transaction::Source::CardDisputeFinancial::Visa
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardDisputeFinancial::Visa
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: EventType
Instance Attribute Summary collapse
-
#event_type ⇒ Symbol, Increase::Models::Transaction::Source::CardDisputeFinancial::Visa::EventType
The type of card dispute financial event.
Instance Method Summary collapse
-
#initialize(event_type:) ⇒ Object
constructor
Information for events related to card dispute for card payments processed over Visa's network.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_type:) ⇒ Object
Information for events related to card dispute for card payments processed over
Visa's network. This field will be present in the JSON response if and only if
network is equal to visa.
|
|
# File 'lib/increase/models/transaction.rb', line 1386
|
Instance Attribute Details
#event_type ⇒ Symbol, Increase::Models::Transaction::Source::CardDisputeFinancial::Visa::EventType
The type of card dispute financial event.
1384 |
# File 'lib/increase/models/transaction.rb', line 1384 required :event_type, enum: -> { Increase::Transaction::Source::CardDisputeFinancial::Visa::EventType } |
Instance Method Details
#to_hash ⇒ {
1023 |
# File 'sig/increase/models/transaction.rbs', line 1023
def to_hash: -> {
|