Class: Increase::Models::Transaction::Source::CardDisputeLoss
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardDisputeLoss
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#explanation ⇒ String
Why the Card Dispute was lost.
-
#lost_at ⇒ Time
The ISO 8601 date and time at which the Card Dispute was lost.
-
#transaction_id ⇒ String
The identifier of the Transaction that was created to debit the disputed funds from your account.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1075 |
# File 'sig/increase/models/transaction.rbs', line 1075
def initialize: (
|
Instance Attribute Details
#explanation ⇒ String
Why the Card Dispute was lost.
1432 |
# File 'lib/increase/models/transaction.rb', line 1432 required :explanation, String |
#lost_at ⇒ Time
The ISO 8601 date and time at which the Card Dispute was lost.
1439 |
# File 'lib/increase/models/transaction.rb', line 1439 required :lost_at, Time |
#transaction_id ⇒ String
The identifier of the Transaction that was created to debit the disputed funds from your account.
1446 |
# File 'lib/increase/models/transaction.rb', line 1446 required :transaction_id, String |
Instance Method Details
#to_hash ⇒ {
1081 |
# File 'sig/increase/models/transaction.rbs', line 1081
def to_hash: -> {
|