Class: Increase::Models::Transaction::Source::CardFinancial

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#card_financial

Defined Under Namespace

Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.



# File 'lib/increase/models/transaction.rb', line 1855

Instance Attribute Details

#actionerSymbol, Increase::Models::Transaction::Source::CardFinancial::Actioner

Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.

Parameters:

  • value (Increase::Models::Transaction::Source::CardFinancial::actioner)

Returns:



1678
# File 'lib/increase/models/transaction.rb', line 1678

required :actioner, enum: -> { Increase::Transaction::Source::CardFinancial::Actioner }

#additional_amountsIncrease::Models::Transaction::Source::CardFinancial::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.

Parameters:

  • value (Increase::Transaction::Source::CardFinancial::AdditionalAmounts)

Returns:



1686
# File 'lib/increase/models/transaction.rb', line 1686

required :additional_amounts, -> { Increase::Transaction::Source::CardFinancial::AdditionalAmounts }

#amountInteger

The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1693
# File 'lib/increase/models/transaction.rb', line 1693

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


1699
# File 'lib/increase/models/transaction.rb', line 1699

required :card_payment_id, String

#currencySymbol, Increase::Models::Transaction::Source::CardFinancial::Currency

The ISO 4217 code for the transaction's currency.

Parameters:

  • value (Increase::Models::Transaction::Source::CardFinancial::currency)

Returns:



1706
# File 'lib/increase/models/transaction.rb', line 1706

required :currency, enum: -> { Increase::Transaction::Source::CardFinancial::Currency }

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1713
# File 'lib/increase/models/transaction.rb', line 1713

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::Transaction::Source::CardFinancial::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.

Parameters:

  • value (Increase::Models::Transaction::Source::CardFinancial::direction)

Returns:



1720
# File 'lib/increase/models/transaction.rb', line 1720

required :direction, enum: -> { Increase::Transaction::Source::CardFinancial::Direction }

#idString

The Card Financial identifier.

Parameters:

  • value (String)

Returns:

  • (String)


1671
# File 'lib/increase/models/transaction.rb', line 1671

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1727
# File 'lib/increase/models/transaction.rb', line 1727

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1734
# File 'lib/increase/models/transaction.rb', line 1734

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1740
# File 'lib/increase/models/transaction.rb', line 1740

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Parameters:

  • value (String)

Returns:

  • (String)


1746
# File 'lib/increase/models/transaction.rb', line 1746

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Parameters:

  • value (String)

Returns:

  • (String)


1752
# File 'lib/increase/models/transaction.rb', line 1752

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1759
# File 'lib/increase/models/transaction.rb', line 1759

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1765
# File 'lib/increase/models/transaction.rb', line 1765

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::Transaction::Source::CardFinancial::NetworkDetails

Fields specific to the network.

Parameters:

  • value (Increase::Transaction::Source::CardFinancial::NetworkDetails)

Returns:



1771
# File 'lib/increase/models/transaction.rb', line 1771

required :network_details, -> { Increase::Transaction::Source::CardFinancial::NetworkDetails }

#network_identifiersIncrease::Models::Transaction::Source::CardFinancial::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.

Parameters:

  • value (Increase::Transaction::Source::CardFinancial::NetworkIdentifiers)

Returns:



1777
# File 'lib/increase/models/transaction.rb', line 1777

required :network_identifiers, -> { Increase::Transaction::Source::CardFinancial::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


1785
# File 'lib/increase/models/transaction.rb', line 1785

required :network_risk_score, Integer, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1792
# File 'lib/increase/models/transaction.rb', line 1792

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The pending amount in the minor unit of the transaction's presentment currency.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


1798
# File 'lib/increase/models/transaction.rb', line 1798

required :presentment_amount, Integer

#presentment_currencyString

The ISO 4217 code for the transaction's presentment currency.

Parameters:

  • value (String)

Returns:

  • (String)


1805
# File 'lib/increase/models/transaction.rb', line 1805

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::Transaction::Source::CardFinancial::ProcessingCategory

The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.

Parameters:

  • value (Increase::Models::Transaction::Source::CardFinancial::processing_category)

Returns:



1812
1813
# File 'lib/increase/models/transaction.rb', line 1812

required :processing_category,
enum: -> { Increase::Transaction::Source::CardFinancial::ProcessingCategory }

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this transaction.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1820
# File 'lib/increase/models/transaction.rb', line 1820

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::Transaction::Source::CardFinancial::SchemeFee>

The scheme fees associated with this card financial.

Parameters:

  • value (::Array[Increase::Transaction::Source::CardFinancial::SchemeFee])

Returns:



1826
1827
# File 'lib/increase/models/transaction.rb', line 1826

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardFinancial::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1834
# File 'lib/increase/models/transaction.rb', line 1834

required :terminal_id, String, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


1840
# File 'lib/increase/models/transaction.rb', line 1840

required :transaction_id, String

#typeSymbol, Increase::Models::Transaction::Source::CardFinancial::Type

A constant representing the object's type. For this resource it will always be card_financial.

Parameters:

  • value (Increase::Models::Transaction::Source::CardFinancial::type_)

Returns:



1847
# File 'lib/increase/models/transaction.rb', line 1847

required :type, enum: -> { Increase::Transaction::Source::CardFinancial::Type }

#verificationIncrease::Models::Transaction::Source::CardFinancial::Verification

Fields related to verification of cardholder-provided values.

Parameters:

  • value (Increase::Transaction::Source::CardFinancial::Verification)

Returns:



1853
# File 'lib/increase/models/transaction.rb', line 1853

required :verification, -> { Increase::Transaction::Source::CardFinancial::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 1973

Instance Method Details

#to_hash{

Returns:

  • ({)


1213
# File 'sig/increase/models/transaction.rbs', line 1213

def to_hash: -> {