Class: Increase::Models::Transaction::Source::CardFinancial
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardFinancial
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification
Instance Attribute Summary collapse
-
#actioner ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Actioner
Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
#additional_amounts ⇒ Increase::Models::Transaction::Source::CardFinancial::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM surcharges fees.
-
#amount ⇒ Integer
The pending amount in the minor unit of the transaction's currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Currency
The ISO 4217 code for the transaction's currency.
-
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
#direction ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
#id ⇒ String
The Card Financial identifier.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
#merchant_city ⇒ String?
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_details ⇒ Increase::Models::Transaction::Source::CardFinancial::NetworkDetails
Fields specific to the
network. -
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardFinancial::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
-
#network_risk_score ⇒ Integer?
The risk score generated by the card network.
-
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#processing_category ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::ProcessingCategory
The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
-
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardFinancial::SchemeFee>
The scheme fees associated with this card financial.
-
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Type
A constant representing the object's type.
-
#verification ⇒ Increase::Models::Transaction::Source::CardFinancial::Verification
Fields related to verification of cardholder-provided values.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for a specific request or transaction.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object
Network-specific identifiers for a specific request or transaction.
|
|
# File 'lib/increase/models/transaction.rb', line 1836
|
Instance Attribute Details
#actioner ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Actioner
Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
1659 |
# File 'lib/increase/models/transaction.rb', line 1659 required :actioner, enum: -> { Increase::Transaction::Source::CardFinancial::Actioner } |
#additional_amounts ⇒ Increase::Models::Transaction::Source::CardFinancial::AdditionalAmounts
Additional amounts associated with the card authorization, such as ATM
surcharges fees. These are usually a subset of the amount field and are used
to provide more detailed information about the transaction.
1667 |
# File 'lib/increase/models/transaction.rb', line 1667 required :additional_amounts, -> { Increase::Transaction::Source::CardFinancial::AdditionalAmounts } |
#amount ⇒ Integer
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
1674 |
# File 'lib/increase/models/transaction.rb', line 1674 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
1680 |
# File 'lib/increase/models/transaction.rb', line 1680 required :card_payment_id, String |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Currency
The ISO 4217 code for the transaction's currency.
1687 |
# File 'lib/increase/models/transaction.rb', line 1687 required :currency, enum: -> { Increase::Transaction::Source::CardFinancial::Currency } |
#digital_wallet_token_id ⇒ String?
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
1694 |
# File 'lib/increase/models/transaction.rb', line 1694 required :digital_wallet_token_id, String, nil?: true |
#direction ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Direction
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
1701 |
# File 'lib/increase/models/transaction.rb', line 1701 required :direction, enum: -> { Increase::Transaction::Source::CardFinancial::Direction } |
#id ⇒ String
The Card Financial identifier.
1652 |
# File 'lib/increase/models/transaction.rb', line 1652 required :id, String |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
1708 |
# File 'lib/increase/models/transaction.rb', line 1708 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
1715 |
# File 'lib/increase/models/transaction.rb', line 1715 required :merchant_category_code, String |
#merchant_city ⇒ String?
The city the merchant resides in.
1721 |
# File 'lib/increase/models/transaction.rb', line 1721 required :merchant_city, String, nil?: true |
#merchant_country ⇒ String
The country the merchant resides in.
1727 |
# File 'lib/increase/models/transaction.rb', line 1727 required :merchant_country, String |
#merchant_descriptor ⇒ String
The merchant descriptor of the merchant the card is transacting with.
1733 |
# File 'lib/increase/models/transaction.rb', line 1733 required :merchant_descriptor, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
1740 |
# File 'lib/increase/models/transaction.rb', line 1740 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
1746 |
# File 'lib/increase/models/transaction.rb', line 1746 required :merchant_state, String, nil?: true |
#network_details ⇒ Increase::Models::Transaction::Source::CardFinancial::NetworkDetails
Fields specific to the network.
1752 |
# File 'lib/increase/models/transaction.rb', line 1752 required :network_details, -> { Increase::Transaction::Source::CardFinancial::NetworkDetails } |
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardFinancial::NetworkIdentifiers
Network-specific identifiers for a specific request or transaction.
1758 |
# File 'lib/increase/models/transaction.rb', line 1758 required :network_identifiers, -> { Increase::Transaction::Source::CardFinancial::NetworkIdentifiers } |
#network_risk_score ⇒ Integer?
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
1766 |
# File 'lib/increase/models/transaction.rb', line 1766 required :network_risk_score, Integer, nil?: true |
#physical_card_id ⇒ String?
If the authorization was made in-person with a physical card, the Physical Card that was used.
1773 |
# File 'lib/increase/models/transaction.rb', line 1773 required :physical_card_id, String, nil?: true |
#presentment_amount ⇒ Integer
The pending amount in the minor unit of the transaction's presentment currency.
1779 |
# File 'lib/increase/models/transaction.rb', line 1779 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
1786 |
# File 'lib/increase/models/transaction.rb', line 1786 required :presentment_currency, String |
#processing_category ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::ProcessingCategory
The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
1793 1794 |
# File 'lib/increase/models/transaction.rb', line 1793 required :processing_category, enum: -> { Increase::Transaction::Source::CardFinancial::ProcessingCategory } |
#real_time_decision_id ⇒ String?
The identifier of the Real-Time Decision sent to approve or decline this transaction.
1801 |
# File 'lib/increase/models/transaction.rb', line 1801 required :real_time_decision_id, String, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardFinancial::SchemeFee>
The scheme fees associated with this card financial.
1807 1808 |
# File 'lib/increase/models/transaction.rb', line 1807 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardFinancial::SchemeFee] } |
#terminal_id ⇒ String?
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
1815 |
# File 'lib/increase/models/transaction.rb', line 1815 required :terminal_id, String, nil?: true |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
1821 |
# File 'lib/increase/models/transaction.rb', line 1821 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardFinancial::Type
A constant representing the object's type. For this resource it will always be
card_financial.
1828 |
# File 'lib/increase/models/transaction.rb', line 1828 required :type, enum: -> { Increase::Transaction::Source::CardFinancial::Type } |
#verification ⇒ Increase::Models::Transaction::Source::CardFinancial::Verification
Fields related to verification of cardholder-provided values.
1834 |
# File 'lib/increase/models/transaction.rb', line 1834 required :verification, -> { Increase::Transaction::Source::CardFinancial::Verification } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 1954
|
Instance Method Details
#to_hash ⇒ {
1208 |
# File 'sig/increase/models/transaction.rbs', line 1208
def to_hash: -> {
|