Class: Increase::Models::Transaction::Source::CardFinancial

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Actioner, Currency, Direction, ProcessingCategory, Type Classes: AdditionalAmounts, NetworkDetails, NetworkIdentifiers, SchemeFee, Verification

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(authorization_identification_response:, retrieval_reference_number:, trace_number:, transaction_id:) ⇒ Object

Some parameter documentations has been truncated, see NetworkIdentifiers for more details.

Network-specific identifiers for a specific request or transaction.

Parameters:

  • authorization_identification_response (String, nil)

    The randomly generated 6-character Authorization Identification Response code se

  • retrieval_reference_number (String, nil)

    A life-cycle identifier used across e.g., an authorization and a reversal. Expec

  • trace_number (String, nil)

    A counter used to verify an individual authorization. Expected to be unique per

  • transaction_id (String, nil)

    A globally unique transaction identifier provided by the card network, used acro



# File 'lib/increase/models/transaction.rb', line 1648

Instance Attribute Details

#actionerSymbol, Increase::Models::Transaction::Source::CardFinancial::Actioner

Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.



1471
# File 'lib/increase/models/transaction.rb', line 1471

required :actioner, enum: -> { Increase::Transaction::Source::CardFinancial::Actioner }

#additional_amountsIncrease::Models::Transaction::Source::CardFinancial::AdditionalAmounts

Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the ‘amount` field and are used to provide more detailed information about the transaction.



1479
# File 'lib/increase/models/transaction.rb', line 1479

required :additional_amounts, -> { Increase::Transaction::Source::CardFinancial::AdditionalAmounts }

#amountInteger

The pending amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


1486
# File 'lib/increase/models/transaction.rb', line 1486

required :amount, Integer

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Returns:

  • (String)


1492
# File 'lib/increase/models/transaction.rb', line 1492

required :card_payment_id, String

#currencySymbol, Increase::Models::Transaction::Source::CardFinancial::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s currency.



1499
# File 'lib/increase/models/transaction.rb', line 1499

required :currency, enum: -> { Increase::Transaction::Source::CardFinancial::Currency }

#digital_wallet_token_idString?

If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.

Returns:

  • (String, nil)


1506
# File 'lib/increase/models/transaction.rb', line 1506

required :digital_wallet_token_id, String, nil?: true

#directionSymbol, Increase::Models::Transaction::Source::CardFinancial::Direction

The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.



1513
# File 'lib/increase/models/transaction.rb', line 1513

required :direction, enum: -> { Increase::Transaction::Source::CardFinancial::Direction }

#idString

The Card Financial identifier.

Returns:

  • (String)


1464
# File 'lib/increase/models/transaction.rb', line 1464

required :id, String

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


1520
# File 'lib/increase/models/transaction.rb', line 1520

required :merchant_acceptor_id, String

#merchant_category_codeString

The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.

Returns:

  • (String)


1527
# File 'lib/increase/models/transaction.rb', line 1527

required :merchant_category_code, String

#merchant_cityString?

The city the merchant resides in.

Returns:

  • (String, nil)


1533
# File 'lib/increase/models/transaction.rb', line 1533

required :merchant_city, String, nil?: true

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


1539
# File 'lib/increase/models/transaction.rb', line 1539

required :merchant_country, String

#merchant_descriptorString

The merchant descriptor of the merchant the card is transacting with.

Returns:

  • (String)


1545
# File 'lib/increase/models/transaction.rb', line 1545

required :merchant_descriptor, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.

Returns:

  • (String, nil)


1552
# File 'lib/increase/models/transaction.rb', line 1552

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


1558
# File 'lib/increase/models/transaction.rb', line 1558

required :merchant_state, String, nil?: true

#network_detailsIncrease::Models::Transaction::Source::CardFinancial::NetworkDetails

Fields specific to the ‘network`.



1564
# File 'lib/increase/models/transaction.rb', line 1564

required :network_details, -> { Increase::Transaction::Source::CardFinancial::NetworkDetails }

#network_identifiersIncrease::Models::Transaction::Source::CardFinancial::NetworkIdentifiers

Network-specific identifiers for a specific request or transaction.



1570
# File 'lib/increase/models/transaction.rb', line 1570

required :network_identifiers, -> { Increase::Transaction::Source::CardFinancial::NetworkIdentifiers }

#network_risk_scoreInteger?

The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.

Returns:

  • (Integer, nil)


1578
# File 'lib/increase/models/transaction.rb', line 1578

required :network_risk_score, Integer, nil?: true

#physical_card_idString?

If the authorization was made in-person with a physical card, the Physical Card that was used.

Returns:

  • (String, nil)


1585
# File 'lib/increase/models/transaction.rb', line 1585

required :physical_card_id, String, nil?: true

#presentment_amountInteger

The pending amount in the minor unit of the transaction’s presentment currency.

Returns:

  • (Integer)


1591
# File 'lib/increase/models/transaction.rb', line 1591

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.

Returns:

  • (String)


1598
# File 'lib/increase/models/transaction.rb', line 1598

required :presentment_currency, String

#processing_categorySymbol, Increase::Models::Transaction::Source::CardFinancial::ProcessingCategory

The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.



1605
1606
# File 'lib/increase/models/transaction.rb', line 1605

required :processing_category,
enum: -> { Increase::Transaction::Source::CardFinancial::ProcessingCategory }

#real_time_decision_idString?

The identifier of the Real-Time Decision sent to approve or decline this transaction.

Returns:

  • (String, nil)


1613
# File 'lib/increase/models/transaction.rb', line 1613

required :real_time_decision_id, String, nil?: true

#scheme_feesArray<Increase::Models::Transaction::Source::CardFinancial::SchemeFee>

The scheme fees associated with this card financial.



1619
1620
# File 'lib/increase/models/transaction.rb', line 1619

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardFinancial::SchemeFee] }

#terminal_idString?

The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.

Returns:

  • (String, nil)


1627
# File 'lib/increase/models/transaction.rb', line 1627

required :terminal_id, String, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Returns:

  • (String)


1633
# File 'lib/increase/models/transaction.rb', line 1633

required :transaction_id, String

#typeSymbol, Increase::Models::Transaction::Source::CardFinancial::Type

A constant representing the object’s type. For this resource it will always be ‘card_financial`.



1640
# File 'lib/increase/models/transaction.rb', line 1640

required :type, enum: -> { Increase::Transaction::Source::CardFinancial::Type }

#verificationIncrease::Models::Transaction::Source::CardFinancial::Verification

Fields related to verification of cardholder-provided values.



1646
# File 'lib/increase/models/transaction.rb', line 1646

required :verification, -> { Increase::Transaction::Source::CardFinancial::Verification }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 1728