Class: Increase::Models::Transaction::Source::CardFinancial::NetworkDetails::Visa
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardFinancial::NetworkDetails::Visa
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: ElectronicCommerceIndicator, PointOfServiceEntryMode, StandInProcessingReason, TerminalEntryCapability
Instance Attribute Summary collapse
-
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential.
-
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder's primary account number and card expiration date.
-
#stand_in_processing_reason ⇒ Symbol, ...
Only present when
actioner: network. -
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
constructor
Fields specific to the
visanetwork. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(electronic_commerce_indicator:, point_of_service_entry_mode:, stand_in_processing_reason:, terminal_entry_capability:) ⇒ Object
Fields specific to the visa network.
|
|
# File 'lib/increase/models/transaction.rb', line 2604
|
Instance Attribute Details
#electronic_commerce_indicator ⇒ Symbol, ...
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
2562 2563 2564 2565 2566 |
# File 'lib/increase/models/transaction.rb', line 2562 required :electronic_commerce_indicator, enum: -> { Increase::Transaction::Source::CardFinancial::NetworkDetails::Visa::ElectronicCommerceIndicator }, nil?: true |
#point_of_service_entry_mode ⇒ Symbol, ...
The method used to enter the cardholder's primary account number and card expiration date.
2573 2574 2575 2576 2577 |
# File 'lib/increase/models/transaction.rb', line 2573 required :point_of_service_entry_mode, enum: -> { Increase::Transaction::Source::CardFinancial::NetworkDetails::Visa::PointOfServiceEntryMode }, nil?: true |
#stand_in_processing_reason ⇒ Symbol, ...
Only present when actioner: network. Describes why a card authorization was
approved or declined by Visa through stand-in processing.
2584 2585 2586 2587 2588 |
# File 'lib/increase/models/transaction.rb', line 2584 required :stand_in_processing_reason, enum: -> { Increase::Transaction::Source::CardFinancial::NetworkDetails::Visa::StandInProcessingReason }, nil?: true |
#terminal_entry_capability ⇒ Symbol, ...
The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
2598 2599 2600 2601 2602 |
# File 'lib/increase/models/transaction.rb', line 2598 required :terminal_entry_capability, enum: -> { Increase::Transaction::Source::CardFinancial::NetworkDetails::Visa::TerminalEntryCapability }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 2660
|
Instance Method Details
#to_hash ⇒ {
1567 |
# File 'sig/increase/models/transaction.rbs', line 1567
def to_hash: -> {
|