Class: Increase::Models::Transaction::Source::CardRefund
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardRefund
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: Currency, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction's settlement currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cashback ⇒ Increase::Models::Transaction::Source::CardRefund::Cashback?
Cashback debited for this transaction, if eligible.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Currency
The ISO 4217 code for the transaction's settlement currency.
-
#id ⇒ String
The Card Refund identifier.
-
#interchange ⇒ Increase::Models::Transaction::Source::CardRefund::Interchange?
Interchange assessed as a part of this transaction.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant's business.
-
#merchant_city ⇒ String
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_name ⇒ String
The name of the merchant.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardRefund::NetworkIdentifiers
Network-specific identifiers for this refund.
-
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#purchase_details ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
-
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardRefund::SchemeFee>
The scheme fees associated with this card refund.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object
constructor
Network-specific identifiers for this refund.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object
Network-specific identifiers for this refund.
|
|
# File 'lib/increase/models/transaction.rb', line 3354
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
3233 |
# File 'lib/increase/models/transaction.rb', line 3233 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
3239 |
# File 'lib/increase/models/transaction.rb', line 3239 required :card_payment_id, String |
#cashback ⇒ Increase::Models::Transaction::Source::CardRefund::Cashback?
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
3246 |
# File 'lib/increase/models/transaction.rb', line 3246 required :cashback, -> { Increase::Transaction::Source::CardRefund::Cashback }, nil?: true |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Currency
The ISO 4217 code for the transaction's settlement currency.
3253 |
# File 'lib/increase/models/transaction.rb', line 3253 required :currency, enum: -> { Increase::Transaction::Source::CardRefund::Currency } |
#id ⇒ String
The Card Refund identifier.
3226 |
# File 'lib/increase/models/transaction.rb', line 3226 required :id, String |
#interchange ⇒ Increase::Models::Transaction::Source::CardRefund::Interchange?
Interchange assessed as a part of this transaction.
3259 |
# File 'lib/increase/models/transaction.rb', line 3259 required :interchange, -> { Increase::Transaction::Source::CardRefund::Interchange }, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
3266 |
# File 'lib/increase/models/transaction.rb', line 3266 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant's business.
3272 |
# File 'lib/increase/models/transaction.rb', line 3272 required :merchant_category_code, String |
#merchant_city ⇒ String
The city the merchant resides in.
3278 |
# File 'lib/increase/models/transaction.rb', line 3278 required :merchant_city, String |
#merchant_country ⇒ String
The country the merchant resides in.
3284 |
# File 'lib/increase/models/transaction.rb', line 3284 required :merchant_country, String |
#merchant_name ⇒ String
The name of the merchant.
3290 |
# File 'lib/increase/models/transaction.rb', line 3290 required :merchant_name, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
3296 |
# File 'lib/increase/models/transaction.rb', line 3296 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
3302 |
# File 'lib/increase/models/transaction.rb', line 3302 required :merchant_state, String, nil?: true |
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardRefund::NetworkIdentifiers
Network-specific identifiers for this refund.
3308 |
# File 'lib/increase/models/transaction.rb', line 3308 required :network_identifiers, -> { Increase::Transaction::Source::CardRefund::NetworkIdentifiers } |
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction's presentment currency.
3314 |
# File 'lib/increase/models/transaction.rb', line 3314 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
3321 |
# File 'lib/increase/models/transaction.rb', line 3321 required :presentment_currency, String |
#purchase_details ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
3328 3329 3330 3331 3332 |
# File 'lib/increase/models/transaction.rb', line 3328 required :purchase_details, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardRefund::SchemeFee>
The scheme fees associated with this card refund.
3338 3339 |
# File 'lib/increase/models/transaction.rb', line 3338 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardRefund::SchemeFee] } |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
3345 |
# File 'lib/increase/models/transaction.rb', line 3345 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Type
A constant representing the object's type. For this resource it will always be
card_refund.
3352 |
# File 'lib/increase/models/transaction.rb', line 3352 required :type, enum: -> { Increase::Transaction::Source::CardRefund::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 3457
|
Instance Method Details
#to_hash ⇒ {
2250 |
# File 'sig/increase/models/transaction.rbs', line 2250
def to_hash: -> {
|