Class: Increase::Models::Transaction::Source::CardRefund
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardRefund
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: Currency, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction’s settlement currency.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cashback ⇒ Increase::Models::Transaction::Source::CardRefund::Cashback?
Cashback debited for this transaction, if eligible.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.
-
#id ⇒ String
The Card Refund identifier.
-
#interchange ⇒ Increase::Models::Transaction::Source::CardRefund::Interchange?
Interchange assessed as a part of this transaction.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant’s business.
-
#merchant_city ⇒ String
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_name ⇒ String
The name of the merchant.
-
#merchant_postal_code ⇒ String?
The merchant’s postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardRefund::NetworkIdentifiers
Network-specific identifiers for this refund.
-
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction’s presentment currency.
-
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
-
#purchase_details ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
-
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardRefund::SchemeFee>
The scheme fees associated with this card refund.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Type
A constant representing the object’s type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(acquirer_business_id:, acquirer_reference_number:, authorization_identification_response:, transaction_id:) ⇒ Object
Some parameter documentations has been truncated, see NetworkIdentifiers for more details.
Network-specific identifiers for this refund.
|
|
# File 'lib/increase/models/transaction.rb', line 3064
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.
2943 |
# File 'lib/increase/models/transaction.rb', line 2943 required :amount, Integer |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
2949 |
# File 'lib/increase/models/transaction.rb', line 2949 required :card_payment_id, String |
#cashback ⇒ Increase::Models::Transaction::Source::CardRefund::Cashback?
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
2956 |
# File 'lib/increase/models/transaction.rb', line 2956 required :cashback, -> { Increase::Transaction::Source::CardRefund::Cashback }, nil?: true |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.
2963 |
# File 'lib/increase/models/transaction.rb', line 2963 required :currency, enum: -> { Increase::Transaction::Source::CardRefund::Currency } |
#id ⇒ String
The Card Refund identifier.
2936 |
# File 'lib/increase/models/transaction.rb', line 2936 required :id, String |
#interchange ⇒ Increase::Models::Transaction::Source::CardRefund::Interchange?
Interchange assessed as a part of this transaction.
2969 |
# File 'lib/increase/models/transaction.rb', line 2969 required :interchange, -> { Increase::Transaction::Source::CardRefund::Interchange }, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
2976 |
# File 'lib/increase/models/transaction.rb', line 2976 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant’s business.
2982 |
# File 'lib/increase/models/transaction.rb', line 2982 required :merchant_category_code, String |
#merchant_city ⇒ String
The city the merchant resides in.
2988 |
# File 'lib/increase/models/transaction.rb', line 2988 required :merchant_city, String |
#merchant_country ⇒ String
The country the merchant resides in.
2994 |
# File 'lib/increase/models/transaction.rb', line 2994 required :merchant_country, String |
#merchant_name ⇒ String
The name of the merchant.
3000 |
# File 'lib/increase/models/transaction.rb', line 3000 required :merchant_name, String |
#merchant_postal_code ⇒ String?
The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.
3006 |
# File 'lib/increase/models/transaction.rb', line 3006 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
3012 |
# File 'lib/increase/models/transaction.rb', line 3012 required :merchant_state, String, nil?: true |
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardRefund::NetworkIdentifiers
Network-specific identifiers for this refund.
3018 |
# File 'lib/increase/models/transaction.rb', line 3018 required :network_identifiers, -> { Increase::Transaction::Source::CardRefund::NetworkIdentifiers } |
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction’s presentment currency.
3024 |
# File 'lib/increase/models/transaction.rb', line 3024 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.
3031 |
# File 'lib/increase/models/transaction.rb', line 3031 required :presentment_currency, String |
#purchase_details ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
3038 3039 3040 3041 3042 |
# File 'lib/increase/models/transaction.rb', line 3038 required :purchase_details, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardRefund::SchemeFee>
The scheme fees associated with this card refund.
3048 3049 |
# File 'lib/increase/models/transaction.rb', line 3048 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardRefund::SchemeFee] } |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
3055 |
# File 'lib/increase/models/transaction.rb', line 3055 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardRefund::Type
A constant representing the object’s type. For this resource it will always be ‘card_refund`.
3062 |
# File 'lib/increase/models/transaction.rb', line 3062 required :type, enum: -> { Increase::Transaction::Source::CardRefund::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 3150
|