Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardRefund::PurchaseDetails
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel
Instance Attribute Summary collapse
-
#car_rental ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental?
Fields specific to car rentals.
-
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
-
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
-
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#lodging ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging?
Fields specific to lodging.
-
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
-
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
-
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
-
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
-
#travel ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel?
Fields specific to travel.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
constructor
Additional details about the card purchase, such as tax and industry-specific fields.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object
Additional details about the card purchase, such as tax and industry-specific fields.
|
|
# File 'lib/increase/models/transaction.rb', line 3655
|
Instance Attribute Details
#car_rental ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental?
Fields specific to car rentals.
3583 3584 3585 |
# File 'lib/increase/models/transaction.rb', line 3583 required :car_rental, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental }, nil?: true |
#customer_reference_identifier ⇒ String?
An identifier from the merchant for the customer or consumer.
3591 |
# File 'lib/increase/models/transaction.rb', line 3591 required :customer_reference_identifier, String, nil?: true |
#local_tax_amount ⇒ Integer?
The state or provincial tax amount in minor units.
3597 |
# File 'lib/increase/models/transaction.rb', line 3597 required :local_tax_amount, Integer, nil?: true |
#local_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
3604 |
# File 'lib/increase/models/transaction.rb', line 3604 required :local_tax_currency, String, nil?: true |
#lodging ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging?
Fields specific to lodging.
3610 3611 3612 3613 3614 |
# File 'lib/increase/models/transaction.rb', line 3610 required :lodging, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Lodging }, nil?: true |
#national_tax_amount ⇒ Integer?
The national tax amount in minor units.
3620 |
# File 'lib/increase/models/transaction.rb', line 3620 required :national_tax_amount, Integer, nil?: true |
#national_tax_currency ⇒ String?
The ISO 4217 code for the local tax assessed.
3627 |
# File 'lib/increase/models/transaction.rb', line 3627 required :national_tax_currency, String, nil?: true |
#purchase_identifier ⇒ String?
An identifier from the merchant for the purchase to the issuer and cardholder.
3633 |
# File 'lib/increase/models/transaction.rb', line 3633 required :purchase_identifier, String, nil?: true |
#purchase_identifier_format ⇒ Symbol, ...
The format of the purchase identifier.
3639 3640 3641 3642 3643 |
# File 'lib/increase/models/transaction.rb', line 3639 required :purchase_identifier_format, enum: -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::PurchaseIdentifierFormat }, nil?: true |
#travel ⇒ Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel?
Fields specific to travel.
3649 3650 3651 3652 3653 |
# File 'lib/increase/models/transaction.rb', line 3649 required :travel, -> { Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 3896
|
Instance Method Details
#to_hash ⇒ {
2435 |
# File 'sig/increase/models/transaction.rbs', line 2435
def to_hash: -> {
|