Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: PurchaseIdentifierFormat Classes: CarRental, Lodging, Travel

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(car_rental:, customer_reference_identifier:, local_tax_amount:, local_tax_currency:, lodging:, national_tax_amount:, national_tax_currency:, purchase_identifier:, purchase_identifier_format:, travel:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CardRefund::PurchaseDetails for more details.

Additional details about the card purchase, such as tax and industry-specific fields.

Parameters:



# File 'lib/increase/models/transaction.rb', line 3344

Instance Attribute Details

#car_rentalIncrease::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental?

Fields specific to car rentals.



3272
3273
3274
# File 'lib/increase/models/transaction.rb', line 3272

required :car_rental,
-> { Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental },
nil?: true

#customer_reference_identifierString?

An identifier from the merchant for the customer or consumer.

Returns:

  • (String, nil)


3280
# File 'lib/increase/models/transaction.rb', line 3280

required :customer_reference_identifier, String, nil?: true

#local_tax_amountInteger?

The state or provincial tax amount in minor units.

Returns:

  • (Integer, nil)


3286
# File 'lib/increase/models/transaction.rb', line 3286

required :local_tax_amount, Integer, nil?: true

#local_tax_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.

Returns:

  • (String, nil)


3293
# File 'lib/increase/models/transaction.rb', line 3293

required :local_tax_currency, String, nil?: true

#lodgingIncrease::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging?

Fields specific to lodging.



3299
3300
3301
3302
3303
# File 'lib/increase/models/transaction.rb', line 3299

required :lodging,
-> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::Lodging
},
nil?: true

#national_tax_amountInteger?

The national tax amount in minor units.

Returns:

  • (Integer, nil)


3309
# File 'lib/increase/models/transaction.rb', line 3309

required :national_tax_amount, Integer, nil?: true

#national_tax_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the local tax assessed.

Returns:

  • (String, nil)


3316
# File 'lib/increase/models/transaction.rb', line 3316

required :national_tax_currency, String, nil?: true

#purchase_identifierString?

An identifier from the merchant for the purchase to the issuer and cardholder.

Returns:

  • (String, nil)


3322
# File 'lib/increase/models/transaction.rb', line 3322

required :purchase_identifier, String, nil?: true

#purchase_identifier_formatSymbol, ...

The format of the purchase identifier.



3328
3329
3330
3331
3332
# File 'lib/increase/models/transaction.rb', line 3328

required :purchase_identifier_format,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::PurchaseIdentifierFormat
},
nil?: true

#travelIncrease::Models::Transaction::Source::CardRefund::PurchaseDetails::Travel?

Fields specific to travel.



3338
3339
3340
3341
3342
# File 'lib/increase/models/transaction.rb', line 3338

required :travel,
-> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::Travel
},
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 3566