Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: ExtraCharges, NoShowIndicator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(car_class_code:, checkout_date:, daily_rental_rate_amount:, daily_rental_rate_currency:, days_rented:, extra_charges:, fuel_charges_amount:, fuel_charges_currency:, insurance_charges_amount:, insurance_charges_currency:, no_show_indicator:, one_way_drop_off_charges_amount:, one_way_drop_off_charges_currency:, renter_name:, weekly_rental_rate_amount:, weekly_rental_rate_currency:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental for more details.

Fields specific to car rentals.

Parameters:

  • car_class_code (String, nil)

    Code indicating the vehicle’s class.

  • checkout_date (Date, nil)

    Date the customer picked up the car or, in the case of a no-show or pre-pay tran

  • daily_rental_rate_amount (Integer, nil)

    Daily rate being charged for the vehicle.

  • daily_rental_rate_currency (String, nil)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily rental

  • days_rented (Integer, nil)

    Number of days the vehicle was rented.

  • extra_charges (Symbol, Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental::ExtraCharges, nil)

    Additional charges (gas, late fee, etc.) being billed.

  • fuel_charges_amount (Integer, nil)

    Fuel charges for the vehicle.

  • fuel_charges_currency (String, nil)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fuel charges

  • insurance_charges_amount (Integer, nil)

    Any insurance being charged for the vehicle.

  • insurance_charges_currency (String, nil)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the insurance ch

  • no_show_indicator (Symbol, Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::CarRental::NoShowIndicator, nil)

    An indicator that the cardholder is being billed for a reserved vehicle that was

  • one_way_drop_off_charges_amount (Integer, nil)

    Charges for returning the vehicle at a different location than where it was pick

  • one_way_drop_off_charges_currency (String, nil)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the one-way drop

  • renter_name (String, nil)

    Name of the person renting the vehicle.

  • weekly_rental_rate_amount (Integer, nil)

    Weekly rate being charged for the vehicle.

  • weekly_rental_rate_currency (String, nil)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the weekly renta



# File 'lib/increase/models/transaction.rb', line 3486

Instance Attribute Details

#car_class_codeString?

Code indicating the vehicle’s class.

Returns:

  • (String, nil)


3378
# File 'lib/increase/models/transaction.rb', line 3378

required :car_class_code, String, nil?: true

#checkout_dateDate?

Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.

Returns:

  • (Date, nil)


3385
# File 'lib/increase/models/transaction.rb', line 3385

required :checkout_date, Date, nil?: true

#daily_rental_rate_amountInteger?

Daily rate being charged for the vehicle.

Returns:

  • (Integer, nil)


3391
# File 'lib/increase/models/transaction.rb', line 3391

required :daily_rental_rate_amount, Integer, nil?: true

#daily_rental_rate_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the daily rental rate.

Returns:

  • (String, nil)


3398
# File 'lib/increase/models/transaction.rb', line 3398

required :daily_rental_rate_currency, String, nil?: true

#days_rentedInteger?

Number of days the vehicle was rented.

Returns:

  • (Integer, nil)


3404
# File 'lib/increase/models/transaction.rb', line 3404

required :days_rented, Integer, nil?: true

#extra_chargesSymbol, ...

Additional charges (gas, late fee, etc.) being billed.



3410
3411
3412
3413
3414
# File 'lib/increase/models/transaction.rb', line 3410

required :extra_charges,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental::ExtraCharges
},
nil?: true

#fuel_charges_amountInteger?

Fuel charges for the vehicle.

Returns:

  • (Integer, nil)


3420
# File 'lib/increase/models/transaction.rb', line 3420

required :fuel_charges_amount, Integer, nil?: true

#fuel_charges_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the fuel charges assessed.

Returns:

  • (String, nil)


3427
# File 'lib/increase/models/transaction.rb', line 3427

required :fuel_charges_currency, String, nil?: true

#insurance_charges_amountInteger?

Any insurance being charged for the vehicle.

Returns:

  • (Integer, nil)


3433
# File 'lib/increase/models/transaction.rb', line 3433

required :insurance_charges_amount, Integer, nil?: true

#insurance_charges_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the insurance charges assessed.

Returns:

  • (String, nil)


3440
# File 'lib/increase/models/transaction.rb', line 3440

required :insurance_charges_currency, String, nil?: true

#no_show_indicatorSymbol, ...

An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a “no-show” charge).



3447
3448
3449
3450
3451
# File 'lib/increase/models/transaction.rb', line 3447

required :no_show_indicator,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::CarRental::NoShowIndicator
},
nil?: true

#one_way_drop_off_charges_amountInteger?

Charges for returning the vehicle at a different location than where it was picked up.

Returns:

  • (Integer, nil)


3458
# File 'lib/increase/models/transaction.rb', line 3458

required :one_way_drop_off_charges_amount, Integer, nil?: true

#one_way_drop_off_charges_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the one-way drop-off charges assessed.

Returns:

  • (String, nil)


3465
# File 'lib/increase/models/transaction.rb', line 3465

required :one_way_drop_off_charges_currency, String, nil?: true

#renter_nameString?

Name of the person renting the vehicle.

Returns:

  • (String, nil)


3471
# File 'lib/increase/models/transaction.rb', line 3471

required :renter_name, String, nil?: true

#weekly_rental_rate_amountInteger?

Weekly rate being charged for the vehicle.

Returns:

  • (Integer, nil)


3477
# File 'lib/increase/models/transaction.rb', line 3477

required :weekly_rental_rate_amount, Integer, nil?: true

#weekly_rental_rate_currencyString?

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the weekly rental rate.

Returns:

  • (String, nil)


3484
# File 'lib/increase/models/transaction.rb', line 3484

required :weekly_rental_rate_currency, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 3549