Class: Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source::CardRefund::PurchaseDetails#lodging

Defined Under Namespace

Modules: ExtraCharges, NoShowIndicator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(check_in_date:, daily_room_rate_amount:, daily_room_rate_currency:, extra_charges:, folio_cash_advances_amount:, folio_cash_advances_currency:, food_beverage_charges_amount:, food_beverage_charges_currency:, no_show_indicator:, prepaid_expenses_amount:, prepaid_expenses_currency:, room_nights:, total_room_tax_amount:, total_room_tax_currency:, total_tax_amount:, total_tax_currency:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging for more details.

Fields specific to lodging.

Parameters:

  • check_in_date (Date, nil)

    Date the customer checked in.

  • daily_room_rate_amount (Integer, nil)

    Daily rate being charged for the room.

  • daily_room_rate_currency (String, nil)

    The ISO 4217 code for the daily room r

  • extra_charges (Symbol, Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging::ExtraCharges, nil)

    Additional charges (phone, late check-out, etc.) being billed.

  • folio_cash_advances_amount (Integer, nil)

    Folio cash advances for the room.

  • folio_cash_advances_currency (String, nil)

    The ISO 4217 code for the folio cash a

  • food_beverage_charges_amount (Integer, nil)

    Food and beverage charges for the room.

  • food_beverage_charges_currency (String, nil)

    The ISO 4217 code for the food and bev

  • no_show_indicator (Symbol, Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging::NoShowIndicator, nil)

    Indicator that the cardholder is being billed for a reserved room that was not a

  • prepaid_expenses_amount (Integer, nil)

    Prepaid expenses being charged for the room.

  • prepaid_expenses_currency (String, nil)

    The ISO 4217 code for the prepaid expe

  • room_nights (Integer, nil)

    Number of nights the room was rented.

  • total_room_tax_amount (Integer, nil)

    Total room tax being charged.

  • total_room_tax_currency (String, nil)

    The ISO 4217 code for the total room t

  • total_tax_amount (Integer, nil)

    Total tax being charged for the room.

  • total_tax_currency (String, nil)

    The ISO 4217 code for the total tax as



# File 'lib/increase/models/transaction.rb', line 3694

Instance Attribute Details

#check_in_dateDate?

Date the customer checked in.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


3587
# File 'lib/increase/models/transaction.rb', line 3587

required :check_in_date, Date, nil?: true

#daily_room_rate_amountInteger?

Daily rate being charged for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3593
# File 'lib/increase/models/transaction.rb', line 3593

required :daily_room_rate_amount, Integer, nil?: true

#daily_room_rate_currencyString?

The ISO 4217 code for the daily room rate.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3600
# File 'lib/increase/models/transaction.rb', line 3600

required :daily_room_rate_currency, String, nil?: true

#extra_chargesSymbol, ...

Additional charges (phone, late check-out, etc.) being billed.

Parameters:

  • value (Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging::extra_charges, nil)

Returns:



3606
3607
3608
3609
3610
# File 'lib/increase/models/transaction.rb', line 3606

required :extra_charges,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::Lodging::ExtraCharges
},
nil?: true

#folio_cash_advances_amountInteger?

Folio cash advances for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3616
# File 'lib/increase/models/transaction.rb', line 3616

required :folio_cash_advances_amount, Integer, nil?: true

#folio_cash_advances_currencyString?

The ISO 4217 code for the folio cash advances.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3623
# File 'lib/increase/models/transaction.rb', line 3623

required :folio_cash_advances_currency, String, nil?: true

#food_beverage_charges_amountInteger?

Food and beverage charges for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3629
# File 'lib/increase/models/transaction.rb', line 3629

required :food_beverage_charges_amount, Integer, nil?: true

#food_beverage_charges_currencyString?

The ISO 4217 code for the food and beverage charges.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3636
# File 'lib/increase/models/transaction.rb', line 3636

required :food_beverage_charges_currency, String, nil?: true

#no_show_indicatorSymbol, ...

Indicator that the cardholder is being billed for a reserved room that was not actually used.

Parameters:

  • value (Increase::Models::Transaction::Source::CardRefund::PurchaseDetails::Lodging::no_show_indicator, nil)

Returns:



3643
3644
3645
3646
3647
# File 'lib/increase/models/transaction.rb', line 3643

required :no_show_indicator,
enum: -> {
  Increase::Transaction::Source::CardRefund::PurchaseDetails::Lodging::NoShowIndicator
},
nil?: true

#prepaid_expenses_amountInteger?

Prepaid expenses being charged for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3653
# File 'lib/increase/models/transaction.rb', line 3653

required :prepaid_expenses_amount, Integer, nil?: true

#prepaid_expenses_currencyString?

The ISO 4217 code for the prepaid expenses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3660
# File 'lib/increase/models/transaction.rb', line 3660

required :prepaid_expenses_currency, String, nil?: true

#room_nightsInteger?

Number of nights the room was rented.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3666
# File 'lib/increase/models/transaction.rb', line 3666

required :room_nights, Integer, nil?: true

#total_room_tax_amountInteger?

Total room tax being charged.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3672
# File 'lib/increase/models/transaction.rb', line 3672

required :total_room_tax_amount, Integer, nil?: true

#total_room_tax_currencyString?

The ISO 4217 code for the total room tax.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3679
# File 'lib/increase/models/transaction.rb', line 3679

required :total_room_tax_currency, String, nil?: true

#total_tax_amountInteger?

Total tax being charged for the room.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


3685
# File 'lib/increase/models/transaction.rb', line 3685

required :total_tax_amount, Integer, nil?: true

#total_tax_currencyString?

The ISO 4217 code for the total tax assessed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


3692
# File 'lib/increase/models/transaction.rb', line 3692

required :total_tax_currency, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 3760

Instance Method Details

#to_hash{

Returns:

  • ({)


2654
# File 'sig/increase/models/transaction.rbs', line 2654

def to_hash: -> {