Class: Increase::Models::Transaction::Source::CardRevenuePayment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardRevenuePayment
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: Currency
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction’s currency.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardRevenuePayment::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction currency.
-
#period_end ⇒ Time
The end of the period for which this transaction paid interest.
-
#period_start ⇒ Time
The start of the period for which this transaction paid interest.
-
#transacted_on_account_id ⇒ String?
The account the card belonged to.
Instance Method Summary collapse
-
#initialize(amount:, currency:, period_end:, period_start:, transacted_on_account_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CardRevenuePayment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:, period_end:, period_start:, transacted_on_account_id:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CardRevenuePayment for more details.
A Card Revenue Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `card_revenue_payment`. Card Revenue Payments reflect earnings from fees on card transactions.
|
|
# File 'lib/increase/models/transaction.rb', line 4463
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
4436 |
# File 'lib/increase/models/transaction.rb', line 4436 required :amount, Integer |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardRevenuePayment::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction currency.
4443 |
# File 'lib/increase/models/transaction.rb', line 4443 required :currency, enum: -> { Increase::Transaction::Source::CardRevenuePayment::Currency } |
#period_end ⇒ Time
The end of the period for which this transaction paid interest.
4449 |
# File 'lib/increase/models/transaction.rb', line 4449 required :period_end, Time |
#period_start ⇒ Time
The start of the period for which this transaction paid interest.
4455 |
# File 'lib/increase/models/transaction.rb', line 4455 required :period_start, Time |
#transacted_on_account_id ⇒ String?
The account the card belonged to.
4461 |
# File 'lib/increase/models/transaction.rb', line 4461 required :transacted_on_account_id, String, nil?: true |