Class: Increase::Models::Transaction::Source::CardSettlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction's settlement currency.
-
#card_authorization ⇒ String?
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
-
#cashback ⇒ Increase::Models::Transaction::Source::CardSettlement::Cashback?
Cashback earned on this transaction, if eligible.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardSettlement::Currency
The ISO 4217 code for the transaction's settlement currency.
-
#id ⇒ String
The Card Settlement identifier.
-
#interchange ⇒ Increase::Models::Transaction::Source::CardSettlement::Interchange?
Interchange assessed as a part of this transaction.
-
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant's business.
-
#merchant_city ⇒ String
The city the merchant resides in.
-
#merchant_country ⇒ String
The country the merchant resides in.
-
#merchant_name ⇒ String
The name of the merchant.
-
#merchant_postal_code ⇒ String?
The merchant's postal code.
-
#merchant_state ⇒ String?
The state the merchant resides in.
-
#network ⇒ Symbol, Increase::Models::Transaction::Source::CardSettlement::Network
The card network on which this transaction was processed.
-
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardSettlement::NetworkIdentifiers
Network-specific identifiers for this refund.
-
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
-
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction's presentment currency.
-
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
-
#purchase_details ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
-
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::SchemeFee>
The scheme fees associated with this card settlement.
-
#surcharge ⇒ Increase::Models::Transaction::Source::CardSettlement::Surcharge?
Surcharge amount details, if applicable.
-
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
-
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardSettlement::Type
A constant representing the object's type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, presentment_amount:) ⇒ Object
constructor
Surcharge amount details, if applicable.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, presentment_amount:) ⇒ Object
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
|
|
# File 'lib/increase/models/transaction.rb', line 4996
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
4850 |
# File 'lib/increase/models/transaction.rb', line 4850 required :amount, Integer |
#card_authorization ⇒ String?
The Card Authorization that was created prior to this Card Settlement, if one exists.
4857 |
# File 'lib/increase/models/transaction.rb', line 4857 required :card_authorization, String, nil?: true |
#card_payment_id ⇒ String
The ID of the Card Payment this transaction belongs to.
4863 |
# File 'lib/increase/models/transaction.rb', line 4863 required :card_payment_id, String |
#cashback ⇒ Increase::Models::Transaction::Source::CardSettlement::Cashback?
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
4870 |
# File 'lib/increase/models/transaction.rb', line 4870 required :cashback, -> { Increase::Transaction::Source::CardSettlement::Cashback }, nil?: true |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CardSettlement::Currency
The ISO 4217 code for the transaction's settlement currency.
4877 |
# File 'lib/increase/models/transaction.rb', line 4877 required :currency, enum: -> { Increase::Transaction::Source::CardSettlement::Currency } |
#id ⇒ String
The Card Settlement identifier.
4843 |
# File 'lib/increase/models/transaction.rb', line 4843 required :id, String |
#interchange ⇒ Increase::Models::Transaction::Source::CardSettlement::Interchange?
Interchange assessed as a part of this transaction.
4883 |
# File 'lib/increase/models/transaction.rb', line 4883 required :interchange, -> { Increase::Transaction::Source::CardSettlement::Interchange }, nil?: true |
#merchant_acceptor_id ⇒ String
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
4890 |
# File 'lib/increase/models/transaction.rb', line 4890 required :merchant_acceptor_id, String |
#merchant_category_code ⇒ String
The 4-digit MCC describing the merchant's business.
4896 |
# File 'lib/increase/models/transaction.rb', line 4896 required :merchant_category_code, String |
#merchant_city ⇒ String
The city the merchant resides in.
4902 |
# File 'lib/increase/models/transaction.rb', line 4902 required :merchant_city, String |
#merchant_country ⇒ String
The country the merchant resides in.
4908 |
# File 'lib/increase/models/transaction.rb', line 4908 required :merchant_country, String |
#merchant_name ⇒ String
The name of the merchant.
4914 |
# File 'lib/increase/models/transaction.rb', line 4914 required :merchant_name, String |
#merchant_postal_code ⇒ String?
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
4920 |
# File 'lib/increase/models/transaction.rb', line 4920 required :merchant_postal_code, String, nil?: true |
#merchant_state ⇒ String?
The state the merchant resides in.
4926 |
# File 'lib/increase/models/transaction.rb', line 4926 required :merchant_state, String, nil?: true |
#network ⇒ Symbol, Increase::Models::Transaction::Source::CardSettlement::Network
The card network on which this transaction was processed.
4932 |
# File 'lib/increase/models/transaction.rb', line 4932 required :network, enum: -> { Increase::Transaction::Source::CardSettlement::Network } |
#network_identifiers ⇒ Increase::Models::Transaction::Source::CardSettlement::NetworkIdentifiers
Network-specific identifiers for this refund.
4938 |
# File 'lib/increase/models/transaction.rb', line 4938 required :network_identifiers, -> { Increase::Transaction::Source::CardSettlement::NetworkIdentifiers } |
#pending_transaction_id ⇒ String?
The identifier of the Pending Transaction associated with this Transaction.
4944 |
# File 'lib/increase/models/transaction.rb', line 4944 required :pending_transaction_id, String, nil?: true |
#presentment_amount ⇒ Integer
The amount in the minor unit of the transaction's presentment currency.
4950 |
# File 'lib/increase/models/transaction.rb', line 4950 required :presentment_amount, Integer |
#presentment_currency ⇒ String
The ISO 4217 code for the transaction's presentment currency.
4957 |
# File 'lib/increase/models/transaction.rb', line 4957 required :presentment_currency, String |
#purchase_details ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails?
Additional details about the card purchase, such as tax and industry-specific fields.
4964 4965 4966 |
# File 'lib/increase/models/transaction.rb', line 4964 required :purchase_details, -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails }, nil?: true |
#scheme_fees ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::SchemeFee>
The scheme fees associated with this card settlement.
4972 4973 |
# File 'lib/increase/models/transaction.rb', line 4972 required :scheme_fees, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardSettlement::SchemeFee] } |
#surcharge ⇒ Increase::Models::Transaction::Source::CardSettlement::Surcharge?
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
4981 |
# File 'lib/increase/models/transaction.rb', line 4981 required :surcharge, -> { Increase::Transaction::Source::CardSettlement::Surcharge }, nil?: true |
#transaction_id ⇒ String
The identifier of the Transaction associated with this Transaction.
4987 |
# File 'lib/increase/models/transaction.rb', line 4987 required :transaction_id, String |
#type ⇒ Symbol, Increase::Models::Transaction::Source::CardSettlement::Type
A constant representing the object's type. For this resource it will always be
card_settlement.
4994 |
# File 'lib/increase/models/transaction.rb', line 4994 required :type, enum: -> { Increase::Transaction::Source::CardSettlement::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 5114
|
Instance Method Details
#to_hash ⇒ {
3477 |
# File 'sig/increase/models/transaction.rbs', line 3477
def to_hash: -> {
|