Class: Increase::Models::Transaction::Source::CardSettlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Currency, Network, Type Classes: Cashback, Interchange, NetworkIdentifiers, PurchaseDetails, SchemeFee, Surcharge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, presentment_amount:) ⇒ Object

Some parameter documentations has been truncated, see Surcharge for more details.

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).

Parameters:

  • amount (Integer)

    The surcharge amount in the minor unit of the transaction’s settlement currency.

  • presentment_amount (Integer)

    The surcharge amount in the minor unit of the transaction’s presentment currency



# File 'lib/increase/models/transaction.rb', line 4662

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction’s settlement currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


4516
# File 'lib/increase/models/transaction.rb', line 4516

required :amount, Integer

#card_authorizationString?

The Card Authorization that was created prior to this Card Settlement, if one exists.

Returns:

  • (String, nil)


4523
# File 'lib/increase/models/transaction.rb', line 4523

required :card_authorization, String, nil?: true

#card_payment_idString

The ID of the Card Payment this transaction belongs to.

Returns:

  • (String)


4529
# File 'lib/increase/models/transaction.rb', line 4529

required :card_payment_id, String

#cashbackIncrease::Models::Transaction::Source::CardSettlement::Cashback?

Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.



4536
# File 'lib/increase/models/transaction.rb', line 4536

required :cashback, -> { Increase::Transaction::Source::CardSettlement::Cashback }, nil?: true

#currencySymbol, Increase::Models::Transaction::Source::CardSettlement::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s settlement currency.



4543
# File 'lib/increase/models/transaction.rb', line 4543

required :currency, enum: -> { Increase::Transaction::Source::CardSettlement::Currency }

#idString

The Card Settlement identifier.

Returns:

  • (String)


4509
# File 'lib/increase/models/transaction.rb', line 4509

required :id, String

#interchangeIncrease::Models::Transaction::Source::CardSettlement::Interchange?

Interchange assessed as a part of this transaction.



4549
# File 'lib/increase/models/transaction.rb', line 4549

required :interchange, -> { Increase::Transaction::Source::CardSettlement::Interchange }, nil?: true

#merchant_acceptor_idString

The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.

Returns:

  • (String)


4556
# File 'lib/increase/models/transaction.rb', line 4556

required :merchant_acceptor_id, String

#merchant_category_codeString

The 4-digit MCC describing the merchant’s business.

Returns:

  • (String)


4562
# File 'lib/increase/models/transaction.rb', line 4562

required :merchant_category_code, String

#merchant_cityString

The city the merchant resides in.

Returns:

  • (String)


4568
# File 'lib/increase/models/transaction.rb', line 4568

required :merchant_city, String

#merchant_countryString

The country the merchant resides in.

Returns:

  • (String)


4574
# File 'lib/increase/models/transaction.rb', line 4574

required :merchant_country, String

#merchant_nameString

The name of the merchant.

Returns:

  • (String)


4580
# File 'lib/increase/models/transaction.rb', line 4580

required :merchant_name, String

#merchant_postal_codeString?

The merchant’s postal code. For US merchants this is always a 5-digit ZIP code.

Returns:

  • (String, nil)


4586
# File 'lib/increase/models/transaction.rb', line 4586

required :merchant_postal_code, String, nil?: true

#merchant_stateString?

The state the merchant resides in.

Returns:

  • (String, nil)


4592
# File 'lib/increase/models/transaction.rb', line 4592

required :merchant_state, String, nil?: true

#networkSymbol, Increase::Models::Transaction::Source::CardSettlement::Network

The card network on which this transaction was processed.



4598
# File 'lib/increase/models/transaction.rb', line 4598

required :network, enum: -> { Increase::Transaction::Source::CardSettlement::Network }

#network_identifiersIncrease::Models::Transaction::Source::CardSettlement::NetworkIdentifiers

Network-specific identifiers for this refund.



4604
# File 'lib/increase/models/transaction.rb', line 4604

required :network_identifiers, -> { Increase::Transaction::Source::CardSettlement::NetworkIdentifiers }

#pending_transaction_idString?

The identifier of the Pending Transaction associated with this Transaction.

Returns:

  • (String, nil)


4610
# File 'lib/increase/models/transaction.rb', line 4610

required :pending_transaction_id, String, nil?: true

#presentment_amountInteger

The amount in the minor unit of the transaction’s presentment currency.

Returns:

  • (Integer)


4616
# File 'lib/increase/models/transaction.rb', line 4616

required :presentment_amount, Integer

#presentment_currencyString

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s presentment currency.

Returns:

  • (String)


4623
# File 'lib/increase/models/transaction.rb', line 4623

required :presentment_currency, String

#purchase_detailsIncrease::Models::Transaction::Source::CardSettlement::PurchaseDetails?

Additional details about the card purchase, such as tax and industry-specific fields.



4630
4631
4632
# File 'lib/increase/models/transaction.rb', line 4630

required :purchase_details,
-> { Increase::Transaction::Source::CardSettlement::PurchaseDetails },
nil?: true

#scheme_feesArray<Increase::Models::Transaction::Source::CardSettlement::SchemeFee>

The scheme fees associated with this card settlement.



4638
4639
# File 'lib/increase/models/transaction.rb', line 4638

required :scheme_fees,
-> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardSettlement::SchemeFee] }

#surchargeIncrease::Models::Transaction::Source::CardSettlement::Surcharge?

Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).



4647
# File 'lib/increase/models/transaction.rb', line 4647

required :surcharge, -> { Increase::Transaction::Source::CardSettlement::Surcharge }, nil?: true

#transaction_idString

The identifier of the Transaction associated with this Transaction.

Returns:

  • (String)


4653
# File 'lib/increase/models/transaction.rb', line 4653

required :transaction_id, String

#typeSymbol, Increase::Models::Transaction::Source::CardSettlement::Type

A constant representing the object’s type. For this resource it will always be ‘card_settlement`.



4660
# File 'lib/increase/models/transaction.rb', line 4660

required :type, enum: -> { Increase::Transaction::Source::CardSettlement::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/increase/models/transaction.rb', line 4757