Class: Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: CreditReasonIndicator, RestrictedTicketIndicator, TicketChangeIndicator Classes: Ancillary, TripLeg
Instance Attribute Summary collapse
-
#ancillary ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
-
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
-
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
-
#departure_date ⇒ Date?
Date of departure.
-
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
-
#passenger_name ⇒ String?
Name of the passenger.
-
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
-
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
-
#ticket_number ⇒ String?
Ticket number.
-
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
-
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
-
#trip_legs ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
constructor
Fields specific to travel.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ancillary:, computerized_reservation_system:, credit_reason_indicator:, departure_date:, origination_city_airport_code:, passenger_name:, restricted_ticket_indicator:, ticket_change_indicator:, ticket_number:, travel_agency_code:, travel_agency_name:, trip_legs:) ⇒ Object
Fields specific to travel.
|
|
# File 'lib/increase/models/transaction.rb', line 5503
|
Instance Attribute Details
#ancillary ⇒ Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary?
Ancillary purchases in addition to the airfare.
5415 5416 5417 5418 5419 |
# File 'lib/increase/models/transaction.rb', line 5415 required :ancillary, -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::Ancillary }, nil?: true |
#computerized_reservation_system ⇒ String?
Indicates the computerized reservation system used to book the ticket.
5425 |
# File 'lib/increase/models/transaction.rb', line 5425 required :computerized_reservation_system, String, nil?: true |
#credit_reason_indicator ⇒ Symbol, ...
Indicates the reason for a credit to the cardholder.
5431 5432 5433 5434 5435 |
# File 'lib/increase/models/transaction.rb', line 5431 required :credit_reason_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::CreditReasonIndicator }, nil?: true |
#departure_date ⇒ Date?
Date of departure.
5441 |
# File 'lib/increase/models/transaction.rb', line 5441 required :departure_date, Date, nil?: true |
#origination_city_airport_code ⇒ String?
Code for the originating city or airport.
5447 |
# File 'lib/increase/models/transaction.rb', line 5447 required :origination_city_airport_code, String, nil?: true |
#passenger_name ⇒ String?
Name of the passenger.
5453 |
# File 'lib/increase/models/transaction.rb', line 5453 required :passenger_name, String, nil?: true |
#restricted_ticket_indicator ⇒ Symbol, ...
Indicates whether this ticket is non-refundable.
5459 5460 5461 5462 5463 |
# File 'lib/increase/models/transaction.rb', line 5459 required :restricted_ticket_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::RestrictedTicketIndicator }, nil?: true |
#ticket_change_indicator ⇒ Symbol, ...
Indicates why a ticket was changed.
5469 5470 5471 5472 5473 |
# File 'lib/increase/models/transaction.rb', line 5469 required :ticket_change_indicator, enum: -> { Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TicketChangeIndicator }, nil?: true |
#ticket_number ⇒ String?
Ticket number.
5479 |
# File 'lib/increase/models/transaction.rb', line 5479 required :ticket_number, String, nil?: true |
#travel_agency_code ⇒ String?
Code for the travel agency if the ticket was issued by a travel agency.
5485 |
# File 'lib/increase/models/transaction.rb', line 5485 required :travel_agency_code, String, nil?: true |
#travel_agency_name ⇒ String?
Name of the travel agency if the ticket was issued by a travel agency.
5491 |
# File 'lib/increase/models/transaction.rb', line 5491 required :travel_agency_name, String, nil?: true |
#trip_legs ⇒ Array<Increase::Models::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TripLeg>?
Fields specific to each leg of the journey.
5497 5498 5499 5500 5501 |
# File 'lib/increase/models/transaction.rb', line 5497 required :trip_legs, -> { Increase::Internal::Type::ArrayOf[Increase::Transaction::Source::CardSettlement::PurchaseDetails::Travel::TripLeg] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/transaction.rb', line 5710
|