Class: Increase::Models::Transaction::Source::CashbackPayment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::CashbackPayment
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Defined Under Namespace
Modules: Currency
Instance Attribute Summary collapse
-
#accrued_on_card_id ⇒ String?
The card on which the cashback was accrued.
-
#amount ⇒ Integer
The amount in the minor unit of the transaction's currency.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CashbackPayment::Currency
The ISO 4217 code for the transaction currency.
-
#period_end ⇒ Time
The end of the period for which this transaction paid cashback.
-
#period_start ⇒ Time
The start of the period for which this transaction paid cashback.
Instance Method Summary collapse
-
#initialize(accrued_on_card_id:, amount:, currency:, period_end:, period_start:) ⇒ Object
constructor
A Cashback Payment object.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accrued_on_card_id:, amount:, currency:, period_end:, period_start:) ⇒ Object
A Cashback Payment object. This field will be present in the JSON response if
and only if category is equal to cashback_payment. A Cashback Payment
represents the cashback paid to a cardholder for a given period. Cashback is
usually paid monthly for the prior month's transactions.
|
|
# File 'lib/increase/models/transaction.rb', line 6520
|
Instance Attribute Details
#accrued_on_card_id ⇒ String?
The card on which the cashback was accrued.
6492 |
# File 'lib/increase/models/transaction.rb', line 6492 required :accrued_on_card_id, String, nil?: true |
#amount ⇒ Integer
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
6499 |
# File 'lib/increase/models/transaction.rb', line 6499 required :amount, Integer |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::CashbackPayment::Currency
The ISO 4217 code for the transaction currency.
6506 |
# File 'lib/increase/models/transaction.rb', line 6506 required :currency, enum: -> { Increase::Transaction::Source::CashbackPayment::Currency } |
#period_end ⇒ Time
The end of the period for which this transaction paid cashback.
6512 |
# File 'lib/increase/models/transaction.rb', line 6512 required :period_end, Time |
#period_start ⇒ Time
The start of the period for which this transaction paid cashback.
6518 |
# File 'lib/increase/models/transaction.rb', line 6518 required :period_start, Time |
Instance Method Details
#to_hash ⇒ {
4618 |
# File 'sig/increase/models/transaction.rbs', line 4618
def to_hash: -> {
|