Class: Increase::Models::Transaction::Source::CashbackPayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

See Also:

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accrued_on_card_id:, amount:, currency:, period_end:, period_start:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CashbackPayment for more details.

A Cashback Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `cashback_payment`. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month’s transactions.

Parameters:

  • accrued_on_card_id (String, nil)

    The card on which the cashback was accrued.

  • amount (Integer)

    The amount in the minor unit of the transaction’s currency. For dollars, for exa

  • currency (Symbol, Increase::Models::Transaction::Source::CashbackPayment::Currency)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction

  • period_end (Time)

    The end of the period for which this transaction paid cashback.

  • period_start (Time)

    The start of the period for which this transaction paid cashback.



# File 'lib/increase/models/transaction.rb', line 6107

Instance Attribute Details

#accrued_on_card_idString?

The card on which the cashback was accrued.

Returns:

  • (String, nil)


6079
# File 'lib/increase/models/transaction.rb', line 6079

required :accrued_on_card_id, String, nil?: true

#amountInteger

The amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


6086
# File 'lib/increase/models/transaction.rb', line 6086

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::CashbackPayment::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction currency.



6093
# File 'lib/increase/models/transaction.rb', line 6093

required :currency, enum: -> { Increase::Transaction::Source::CashbackPayment::Currency }

#period_endTime

The end of the period for which this transaction paid cashback.

Returns:

  • (Time)


6099
# File 'lib/increase/models/transaction.rb', line 6099

required :period_end, Time

#period_startTime

The start of the period for which this transaction paid cashback.

Returns:

  • (Time)


6105
# File 'lib/increase/models/transaction.rb', line 6105

required :period_start, Time