Module: Increase::Models::Transaction::Source::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
Constant Summary collapse
- ACCOUNT_TRANSFER_INTENTION =
Account Transfer Intention: details will be under the
account_transfer_intentionobject. :account_transfer_intention- ACH_TRANSFER_INTENTION =
ACH Transfer Intention: details will be under the
ach_transfer_intentionobject. :ach_transfer_intention- ACH_TRANSFER_REJECTION =
ACH Transfer Rejection: details will be under the
ach_transfer_rejectionobject. :ach_transfer_rejection- ACH_TRANSFER_RETURN =
ACH Transfer Return: details will be under the
ach_transfer_returnobject. :ach_transfer_return- CASHBACK_PAYMENT =
Cashback Payment: details will be under the
cashback_paymentobject. :cashback_payment- CARD_DISPUTE_ACCEPTANCE =
Legacy Card Dispute Acceptance: details will be under the
card_dispute_acceptanceobject. :card_dispute_acceptance- CARD_DISPUTE_FINANCIAL =
Card Dispute Financial: details will be under the
card_dispute_financialobject. :card_dispute_financial- CARD_DISPUTE_LOSS =
Legacy Card Dispute Loss: details will be under the
card_dispute_lossobject. :card_dispute_loss- CARD_REFUND =
Card Refund: details will be under the
card_refundobject. :card_refund- CARD_SETTLEMENT =
Card Settlement: details will be under the
card_settlementobject. :card_settlement- CARD_FINANCIAL =
Card Financial: details will be under the
card_financialobject. :card_financial- CARD_REVENUE_PAYMENT =
Card Revenue Payment: details will be under the
card_revenue_paymentobject. :card_revenue_payment- CHECK_DEPOSIT_ACCEPTANCE =
Check Deposit Acceptance: details will be under the
check_deposit_acceptanceobject. :check_deposit_acceptance- CHECK_DEPOSIT_RETURN =
Check Deposit Return: details will be under the
check_deposit_returnobject. :check_deposit_return- FEDNOW_TRANSFER_ACKNOWLEDGEMENT =
FedNow Transfer Acknowledgement: details will be under the
fednow_transfer_acknowledgementobject. :fednow_transfer_acknowledgement- CHECK_TRANSFER_DEPOSIT =
Check Transfer Deposit: details will be under the
check_transfer_depositobject. :check_transfer_deposit- FEE_PAYMENT =
Fee Payment: details will be under the
fee_paymentobject. :fee_payment- INBOUND_ACH_TRANSFER =
Inbound ACH Transfer Intention: details will be under the
inbound_ach_transferobject. :inbound_ach_transfer- INBOUND_ACH_TRANSFER_RETURN_INTENTION =
Inbound ACH Transfer Return Intention: details will be under the
inbound_ach_transfer_return_intentionobject. :inbound_ach_transfer_return_intention- INBOUND_CHECK_DEPOSIT_RETURN_INTENTION =
Inbound Check Deposit Return Intention: details will be under the
inbound_check_deposit_return_intentionobject. :inbound_check_deposit_return_intention- INBOUND_CHECK_ADJUSTMENT =
Inbound Check Adjustment: details will be under the
inbound_check_adjustmentobject. :inbound_check_adjustment- INBOUND_FEDNOW_TRANSFER_CONFIRMATION =
Inbound FedNow Transfer Confirmation: details will be under the
inbound_fednow_transfer_confirmationobject. :inbound_fednow_transfer_confirmation- INBOUND_REAL_TIME_PAYMENTS_TRANSFER_CONFIRMATION =
Inbound Real-Time Payments Transfer Confirmation: details will be under the
inbound_real_time_payments_transfer_confirmationobject. :inbound_real_time_payments_transfer_confirmation- INBOUND_WIRE_REVERSAL =
Inbound Wire Reversal: details will be under the
inbound_wire_reversalobject. :inbound_wire_reversal- INBOUND_WIRE_TRANSFER =
Inbound Wire Transfer Intention: details will be under the
inbound_wire_transferobject. :inbound_wire_transfer- INBOUND_WIRE_TRANSFER_REVERSAL =
Inbound Wire Transfer Reversal Intention: details will be under the
inbound_wire_transfer_reversalobject. :inbound_wire_transfer_reversal- INTEREST_PAYMENT =
Interest Payment: details will be under the
interest_paymentobject. :interest_payment- INTERNAL_SOURCE =
Internal Source: details will be under the
internal_sourceobject. :internal_source- REAL_TIME_PAYMENTS_TRANSFER_ACKNOWLEDGEMENT =
Real-Time Payments Transfer Acknowledgement: details will be under the
real_time_payments_transfer_acknowledgementobject. :real_time_payments_transfer_acknowledgement- SAMPLE_FUNDS =
Sample Funds: details will be under the
sample_fundsobject. :sample_funds- WIRE_TRANSFER_INTENTION =
Wire Transfer Intention: details will be under the
wire_transfer_intentionobject. :wire_transfer_intention- SWIFT_TRANSFER_INTENTION =
Swift Transfer Intention: details will be under the
swift_transfer_intentionobject. :swift_transfer_intention- SWIFT_TRANSFER_RETURN =
Swift Transfer Return: details will be under the
swift_transfer_returnobject. :swift_transfer_return- CARD_PUSH_TRANSFER_ACCEPTANCE =
Card Push Transfer Acceptance: details will be under the
card_push_transfer_acceptanceobject. :card_push_transfer_acceptance- ACCOUNT_REVENUE_PAYMENT =
Account Revenue Payment: details will be under the
account_revenue_paymentobject. :account_revenue_payment- BLOCKCHAIN_ONRAMP_TRANSFER_INTENTION =
Blockchain On-Ramp Transfer Intention: details will be under the
blockchain_onramp_transfer_intentionobject. :blockchain_onramp_transfer_intention- BLOCKCHAIN_OFFRAMP_TRANSFER_SETTLEMENT =
Blockchain Off-Ramp Transfer Settlement: details will be under the
blockchain_offramp_transfer_settlementobject. :blockchain_offramp_transfer_settlement- OTHER =
The Transaction was made for an undocumented or deprecated reason.
:other
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Increase::Models::Transaction::Source::category]
455 |
# File 'sig/increase/models/transaction.rbs', line 455
def self?.values: -> ::Array[Increase::Models::Transaction::Source::category]
|