Class: Increase::Models::Transaction::Source::CheckDepositAcceptance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, amount:, auxiliary_on_us:, check_deposit_id:, currency:, routing_number:, serial_number:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CheckDepositAcceptance for more details.

A Check Deposit Acceptance object. This field will be present in the JSON response if and only if ‘category` is equal to `check_deposit_acceptance`. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.

Parameters:

  • account_number (String)

    The account number printed on the check. This is an account at the bank that iss

  • amount (Integer)

    The amount to be deposited in the minor unit of the transaction’s currency. For

  • auxiliary_on_us (String, nil)

    An additional line of metadata printed on the check. This typically includes the

  • check_deposit_id (String)

    The ID of the Check Deposit that was accepted.

  • currency (Symbol, Increase::Models::Transaction::Source::CheckDepositAcceptance::Currency)

    The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’

  • routing_number (String)

    The routing number printed on the check. This is a routing number for the bank t

  • serial_number (String, nil)

    The check serial number, if present, for consumer checks. For business checks, t



# File 'lib/increase/models/transaction.rb', line 6191

Instance Attribute Details

#account_numberString

The account number printed on the check. This is an account at the bank that issued the check.

Returns:

  • (String)


6148
# File 'lib/increase/models/transaction.rb', line 6148

required :account_number, String

#amountInteger

The amount to be deposited in the minor unit of the transaction’s currency. For dollars, for example, this is cents.

Returns:

  • (Integer)


6155
# File 'lib/increase/models/transaction.rb', line 6155

required :amount, Integer

#auxiliary_on_usString?

An additional line of metadata printed on the check. This typically includes the check number for business checks.

Returns:

  • (String, nil)


6162
# File 'lib/increase/models/transaction.rb', line 6162

required :auxiliary_on_us, String, nil?: true

#check_deposit_idString

The ID of the Check Deposit that was accepted.

Returns:

  • (String)


6168
# File 'lib/increase/models/transaction.rb', line 6168

required :check_deposit_id, String

#currencySymbol, Increase::Models::Transaction::Source::CheckDepositAcceptance::Currency

The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction’s currency.



6175
# File 'lib/increase/models/transaction.rb', line 6175

required :currency, enum: -> { Increase::Transaction::Source::CheckDepositAcceptance::Currency }

#routing_numberString

The routing number printed on the check. This is a routing number for the bank that issued the check.

Returns:

  • (String)


6182
# File 'lib/increase/models/transaction.rb', line 6182

required :routing_number, String

#serial_numberString?

The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the ‘auxiliary_on_us` field.

Returns:

  • (String, nil)


6189
# File 'lib/increase/models/transaction.rb', line 6189

required :serial_number, String, nil?: true