Class: Increase::Models::Transaction::Source::CheckTransferDeposit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(back_image_file_id:, bank_of_first_deposit_routing_number:, deposited_at:, front_image_file_id:, inbound_check_deposit_id:, transaction_id:, transfer_id:, type:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::CheckTransferDeposit for more details.

A Check Transfer Deposit object. This field will be present in the JSON response if and only if ‘category` is equal to `check_transfer_deposit`. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.

Parameters:

  • back_image_file_id (String, nil)

    The identifier of the API File object containing an image of the back of the dep

  • bank_of_first_deposit_routing_number (String, nil)

    The American Bankers’ Association (ABA) Routing Transit Number (RTN) for the ban

  • deposited_at (Time)

    When the check was deposited.

  • front_image_file_id (String, nil)

    The identifier of the API File object containing an image of the front of the de

  • inbound_check_deposit_id (String, nil)

    The identifier of the Inbound Check Deposit object associated with this transact

  • transaction_id (String, nil)

    The identifier of the Transaction object created when the check was deposited.

  • transfer_id (String, nil)

    The identifier of the Check Transfer object that was deposited.

  • type (Symbol, Increase::Models::Transaction::Source::CheckTransferDeposit::Type)

    A constant representing the object’s type. For this resource it will always be ‘



# File 'lib/increase/models/transaction.rb', line 6456

Instance Attribute Details

#back_image_file_idString?

The identifier of the API File object containing an image of the back of the deposited check.

Returns:

  • (String, nil)


6407
# File 'lib/increase/models/transaction.rb', line 6407

required :back_image_file_id, String, nil?: true

#bank_of_first_deposit_routing_numberString?

The American Bankers’ Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.

Returns:

  • (String, nil)


6415
# File 'lib/increase/models/transaction.rb', line 6415

required :bank_of_first_deposit_routing_number, String, nil?: true

#deposited_atTime

When the check was deposited.

Returns:

  • (Time)


6421
# File 'lib/increase/models/transaction.rb', line 6421

required :deposited_at, Time

#front_image_file_idString?

The identifier of the API File object containing an image of the front of the deposited check.

Returns:

  • (String, nil)


6428
# File 'lib/increase/models/transaction.rb', line 6428

required :front_image_file_id, String, nil?: true

#inbound_check_deposit_idString?

The identifier of the Inbound Check Deposit object associated with this transaction.

Returns:

  • (String, nil)


6435
# File 'lib/increase/models/transaction.rb', line 6435

required :inbound_check_deposit_id, String, nil?: true

#transaction_idString?

The identifier of the Transaction object created when the check was deposited.

Returns:

  • (String, nil)


6441
# File 'lib/increase/models/transaction.rb', line 6441

required :transaction_id, String, nil?: true

#transfer_idString?

The identifier of the Check Transfer object that was deposited.

Returns:

  • (String, nil)


6447
# File 'lib/increase/models/transaction.rb', line 6447

required :transfer_id, String, nil?: true

#typeSymbol, Increase::Models::Transaction::Source::CheckTransferDeposit::Type

A constant representing the object’s type. For this resource it will always be ‘check_transfer_deposit`.



6454
# File 'lib/increase/models/transaction.rb', line 6454

required :type, enum: -> { Increase::Transaction::Source::CheckTransferDeposit::Type }