Class: Increase::Models::Transaction::Source::FeePayment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#fee_payment

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, currency:, fee_period_start:, program_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::FeePayment for more details.

A Fee Payment object. This field will be present in the JSON response if and only if category is equal to fee_payment. A Fee Payment represents a payment made to Increase.

Parameters:

  • amount (Integer)

    The amount in the minor unit of the transaction's currency. For dollars, for exa

  • currency (Symbol, Increase::Models::Transaction::Source::FeePayment::Currency)

    The ISO 4217 code for the transaction

  • fee_period_start (Date)

    The start of this payment's fee period, usually the first day of a month.

  • program_id (String, nil)

    The Program for which this fee was incurred.



# File 'lib/increase/models/transaction.rb', line 6550

Instance Attribute Details

#amountInteger

The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


6529
# File 'lib/increase/models/transaction.rb', line 6529

required :amount, Integer

#currencySymbol, Increase::Models::Transaction::Source::FeePayment::Currency

The ISO 4217 code for the transaction currency.

Parameters:

  • value (Increase::Models::Transaction::Source::FeePayment::currency)

Returns:



6536
# File 'lib/increase/models/transaction.rb', line 6536

required :currency, enum: -> { Increase::Transaction::Source::FeePayment::Currency }

#fee_period_startDate

The start of this payment's fee period, usually the first day of a month.

Parameters:

  • value (Date)

Returns:

  • (Date)


6542
# File 'lib/increase/models/transaction.rb', line 6542

required :fee_period_start, Date

#program_idString?

The Program for which this fee was incurred.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


6548
# File 'lib/increase/models/transaction.rb', line 6548

required :program_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


4957
# File 'sig/increase/models/transaction.rbs', line 4957

def to_hash: -> {