Class: Increase::Models::Transaction::Source::FeePayment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::FeePayment
- Defined in:
- lib/increase/models/transaction.rb
Overview
Defined Under Namespace
Modules: Currency
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in the minor unit of the transaction’s currency.
-
#currency ⇒ Symbol, Increase::Models::Transaction::Source::FeePayment::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction currency.
-
#fee_period_start ⇒ Date
The start of this payment’s fee period, usually the first day of a month.
-
#program_id ⇒ String?
The Program for which this fee was incurred.
Instance Method Summary collapse
-
#initialize(amount:, currency:, fee_period_start:, program_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see FeePayment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:, fee_period_start:, program_id:) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::FeePayment for more details.
A Fee Payment object. This field will be present in the JSON response if and only if ‘category` is equal to `fee_payment`. A Fee Payment represents a payment made to Increase.
|
|
# File 'lib/increase/models/transaction.rb', line 6540
|
Instance Attribute Details
#amount ⇒ Integer
The amount in the minor unit of the transaction’s currency. For dollars, for example, this is cents.
6519 |
# File 'lib/increase/models/transaction.rb', line 6519 required :amount, Integer |
#currency ⇒ Symbol, Increase::Models::Transaction::Source::FeePayment::Currency
The [ISO 4217](en.wikipedia.org/wiki/ISO_4217) code for the transaction currency.
6526 |
# File 'lib/increase/models/transaction.rb', line 6526 required :currency, enum: -> { Increase::Transaction::Source::FeePayment::Currency } |
#fee_period_start ⇒ Date
The start of this payment’s fee period, usually the first day of a month.
6532 |
# File 'lib/increase/models/transaction.rb', line 6532 required :fee_period_start, Date |
#program_id ⇒ String?
The Program for which this fee was incurred.
6538 |
# File 'lib/increase/models/transaction.rb', line 6538 required :program_id, String, nil?: true |