Class: Increase::Models::Transaction::Source::InboundACHTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

Defined Under Namespace

Classes: Addenda

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(addenda:, amount:, originator_company_descriptive_date:, originator_company_discretionary_data:, originator_company_entry_description:, originator_company_id:, originator_company_name:, receiver_id_number:, receiver_name:, trace_number:, transfer_id:) ⇒ Object

Some parameter documentations has been truncated, see Increase::Models::Transaction::Source::InboundACHTransfer for more details.

An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if ‘category` is equal to `inbound_ach_transfer`. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.

Parameters:

  • addenda (Increase::Models::Transaction::Source::InboundACHTransfer::Addenda, nil)

    Additional information sent from the originator.

  • amount (Integer)

    The transfer amount in USD cents.

  • originator_company_descriptive_date (String, nil)

    The description of the date of the transfer, usually in the format ‘YYMMDD`.

  • originator_company_discretionary_data (String, nil)

    Data set by the originator.

  • originator_company_entry_description (String)

    An informational description of the transfer.

  • originator_company_id (String)

    An identifier for the originating company. This is generally, but not always, a

  • originator_company_name (String)

    A name set by the originator to identify themselves.

  • receiver_id_number (String, nil)

    The originator’s identifier for the transfer recipient.

  • receiver_name (String, nil)

    The name of the transfer recipient. This value is informational and not verified

  • trace_number (String)

    A 15 digit number recorded in the Nacha file and available to both the originati

  • transfer_id (String)

    The Inbound ACH Transfer’s identifier.



# File 'lib/increase/models/transaction.rb', line 6645

Instance Attribute Details

#addendaIncrease::Models::Transaction::Source::InboundACHTransfer::Addenda?

Additional information sent from the originator.



6577
# File 'lib/increase/models/transaction.rb', line 6577

required :addenda, -> { Increase::Transaction::Source::InboundACHTransfer::Addenda }, nil?: true

#amountInteger

The transfer amount in USD cents.

Returns:

  • (Integer)


6583
# File 'lib/increase/models/transaction.rb', line 6583

required :amount, Integer

#originator_company_descriptive_dateString?

The description of the date of the transfer, usually in the format ‘YYMMDD`.

Returns:

  • (String, nil)


6589
# File 'lib/increase/models/transaction.rb', line 6589

required :originator_company_descriptive_date, String, nil?: true

#originator_company_discretionary_dataString?

Data set by the originator.

Returns:

  • (String, nil)


6595
# File 'lib/increase/models/transaction.rb', line 6595

required :originator_company_discretionary_data, String, nil?: true

#originator_company_entry_descriptionString

An informational description of the transfer.

Returns:

  • (String)


6601
# File 'lib/increase/models/transaction.rb', line 6601

required :originator_company_entry_description, String

#originator_company_idString

An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.

Returns:

  • (String)


6608
# File 'lib/increase/models/transaction.rb', line 6608

required :originator_company_id, String

#originator_company_nameString

A name set by the originator to identify themselves.

Returns:

  • (String)


6614
# File 'lib/increase/models/transaction.rb', line 6614

required :originator_company_name, String

#receiver_id_numberString?

The originator’s identifier for the transfer recipient.

Returns:

  • (String, nil)


6620
# File 'lib/increase/models/transaction.rb', line 6620

required :receiver_id_number, String, nil?: true

#receiver_nameString?

The name of the transfer recipient. This value is informational and not verified by Increase.

Returns:

  • (String, nil)


6627
# File 'lib/increase/models/transaction.rb', line 6627

required :receiver_name, String, nil?: true

#trace_numberString

A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are [used to correlate returns](increase.com/documentation/ach-returns#ach-returns).

Returns:

  • (String)


6637
# File 'lib/increase/models/transaction.rb', line 6637

required :trace_number, String

#transfer_idString

The Inbound ACH Transfer’s identifier.

Returns:

  • (String)


6643
# File 'lib/increase/models/transaction.rb', line 6643

required :transfer_id, String