Class: Increase::Models::Transaction::Source::InboundWireTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundWireTransfer
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in USD cents.
-
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#creditor_name ⇒ String?
A name set by the sender.
-
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#debtor_name ⇒ String?
A name set by the sender.
-
#description ⇒ String
An Increase-constructed description of the transfer.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
-
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD.
-
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
#instruction_identification ⇒ String?
The sending bank's identifier for the wire transfer.
-
#purpose ⇒ String?
The reason for the wire transfer, as set by the sender.
-
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
5412 |
# File 'sig/increase/models/transaction.rbs', line 5412
def initialize: (
|
Instance Attribute Details
#amount ⇒ Integer
The amount in USD cents.
7579 |
# File 'lib/increase/models/transaction.rb', line 7579 required :amount, Integer |
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
7585 |
# File 'lib/increase/models/transaction.rb', line 7585 required :creditor_address_line1, String, nil?: true |
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
7591 |
# File 'lib/increase/models/transaction.rb', line 7591 required :creditor_address_line2, String, nil?: true |
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
7597 |
# File 'lib/increase/models/transaction.rb', line 7597 required :creditor_address_line3, String, nil?: true |
#creditor_name ⇒ String?
A name set by the sender.
7603 |
# File 'lib/increase/models/transaction.rb', line 7603 required :creditor_name, String, nil?: true |
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
7609 |
# File 'lib/increase/models/transaction.rb', line 7609 required :debtor_address_line1, String, nil?: true |
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
7615 |
# File 'lib/increase/models/transaction.rb', line 7615 required :debtor_address_line2, String, nil?: true |
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
7621 |
# File 'lib/increase/models/transaction.rb', line 7621 required :debtor_address_line3, String, nil?: true |
#debtor_name ⇒ String?
A name set by the sender.
7627 |
# File 'lib/increase/models/transaction.rb', line 7627 required :debtor_name, String, nil?: true |
#description ⇒ String
An Increase-constructed description of the transfer.
7633 |
# File 'lib/increase/models/transaction.rb', line 7633 required :description, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
7639 |
# File 'lib/increase/models/transaction.rb', line 7639 required :end_to_end_identification, String, nil?: true |
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
7647 |
# File 'lib/increase/models/transaction.rb', line 7647 required :input_message_accountability_data, String, nil?: true |
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
7654 |
# File 'lib/increase/models/transaction.rb', line 7654 required :instructing_agent_routing_number, String, nil?: true |
#instruction_identification ⇒ String?
The sending bank's identifier for the wire transfer.
7660 |
# File 'lib/increase/models/transaction.rb', line 7660 required :instruction_identification, String, nil?: true |
#purpose ⇒ String?
The reason for the wire transfer, as set by the sender.
7666 |
# File 'lib/increase/models/transaction.rb', line 7666 required :purpose, String, nil?: true |
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
7672 |
# File 'lib/increase/models/transaction.rb', line 7672 required :transfer_id, String |
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference (UETR) of the transfer.
7680 |
# File 'lib/increase/models/transaction.rb', line 7680 required :unique_end_to_end_transaction_reference, String, nil?: true |
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
7686 |
# File 'lib/increase/models/transaction.rb', line 7686 required :unstructured_remittance_information, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
5433 |
# File 'sig/increase/models/transaction.rbs', line 5433
def to_hash: -> {
|