Class: Increase::Models::Transaction::Source::InboundWireTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs

Overview

See Also:

  • Increase::Models::Transaction::Source#inbound_wire_transfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



5407
# File 'sig/increase/models/transaction.rbs', line 5407

def initialize: (

Instance Attribute Details

#amountInteger

The amount in USD cents.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


7108
# File 'lib/increase/models/transaction.rb', line 7108

required :amount, Integer

#creditor_address_line1String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7114
# File 'lib/increase/models/transaction.rb', line 7114

required :creditor_address_line1, String, nil?: true

#creditor_address_line2String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7120
# File 'lib/increase/models/transaction.rb', line 7120

required :creditor_address_line2, String, nil?: true

#creditor_address_line3String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7126
# File 'lib/increase/models/transaction.rb', line 7126

required :creditor_address_line3, String, nil?: true

#creditor_nameString?

A name set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7132
# File 'lib/increase/models/transaction.rb', line 7132

required :creditor_name, String, nil?: true

#debtor_address_line1String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7138
# File 'lib/increase/models/transaction.rb', line 7138

required :debtor_address_line1, String, nil?: true

#debtor_address_line2String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7144
# File 'lib/increase/models/transaction.rb', line 7144

required :debtor_address_line2, String, nil?: true

#debtor_address_line3String?

A free-form address field set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7150
# File 'lib/increase/models/transaction.rb', line 7150

required :debtor_address_line3, String, nil?: true

#debtor_nameString?

A name set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7156
# File 'lib/increase/models/transaction.rb', line 7156

required :debtor_name, String, nil?: true

#descriptionString

An Increase-constructed description of the transfer.

Parameters:

  • value (String)

Returns:

  • (String)


7162
# File 'lib/increase/models/transaction.rb', line 7162

required :description, String

#end_to_end_identificationString?

A free-form reference string set by the sender, to help identify the transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7168
# File 'lib/increase/models/transaction.rb', line 7168

required :end_to_end_identification, String, nil?: true

#input_message_accountability_dataString?

A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7176
# File 'lib/increase/models/transaction.rb', line 7176

required :input_message_accountability_data, String, nil?: true

#instructing_agent_routing_numberString?

The American Banking Association (ABA) routing number of the bank that sent the wire.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7183
# File 'lib/increase/models/transaction.rb', line 7183

required :instructing_agent_routing_number, String, nil?: true

#instruction_identificationString?

The sending bank's identifier for the wire transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7189
# File 'lib/increase/models/transaction.rb', line 7189

required :instruction_identification, String, nil?: true

#purposeString?

The reason for the wire transfer, as set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7195
# File 'lib/increase/models/transaction.rb', line 7195

required :purpose, String, nil?: true

#transfer_idString

The ID of the Inbound Wire Transfer object that resulted in this Transaction.

Parameters:

  • value (String)

Returns:

  • (String)


7201
# File 'lib/increase/models/transaction.rb', line 7201

required :transfer_id, String

#unique_end_to_end_transaction_referenceString?

The Unique End-to-end Transaction Reference (UETR) of the transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7209
# File 'lib/increase/models/transaction.rb', line 7209

required :unique_end_to_end_transaction_reference, String, nil?: true

#unstructured_remittance_informationString?

A free-form message set by the sender.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


7215
# File 'lib/increase/models/transaction.rb', line 7215

required :unstructured_remittance_information, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


5428
# File 'sig/increase/models/transaction.rbs', line 5428

def to_hash: -> {