Class: Increase::Models::Transaction::Source::InboundWireTransfer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/increase/models/transaction.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Increase::Internal::Type::BaseModel

Instance Attribute Details

#amountInteger

The amount in USD cents.

Returns:

  • (Integer)


7105
# File 'lib/increase/models/transaction.rb', line 7105

required :amount, Integer

#creditor_address_line1String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


7111
# File 'lib/increase/models/transaction.rb', line 7111

required :creditor_address_line1, String, nil?: true

#creditor_address_line2String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


7117
# File 'lib/increase/models/transaction.rb', line 7117

required :creditor_address_line2, String, nil?: true

#creditor_address_line3String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


7123
# File 'lib/increase/models/transaction.rb', line 7123

required :creditor_address_line3, String, nil?: true

#creditor_nameString?

A name set by the sender.

Returns:

  • (String, nil)


7129
# File 'lib/increase/models/transaction.rb', line 7129

required :creditor_name, String, nil?: true

#debtor_address_line1String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


7135
# File 'lib/increase/models/transaction.rb', line 7135

required :debtor_address_line1, String, nil?: true

#debtor_address_line2String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


7141
# File 'lib/increase/models/transaction.rb', line 7141

required :debtor_address_line2, String, nil?: true

#debtor_address_line3String?

A free-form address field set by the sender.

Returns:

  • (String, nil)


7147
# File 'lib/increase/models/transaction.rb', line 7147

required :debtor_address_line3, String, nil?: true

#debtor_nameString?

A name set by the sender.

Returns:

  • (String, nil)


7153
# File 'lib/increase/models/transaction.rb', line 7153

required :debtor_name, String, nil?: true

#descriptionString

An Increase-constructed description of the transfer.

Returns:

  • (String)


7159
# File 'lib/increase/models/transaction.rb', line 7159

required :description, String

#end_to_end_identificationString?

A free-form reference string set by the sender, to help identify the transfer.

Returns:

  • (String, nil)


7165
# File 'lib/increase/models/transaction.rb', line 7165

required :end_to_end_identification, String, nil?: true

#input_message_accountability_dataString?

A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.

Returns:

  • (String, nil)


7173
# File 'lib/increase/models/transaction.rb', line 7173

required :input_message_accountability_data, String, nil?: true

#instructing_agent_routing_numberString?

The American Banking Association (ABA) routing number of the bank that sent the wire.

Returns:

  • (String, nil)


7180
# File 'lib/increase/models/transaction.rb', line 7180

required :instructing_agent_routing_number, String, nil?: true

#instruction_identificationString?

The sending bank’s identifier for the wire transfer.

Returns:

  • (String, nil)


7186
# File 'lib/increase/models/transaction.rb', line 7186

required :instruction_identification, String, nil?: true

#purposeString?

The reason for the wire transfer, as set by the sender.

Returns:

  • (String, nil)


7192
# File 'lib/increase/models/transaction.rb', line 7192

required :purpose, String, nil?: true

#transfer_idString

The ID of the Inbound Wire Transfer object that resulted in this Transaction.

Returns:

  • (String)


7198
# File 'lib/increase/models/transaction.rb', line 7198

required :transfer_id, String

#unique_end_to_end_transaction_referenceString?

The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.

Returns:

  • (String, nil)


7206
# File 'lib/increase/models/transaction.rb', line 7206

required :unique_end_to_end_transaction_reference, String, nil?: true

#unstructured_remittance_informationString?

A free-form message set by the sender.

Returns:

  • (String, nil)


7212
# File 'lib/increase/models/transaction.rb', line 7212

required :unstructured_remittance_information, String, nil?: true