Class: Increase::Models::Transaction::Source::InboundWireTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundWireTransfer
- Defined in:
- lib/increase/models/transaction.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in USD cents.
-
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#creditor_name ⇒ String?
A name set by the sender.
-
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#debtor_name ⇒ String?
A name set by the sender.
-
#description ⇒ String
An Increase-constructed description of the transfer.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
-
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD.
-
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
#instruction_identification ⇒ String?
The sending bank’s identifier for the wire transfer.
-
#purpose ⇒ String?
The reason for the wire transfer, as set by the sender.
-
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
-
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#amount ⇒ Integer
The amount in USD cents.
7102 |
# File 'lib/increase/models/transaction.rb', line 7102 required :amount, Integer |
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
7108 |
# File 'lib/increase/models/transaction.rb', line 7108 required :creditor_address_line1, String, nil?: true |
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
7114 |
# File 'lib/increase/models/transaction.rb', line 7114 required :creditor_address_line2, String, nil?: true |
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
7120 |
# File 'lib/increase/models/transaction.rb', line 7120 required :creditor_address_line3, String, nil?: true |
#creditor_name ⇒ String?
A name set by the sender.
7126 |
# File 'lib/increase/models/transaction.rb', line 7126 required :creditor_name, String, nil?: true |
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
7132 |
# File 'lib/increase/models/transaction.rb', line 7132 required :debtor_address_line1, String, nil?: true |
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
7138 |
# File 'lib/increase/models/transaction.rb', line 7138 required :debtor_address_line2, String, nil?: true |
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
7144 |
# File 'lib/increase/models/transaction.rb', line 7144 required :debtor_address_line3, String, nil?: true |
#debtor_name ⇒ String?
A name set by the sender.
7150 |
# File 'lib/increase/models/transaction.rb', line 7150 required :debtor_name, String, nil?: true |
#description ⇒ String
An Increase-constructed description of the transfer.
7156 |
# File 'lib/increase/models/transaction.rb', line 7156 required :description, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
7162 |
# File 'lib/increase/models/transaction.rb', line 7162 required :end_to_end_identification, String, nil?: true |
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
7170 |
# File 'lib/increase/models/transaction.rb', line 7170 required :input_message_accountability_data, String, nil?: true |
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
7177 |
# File 'lib/increase/models/transaction.rb', line 7177 required :instructing_agent_routing_number, String, nil?: true |
#instruction_identification ⇒ String?
The sending bank’s identifier for the wire transfer.
7183 |
# File 'lib/increase/models/transaction.rb', line 7183 required :instruction_identification, String, nil?: true |
#purpose ⇒ String?
The reason for the wire transfer, as set by the sender.
7189 |
# File 'lib/increase/models/transaction.rb', line 7189 required :purpose, String, nil?: true |
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
7195 |
# File 'lib/increase/models/transaction.rb', line 7195 required :transfer_id, String |
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
7203 |
# File 'lib/increase/models/transaction.rb', line 7203 required :unique_end_to_end_transaction_reference, String, nil?: true |
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
7209 |
# File 'lib/increase/models/transaction.rb', line 7209 required :unstructured_remittance_information, String, nil?: true |