Class: Increase::Models::Transaction::Source::InboundWireTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundWireTransfer
- Defined in:
- lib/increase/models/transaction.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in USD cents.
-
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#creditor_name ⇒ String?
A name set by the sender.
-
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#debtor_name ⇒ String?
A name set by the sender.
-
#description ⇒ String
An Increase-constructed description of the transfer.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
-
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD.
-
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
#instruction_identification ⇒ String?
The sending bank’s identifier for the wire transfer.
-
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
-
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Increase::Internal::Type::BaseModel
Instance Attribute Details
#amount ⇒ Integer
The amount in USD cents.
7098 |
# File 'lib/increase/models/transaction.rb', line 7098 required :amount, Integer |
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
7104 |
# File 'lib/increase/models/transaction.rb', line 7104 required :creditor_address_line1, String, nil?: true |
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
7110 |
# File 'lib/increase/models/transaction.rb', line 7110 required :creditor_address_line2, String, nil?: true |
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
7116 |
# File 'lib/increase/models/transaction.rb', line 7116 required :creditor_address_line3, String, nil?: true |
#creditor_name ⇒ String?
A name set by the sender.
7122 |
# File 'lib/increase/models/transaction.rb', line 7122 required :creditor_name, String, nil?: true |
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
7128 |
# File 'lib/increase/models/transaction.rb', line 7128 required :debtor_address_line1, String, nil?: true |
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
7134 |
# File 'lib/increase/models/transaction.rb', line 7134 required :debtor_address_line2, String, nil?: true |
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
7140 |
# File 'lib/increase/models/transaction.rb', line 7140 required :debtor_address_line3, String, nil?: true |
#debtor_name ⇒ String?
A name set by the sender.
7146 |
# File 'lib/increase/models/transaction.rb', line 7146 required :debtor_name, String, nil?: true |
#description ⇒ String
An Increase-constructed description of the transfer.
7152 |
# File 'lib/increase/models/transaction.rb', line 7152 required :description, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
7158 |
# File 'lib/increase/models/transaction.rb', line 7158 required :end_to_end_identification, String, nil?: true |
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
7166 |
# File 'lib/increase/models/transaction.rb', line 7166 required :input_message_accountability_data, String, nil?: true |
#instructing_agent_routing_number ⇒ String?
The American Banking Association (ABA) routing number of the bank that sent the wire.
7173 |
# File 'lib/increase/models/transaction.rb', line 7173 required :instructing_agent_routing_number, String, nil?: true |
#instruction_identification ⇒ String?
The sending bank’s identifier for the wire transfer.
7179 |
# File 'lib/increase/models/transaction.rb', line 7179 required :instruction_identification, String, nil?: true |
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
7185 |
# File 'lib/increase/models/transaction.rb', line 7185 required :transfer_id, String |
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference ([UETR](www.swift.com/payments/what-unique-end-end-transaction-reference-uetr)) of the transfer.
7193 |
# File 'lib/increase/models/transaction.rb', line 7193 required :unique_end_to_end_transaction_reference, String, nil?: true |
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
7199 |
# File 'lib/increase/models/transaction.rb', line 7199 required :unstructured_remittance_information, String, nil?: true |