Class: Increase::Models::Transaction::Source::InboundWireTransfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::Transaction::Source::InboundWireTransfer
- Defined in:
- lib/increase/models/transaction.rb,
sig/increase/models/transaction.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount in USD cents.
-
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#creditor_name ⇒ String?
A name set by the sender.
-
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
-
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
-
#debtor_name ⇒ String?
A name set by the sender.
-
#description ⇒ String
An Increase-constructed description of the transfer.
-
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
-
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD.
-
#instructing_agent_routing_number ⇒ String?
The American Bankers' Association (ABA) routing number of the bank that sent the wire.
-
#instruction_identification ⇒ String?
The sending bank's identifier for the wire transfer.
-
#purpose ⇒ String?
The reason for the wire transfer, as set by the sender.
-
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
5543 |
# File 'sig/increase/models/transaction.rbs', line 5543 def initialize: ( |
Instance Attribute Details
#amount ⇒ Integer
The amount in USD cents.
7747 |
# File 'lib/increase/models/transaction.rb', line 7747 required :amount, Integer |
#creditor_address_line1 ⇒ String?
A free-form address field set by the sender.
7753 |
# File 'lib/increase/models/transaction.rb', line 7753 required :creditor_address_line1, String, nil?: true |
#creditor_address_line2 ⇒ String?
A free-form address field set by the sender.
7759 |
# File 'lib/increase/models/transaction.rb', line 7759 required :creditor_address_line2, String, nil?: true |
#creditor_address_line3 ⇒ String?
A free-form address field set by the sender.
7765 |
# File 'lib/increase/models/transaction.rb', line 7765 required :creditor_address_line3, String, nil?: true |
#creditor_name ⇒ String?
A name set by the sender.
7771 |
# File 'lib/increase/models/transaction.rb', line 7771 required :creditor_name, String, nil?: true |
#debtor_address_line1 ⇒ String?
A free-form address field set by the sender.
7777 |
# File 'lib/increase/models/transaction.rb', line 7777 required :debtor_address_line1, String, nil?: true |
#debtor_address_line2 ⇒ String?
A free-form address field set by the sender.
7783 |
# File 'lib/increase/models/transaction.rb', line 7783 required :debtor_address_line2, String, nil?: true |
#debtor_address_line3 ⇒ String?
A free-form address field set by the sender.
7789 |
# File 'lib/increase/models/transaction.rb', line 7789 required :debtor_address_line3, String, nil?: true |
#debtor_name ⇒ String?
A name set by the sender.
7795 |
# File 'lib/increase/models/transaction.rb', line 7795 required :debtor_name, String, nil?: true |
#description ⇒ String
An Increase-constructed description of the transfer.
7801 |
# File 'lib/increase/models/transaction.rb', line 7801 required :description, String |
#end_to_end_identification ⇒ String?
A free-form reference string set by the sender, to help identify the transfer.
7807 |
# File 'lib/increase/models/transaction.rb', line 7807 required :end_to_end_identification, String, nil?: true |
#input_message_accountability_data ⇒ String?
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
7815 |
# File 'lib/increase/models/transaction.rb', line 7815 required :input_message_accountability_data, String, nil?: true |
#instructing_agent_routing_number ⇒ String?
The American Bankers' Association (ABA) routing number of the bank that sent the wire.
7822 |
# File 'lib/increase/models/transaction.rb', line 7822 required :instructing_agent_routing_number, String, nil?: true |
#instruction_identification ⇒ String?
The sending bank's identifier for the wire transfer.
7828 |
# File 'lib/increase/models/transaction.rb', line 7828 required :instruction_identification, String, nil?: true |
#purpose ⇒ String?
The reason for the wire transfer, as set by the sender.
7834 |
# File 'lib/increase/models/transaction.rb', line 7834 required :purpose, String, nil?: true |
#transfer_id ⇒ String
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
7840 |
# File 'lib/increase/models/transaction.rb', line 7840 required :transfer_id, String |
#unique_end_to_end_transaction_reference ⇒ String?
The Unique End-to-end Transaction Reference (UETR) of the transfer.
7848 |
# File 'lib/increase/models/transaction.rb', line 7848 required :unique_end_to_end_transaction_reference, String, nil?: true |
#unstructured_remittance_information ⇒ String?
A free-form message set by the sender.
7854 |
# File 'lib/increase/models/transaction.rb', line 7854 required :unstructured_remittance_information, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
5564 |
# File 'sig/increase/models/transaction.rbs', line 5564 def to_hash: -> { |