Class: Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress
- Defined in:
- lib/increase/models/wire_drawdown_request_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for the country of the address.
-
#line1 ⇒ String
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#postal_code ⇒ String?
The ZIP code of the address.
-
#state ⇒ String?
The address state.
Instance Method Summary collapse
-
#initialize(account_number_id:, amount:, creditor_address:, creditor_name:, debtor_address:, debtor_name:, unstructured_remittance_information:, charge_bearer: nil, debtor_account_number: nil, debtor_external_account_id: nil, debtor_routing_number: nil, end_to_end_identification: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Increase::Models::WireDrawdownRequestCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number_id:, amount:, creditor_address:, creditor_name:, debtor_address:, debtor_name:, unstructured_remittance_information:, charge_bearer: nil, debtor_account_number: nil, debtor_external_account_id: nil, debtor_routing_number: nil, end_to_end_identification: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Increase::Models::WireDrawdownRequestCreateParams for more details.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 115 class CreditorAddress < Increase::Internal::Type::BaseModel # @!attribute city # The city, district, town, or village of the address. # # @return [String] required :city, String # @!attribute country # The two-letter # [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for # the country of the address. # # @return [String] required :country, String # @!attribute line1 # The first line of the address. This is usually the street number and street. # # @return [String] required :line1, String # @!attribute line2 # The second line of the address. This might be the floor or room number. # # @return [String, nil] optional :line2, String # @!attribute postal_code # The ZIP code of the address. # # @return [String, nil] optional :postal_code, String # @!attribute state # The address state. # # @return [String, nil] optional :state, String # @!method initialize(city:, country:, line1:, line2: nil, postal_code: nil, state: nil) # Some parameter documentations has been truncated, see # {Increase::Models::WireDrawdownRequestCreateParams::CreditorAddress} for more # details. # # The creditor's address. # # @param city [String] The city, district, town, or village of the address. # # @param country [String] The two-letter [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alp # # @param line1 [String] The first line of the address. This is usually the street number and street. # # @param line2 [String] The second line of the address. This might be the floor or room number. # # @param postal_code [String] The ZIP code of the address. # # @param state [String] The address state. end |
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
120 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 120 required :city, String |
#country ⇒ String
The two-letter [ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for the country of the address.
128 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 128 required :country, String |
#line1 ⇒ String
The first line of the address. This is usually the street number and street.
134 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 134 required :line1, String |
#line2 ⇒ String?
The second line of the address. This might be the floor or room number.
140 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 140 optional :line2, String |
#postal_code ⇒ String?
The ZIP code of the address.
146 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 146 optional :postal_code, String |
#state ⇒ String?
The address state.
152 |
# File 'lib/increase/models/wire_drawdown_request_create_params.rb', line 152 optional :state, String |