Module: Increase::Models::WireDrawdownRequestListParams::Status::In
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/increase/models/wire_drawdown_request_list_params.rb,
sig/increase/models/wire_drawdown_request_list_params.rbs
Constant Summary collapse
- PENDING_SUBMISSION =
The drawdown request is queued to be submitted to Fedwire.
:pending_submission- FULFILLED =
The drawdown request has been fulfilled by the recipient.
:fulfilled- PENDING_RESPONSE =
The drawdown request has been sent and the recipient should respond in some way.
:pending_response- REFUSED =
The drawdown request has been refused by the recipient.
:refused
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(in_: nil) ⇒ Object
- #self?.values ⇒ ::Array[Increase::Models::WireDrawdownRequestListParams::Status::in_]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/increase/models/wire_drawdown_request_list_params.rb', line 88
|
Instance Method Details
#initialize(in_: nil) ⇒ Object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/increase/models/wire_drawdown_request_list_params.rb', line 73 module In extend Increase::Internal::Type::Enum # The drawdown request is queued to be submitted to Fedwire. PENDING_SUBMISSION = :pending_submission # The drawdown request has been fulfilled by the recipient. FULFILLED = :fulfilled # The drawdown request has been sent and the recipient should respond in some way. PENDING_RESPONSE = :pending_response # The drawdown request has been refused by the recipient. REFUSED = :refused # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[Increase::Models::WireDrawdownRequestListParams::Status::in_]
88 |
# File 'sig/increase/models/wire_drawdown_request_list_params.rbs', line 88
def self?.values: -> ::Array[Increase::Models::WireDrawdownRequestListParams::Status::in_]
|