Class: Increase::Models::WireTransfer::Reversal
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireTransfer::Reversal
- Defined in:
- lib/increase/models/wire_transfer.rb,
sig/increase/models/wire_transfer.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The amount that was reversed in USD cents.
-
#created_at ⇒ Time
The ISO 8601 date and time at which the reversal was created.
-
#debtor_routing_number ⇒ String?
The debtor's routing number.
-
#description ⇒ String
The description on the reversal message from Fedwire, set by the reversing bank.
-
#input_cycle_date ⇒ Date
The Fedwire cycle date for the wire reversal.
-
#input_message_accountability_data ⇒ String
The Fedwire transaction identifier.
-
#input_sequence_number ⇒ String
The Fedwire sequence number.
-
#input_source ⇒ String
The Fedwire input source identifier.
-
#instruction_identification ⇒ String?
The sending bank's identifier for the reversal.
-
#return_reason_additional_information ⇒ String?
Additional information about the reason for the reversal.
-
#return_reason_code ⇒ String?
A code provided by the sending bank giving a reason for the reversal.
-
#return_reason_code_description ⇒ String?
An Increase-generated description of the
return_reason_code. -
#transaction_id ⇒ String
The ID for the Transaction associated with the transfer reversal.
-
#wire_transfer_id ⇒ String
The ID for the Wire Transfer that is being reversed.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
502 |
# File 'sig/increase/models/wire_transfer.rbs', line 502
def initialize: (
|
Instance Attribute Details
#amount ⇒ Integer
The amount that was reversed in USD cents.
649 |
# File 'lib/increase/models/wire_transfer.rb', line 649 required :amount, Integer |
#created_at ⇒ Time
The ISO 8601 date and time at which the reversal was created.
656 |
# File 'lib/increase/models/wire_transfer.rb', line 656 required :created_at, Time |
#debtor_routing_number ⇒ String?
The debtor's routing number.
662 |
# File 'lib/increase/models/wire_transfer.rb', line 662 required :debtor_routing_number, String, nil?: true |
#description ⇒ String
The description on the reversal message from Fedwire, set by the reversing bank.
668 |
# File 'lib/increase/models/wire_transfer.rb', line 668 required :description, String |
#input_cycle_date ⇒ Date
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00
PM Eastern Time on the evening before the cycle date.
675 |
# File 'lib/increase/models/wire_transfer.rb', line 675 required :input_cycle_date, Date |
#input_message_accountability_data ⇒ String
The Fedwire transaction identifier.
681 |
# File 'lib/increase/models/wire_transfer.rb', line 681 required :input_message_accountability_data, String |
#input_sequence_number ⇒ String
The Fedwire sequence number.
687 |
# File 'lib/increase/models/wire_transfer.rb', line 687 required :input_sequence_number, String |
#input_source ⇒ String
The Fedwire input source identifier.
693 |
# File 'lib/increase/models/wire_transfer.rb', line 693 required :input_source, String |
#instruction_identification ⇒ String?
The sending bank's identifier for the reversal.
699 |
# File 'lib/increase/models/wire_transfer.rb', line 699 required :instruction_identification, String, nil?: true |
#return_reason_additional_information ⇒ String?
Additional information about the reason for the reversal.
705 |
# File 'lib/increase/models/wire_transfer.rb', line 705 required :return_reason_additional_information, String, nil?: true |
#return_reason_code ⇒ String?
A code provided by the sending bank giving a reason for the reversal. The common return reason codes are documented here.
713 |
# File 'lib/increase/models/wire_transfer.rb', line 713 required :return_reason_code, String, nil?: true |
#return_reason_code_description ⇒ String?
An Increase-generated description of the return_reason_code.
719 |
# File 'lib/increase/models/wire_transfer.rb', line 719 required :return_reason_code_description, String, nil?: true |
#transaction_id ⇒ String
The ID for the Transaction associated with the transfer reversal.
725 |
# File 'lib/increase/models/wire_transfer.rb', line 725 required :transaction_id, String |
#wire_transfer_id ⇒ String
The ID for the Wire Transfer that is being reversed.
731 |
# File 'lib/increase/models/wire_transfer.rb', line 731 required :wire_transfer_id, String |
Instance Method Details
#to_hash ⇒ {
519 |
# File 'sig/increase/models/wire_transfer.rbs', line 519
def to_hash: -> {
|