Class: Increase::Models::WireTransferCreateParams::Creditor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireTransferCreateParams::Creditor
- Defined in:
- lib/increase/models/wire_transfer_create_params.rb,
sig/increase/models/wire_transfer_create_params.rbs
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Increase::Models::WireTransferCreateParams::Creditor::Address?
The person or business's address.
-
#name ⇒ String
The person or business's name.
Instance Method Summary collapse
-
#initialize(name:, address: nil) ⇒ Object
constructor
The person or business that is receiving the funds from the transfer.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, address: nil) ⇒ Object
The person or business that is receiving the funds from the transfer.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 119 class Creditor < Increase::Internal::Type::BaseModel # @!attribute name # The person or business's name. # # @return [String] required :name, String # @!attribute address # The person or business's address. # # @return [Increase::Models::WireTransferCreateParams::Creditor::Address, nil] optional :address, -> { Increase::WireTransferCreateParams::Creditor::Address } # @!method initialize(name:, address: nil) # The person or business that is receiving the funds from the transfer. # # @param name [String] The person or business's name. # # @param address [Increase::Models::WireTransferCreateParams::Creditor::Address] # The person or business's address. # @see Increase::Models::WireTransferCreateParams::Creditor#address class Address < Increase::Internal::Type::BaseModel # @!attribute structured # Structured address components. City and country are required. # # @return [Increase::Models::WireTransferCreateParams::Creditor::Address::Structured, nil] optional :structured, -> { Increase::WireTransferCreateParams::Creditor::Address::Structured } # @!method initialize(structured: nil) # The person or business's address. # # @param structured [Increase::Models::WireTransferCreateParams::Creditor::Address::Structured] # Structured address components. City and country are required. # @see Increase::Models::WireTransferCreateParams::Creditor::Address#structured class Structured < Increase::Internal::Type::BaseModel # @!attribute city # The city, district, town, or village of the address. # # @return [String] required :city, String # @!attribute country # The two-letter # [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for # the country of the address. # # @return [String] required :country, String # @!attribute line1 # The first line of the address. # # @return [String, nil] optional :line1, String # @!attribute line2 # The second line of the address. # # @return [String, nil] optional :line2, String # @!attribute postal_code # The postal code of the address. # # @return [String, nil] optional :postal_code, String # @!attribute state # The address state. # # @return [String, nil] optional :state, String # @!method initialize(city:, country:, line1: nil, line2: nil, postal_code: nil, state: nil) # Structured address components. City and country are required. # # @param city [String] The city, district, town, or village of the address. # # @param country [String] # The two-letter # [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code for # the country of the address. # # @param line1 [String] The first line of the address. # # @param line2 [String] The second line of the address. # # @param postal_code [String] The postal code of the address. # # @param state [String] The address state. end end end |
Instance Attribute Details
#address ⇒ Increase::Models::WireTransferCreateParams::Creditor::Address?
The person or business's address.
130 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 130 optional :address, -> { Increase::WireTransferCreateParams::Creditor::Address } |
#name ⇒ String
The person or business's name.
124 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 124 required :name, String |
Instance Method Details
#to_hash ⇒ {
111 |
# File 'sig/increase/models/wire_transfer_create_params.rbs', line 111
def to_hash: -> {
|