Class: Increase::Models::WireTransferCreateParams::Debtor::Address::Structured
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Increase::Models::WireTransferCreateParams::Debtor::Address::Structured
- Defined in:
- lib/increase/models/wire_transfer_create_params.rb,
sig/increase/models/wire_transfer_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String
The city, district, town, or village of the address.
-
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
#line1 ⇒ String?
The first line of the address.
-
#line2 ⇒ String?
The second line of the address.
-
#postal_code ⇒ String?
The postal code of the address.
-
#state ⇒ String?
The address state.
Instance Method Summary collapse
-
#initialize(city:, country:, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Structured address components.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
Structured address components. City and country are required.
|
|
# File 'lib/increase/models/wire_transfer_create_params.rb', line 396
|
Instance Attribute Details
#city ⇒ String
The city, district, town, or village of the address.
362 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 362 required :city, String |
#country ⇒ String
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
370 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 370 required :country, String |
#line1 ⇒ String?
The first line of the address.
376 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 376 optional :line1, String |
#line2 ⇒ String?
The second line of the address.
382 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 382 optional :line2, String |
#postal_code ⇒ String?
The postal code of the address.
388 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 388 optional :postal_code, String |
#state ⇒ String?
The address state.
394 |
# File 'lib/increase/models/wire_transfer_create_params.rb', line 394 optional :state, String |
Instance Method Details
#to_hash ⇒ {
355 |
# File 'sig/increase/models/wire_transfer_create_params.rbs', line 355
def to_hash: -> {
|