Class: Increase::Resources::Accounts
- Inherits:
-
Object
- Object
- Increase::Resources::Accounts
- Defined in:
- lib/increase/resources/accounts.rb
Instance Method Summary collapse
-
#balance(account_id, at_time: nil, request_options: {}) ⇒ Increase::Models::BalanceLookup
Retrieve the current and available balances for an account in minor units of the account’s currency.
-
#close(account_id, request_options: {}) ⇒ Increase::Models::Account
Close an Account.
-
#create(name:, entity_id: nil, funding: nil, informational_entity_id: nil, loan: nil, program_id: nil, request_options: {}) ⇒ Increase::Models::Account
Some parameter documentations has been truncated, see Models::AccountCreateParams for more details.
-
#initialize(client:) ⇒ Accounts
constructor
private
A new instance of Accounts.
-
#list(created_at: nil, cursor: nil, entity_id: nil, idempotency_key: nil, informational_entity_id: nil, limit: nil, program_id: nil, status: nil, request_options: {}) ⇒ Increase::Internal::Page<Increase::Models::Account>
Some parameter documentations has been truncated, see Models::AccountListParams for more details.
-
#retrieve(account_id, request_options: {}) ⇒ Increase::Models::Account
Retrieve an Account.
-
#update(account_id, loan: nil, name: nil, request_options: {}) ⇒ Increase::Models::Account
Update an Account.
Constructor Details
#initialize(client:) ⇒ Accounts
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Accounts.
177 178 179 |
# File 'lib/increase/resources/accounts.rb', line 177 def initialize(client:) @client = client end |
Instance Method Details
#balance(account_id, at_time: nil, request_options: {}) ⇒ Increase::Models::BalanceLookup
Retrieve the current and available balances for an account in minor units of the account’s currency. Learn more about [account balances](/documentation/balance).
142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/increase/resources/accounts.rb', line 142 def balance(account_id, params = {}) parsed, = Increase::AccountBalanceParams.dump_request(params) query = Increase::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["accounts/%1$s/balance", account_id], query: query, model: Increase::BalanceLookup, options: ) end |
#close(account_id, request_options: {}) ⇒ Increase::Models::Account
Close an Account
165 166 167 168 169 170 171 172 |
# File 'lib/increase/resources/accounts.rb', line 165 def close(account_id, params = {}) @client.request( method: :post, path: ["accounts/%1$s/close", account_id], model: Increase::Account, options: params[:request_options] ) end |
#create(name:, entity_id: nil, funding: nil, informational_entity_id: nil, loan: nil, program_id: nil, request_options: {}) ⇒ Increase::Models::Account
Some parameter documentations has been truncated, see Models::AccountCreateParams for more details.
Create an Account
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/increase/resources/accounts.rb', line 30 def create(params) parsed, = Increase::AccountCreateParams.dump_request(params) @client.request( method: :post, path: "accounts", body: parsed, model: Increase::Account, options: ) end |
#list(created_at: nil, cursor: nil, entity_id: nil, idempotency_key: nil, informational_entity_id: nil, limit: nil, program_id: nil, status: nil, request_options: {}) ⇒ Increase::Internal::Page<Increase::Models::Account>
Some parameter documentations has been truncated, see Models::AccountListParams for more details.
List Accounts
115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/increase/resources/accounts.rb', line 115 def list(params = {}) parsed, = Increase::AccountListParams.dump_request(params) query = Increase::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "accounts", query: query, page: Increase::Internal::Page, model: Increase::Account, options: ) end |
#retrieve(account_id, request_options: {}) ⇒ Increase::Models::Account
Retrieve an Account
52 53 54 55 56 57 58 59 |
# File 'lib/increase/resources/accounts.rb', line 52 def retrieve(account_id, params = {}) @client.request( method: :get, path: ["accounts/%1$s", account_id], model: Increase::Account, options: params[:request_options] ) end |
#update(account_id, loan: nil, name: nil, request_options: {}) ⇒ Increase::Models::Account
Update an Account
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/increase/resources/accounts.rb', line 76 def update(account_id, params = {}) parsed, = Increase::AccountUpdateParams.dump_request(params) @client.request( method: :patch, path: ["accounts/%1$s", account_id], body: parsed, model: Increase::Account, options: ) end |