Class: Increase::Resources::Simulations::InboundCheckDeposits

Inherits:
Object
  • Object
show all
Defined in:
lib/increase/resources/simulations/inbound_check_deposits.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ InboundCheckDeposits

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of InboundCheckDeposits.

Parameters:



78
79
80
# File 'lib/increase/resources/simulations/inbound_check_deposits.rb', line 78

def initialize(client:)
  @client = client
end

Instance Method Details

#adjustment(inbound_check_deposit_id, amount: nil, reason: nil, request_options: {}) ⇒ Increase::Models::InboundCheckDeposit

Some parameter documentations has been truncated, see Models::Simulations::InboundCheckDepositAdjustmentParams for more details.

Simulates an adjustment on an Inbound Check Deposit. The Inbound Check Deposit must have a ‘status` of `accepted`.

Parameters:

Returns:

See Also:



64
65
66
67
68
69
70
71
72
73
# File 'lib/increase/resources/simulations/inbound_check_deposits.rb', line 64

def adjustment(inbound_check_deposit_id, params = {})
  parsed, options = Increase::Simulations::InboundCheckDepositAdjustmentParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["simulations/inbound_check_deposits/%1$s/adjustment", inbound_check_deposit_id],
    body: parsed,
    model: Increase::InboundCheckDeposit,
    options: options
  )
end

#create(account_number_id:, amount:, check_number:, payee_name_analysis: nil, request_options: {}) ⇒ Increase::Models::InboundCheckDeposit

Some parameter documentations has been truncated, see Models::Simulations::InboundCheckDepositCreateParams for more details.

Simulates an Inbound Check Deposit against your account. This imitates someone depositing a check at their bank that was issued from your account. It may or may not be associated with a Check Transfer. Increase will evaluate the Inbound Check Deposit as we would in production and either create a Transaction or a Declined Transaction as a result. You can inspect the resulting Inbound Check Deposit object to see the result.

Parameters:

Returns:

See Also:



33
34
35
36
37
38
39
40
41
42
# File 'lib/increase/resources/simulations/inbound_check_deposits.rb', line 33

def create(params)
  parsed, options = Increase::Simulations::InboundCheckDepositCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: "simulations/inbound_check_deposits",
    body: parsed,
    model: Increase::InboundCheckDeposit,
    options: options
  )
end